from typing_extensions import Unpack
from instaui.components.element import Element
from instaui.arco import component_types
from ._utils import handle_props


class Space(Element):
    def __init__(
        self,
        **kwargs: Unpack[component_types.TSpace],
    ):
        super().__init__("a-space")

        self.props(handle_props(kwargs))  # type: ignore
