:root {
  --shiki-font-family-mono: ui-monospace, "Menlo", "Monaco", "Consolas", "Liberation Mono", "Courier New", monospace;
  --shiki-code-line-height: 1.5;
  --shiki-code-font-size: 0.875em;
  --shiki-code-block-color: #67676c;
  --shiki-icon-copy: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='none' stroke='rgba(128,128,128,1)' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' viewBox='0 0 24 24'%3E%3Crect width='8' height='4' x='8' y='2' rx='1' ry='1'/%3E%3Cpath d='M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2'/%3E%3C/svg%3E");
  --shiki-icon-copied: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='none' stroke='rgba(128,128,128,1)' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' viewBox='0 0 24 24'%3E%3Crect width='8' height='4' x='8' y='2' rx='1' ry='1'/%3E%3Cpath d='M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2'/%3E%3Cpath d='m9 14 2 2 4-4'/%3E%3C/svg%3E");
  --shiki-code-copy-code-border-color: #e2e2e3;
  --shiki-code-copy-code-bg: #f6f6f7;
  --shiki-code-copy-code-hover-border-color: #e2e2e3;
  --shiki-code-copy-code-hover-bg: #ffffff;
  --shiki-code-copy-code-active-text: #67676c;
  --shiki-code-copy-copied-text-content: "Copied";
  --shiki-code-lang-color: #929295;
}
@media (min-width: 640px) {
  .shiki-code[class*=language-] {
    border-radius: 8px;
    margin: 15px 0;
  }
}
.shiki-code[class*=language-] {
  position: relative;
  margin: 16px 0;
  background-color: #f9f9f9;
  overflow-x: auto;
  transition: background-color 0.5s;
  /* line numbers */
}
.shiki-code[class*=language-] pre,
.shiki-code[class*=language-] code {
  font-family: var(--shiki-font-family-mono);
}
.shiki-code[class*=language-] pre {
  position: relative;
  z-index: 1;
  margin: 0;
  padding: 20px 0;
  background: transparent;
  overflow-x: auto;
}
.shiki-code[class*=language-] code {
  display: block;
  padding: 0 24px 0 0;
  width: fit-content;
  min-width: 100%;
  line-height: var(--shiki-code-line-height);
  font-size: var(--shiki-code-font-size);
  color: var(--shiki-code-block-color);
  transition: color 0.5s;
}
.shiki-code[class*=language-] code > .line:before {
  content: ' ';
  padding: 0 5px;
}
.shiki-code[class*=language-] > button.copy {
  direction: ltr;
  position: absolute;
  top: 12px;
  right: 12px;
  z-index: 3;
  border: 1px solid var(--shiki-code-copy-code-border-color);
  border-radius: 4px;
  width: 40px;
  height: 40px;
  background-color: var(--shiki-code-copy-code-bg);
  opacity: 0;
  cursor: pointer;
  background-image: var(--shiki-icon-copy);
  background-position: 50%;
  background-size: 20px;
  background-repeat: no-repeat;
  transition: border-color 0.25s, background-color 0.25s, opacity 0.25s;
}
.shiki-code[class*=language-]:hover > button.copy,
.shiki-code[class*=language-] > button.copy:focus {
  opacity: 1;
}
.shiki-code[class*=language-] > button.copy:hover,
.shiki-code[class*=language-] > button.copy.copied {
  border-color: var(--shiki-code-copy-code-hover-border-color);
  background-color: var(--shiki-code-copy-code-hover-bg);
}
.shiki-code[class*=language-] > button.copy.copied,
.shiki-code[class*=language-] > button.copy:hover.copied {
  border-radius: 0 4px 4px 0;
  background-color: var(--shiki-code-copy-code-hover-bg);
  background-image: var(--shiki-icon-copied);
}
.shiki-code[class*=language-] > button.copy.copied:before,
.shiki-code[class*=language-] > button.copy:hover.copied:before {
  position: relative;
  top: -1px;
  display: flex;
  justify-content: center;
  align-items: center;
  border: 1px solid var(--shiki-code-copy-code-hover-border-color);
  border-right: 0;
  border-radius: 4px 0 0 4px;
  padding: 0 10px;
  width: fit-content;
  height: 40px;
  text-align: center;
  font-size: 12px;
  font-weight: 500;
  color: var(--shiki-code-copy-code-active-text);
  background-color: var(--shiki-code-copy-code-hover-bg);
  white-space: nowrap;
  content: var(--shiki-code-copy-copied-text-content);
  transform: translate(calc(-100% - 1px));
}
.shiki-code[class*=language-] > span.lang {
  position: absolute;
  top: 2px;
  right: 8px;
  z-index: 2;
  font-size: 12px;
  font-weight: 500;
  -webkit-user-select: none;
  user-select: none;
  color: var(--shiki-code-lang-color);
  transition: color 0.4s, opacity 0.4s;
}
.shiki-code[class*=language-]:hover > button.copy + span.lang,
.shiki-code[class*=language-] > button.copy:focus + span.lang {
  opacity: 0;
}
.shiki-code[class*=language-].theme-dark {
  --shiki-code-line-diff-add-color: #3dd68c;
  --shiki-code-line-diff-add-symbol-color: #3dd68c;
  --shiki-code-line-diff-remove-color: hsla(349.72, 89.16%, 60.2%, 0.16);
  --shiki-code-line-diff-remove-symbol-color: hsl(357.62, 39.92%, 50.39%);
  --shiki-code-line-line-number-color: hsla(198.18, 13.36%, 80%, 0.7);
}
.shiki-code[class*=language-] pre.shiki .diff {
  all: unset;
}
.shiki-code[class*=language-] pre.shiki code .diff.remove {
  background-color: var(--shiki-code-line-diff-remove-color, rgba(244, 63, 94, 0.14));
  opacity: 0.7;
}
.shiki-code[class*=language-] pre.shiki code .diff.add {
  background-color: rgba(16, 185, 129, 0.14);
}
.shiki-code[class*=language-] pre.shiki code .diff.add:before {
  content: "+";
  color: var(--shiki-code-line-diff-add-symbol-color, #18794e);
}
.shiki-code[class*=language-] pre.shiki code .diff.remove:before {
  content: "-";
  color: var(--shiki-code-line-diff-remove-symbol-color, hsl(357.62, 39.92%, 50.39%));
}
.shiki-code[class*=language-] pre.shiki code .diff:before {
  width: 2.5em;
  text-align: left;
  padding-left: 10px;
}
.shiki-code[class*=language-] pre.shiki code .diff {
  box-sizing: border-box;
  transition: background-color 0.5s;
  margin: 0 -24px;
  padding: 0 24px;
  width: calc(100% + 48px);
  display: inline-block;
}
.shiki-code[class*=language-].line-numbers code {
  counter-reset: step;
  counter-increment: step 0;
}
.shiki-code[class*=language-].line-numbers code .line::before {
  content: counter(step);
  counter-increment: step;
  display: inline-block;
  text-align: right;
  color: var(--shiki-code-line-line-number-color, hsla(198.18, 13.36%, 51.57%, 0.7));
  width: 2.5em;
  text-align: left;
  padding-left: 10px;
}
