locale = {
    "locale": "en-US",
    "empty": {"description": "No Data"},
    "drawer": {"okText": "Ok", "cancelText": "Cancel"},
    "popconfirm": {"okText": "Ok", "cancelText": "Cancel"},
    "modal": {"okText": "Ok", "cancelText": "Cancel"},
    "pagination": {
        "goto": "Goto",
        "page": "Page",
        "countPerPage": " / Page",
        "total": "Total: {0}",
    },
    "table": {"okText": "Ok", "resetText": "Reset"},
    "upload": {
        "start": "Start",
        "cancel": "Cancel",
        "delete": "Delete",
        "retry": "Click to retry",
        "buttonText": "Upload",
        "preview": "Preview",
        "drag": "Click or drag file to this area to upload",
        "dragHover": "Release to upload",
        "error": "Upload Error",
    },
    "calendar": {
        "formatYear": "YYYY",
        "formatMonth": "MMM YYYY",
        "today": "Today",
        "view": {"month": "Month", "year": "Year", "week": "Week", "day": "Day"},
        "month": {
            "long": {
                "January": "January",
                "February": "February",
                "March": "March",
                "April": "April",
                "May": "May",
                "June": "June",
                "July": "July",
                "August": "August",
                "September": "September",
                "October": "October",
                "November": "November",
                "December": "December",
            },
            "short": {
                "January": "Jan",
                "February": "Feb",
                "March": "Mar",
                "April": "Apr",
                "May": "May",
                "June": "Jun",
                "July": "Jul",
                "August": "Aug",
                "September": "Sept",
                "October": "Oct",
                "November": "Nov",
                "December": "Dec",
            },
        },
        "week": {
            "long": {
                "self": "Week",
                "monday": "Monday",
                "tuesday": "Tuesday",
                "wednesday": "Wednesday",
                "thursday": "Thursday",
                "friday": "Friday",
                "saturday": "Saturday",
                "sunday": "Sunday",
            },
            "short": {
                "self": "Week",
                "monday": "Mon",
                "tuesday": "Tue",
                "wednesday": "Wed",
                "thursday": "Thu",
                "friday": "Fri",
                "saturday": "Sat",
                "sunday": "Sun",
            },
        },
    },
    "datePicker": {
        "view": {"month": "Month", "year": "Year", "week": "Week", "day": "Day"},
        "month": {
            "long": {
                "January": "January",
                "February": "February",
                "March": "March",
                "April": "April",
                "May": "May",
                "June": "June",
                "July": "July",
                "August": "August",
                "September": "September",
                "October": "October",
                "November": "November",
                "December": "December",
            },
            "short": {
                "January": "Jan",
                "February": "Feb",
                "March": "Mar",
                "April": "Apr",
                "May": "May",
                "June": "Jun",
                "July": "Jul",
                "August": "Aug",
                "September": "Sept",
                "October": "Oct",
                "November": "Nov",
                "December": "Dec",
            },
        },
        "week": {
            "long": {
                "self": "Week",
                "monday": "Monday",
                "tuesday": "Tuesday",
                "wednesday": "Wednesday",
                "thursday": "Thursday",
                "friday": "Friday",
                "saturday": "Saturday",
                "sunday": "Sunday",
            },
            "short": {
                "self": "Week",
                "monday": "Mon",
                "tuesday": "Tue",
                "wednesday": "Wed",
                "thursday": "Thu",
                "friday": "Fri",
                "saturday": "Sat",
                "sunday": "Sun",
            },
        },
        "placeholder": {
            "date": "Please select date",
            "week": "Please select week",
            "month": "Please select month",
            "year": "Please select year",
            "quarter": "Please select quarter",
            "time": "Please select time",
        },
        "rangePlaceholder": {
            "date": ["Start date", "End date"],
            "week": ["Start week", "End week"],
            "month": ["Start month", "End month"],
            "year": ["Start year", "End year"],
            "quarter": ["Start quarter", "End quarter"],
            "time": ["Start time", "End time"],
        },
        "selectTime": "Select time",
        "today": "Today",
        "now": "Now",
        "ok": "Ok",
    },
    "image": {"loading": "loading"},
    "imagePreview": {
        "fullScreen": "Full Screen",
        "rotateRight": "Rotate Right",
        "rotateLeft": "Rotate Left",
        "zoomIn": "Zoom In",
        "zoomOut": "Zoom Out",
        "originalSize": "Original Size",
    },
    "typography": {
        "copied": "Copied",
        "copy": "Copy",
        "expand": "Expand",
        "collapse": "Collapse",
        "edit": "Edit",
    },
    "form": {
        "validateMessages": {
            "required": "#{field} is required",
            "type": {
                "ip": "#{field} is not a #{type} type",
                "email": "#{field} is not a #{type} type",
                "url": "#{field} is not a #{type} type",
                "string": "#{field} is not a #{type} type",
                "number": "#{field} is not a #{type} type",
                "array": "#{field} is not a #{type} type",
                "object": "#{field} is not a #{type} type",
                "boolean": "#{field} is not a #{type} type",
            },
            "number": {
                "min": "`#{value}` is not greater than `#{min}`",
                "max": "`#{value}` is not less than `#{max}`",
                "equal": "`#{value}` is not equal to `#{equal}`",
                "range": "`#{value}` is not in range `#{min} ~ #{max}`",
                "positive": "`#{value}` is not a positive number",
                "negative": "`#{value}` is not a negative number",
            },
            "string": {
                "maxLength": "#{field} cannot be longer than #{maxLength} characters",
                "minLength": "#{field} must be at least #{minLength} characters",
                "length": "#{field} must be exactly #{length} characters",
                "match": "`#{value}` does not match pattern #{pattern}",
                "uppercase": "`#{value}` must be all uppercase",
                "lowercase": "`#{value}` must be all lowercased",
            },
            "array": {
                "length": "#{field} must be exactly #{length} in length",
                "minLength": "#{field} cannot be less than #{minLength} in length",
                "maxLength": "#{field} cannot be greater than #{maxLength} in length",
                "includes": "#{field} is not includes #{includes}",
                "deepEqual": "#{field} is not deep equal with #{deepEqual}",
                "empty": "#{field} is not an empty array",
            },
            "object": {
                "deepEqual": "#{field} is not deep equal to expected value",
                "hasKeys": "#{field} does not contain required fields",
                "empty": "#{field} is not an empty object",
            },
            "boolean": {
                "true": "Expect true but got `#{value}`",
                "false": "Expect false but got `#{value}`",
            },
        }
    },
    "colorPicker": {
        "history": "History Colors",
        "preset": "Preset Colors",
        "empty": "Empty",
    },
}
