from typing import Any, Dict, Literal


TLocale = Literal[
    "zh-CN",
    "en-US",
    "ja-JP",
    "zh-TW",
    "pt-PT",
    "es-ES",
    "id-ID",
    "fr-FR",
    "de-DE",
    "ko-KR",
    "it-IT",
    "ms-MY",
    "th-TH",
    "vi-VN",
    "km-KH",
    "ar-EG",
    "ru-RU",
]

TCustomizeLocale = Dict[str, Any]
