import { ref as V, reactive as me, inject as Ge, computed as a, getCurrentInstance as dn, cloneVNode as Kl, isVNode as Ct, Fragment as Ae, defineComponent as S, watch as ze, onMounted as Je, onUnmounted as Zt, resolveComponent as J, createBlock as oe, openBlock as v, withCtx as ue, createElementVNode as $, createElementBlock as b, createCommentVNode as te, normalizeStyle as F, normalizeClass as m, createVNode as c, renderSlot as _, toRefs as ve, watchEffect as Wt, Transition as on, createTextVNode as Re, toDisplayString as Pe, onBeforeUnmount as _t, provide as it, nextTick as at, toRef as un, mergeProps as se, createSlots as kt, withModifiers as an, onUpdated as fn, readonly as _2, onDeactivated as J2, Teleport as br, withDirectives as hn, vShow as kn, resolveDynamicComponent as sn, renderList as St, createStaticVNode as Cr, TransitionGroup as jo, normalizeProps as dt, guardReactiveProps as Gt, withKeys as El, render as il, h as mn, isRef as Hp, Comment as ek, createApp as qp, unref as tk, getCurrentScope as nk, onScopeDispose as lk, shallowRef as ok } from "vue";
const Ll = Object.prototype.toString;
function He(e) {
  return Ll.call(e) === "[object Array]";
}
function Jt(e) {
  return Ll.call(e) === "[object Null]";
}
function Xt(e) {
  return Ll.call(e) === "[object Boolean]";
}
function Qe(e) {
  return Ll.call(e) === "[object Object]";
}
const $l = (e) => Ll.call(e) === "[object Promise]";
function zt(e) {
  return Ll.call(e) === "[object String]";
}
function A(e) {
  return Ll.call(e) === "[object Number]" && e === e;
}
function Ve(e) {
  return e === void 0;
}
function Ne(e) {
  return typeof e == "function";
}
function ik(e) {
  return Qe(e) && Object.keys(e).length === 0;
}
function T0(e) {
  return e || e === 0;
}
function ti(e) {
  return e === window;
}
const Zp = (e) => (e == null ? void 0 : e.$) !== void 0, rk = (e) => /\[Q]Q/.test(e);
function gn(e) {
  return Qe(e) && "$y" in e && "$M" in e && "$D" in e && "$d" in e && "$H" in e && "$m" in e && "$s" in e;
}
const Kt = Symbol("ArcoConfigProvider"), Zo = {
  formatYear: "YYYY 年",
  formatMonth: "YYYY 年 MM 月",
  today: "今天",
  view: {
    month: "月",
    year: "年",
    week: "周",
    day: "日"
  },
  month: {
    long: {
      January: "一月",
      February: "二月",
      March: "三月",
      April: "四月",
      May: "五月",
      June: "六月",
      July: "七月",
      August: "八月",
      September: "九月",
      October: "十月",
      November: "十一月",
      December: "十二月"
    },
    short: {
      January: "一月",
      February: "二月",
      March: "三月",
      April: "四月",
      May: "五月",
      June: "六月",
      July: "七月",
      August: "八月",
      September: "九月",
      October: "十月",
      November: "十一月",
      December: "十二月"
    }
  },
  week: {
    long: {
      self: "周",
      monday: "周一",
      tuesday: "周二",
      wednesday: "周三",
      thursday: "周四",
      friday: "周五",
      saturday: "周六",
      sunday: "周日"
    },
    short: {
      self: "周",
      monday: "一",
      tuesday: "二",
      wednesday: "三",
      thursday: "四",
      friday: "五",
      saturday: "六",
      sunday: "日"
    }
  }
}, ak = {
  locale: "zh-CN",
  empty: {
    description: "暂无数据"
  },
  drawer: {
    okText: "确定",
    cancelText: "取消"
  },
  popconfirm: {
    okText: "确定",
    cancelText: "取消"
  },
  modal: {
    okText: "确定",
    cancelText: "取消"
  },
  pagination: {
    goto: "前往",
    page: "页",
    countPerPage: "条/页",
    total: "共 {0} 条"
  },
  table: {
    okText: "确定",
    resetText: "重置"
  },
  upload: {
    start: "开始",
    cancel: "取消",
    delete: "删除",
    retry: "点击重试",
    buttonText: "点击上传",
    preview: "预览",
    drag: "点击或拖拽文件到此处上传",
    dragHover: "释放文件并开始上传",
    error: "上传失败"
  },
  calendar: Zo,
  datePicker: {
    view: Zo.view,
    month: Zo.month,
    week: Zo.week,
    placeholder: {
      date: "请选择日期",
      week: "请选择周",
      month: "请选择月份",
      year: "请选择年份",
      quarter: "请选择季度",
      time: "请选择时间"
    },
    rangePlaceholder: {
      date: ["开始日期", "结束日期"],
      week: ["开始周", "结束周"],
      month: ["开始月份", "结束月份"],
      year: ["开始年份", "结束年份"],
      quarter: ["开始季度", "结束季度"],
      time: ["开始时间", "结束时间"]
    },
    selectTime: "选择时间",
    today: "今天",
    now: "此刻",
    ok: "确定"
  },
  image: {
    loading: "加载中"
  },
  imagePreview: {
    fullScreen: "全屏",
    rotateRight: "向右旋转",
    rotateLeft: "向左旋转",
    zoomIn: "放大",
    zoomOut: "缩小",
    originalSize: "原始尺寸"
  },
  typography: {
    copied: "已复制",
    copy: "复制",
    expand: "展开",
    collapse: "折叠",
    edit: "编辑"
  },
  form: {
    validateMessages: {
      required: "#{field} 是必填项",
      type: {
        string: "#{field} 不是合法的文本类型",
        number: "#{field} 不是合法的数字类型",
        boolean: "#{field} 不是合法的布尔类型",
        array: "#{field} 不是合法的数组类型",
        object: "#{field} 不是合法的对象类型",
        url: "#{field} 不是合法的 url 地址",
        email: "#{field} 不是合法的邮箱地址",
        ip: "#{field} 不是合法的 IP 地址"
      },
      number: {
        min: "`#{value}` 小于最小值 `#{min}`",
        max: "`#{value}` 大于最大值 `#{max}`",
        equal: "`#{value}` 不等于 `#{equal}`",
        range: "`#{value}` 不在 `#{min} ~ #{max}` 范围内",
        positive: "`#{value}` 不是正数",
        negative: "`#{value}` 不是负数"
      },
      array: {
        length: "`#{field}` 个数不等于 #{length}",
        minLength: "`#{field}` 个数最少为 #{minLength}",
        maxLength: "`#{field}` 个数最多为 #{maxLength}",
        includes: "#{field} 不包含 #{includes}",
        deepEqual: "#{field} 不等于 #{deepEqual}",
        empty: "`#{field}` 不是空数组"
      },
      string: {
        minLength: "字符数最少为 #{minLength}",
        maxLength: "字符数最多为 #{maxLength}",
        length: "字符数必须是 #{length}",
        match: "`#{value}` 不符合模式 #{pattern}",
        uppercase: "`#{value}` 必须全大写",
        lowercase: "`#{value}` 必须全小写"
      },
      object: {
        deepEqual: "`#{field}` 不等于期望值",
        hasKeys: "`#{field}` 不包含必须字段",
        empty: "`#{field}` 不是对象"
      },
      boolean: {
        true: "期望是 `true`",
        false: "期望是 `false`"
      }
    }
  },
  colorPicker: {
    history: "最近使用颜色",
    preset: "系统预设颜色",
    empty: "暂无"
  }
}, zv = V("zh-CN"), ir = me({
  "zh-CN": ak
}), sk = (e, t) => {
  for (const n of Object.keys(e))
    (!ir[n] || t != null && t.overwrite) && (ir[n] = e[n]);
}, uk = (e) => {
  if (!ir[e]) {
    console.warn(`use ${e} failed! Please add ${e} first`);
    return;
  }
  zv.value = e;
}, ck = () => zv.value, gt = () => {
  const e = Ge(Kt, void 0), t = a(
    () => {
      var i;
      return (i = e == null ? void 0 : e.locale) != null ? i : ir[zv.value];
    }
  ), n = a(() => t.value.locale);
  return {
    i18nMessage: t,
    locale: n,
    t: (i, ...r) => {
      const l = i.split(".");
      let s = t.value;
      for (const u of l) {
        if (!s[u])
          return i;
        s = s[u];
      }
      return zt(s) && r.length > 0 ? s.replace(/{(\d+)}/g, (u, f) => {
        var d;
        return (d = r[f]) != null ? d : u;
      }) : s;
    }
  };
}, dk = "A", fk = "arco", X1 = "$arco", Fe = (e) => {
  var t;
  return (t = e == null ? void 0 : e.componentPrefix) != null ? t : dk;
}, De = (e, t) => {
  var n;
  t && t.classPrefix && (e.config.globalProperties[X1] = {
    ...(n = e.config.globalProperties[X1]) != null ? n : {},
    classPrefix: t.classPrefix
  });
}, B = (e) => {
  var t, n, o;
  const i = dn(), r = Ge(Kt, void 0), l = (o = (n = r == null ? void 0 : r.prefixCls) != null ? n : (t = i == null ? void 0 : i.appContext.config.globalProperties[X1]) == null ? void 0 : t.classPrefix) != null ? o : fk;
  return e ? `${l}-${e}` : l;
};
var Kp = function() {
  if (typeof Map < "u")
    return Map;
  function e(t, n) {
    var o = -1;
    return t.some(function(i, r) {
      return i[0] === n ? (o = r, !0) : !1;
    }), o;
  }
  return (
    /** @class */
    function() {
      function t() {
        this.__entries__ = [];
      }
      return Object.defineProperty(t.prototype, "size", {
        /**
         * @returns {boolean}
         */
        get: function() {
          return this.__entries__.length;
        },
        enumerable: !0,
        configurable: !0
      }), t.prototype.get = function(n) {
        var o = e(this.__entries__, n), i = this.__entries__[o];
        return i && i[1];
      }, t.prototype.set = function(n, o) {
        var i = e(this.__entries__, n);
        ~i ? this.__entries__[i][1] = o : this.__entries__.push([n, o]);
      }, t.prototype.delete = function(n) {
        var o = this.__entries__, i = e(o, n);
        ~i && o.splice(i, 1);
      }, t.prototype.has = function(n) {
        return !!~e(this.__entries__, n);
      }, t.prototype.clear = function() {
        this.__entries__.splice(0);
      }, t.prototype.forEach = function(n, o) {
        o === void 0 && (o = null);
        for (var i = 0, r = this.__entries__; i < r.length; i++) {
          var l = r[i];
          n.call(o, l[1], l[0]);
        }
      }, t;
    }()
  );
}(), Q1 = typeof window < "u" && typeof document < "u" && window.document === document, rr = function() {
  return typeof global < "u" && global.Math === Math ? global : typeof self < "u" && self.Math === Math ? self : typeof window < "u" && window.Math === Math ? window : Function("return this")();
}(), vk = function() {
  return typeof requestAnimationFrame == "function" ? requestAnimationFrame.bind(rr) : function(e) {
    return setTimeout(function() {
      return e(Date.now());
    }, 1e3 / 60);
  };
}(), pk = 2;
function mk(e, t) {
  var n = !1, o = !1, i = 0;
  function r() {
    n && (n = !1, e()), o && s();
  }
  function l() {
    vk(r);
  }
  function s() {
    var u = Date.now();
    if (n) {
      if (u - i < pk)
        return;
      o = !0;
    } else
      n = !0, o = !1, setTimeout(l, t);
    i = u;
  }
  return s;
}
var hk = 20, kk = ["top", "right", "bottom", "left", "width", "height", "size", "weight"], gk = typeof MutationObserver < "u", yk = (
  /** @class */
  function() {
    function e() {
      this.connected_ = !1, this.mutationEventsAdded_ = !1, this.mutationsObserver_ = null, this.observers_ = [], this.onTransitionEnd_ = this.onTransitionEnd_.bind(this), this.refresh = mk(this.refresh.bind(this), hk);
    }
    return e.prototype.addObserver = function(t) {
      ~this.observers_.indexOf(t) || this.observers_.push(t), this.connected_ || this.connect_();
    }, e.prototype.removeObserver = function(t) {
      var n = this.observers_, o = n.indexOf(t);
      ~o && n.splice(o, 1), !n.length && this.connected_ && this.disconnect_();
    }, e.prototype.refresh = function() {
      var t = this.updateObservers_();
      t && this.refresh();
    }, e.prototype.updateObservers_ = function() {
      var t = this.observers_.filter(function(n) {
        return n.gatherActive(), n.hasActive();
      });
      return t.forEach(function(n) {
        return n.broadcastActive();
      }), t.length > 0;
    }, e.prototype.connect_ = function() {
      !Q1 || this.connected_ || (document.addEventListener("transitionend", this.onTransitionEnd_), window.addEventListener("resize", this.refresh), gk ? (this.mutationsObserver_ = new MutationObserver(this.refresh), this.mutationsObserver_.observe(document, {
        attributes: !0,
        childList: !0,
        characterData: !0,
        subtree: !0
      })) : (document.addEventListener("DOMSubtreeModified", this.refresh), this.mutationEventsAdded_ = !0), this.connected_ = !0);
    }, e.prototype.disconnect_ = function() {
      !Q1 || !this.connected_ || (document.removeEventListener("transitionend", this.onTransitionEnd_), window.removeEventListener("resize", this.refresh), this.mutationsObserver_ && this.mutationsObserver_.disconnect(), this.mutationEventsAdded_ && document.removeEventListener("DOMSubtreeModified", this.refresh), this.mutationsObserver_ = null, this.mutationEventsAdded_ = !1, this.connected_ = !1);
    }, e.prototype.onTransitionEnd_ = function(t) {
      var n = t.propertyName, o = n === void 0 ? "" : n, i = kk.some(function(r) {
        return !!~o.indexOf(r);
      });
      i && this.refresh();
    }, e.getInstance = function() {
      return this.instance_ || (this.instance_ = new e()), this.instance_;
    }, e.instance_ = null, e;
  }()
), Yp = function(e, t) {
  for (var n = 0, o = Object.keys(t); n < o.length; n++) {
    var i = o[n];
    Object.defineProperty(e, i, {
      value: t[i],
      enumerable: !1,
      writable: !1,
      configurable: !0
    });
  }
  return e;
}, Yl = function(e) {
  var t = e && e.ownerDocument && e.ownerDocument.defaultView;
  return t || rr;
}, Up = $r(0, 0, 0, 0);
function ar(e) {
  return parseFloat(e) || 0;
}
function A0(e) {
  for (var t = [], n = 1; n < arguments.length; n++)
    t[n - 1] = arguments[n];
  return t.reduce(function(o, i) {
    var r = e["border-" + i + "-width"];
    return o + ar(r);
  }, 0);
}
function bk(e) {
  for (var t = ["top", "right", "bottom", "left"], n = {}, o = 0, i = t; o < i.length; o++) {
    var r = i[o], l = e["padding-" + r];
    n[r] = ar(l);
  }
  return n;
}
function Ck(e) {
  var t = e.getBBox();
  return $r(0, 0, t.width, t.height);
}
function $k(e) {
  var t = e.clientWidth, n = e.clientHeight;
  if (!t && !n)
    return Up;
  var o = Yl(e).getComputedStyle(e), i = bk(o), r = i.left + i.right, l = i.top + i.bottom, s = ar(o.width), u = ar(o.height);
  if (o.boxSizing === "border-box" && (Math.round(s + r) !== t && (s -= A0(o, "left", "right") + r), Math.round(u + l) !== n && (u -= A0(o, "top", "bottom") + l)), !Sk(e)) {
    var f = Math.round(s + r) - t, d = Math.round(u + l) - n;
    Math.abs(f) !== 1 && (s -= f), Math.abs(d) !== 1 && (u -= d);
  }
  return $r(i.left, i.top, s, u);
}
var wk = /* @__PURE__ */ function() {
  return typeof SVGGraphicsElement < "u" ? function(e) {
    return e instanceof Yl(e).SVGGraphicsElement;
  } : function(e) {
    return e instanceof Yl(e).SVGElement && typeof e.getBBox == "function";
  };
}();
function Sk(e) {
  return e === Yl(e).document.documentElement;
}
function zk(e) {
  return Q1 ? wk(e) ? Ck(e) : $k(e) : Up;
}
function Lk(e) {
  var t = e.x, n = e.y, o = e.width, i = e.height, r = typeof DOMRectReadOnly < "u" ? DOMRectReadOnly : Object, l = Object.create(r.prototype);
  return Yp(l, {
    x: t,
    y: n,
    width: o,
    height: i,
    top: n,
    right: t + o,
    bottom: i + n,
    left: t
  }), l;
}
function $r(e, t, n, o) {
  return { x: e, y: t, width: n, height: o };
}
var jk = (
  /** @class */
  function() {
    function e(t) {
      this.broadcastWidth = 0, this.broadcastHeight = 0, this.contentRect_ = $r(0, 0, 0, 0), this.target = t;
    }
    return e.prototype.isActive = function() {
      var t = zk(this.target);
      return this.contentRect_ = t, t.width !== this.broadcastWidth || t.height !== this.broadcastHeight;
    }, e.prototype.broadcastRect = function() {
      var t = this.contentRect_;
      return this.broadcastWidth = t.width, this.broadcastHeight = t.height, t;
    }, e;
  }()
), Pk = (
  /** @class */
  /* @__PURE__ */ function() {
    function e(t, n) {
      var o = Lk(n);
      Yp(this, { target: t, contentRect: o });
    }
    return e;
  }()
), Ik = (
  /** @class */
  function() {
    function e(t, n, o) {
      if (this.activeObservations_ = [], this.observations_ = new Kp(), typeof t != "function")
        throw new TypeError("The callback provided as parameter 1 is not a function.");
      this.callback_ = t, this.controller_ = n, this.callbackCtx_ = o;
    }
    return e.prototype.observe = function(t) {
      if (!arguments.length)
        throw new TypeError("1 argument required, but only 0 present.");
      if (!(typeof Element > "u" || !(Element instanceof Object))) {
        if (!(t instanceof Yl(t).Element))
          throw new TypeError('parameter 1 is not of type "Element".');
        var n = this.observations_;
        n.has(t) || (n.set(t, new jk(t)), this.controller_.addObserver(this), this.controller_.refresh());
      }
    }, e.prototype.unobserve = function(t) {
      if (!arguments.length)
        throw new TypeError("1 argument required, but only 0 present.");
      if (!(typeof Element > "u" || !(Element instanceof Object))) {
        if (!(t instanceof Yl(t).Element))
          throw new TypeError('parameter 1 is not of type "Element".');
        var n = this.observations_;
        n.has(t) && (n.delete(t), n.size || this.controller_.removeObserver(this));
      }
    }, e.prototype.disconnect = function() {
      this.clearActive(), this.observations_.clear(), this.controller_.removeObserver(this);
    }, e.prototype.gatherActive = function() {
      var t = this;
      this.clearActive(), this.observations_.forEach(function(n) {
        n.isActive() && t.activeObservations_.push(n);
      });
    }, e.prototype.broadcastActive = function() {
      if (this.hasActive()) {
        var t = this.callbackCtx_, n = this.activeObservations_.map(function(o) {
          return new Pk(o.target, o.broadcastRect());
        });
        this.callback_.call(t, n, t), this.clearActive();
      }
    }, e.prototype.clearActive = function() {
      this.activeObservations_.splice(0);
    }, e.prototype.hasActive = function() {
      return this.activeObservations_.length > 0;
    }, e;
  }()
), Gp = typeof WeakMap < "u" ? /* @__PURE__ */ new WeakMap() : new Kp(), Xp = (
  /** @class */
  /* @__PURE__ */ function() {
    function e(t) {
      if (!(this instanceof e))
        throw new TypeError("Cannot call a class as a function.");
      if (!arguments.length)
        throw new TypeError("1 argument required, but only 0 present.");
      var n = yk.getInstance(), o = new Ik(t, n, this);
      Gp.set(this, o);
    }
    return e;
  }()
);
[
  "observe",
  "unobserve",
  "disconnect"
].forEach(function(e) {
  Xp.prototype[e] = function() {
    var t;
    return (t = Gp.get(this))[e].apply(t, arguments);
  };
});
var wr = function() {
  return typeof rr.ResizeObserver < "u" ? rr.ResizeObserver : Xp;
}();
const Sr = (e) => !!(e && e.shapeFlag & 1), Po = (e, t) => !!(e && e.shapeFlag & 6), Bk = (e, t) => !!(e && e.shapeFlag & 8), zr = (e, t) => !!(e && e.shapeFlag & 16), Lr = (e, t) => !!(e && e.shapeFlag & 32), Fl = (e) => {
  var t, n;
  if (e)
    for (const o of e) {
      if (Sr(o) || Po(o))
        return o;
      if (zr(o, o.children)) {
        const i = Fl(o.children);
        if (i)
          return i;
      } else if (Lr(o, o.children)) {
        const i = (n = (t = o.children).default) == null ? void 0 : n.call(t);
        if (i) {
          const r = Fl(i);
          if (r)
            return r;
        }
      } else if (He(o)) {
        const i = Fl(o);
        if (i)
          return i;
      }
    }
}, Mk = (e) => {
  if (!e)
    return !0;
  for (const t of e)
    if (t.children)
      return !1;
  return !0;
}, Qp = (e, t) => {
  if (e && e.length > 0)
    for (let n = 0; n < e.length; n++) {
      const o = e[n];
      if (Sr(o) || Po(o)) {
        const r = Ne(t) ? t(o) : t;
        return e[n] = Kl(o, r, !0), !0;
      }
      const i = Lv(o);
      if (i && i.length > 0 && Qp(i, t))
        return !0;
    }
  return !1;
}, Lv = (e) => {
  if (zr(e, e.children))
    return e.children;
  if (He(e))
    return e;
}, _p = (e) => {
  var t, n;
  if (Sr(e))
    return e.el;
  if (Po(e)) {
    if (((t = e.el) == null ? void 0 : t.nodeType) === 1)
      return e.el;
    if ((n = e.component) != null && n.subTree) {
      const o = _p(e.component.subTree);
      if (o)
        return o;
    }
  } else {
    const o = Lv(e);
    return Jp(o);
  }
}, Jp = (e) => {
  if (e && e.length > 0)
    for (const t of e) {
      const n = _p(t);
      if (n)
        return n;
    }
}, En = (e, t = !1) => {
  var n, o;
  const i = [];
  for (const r of e ?? [])
    Sr(r) || Po(r) || t && Bk(r, r.children) ? i.push(r) : zr(r, r.children) ? i.push(...En(r.children, t)) : Lr(r, r.children) ? i.push(...En((o = (n = r.children).default) == null ? void 0 : o.call(n), t)) : He(r) && i.push(...En(r, t));
  return i;
};
function Nk(e) {
  function t(n) {
    const o = [];
    return n.forEach((i) => {
      var r, l;
      Ct(i) && i.type === Ae ? Lr(i, i.children) ? o.push(...t(((l = (r = i.children).default) == null ? void 0 : l.call(r)) || [])) : zr(i, i.children) ? o.push(...t(i.children)) : zt(i.children) && o.push(i.children) : o.push(i);
    }), o;
  }
  return t(e);
}
const nn = (e) => {
  if (e)
    return Ne(e) ? e : () => e;
}, em = (e, t) => {
  var n;
  const o = [];
  if (Po(e, e.type))
    e.type.name === t ? e.component && o.push(e.component.uid) : (n = e.component) != null && n.subTree && o.push(...em(e.component.subTree, t));
  else {
    const i = Lv(e);
    i && o.push(...tm(i, t));
  }
  return o;
}, tm = (e, t) => {
  const n = [];
  if (e && e.length > 0)
    for (const o of e)
      n.push(...em(o, t));
  return n;
};
var jn = S({
  name: "ResizeObserver",
  emits: [
    "resize"
  ],
  setup(e, {
    emit: t,
    slots: n
  }) {
    let o;
    const i = V(), r = a(() => Zp(i.value) ? i.value.$el : i.value), l = (u) => {
      u && (o = new wr((f) => {
        const d = f[0];
        t("resize", d);
      }), o.observe(u));
    }, s = () => {
      o && (o.disconnect(), o = null);
    };
    return ze(r, (u) => {
      o && s(), u && l(u);
    }), Je(() => {
      r.value && l(r.value);
    }), Zt(() => {
      s();
    }), () => {
      var u, f;
      const d = Fl((f = (u = n.default) == null ? void 0 : u.call(n)) != null ? f : []);
      return d ? Kl(d, {
        ref: i
      }, !0) : null;
    };
  }
});
const nm = typeof window > "u" ? global : window, lm = nm.requestAnimationFrame, sr = nm.cancelAnimationFrame;
function wl(e) {
  let t = 0;
  const n = (...o) => {
    t && sr(t), t = lm(() => {
      e(...o), t = 0;
    });
  };
  return n.cancel = () => {
    sr(t), t = 0;
  }, n;
}
const Dl = () => {
}, om = () => {
  const { body: e } = document, t = document.documentElement;
  let n;
  try {
    n = (window.top || window.self || window).document.body;
  } catch {
  }
  return {
    height: Math.max(
      e.scrollHeight,
      e.offsetHeight,
      t.clientHeight,
      t.scrollHeight,
      t.offsetHeight,
      (n == null ? void 0 : n.scrollHeight) || 0,
      (n == null ? void 0 : n.clientHeight) || 0
    ),
    width: Math.max(
      e.scrollWidth,
      e.offsetWidth,
      t.clientWidth,
      t.scrollWidth,
      t.offsetWidth,
      (n == null ? void 0 : n.scrollWidth) || 0,
      (n == null ? void 0 : n.clientWidth) || 0
    )
  };
}, Io = (() => {
  try {
    return !(typeof window < "u" && document !== void 0);
  } catch {
    return !0;
  }
})(), rt = Io ? Dl : (e, t, n, o = !1) => {
  e.addEventListener(
    t,
    n,
    o
  );
}, ct = Io ? Dl : (e, t, n, o = !1) => {
  e.removeEventListener(
    t,
    n,
    o
  );
}, Ok = (e, t) => {
  if (!e || !t)
    return !1;
  let n = t;
  for (; n; ) {
    if (n === e)
      return !0;
    n = n.parentNode;
  }
  return !1;
}, jr = (e) => {
  const t = document.createElement("div");
  return t.setAttribute("class", `arco-overlay arco-overlay-${e}`), t;
}, im = (e, t) => {
  var n;
  return Io ? Dl() : (n = (t ?? document).querySelector(e)) != null ? n : void 0;
}, Tn = (e, t) => {
  if (zt(e)) {
    const n = e[0] === "#" ? `[id='${e.slice(1)}']` : e;
    return im(n, t);
  }
  return e;
}, Vk = (e, t) => {
  const n = e.getBoundingClientRect(), o = t.getBoundingClientRect();
  return {
    top: n.top - o.top,
    bottom: o.bottom - n.bottom,
    left: n.left - o.left,
    right: o.right - n.right,
    width: n.width,
    height: n.height
  };
}, Tk = (e) => e.tagName === "BODY" ? document.documentElement.scrollHeight > window.innerHeight : e.scrollHeight > e.offsetHeight, Ak = (e) => e.tagName === "BODY" ? window.innerWidth - om().width : e.offsetWidth - e.clientWidth;
var N = (e, t) => {
  for (const [n, o] of t)
    e[n] = o;
  return e;
};
function Ek(e) {
  return ti(e) ? {
    top: 0,
    bottom: window.innerHeight
  } : e.getBoundingClientRect();
}
const Wk = S({
  name: "Affix",
  components: {
    ResizeObserver: jn
  },
  props: {
    offsetTop: {
      type: Number,
      default: 0
    },
    offsetBottom: {
      type: Number
    },
    target: {
      type: [String, Object, Function]
    },
    targetContainer: {
      type: [String, Object, Function]
    }
  },
  emits: {
    change: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("affix"), { target: o, targetContainer: i } = ve(e), r = V(), l = V(), s = V(!1), u = V({}), f = V({}), d = a(() => ({ [n]: s.value })), p = wl(() => {
      if (!r.value || !l.value)
        return;
      const { offsetTop: h, offsetBottom: k } = e, y = Ve(k) ? "top" : "bottom", w = r.value.getBoundingClientRect(), g = Ek(l.value);
      let C = !1, P = {};
      const z = {
        width: `${r.value.offsetWidth}px`,
        height: `${r.value.offsetHeight}px`
      };
      y === "top" ? (C = w.top - g.top < (h || 0), P = C ? {
        position: "fixed",
        top: `${g.top + (h || 0)}px`
      } : {}) : (C = g.bottom - w.bottom < (k || 0), P = C ? {
        position: "fixed",
        bottom: `${window.innerHeight - g.bottom + (k || 0)}px`
      } : {}), C !== s.value && (s.value = C, t("change", C)), u.value = z, f.value = {
        ...P,
        ...C ? z : {}
      };
    });
    return Je(() => {
      Wt((h) => {
        const k = o && o.value !== window && Tn(o.value) || window;
        l.value = k, k && (rt(k, "scroll", p), rt(k, "resize", p), h(() => {
          ct(k, "scroll", p), ct(k, "resize", p);
        }));
      }), Wt((h) => {
        if (!l.value)
          return;
        const k = i && i.value !== window && Tn(i.value) || window;
        k && (rt(k, "scroll", p), rt(k, "resize", p), h(() => {
          ct(k, "scroll", p), ct(k, "resize", p);
        }));
      });
    }), {
      wrapperRef: r,
      isFixed: s,
      classNames: d,
      placeholderStyles: u,
      fixedStyles: f,
      updatePositionThrottle: p
    };
  },
  methods: {
    updatePosition() {
      this.updatePositionThrottle();
    }
  }
}), Fk = { ref: "wrapperRef" };
function Dk(e, t, n, o, i, r) {
  const l = J("ResizeObserver");
  return v(), oe(l, { onResize: e.updatePositionThrottle }, {
    default: ue(() => [
      $("div", Fk, [
        e.isFixed ? (v(), b("div", {
          key: 0,
          style: F(e.placeholderStyles)
        }, null, 4)) : te("v-if", !0),
        $("div", {
          class: m(e.classNames),
          style: F(e.fixedStyles)
        }, [
          c(l, { onResize: e.updatePositionThrottle }, {
            default: ue(() => [
              _(e.$slots, "default")
            ]),
            _: 3
          }, 8, ["onResize"])
        ], 6)
      ], 512)
    ]),
    _: 3
  }, 8, ["onResize"]);
}
var ua = /* @__PURE__ */ N(Wk, [["render", Dk]]);
const xk = Object.assign(ua, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ua.name, ua);
  }
}), Rk = S({
  name: "IconHover",
  props: {
    prefix: {
      type: String
    },
    size: {
      type: String,
      default: "medium"
    },
    disabled: {
      type: Boolean,
      default: !1
    }
  },
  setup() {
    return {
      prefixCls: B("icon-hover")
    };
  }
});
function Hk(e, t, n, o, i, r) {
  return v(), b("span", {
    class: m([
      e.prefixCls,
      {
        [`${e.prefix}-icon-hover`]: e.prefix,
        [`${e.prefixCls}-size-${e.size}`]: e.size !== "medium",
        [`${e.prefixCls}-disabled`]: e.disabled
      }
    ])
  }, [
    _(e.$slots, "default")
  ], 2);
}
var pt = /* @__PURE__ */ N(Rk, [["render", Hk]]);
const qk = S({
  name: "IconClose",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-close`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Zk = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Kk(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M9.857 9.858 24 24m0 0 14.142 14.142M24 24 38.142 9.858M24 24 9.857 38.142" }, null, -1)
  ]), 14, Zk);
}
var ca = /* @__PURE__ */ N(qk, [["render", Kk]]);
const Dt = Object.assign(ca, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ca.name, ca);
  }
}), Yk = S({
  name: "IconInfoCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-info-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Uk = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Gk(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4 4 12.954 4 24s8.954 20 20 20Zm2-30a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-2Zm0 17h1a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-6a1 1 0 0 1-1-1v-2a1 1 0 0 1 1-1h1v-8a1 1 0 0 1-1-1v-2a1 1 0 0 1 1-1h3a1 1 0 0 1 1 1v11Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, Uk);
}
var da = /* @__PURE__ */ N(Yk, [["render", Gk]]);
const Xl = Object.assign(da, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + da.name, da);
  }
}), Xk = S({
  name: "IconCheckCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-check-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Qk = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function _k(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4 4 12.954 4 24s8.954 20 20 20Zm10.207-24.379a1 1 0 0 0 0-1.414l-1.414-1.414a1 1 0 0 0-1.414 0L22 26.172l-4.878-4.88a1 1 0 0 0-1.415 0l-1.414 1.415a1 1 0 0 0 0 1.414l7 7a1 1 0 0 0 1.414 0l11.5-11.5Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, Qk);
}
var fa = /* @__PURE__ */ N(Xk, [["render", _k]]);
const ul = Object.assign(fa, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + fa.name, fa);
  }
}), Jk = S({
  name: "IconExclamationCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-exclamation-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), eg = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function tg(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4 4 12.954 4 24s8.954 20 20 20Zm-2-11a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1v2Zm4-18a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V15Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, eg);
}
var va = /* @__PURE__ */ N(Jk, [["render", tg]]);
const Dn = Object.assign(va, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + va.name, va);
  }
}), ng = S({
  name: "IconCloseCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-close-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), lg = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function og(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4 4 12.954 4 24s8.954 20 20 20Zm4.955-27.771-4.95 4.95-4.95-4.95a1 1 0 0 0-1.414 0l-1.414 1.414a1 1 0 0 0 0 1.414l4.95 4.95-4.95 4.95a1 1 0 0 0 0 1.414l1.414 1.414a1 1 0 0 0 1.414 0l4.95-4.95 4.95 4.95a1 1 0 0 0 1.414 0l1.414-1.414a1 1 0 0 0 0-1.414l-4.95-4.95 4.95-4.95a1 1 0 0 0 0-1.414l-1.414-1.414a1 1 0 0 0-1.414 0Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, lg);
}
var pa = /* @__PURE__ */ N(ng, [["render", og]]);
const jl = Object.assign(pa, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + pa.name, pa);
  }
}), ig = S({
  name: "Alert",
  components: {
    IconHover: pt,
    IconClose: Dt,
    IconInfoCircleFill: Xl,
    IconCheckCircleFill: ul,
    IconExclamationCircleFill: Dn,
    IconCloseCircleFill: jl
  },
  props: {
    type: {
      type: String,
      default: "info"
    },
    showIcon: {
      type: Boolean,
      default: !0
    },
    closable: {
      type: Boolean,
      default: !1
    },
    title: String,
    banner: {
      type: Boolean,
      default: !1
    },
    center: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    close: (e) => !0,
    afterClose: () => !0
  },
  setup(e, { slots: t, emit: n }) {
    const o = B("alert"), i = V(!0), r = (u) => {
      i.value = !1, n("close", u);
    }, l = () => {
      n("afterClose");
    }, s = a(() => [
      o,
      `${o}-${e.type}`,
      {
        [`${o}-with-title`]: !!(e.title || t.title),
        [`${o}-banner`]: e.banner,
        [`${o}-center`]: e.center
      }
    ]);
    return {
      prefixCls: o,
      cls: s,
      visible: i,
      handleClose: r,
      handleAfterLeave: l
    };
  }
});
function rg(e, t, n, o, i, r) {
  const l = J("icon-info-circle-fill"), s = J("icon-check-circle-fill"), u = J("icon-exclamation-circle-fill"), f = J("icon-close-circle-fill"), d = J("icon-close"), p = J("icon-hover");
  return v(), oe(on, {
    name: "zoom-in-top",
    onAfterLeave: e.handleAfterLeave
  }, {
    default: ue(() => [
      e.visible ? (v(), b("div", {
        key: 0,
        role: "alert",
        class: m(e.cls)
      }, [
        e.showIcon && !(e.type === "normal" && !e.$slots.icon) ? (v(), b("div", {
          key: 0,
          class: m(`${e.prefixCls}-icon`)
        }, [
          _(e.$slots, "icon", {}, () => [
            e.type === "info" ? (v(), oe(l, { key: 0 })) : e.type === "success" ? (v(), oe(s, { key: 1 })) : e.type === "warning" ? (v(), oe(u, { key: 2 })) : e.type === "error" ? (v(), oe(f, { key: 3 })) : te("v-if", !0)
          ])
        ], 2)) : te("v-if", !0),
        $("div", {
          class: m(`${e.prefixCls}-body`)
        }, [
          e.title || e.$slots.title ? (v(), b("div", {
            key: 0,
            class: m(`${e.prefixCls}-title`)
          }, [
            _(e.$slots, "title", {}, () => [
              Re(Pe(e.title), 1)
            ])
          ], 2)) : te("v-if", !0),
          $("div", {
            class: m(`${e.prefixCls}-content`)
          }, [
            _(e.$slots, "default")
          ], 2)
        ], 2),
        e.$slots.action ? (v(), b("div", {
          key: 1,
          class: m(`${e.prefixCls}-action`)
        }, [
          _(e.$slots, "action")
        ], 2)) : te("v-if", !0),
        e.closable ? (v(), b("div", {
          key: 2,
          tabindex: "-1",
          role: "button",
          "aria-label": "Close",
          class: m(`${e.prefixCls}-close-btn`),
          onClick: t[0] || (t[0] = (...h) => e.handleClose && e.handleClose(...h))
        }, [
          _(e.$slots, "close-element", {}, () => [
            c(p, null, {
              default: ue(() => [
                c(d)
              ]),
              _: 1
            })
          ])
        ], 2)) : te("v-if", !0)
      ], 2)) : te("v-if", !0)
    ]),
    _: 3
  }, 8, ["onAfterLeave"]);
}
var ma = /* @__PURE__ */ N(ig, [["render", rg]]);
const rm = Object.assign(ma, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ma.name, ma);
  }
});
function E0(e) {
  return typeof e == "object" && e != null && e.nodeType === 1;
}
function W0(e, t) {
  return (!t || e !== "hidden") && e !== "visible" && e !== "clip";
}
function ha(e, t) {
  if (e.clientHeight < e.scrollHeight || e.clientWidth < e.scrollWidth) {
    var n = getComputedStyle(e, null);
    return W0(n.overflowY, t) || W0(n.overflowX, t) || function(o) {
      var i = function(r) {
        if (!r.ownerDocument || !r.ownerDocument.defaultView) return null;
        try {
          return r.ownerDocument.defaultView.frameElement;
        } catch {
          return null;
        }
      }(o);
      return !!i && (i.clientHeight < o.scrollHeight || i.clientWidth < o.scrollWidth);
    }(e);
  }
  return !1;
}
function Ko(e, t, n, o, i, r, l, s) {
  return r < e && l > t || r > e && l < t ? 0 : r <= e && s <= n || l >= t && s >= n ? r - e - o : l > t && s < n || r < e && s > n ? l - t + i : 0;
}
var _1 = function(e, t) {
  var n = window, o = t.scrollMode, i = t.block, r = t.inline, l = t.boundary, s = t.skipOverflowHiddenElements, u = typeof l == "function" ? l : function(le) {
    return le !== l;
  };
  if (!E0(e)) throw new TypeError("Invalid target");
  for (var f, d, p = document.scrollingElement || document.documentElement, h = [], k = e; E0(k) && u(k); ) {
    if ((k = (d = (f = k).parentElement) == null ? f.getRootNode().host || null : d) === p) {
      h.push(k);
      break;
    }
    k != null && k === document.body && ha(k) && !ha(document.documentElement) || k != null && ha(k, s) && h.push(k);
  }
  for (var y = n.visualViewport ? n.visualViewport.width : innerWidth, w = n.visualViewport ? n.visualViewport.height : innerHeight, g = window.scrollX || pageXOffset, C = window.scrollY || pageYOffset, P = e.getBoundingClientRect(), z = P.height, j = P.width, I = P.top, L = P.right, M = P.bottom, E = P.left, K = i === "start" || i === "nearest" ? I : i === "end" ? M : I + z / 2, q = r === "center" ? E + j / 2 : r === "end" ? L : E, T = [], X = 0; X < h.length; X++) {
    var Y = h[X], Z = Y.getBoundingClientRect(), U = Z.height, H = Z.width, D = Z.top, R = Z.right, W = Z.bottom, O = Z.left;
    if (o === "if-needed" && I >= 0 && E >= 0 && M <= w && L <= y && I >= D && M <= W && E >= O && L <= R) return T;
    var x = getComputedStyle(Y), G = parseInt(x.borderLeftWidth, 10), ne = parseInt(x.borderTopWidth, 10), ee = parseInt(x.borderRightWidth, 10), Q = parseInt(x.borderBottomWidth, 10), ae = 0, ge = 0, Se = "offsetWidth" in Y ? Y.offsetWidth - Y.clientWidth - G - ee : 0, be = "offsetHeight" in Y ? Y.offsetHeight - Y.clientHeight - ne - Q : 0, Le = "offsetWidth" in Y ? Y.offsetWidth === 0 ? 0 : H / Y.offsetWidth : 0, pe = "offsetHeight" in Y ? Y.offsetHeight === 0 ? 0 : U / Y.offsetHeight : 0;
    if (p === Y) ae = i === "start" ? K : i === "end" ? K - w : i === "nearest" ? Ko(C, C + w, w, ne, Q, C + K, C + K + z, z) : K - w / 2, ge = r === "start" ? q : r === "center" ? q - y / 2 : r === "end" ? q - y : Ko(g, g + y, y, G, ee, g + q, g + q + j, j), ae = Math.max(0, ae + C), ge = Math.max(0, ge + g);
    else {
      ae = i === "start" ? K - D - ne : i === "end" ? K - W + Q + be : i === "nearest" ? Ko(D, W, U, ne, Q + be, K, K + z, z) : K - (D + U / 2) + be / 2, ge = r === "start" ? q - O - G : r === "center" ? q - (O + H / 2) + Se / 2 : r === "end" ? q - R + ee + Se : Ko(O, R, H, G, ee + Se, q, q + j, j);
      var Me = Y.scrollLeft, ke = Y.scrollTop;
      K += ke - (ae = Math.max(0, Math.min(ke + ae / pe, Y.scrollHeight - U / pe + be))), q += Me - (ge = Math.max(0, Math.min(Me + ge / Le, Y.scrollWidth - H / Le + Se)));
    }
    T.push({ el: Y, top: ae, left: ge });
  }
  return T;
}, Bo = function(e) {
  return function(t) {
    return Math.pow(t, e);
  };
}, Mo = function(e) {
  return function(t) {
    return 1 - Math.abs(Math.pow(t - 1, e));
  };
}, Pr = function(e) {
  return function(t) {
    return t < 0.5 ? Bo(e)(t * 2) / 2 : Mo(e)(t * 2 - 1) / 2 + 0.5;
  };
}, ag = function(e) {
  return e;
}, sg = Bo(2), ug = Mo(2), cg = Pr(2), dg = Bo(3), fg = Mo(3), vg = Pr(3), pg = Bo(4), mg = Mo(4), hg = Pr(4), kg = Bo(5), gg = Mo(5), yg = Pr(5), bg = function(e) {
  return 1 + Math.sin(Math.PI / 2 * e - Math.PI / 2);
}, Cg = function(e) {
  return Math.sin(Math.PI / 2 * e);
}, $g = function(e) {
  return (1 + Math.sin(Math.PI * e - Math.PI / 2)) / 2;
}, jv = function(e) {
  var t = 7.5625, n = 2.75;
  return e < 1 / n ? t * e * e : e < 2 / n ? (e -= 1.5 / n, t * e * e + 0.75) : e < 2.5 / n ? (e -= 2.25 / n, t * e * e + 0.9375) : (e -= 2.625 / n, t * e * e + 0.984375);
}, am = function(e) {
  return 1 - jv(1 - e);
}, wg = function(e) {
  return e < 0.5 ? am(e * 2) * 0.5 : jv(e * 2 - 1) * 0.5 + 0.5;
}, Sg = /* @__PURE__ */ Object.freeze({
  linear: ag,
  quadIn: sg,
  quadOut: ug,
  quadInOut: cg,
  cubicIn: dg,
  cubicOut: fg,
  cubicInOut: vg,
  quartIn: pg,
  quartOut: mg,
  quartInOut: hg,
  quintIn: kg,
  quintOut: gg,
  quintInOut: yg,
  sineIn: bg,
  sineOut: Cg,
  sineInOut: $g,
  bounceOut: jv,
  bounceIn: am,
  bounceInOut: wg
}), Pl = function(t) {
  var n = t.from, o = t.to, i = t.duration, r = t.delay, l = t.easing, s = t.onStart, u = t.onUpdate, f = t.onFinish;
  for (var d in n)
    o[d] === void 0 && (o[d] = n[d]);
  for (var p in o)
    n[p] === void 0 && (n[p] = o[p]);
  this.from = n, this.to = o, this.duration = i || 500, this.delay = r || 0, this.easing = l || "linear", this.onStart = s, this.onUpdate = u || function() {
  }, this.onFinish = f, this.startTime = Date.now() + this.delay, this.started = !1, this.finished = !1, this.timer = null, this.keys = {};
};
Pl.prototype.update = function() {
  if (this.time = Date.now(), !(this.time < this.startTime) && !this.finished) {
    if (this.elapsed === this.duration) {
      this.finished || (this.finished = !0, this.onFinish && this.onFinish(this.keys));
      return;
    }
    this.elapsed = this.time - this.startTime, this.elapsed = this.elapsed > this.duration ? this.duration : this.elapsed;
    for (var t in this.to)
      this.keys[t] = this.from[t] + (this.to[t] - this.from[t]) * Sg[this.easing](this.elapsed / this.duration);
    this.started || (this.onStart && this.onStart(this.keys), this.started = !0), this.onUpdate(this.keys);
  }
};
Pl.prototype.start = function() {
  var t = this;
  this.startTime = Date.now() + this.delay;
  var n = function() {
    t.update(), t.timer = requestAnimationFrame(n), t.finished && (cancelAnimationFrame(t.timer), t.timer = null);
  };
  n();
};
Pl.prototype.stop = function() {
  cancelAnimationFrame(this.timer), this.timer = null;
};
function zg(e, t, n) {
  new Pl({
    from: {
      scrollTop: e.scrollTop
    },
    to: {
      scrollTop: t
    },
    easing: "quartOut",
    duration: 300,
    onUpdate: (i) => {
      e.scrollTop = i.scrollTop;
    },
    onFinish: () => {
      Ne(n) && n();
    }
  }).start();
}
const sm = Symbol("ArcoAnchor"), Lg = ["start", "end", "center", "nearest"], jg = S({
  name: "Anchor",
  props: {
    boundary: {
      type: [Number, String],
      default: "start",
      validator: (e) => A(e) || Lg.includes(e)
    },
    lineLess: {
      type: Boolean,
      default: !1
    },
    scrollContainer: {
      type: [String, Object]
    },
    changeHash: {
      type: Boolean,
      default: !0
    },
    smooth: {
      type: Boolean,
      default: !0
    }
  },
  emits: {
    select: (e, t) => !0,
    change: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("anchor"), o = V(), i = V(), r = me({}), l = V(""), s = V(!1), u = V(), f = V(), d = (I, L) => {
      I && (r[I] = L);
    }, p = (I) => {
      delete r[I];
    }, h = (I, L) => {
      e.changeHash || I.preventDefault(), L && (k(L), w(L)), t("select", L, l.value);
    }, k = (I) => {
      try {
        const L = Tn(I);
        if (!L)
          return;
        let M, E = 0;
        A(e.boundary) ? (M = "start", E = e.boundary) : M = e.boundary;
        const K = _1(L, { block: M });
        if (!K.length)
          return;
        const { el: q, top: T } = K[0], X = T - E;
        zg(q, X, () => {
          s.value = !1;
        }), s.value = !0;
      } catch (L) {
        console.error(L);
      }
    }, y = wl(() => {
      if (s.value)
        return;
      const I = g();
      if (I && I.id) {
        const L = `#${I.id}`;
        w(L);
      }
    }), w = (I) => {
      if (!r[I] && o.value) {
        const L = Tn(`a[data-href='${I}']`, o.value);
        if (!L)
          return;
        r[I] = L;
      }
      I !== l.value && (l.value = I, at(() => {
        t("change", I);
      }));
    }, g = () => {
      if (!u.value || !f.value)
        return;
      const I = A(e.boundary) ? e.boundary : 0, L = f.value.getBoundingClientRect();
      for (const M of Object.keys(r)) {
        const E = Tn(M);
        if (E) {
          const { top: K } = E.getBoundingClientRect(), q = ti(u.value) ? K - I : K - L.top - I;
          if (q >= 0 && q <= L.height / 2)
            return E;
        }
      }
    };
    ze(l, () => {
      const I = r[l.value];
      !e.lineLess && I && i.value && (i.value.style.top = `${I.offsetTop}px`);
    });
    const C = () => {
      u.value && rt(u.value, "scroll", y);
    }, P = () => {
      u.value && ct(u.value, "scroll", y);
    }, z = () => {
      e.scrollContainer ? (u.value = ti(e.scrollContainer) ? window : Tn(e.scrollContainer), f.value = ti(e.scrollContainer) ? document.documentElement : Tn(e.scrollContainer)) : (u.value = window, f.value = document.documentElement);
    };
    Je(() => {
      z();
      const I = decodeURIComponent(window.location.hash);
      I ? (k(I), w(I)) : y(), C();
    }), _t(() => {
      P();
    }), it(
      sm,
      me({
        currentLink: l,
        addLink: d,
        removeLink: p,
        handleClick: h
      })
    );
    const j = a(() => [
      n,
      {
        [`${n}-line-less`]: e.lineLess
      }
    ]);
    return {
      prefixCls: n,
      cls: j,
      anchorRef: o,
      lineSliderRef: i
    };
  }
});
function Pg(e, t, n, o, i, r) {
  return v(), b("div", {
    ref: "anchorRef",
    class: m(e.cls)
  }, [
    e.lineLess ? te("v-if", !0) : (v(), b("div", {
      key: 0,
      ref: "lineSliderRef",
      class: m(`${e.prefixCls}-line-slider`)
    }, null, 2)),
    $("ul", {
      class: m(`${e.prefixCls}-list`)
    }, [
      _(e.$slots, "default")
    ], 2)
  ], 2);
}
var ka = /* @__PURE__ */ N(jg, [["render", Pg]]);
const Ig = S({
  name: "AnchorLink",
  props: {
    title: String,
    href: String
  },
  setup(e) {
    const t = B("anchor"), n = `${t}-link`, o = V(), i = Ge(sm, void 0);
    Je(() => {
      e.href && o.value && (i == null || i.addLink(e.href, o.value));
    });
    const r = a(() => [
      `${n}-item`,
      {
        [`${n}-active`]: (i == null ? void 0 : i.currentLink) === e.href
      }
    ]);
    return {
      prefixCls: t,
      linkCls: n,
      cls: r,
      linkRef: o,
      handleClick: (s) => i == null ? void 0 : i.handleClick(s, e.href)
    };
  }
}), Bg = ["href"];
function Mg(e, t, n, o, i, r) {
  return v(), b("li", {
    ref: "linkRef",
    class: m(e.cls)
  }, [
    $("a", {
      class: m(e.linkCls),
      href: e.href,
      onClick: t[0] || (t[0] = (...l) => e.handleClick && e.handleClick(...l))
    }, [
      _(e.$slots, "default", {}, () => [
        Re(Pe(e.title), 1)
      ])
    ], 10, Bg),
    e.$slots.sublist ? (v(), b("ul", {
      key: 0,
      class: m(`${e.prefixCls}-sublist`)
    }, [
      _(e.$slots, "sublist")
    ], 2)) : te("v-if", !0)
  ], 2);
}
var ni = /* @__PURE__ */ N(Ig, [["render", Mg]]);
const Ng = Object.assign(ka, {
  Link: ni,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ka.name, ka), e.component(n + ni.name, ni);
  }
}), Ir = ["info", "success", "warning", "error"], rl = [
  "onFocus",
  "onFocusin",
  "onFocusout",
  "onBlur",
  "onChange",
  "onBeforeinput",
  "onInput",
  "onReset",
  "onSubmit",
  "onInvalid",
  "onKeydown",
  "onKeypress",
  "onKeyup",
  "onCopy",
  "onCut",
  "onPaste",
  "onCompositionstart",
  "onCompositionupdate",
  "onCompositionend",
  "onSelect",
  "autocomplete",
  "autofocus",
  "maxlength",
  "minlength",
  "name",
  "pattern",
  "readonly",
  "required"
], Og = S({
  name: "IconLoading",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-loading`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Vg = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Tg(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M42 24c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6" }, null, -1)
  ]), 14, Vg);
}
var ga = /* @__PURE__ */ N(Og, [["render", Tg]]);
const Yt = Object.assign(ga, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ga.name, ga);
  }
}), Ag = S({
  name: "FeedbackIcon",
  components: {
    IconLoading: Yt,
    IconCheckCircleFill: ul,
    IconExclamationCircleFill: Dn,
    IconCloseCircleFill: jl
  },
  props: {
    type: {
      type: String
    }
  },
  setup(e) {
    const t = B("feedback-icon");
    return {
      cls: a(() => [
        t,
        `${t}-status-${e.type}`
      ])
    };
  }
});
function Eg(e, t, n, o, i, r) {
  const l = J("icon-loading"), s = J("icon-check-circle-fill"), u = J("icon-exclamation-circle-fill"), f = J("icon-close-circle-fill");
  return v(), b("span", {
    class: m(e.cls)
  }, [
    e.type === "validating" ? (v(), oe(l, { key: 0 })) : e.type === "success" ? (v(), oe(s, { key: 1 })) : e.type === "warning" ? (v(), oe(u, { key: 2 })) : e.type === "error" ? (v(), oe(f, { key: 3 })) : te("v-if", !0)
  ], 2);
}
var No = /* @__PURE__ */ N(Ag, [["render", Eg]]);
const Pv = {
  key: "Enter"
}, um = {
  key: "Backspace",
  code: "Backspace"
}, Wg = {
  code: "ArrowLeft"
}, Fg = {
  code: "ArrowRight"
}, Ft = (e, t) => {
  const n = { ...e };
  for (const o of t)
    o in n && delete n[o];
  return n;
};
function Wn(e, t) {
  const n = {};
  return t.forEach((o) => {
    const i = o;
    o in e && (n[i] = e[i]);
  }), n;
}
const J1 = Symbol(
  "ArcoFormItemContext"
), Iv = Symbol("ArcoFormContext"), mt = ({
  size: e,
  disabled: t,
  error: n,
  uninject: o
} = {}) => {
  const i = o ? {} : Ge(J1, {}), r = a(() => {
    var d;
    return (d = e == null ? void 0 : e.value) != null ? d : i.size;
  }), l = a(
    () => (t == null ? void 0 : t.value) || i.disabled
  ), s = a(() => (n == null ? void 0 : n.value) || i.error), u = un(i, "feedback"), f = un(i, "eventHandlers");
  return {
    formItemCtx: i,
    mergedSize: r,
    mergedDisabled: l,
    mergedError: s,
    feedback: u,
    eventHandlers: f
  };
}, xt = (e, { defaultValue: t = "medium" } = {}) => {
  const n = Ge(Kt, void 0);
  return {
    mergedSize: a(
      () => {
        var i, r;
        return (r = (i = e == null ? void 0 : e.value) != null ? i : n == null ? void 0 : n.size) != null ? r : t;
      }
    )
  };
};
function cm(e) {
  const t = V();
  function n() {
    if (!e.value)
      return;
    const { selectionStart: i, selectionEnd: r, value: l } = e.value;
    if (i == null || r == null)
      return;
    const s = l.slice(0, Math.max(0, i)), u = l.slice(Math.max(0, r));
    t.value = {
      selectionStart: i,
      selectionEnd: r,
      value: l,
      beforeTxt: s,
      afterTxt: u
    };
  }
  function o() {
    if (!e.value || !t.value)
      return;
    const { value: i } = e.value, { beforeTxt: r, afterTxt: l, selectionStart: s } = t.value;
    if (!r || !l || !s)
      return;
    let u = i.length;
    if (i.endsWith(l))
      u = i.length - l.length;
    else if (i.startsWith(r))
      u = r.length;
    else {
      const f = r[s - 1], d = i.indexOf(f, s - 1);
      d !== -1 && (u = d + 1);
    }
    e.value.setSelectionRange(u, u);
  }
  return [n, o];
}
var co = S({
  name: "Input",
  inheritAttrs: !1,
  props: {
    modelValue: String,
    defaultValue: {
      type: String,
      default: ""
    },
    size: {
      type: String
    },
    allowClear: {
      type: Boolean,
      default: !1
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    readonly: {
      type: Boolean,
      default: !1
    },
    error: {
      type: Boolean,
      default: !1
    },
    placeholder: String,
    maxLength: {
      type: [Number, Object],
      default: 0
    },
    showWordLimit: {
      type: Boolean,
      default: !1
    },
    wordLength: {
      type: Function
    },
    wordSlice: {
      type: Function
    },
    inputAttrs: {
      type: Object
    },
    type: {
      type: String,
      default: "text"
    },
    prepend: String,
    append: String
  },
  emits: {
    "update:modelValue": (e) => !0,
    input: (e, t) => !0,
    change: (e, t) => !0,
    pressEnter: (e) => !0,
    clear: (e) => !0,
    focus: (e) => !0,
    blur: (e) => !0
  },
  setup(e, {
    emit: t,
    slots: n,
    attrs: o
  }) {
    const {
      size: i,
      disabled: r,
      error: l,
      modelValue: s
    } = ve(e), u = B("input"), f = V(), {
      mergedSize: d,
      mergedDisabled: p,
      mergedError: h,
      feedback: k,
      eventHandlers: y
    } = mt({
      size: i,
      disabled: r,
      error: l
    }), {
      mergedSize: w
    } = xt(d), [g, C] = cm(f), P = V(e.defaultValue), z = a(() => {
      var ke;
      return (ke = e.modelValue) != null ? ke : P.value;
    });
    let j = z.value;
    ze(s, (ke) => {
      (Ve(ke) || Jt(ke)) && (P.value = "");
    }), ze(z, (ke, le) => {
      j = le;
    });
    const I = V(!1), L = a(() => e.allowClear && !e.readonly && !p.value && !!z.value), M = V(!1), E = V(""), K = (ke) => {
      var le;
      return Ne(e.wordLength) ? e.wordLength(ke) : (le = ke.length) != null ? le : 0;
    }, q = a(() => K(z.value)), T = a(() => h.value || !!(Qe(e.maxLength) && e.maxLength.errorOnly && q.value > Y.value)), X = a(() => Qe(e.maxLength) && !!e.maxLength.errorOnly), Y = a(() => Qe(e.maxLength) ? e.maxLength.length : e.maxLength), Z = a(() => {
      const ke = K("a");
      return Math.floor(Y.value / ke);
    }), U = (ke) => {
      var le, re;
      Y.value && !X.value && K(ke) > Y.value && (ke = (re = (le = e.wordSlice) == null ? void 0 : le.call(e, ke, Y.value)) != null ? re : ke.slice(0, Z.value)), P.value = ke, t("update:modelValue", ke);
    }, H = (ke) => {
      f.value && ke.target !== f.value && (ke.preventDefault(), f.value.focus());
    }, D = (ke, le) => {
      var re, fe;
      ke !== j && (j = ke, t("change", ke, le), (fe = (re = y.value) == null ? void 0 : re.onChange) == null || fe.call(re, le));
    }, R = (ke) => {
      var le, re;
      I.value = !0, t("focus", ke), (re = (le = y.value) == null ? void 0 : le.onFocus) == null || re.call(le, ke);
    }, W = (ke) => {
      var le, re;
      I.value = !1, D(z.value, ke), t("blur", ke), (re = (le = y.value) == null ? void 0 : le.onBlur) == null || re.call(le, ke);
    }, O = (ke) => {
      var le, re, fe;
      const {
        value: Oe,
        selectionStart: Be,
        selectionEnd: $e
      } = ke.target;
      if (ke.type === "compositionend") {
        if (M.value = !1, E.value = "", Y.value && !X.value && q.value >= Y.value && K(Oe) > Y.value && Be === $e) {
          x();
          return;
        }
        U(Oe), t("input", Oe, ke), (re = (le = y.value) == null ? void 0 : le.onInput) == null || re.call(le, ke), x();
      } else
        M.value = !0, E.value = z.value + ((fe = ke.data) != null ? fe : "");
    }, x = () => {
      g(), at(() => {
        f.value && z.value !== f.value.value && (f.value.value = z.value, C());
      });
    }, G = (ke) => {
      var le, re;
      const {
        value: fe
      } = ke.target;
      if (!M.value) {
        if (Y.value && !X.value && q.value >= Y.value && K(fe) > Y.value && ke.inputType === "insertText") {
          x();
          return;
        }
        U(fe), t("input", fe, ke), (re = (le = y.value) == null ? void 0 : le.onInput) == null || re.call(le, ke), x();
      }
    }, ne = (ke) => {
      U(""), D("", ke), t("clear", ke);
    }, ee = (ke) => {
      const le = ke.key || ke.code;
      !M.value && le === Pv.key && (D(z.value, ke), t("pressEnter", ke));
    }, Q = a(() => [`${u}-outer`, `${u}-outer-size-${w.value}`, {
      [`${u}-outer-has-suffix`]: !!n.suffix,
      [`${u}-outer-disabled`]: p.value
    }]), ae = a(() => [`${u}-wrapper`, {
      [`${u}-error`]: T.value,
      [`${u}-disabled`]: p.value,
      [`${u}-focus`]: I.value
    }]), ge = a(() => [u, `${u}-size-${w.value}`]), Se = a(() => Ft(o, rl)), be = a(() => Wn(o, rl)), Le = a(() => {
      const ke = {
        ...be.value,
        ...e.inputAttrs
      };
      return T.value && (ke["aria-invalid"] = !0), ke;
    }), pe = (ke) => {
      var le;
      return c("span", se({
        class: ae.value,
        onMousedown: H
      }, ke ? void 0 : Se.value), [n.prefix && c("span", {
        class: `${u}-prefix`
      }, [n.prefix()]), c("input", se({
        ref: f,
        class: ge.value,
        value: z.value,
        type: e.type,
        placeholder: e.placeholder,
        readonly: e.readonly,
        disabled: p.value,
        onInput: G,
        onKeydown: ee,
        onFocus: R,
        onBlur: W,
        onCompositionstart: O,
        onCompositionupdate: O,
        onCompositionend: O
      }, Le.value), null), L.value && c(pt, {
        prefix: u,
        class: `${u}-clear-btn`,
        onClick: ne
      }, {
        default: () => [c(Dt, null, null)]
      }), (n.suffix || !!e.maxLength && e.showWordLimit || !!k.value) && c("span", {
        class: [`${u}-suffix`, {
          [`${u}-suffix-has-feedback`]: k.value
        }]
      }, [!!e.maxLength && e.showWordLimit && c("span", {
        class: `${u}-word-limit`
      }, [q.value, Re("/"), Y.value]), (le = n.suffix) == null ? void 0 : le.call(n), !!k.value && c(No, {
        type: k.value
      }, null)])]);
    };
    return {
      inputRef: f,
      render: () => n.prepend || n.append || e.prepend || e.append ? c("span", se({
        class: Q.value
      }, Se.value), [(n.prepend || e.prepend) && c("span", {
        class: `${u}-prepend`
      }, [n.prepend ? n.prepend() : e.prepend]), pe(!0), (n.append || e.append) && c("span", {
        class: `${u}-append`
      }, [n.append ? n.append() : e.append])]) : pe()
    };
  },
  methods: {
    focus() {
      var e;
      (e = this.inputRef) == null || e.focus();
    },
    blur() {
      var e;
      (e = this.inputRef) == null || e.blur();
    }
  },
  render() {
    return this.render();
  }
});
const Dg = S({
  name: "IconSearch",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-search`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), xg = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Rg(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M33.072 33.071c6.248-6.248 6.248-16.379 0-22.627-6.249-6.249-16.38-6.249-22.628 0-6.248 6.248-6.248 16.379 0 22.627 6.248 6.248 16.38 6.248 22.628 0Zm0 0 8.485 8.485" }, null, -1)
  ]), 14, xg);
}
var ya = /* @__PURE__ */ N(Dg, [["render", Rg]]);
const ur = Object.assign(ya, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ya.name, ya);
  }
}), dm = Symbol("ArcoButtonGroup"), Hg = S({
  name: "Button",
  components: {
    IconLoading: Yt
  },
  props: {
    type: {
      type: String
    },
    shape: {
      type: String
    },
    status: {
      type: String
    },
    size: {
      type: String
    },
    long: {
      type: Boolean,
      default: !1
    },
    loading: {
      type: Boolean,
      default: !1
    },
    disabled: {
      type: Boolean
    },
    htmlType: {
      type: String,
      default: "button"
    },
    autofocus: {
      type: Boolean,
      default: !1
    },
    href: String
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const { size: n, disabled: o } = ve(e), i = B("btn"), r = Ge(dm, void 0), l = a(() => {
      var k;
      return (k = n.value) != null ? k : r == null ? void 0 : r.size;
    }), s = a(
      () => !!(o.value || r != null && r.disabled)
    ), { mergedSize: u, mergedDisabled: f } = mt({
      size: l,
      disabled: s
    }), { mergedSize: d } = xt(u), p = a(() => {
      var k, y, w, g, C, P;
      return [
        i,
        `${i}-${(y = (k = e.type) != null ? k : r == null ? void 0 : r.type) != null ? y : "secondary"}`,
        `${i}-shape-${(g = (w = e.shape) != null ? w : r == null ? void 0 : r.shape) != null ? g : "square"}`,
        `${i}-size-${d.value}`,
        `${i}-status-${(P = (C = e.status) != null ? C : r == null ? void 0 : r.status) != null ? P : "normal"}`,
        {
          [`${i}-long`]: e.long,
          [`${i}-loading`]: e.loading,
          [`${i}-disabled`]: f.value,
          [`${i}-link`]: zt(e.href)
        }
      ];
    });
    return {
      prefixCls: i,
      cls: p,
      mergedDisabled: f,
      handleClick: (k) => {
        if (e.disabled || e.loading) {
          k.preventDefault();
          return;
        }
        t("click", k);
      }
    };
  }
}), qg = ["href"], Zg = ["type", "disabled", "autofocus"];
function Kg(e, t, n, o, i, r) {
  const l = J("icon-loading");
  return e.href ? (v(), b("a", {
    key: 0,
    class: m([
      e.cls,
      { [`${e.prefixCls}-only-icon`]: e.$slots.icon && !e.$slots.default }
    ]),
    href: e.mergedDisabled || e.loading ? void 0 : e.href,
    onClick: t[0] || (t[0] = (...s) => e.handleClick && e.handleClick(...s))
  }, [
    e.loading || e.$slots.icon ? (v(), b("span", {
      key: 0,
      class: m(`${e.prefixCls}-icon`)
    }, [
      e.loading ? (v(), oe(l, {
        key: 0,
        spin: "true"
      })) : _(e.$slots, "icon", { key: 1 })
    ], 2)) : te("v-if", !0),
    _(e.$slots, "default")
  ], 10, qg)) : (v(), b("button", {
    key: 1,
    class: m([
      e.cls,
      { [`${e.prefixCls}-only-icon`]: e.$slots.icon && !e.$slots.default }
    ]),
    type: e.htmlType,
    disabled: e.mergedDisabled,
    autofocus: e.autofocus,
    onClick: t[1] || (t[1] = (...s) => e.handleClick && e.handleClick(...s))
  }, [
    e.loading || e.$slots.icon ? (v(), b("span", {
      key: 0,
      class: m(`${e.prefixCls}-icon`)
    }, [
      e.loading ? (v(), oe(l, {
        key: 0,
        spin: !0
      })) : _(e.$slots, "icon", { key: 1 })
    ], 2)) : te("v-if", !0),
    _(e.$slots, "default")
  ], 10, Zg));
}
var ba = /* @__PURE__ */ N(Hg, [["render", Kg]]);
const Yg = S({
  name: "ButtonGroup",
  props: {
    type: {
      type: String
    },
    status: {
      type: String
    },
    shape: {
      type: String
    },
    size: {
      type: String
    },
    disabled: {
      type: Boolean
    }
  },
  setup(e) {
    const { type: t, size: n, status: o, disabled: i, shape: r } = ve(e), l = B("btn-group");
    return it(
      dm,
      me({
        type: t,
        size: n,
        shape: r,
        status: o,
        disabled: i
      })
    ), {
      prefixCls: l
    };
  }
});
function Ug(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    _(e.$slots, "default")
  ], 2);
}
var fo = /* @__PURE__ */ N(Yg, [["render", Ug]]);
const Qt = Object.assign(ba, {
  Group: fo,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ba.name, ba), e.component(n + fo.name, fo);
  }
});
var li = S({
  name: "InputSearch",
  props: {
    searchButton: {
      type: Boolean,
      default: !1
    },
    loading: {
      type: Boolean,
      default: !1
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    size: {
      type: String
    },
    buttonText: {
      type: String
    },
    buttonProps: {
      type: Object
    }
  },
  emits: {
    search: (e, t) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      size: o
    } = ve(e), i = B("input-search"), {
      mergedSize: r
    } = xt(o), l = V(), s = (p) => {
      l.value.inputRef && t("search", l.value.inputRef.value, p);
    }, u = () => {
      var p;
      return c(Ae, null, [e.loading ? c(Yt, null, null) : c(pt, {
        onClick: s
      }, {
        default: () => [c(ur, null, null)]
      }), (p = n.suffix) == null ? void 0 : p.call(n)]);
    }, f = () => {
      var p;
      let h = {};
      return e.buttonText || n["button-default"] || n["button-icon"] ? h = {
        default: (p = n["button-default"]) != null ? p : e.buttonText ? () => e.buttonText : void 0,
        icon: n["button-icon"]
      } : h = {
        icon: () => c(ur, null, null)
      }, c(Qt, se({
        type: "primary",
        class: `${i}-btn`,
        disabled: e.disabled,
        size: r.value,
        loading: e.loading
      }, e.buttonProps, {
        onClick: s
      }), h);
    };
    return {
      inputRef: l,
      render: () => c(co, {
        ref: l,
        class: i,
        size: r.value,
        disabled: e.disabled
      }, {
        prepend: n.prepend,
        prefix: n.prefix,
        suffix: e.searchButton ? n.suffix : u,
        append: e.searchButton ? f : n.append
      })
    };
  },
  methods: {
    focus() {
      var e;
      (e = this.inputRef) == null || e.focus();
    },
    blur() {
      var e;
      (e = this.inputRef) == null || e.blur();
    }
  },
  render() {
    return this.render();
  }
});
const Gg = S({
  name: "IconEye",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-eye`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Xg = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Qg(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "clip-rule": "evenodd",
      d: "M24 37c6.627 0 12.627-4.333 18-13-5.373-8.667-11.373-13-18-13-6.627 0-12.627 4.333-18 13 5.373 8.667 11.373 13 18 13Z"
    }, null, -1),
    $("path", { d: "M29 24a5 5 0 1 1-10 0 5 5 0 0 1 10 0Z" }, null, -1)
  ]), 14, Xg);
}
var Ca = /* @__PURE__ */ N(Gg, [["render", Qg]]);
const Bv = Object.assign(Ca, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ca.name, Ca);
  }
}), _g = S({
  name: "IconEyeInvisible",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-eye-invisible`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Jg = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function ey(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M14 14.5c-2.69 2-5.415 5.33-8 9.5 5.373 8.667 11.373 13 18 13 3.325 0 6.491-1.09 9.5-3.271M17.463 12.5C19 11 21.75 11 24 11c6.627 0 12.627 4.333 18 13-1.766 2.848-3.599 5.228-5.5 7.14" }, null, -1),
    $("path", { d: "M29 24a5 5 0 1 1-10 0 5 5 0 0 1 10 0ZM6.852 7.103l34.294 34.294" }, null, -1)
  ]), 14, Jg);
}
var $a = /* @__PURE__ */ N(_g, [["render", ey]]);
const fm = Object.assign($a, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + $a.name, $a);
  }
});
function Ht(e) {
  const t = V(e);
  return [t, (o) => {
    t.value = o;
  }];
}
function Vt(e, t) {
  const { value: n } = ve(t), [o, i] = Ht(
    Ve(n.value) ? e : n.value
  );
  return ze(n, (l) => {
    Ve(l) && i(void 0);
  }), [a(
    () => Ve(n.value) ? o.value : n.value
  ), i, o];
}
const ty = S({
  name: "InputPassword",
  components: {
    IconEye: Bv,
    IconEyeInvisible: fm,
    AIconHover: pt,
    AInput: co
  },
  props: {
    visibility: {
      type: Boolean,
      default: void 0
    },
    defaultVisibility: {
      type: Boolean,
      default: !0
    },
    invisibleButton: {
      type: Boolean,
      default: !0
    }
  },
  emits: [
    "visibility-change",
    "update:visibility"
  ],
  setup(e, { emit: t }) {
    const { visibility: n, defaultVisibility: o } = ve(e), i = V(), r = () => {
      u(!l.value);
    }, [l, s] = Vt(
      o.value,
      me({
        value: n
      })
    ), u = (f) => {
      f !== l.value && (t("visibility-change", f), t("update:visibility", f), s(f));
    };
    return {
      inputRef: i,
      mergedVisible: l,
      handleInvisible: r
    };
  },
  methods: {
    focus() {
      var e;
      (e = this.inputRef) == null || e.focus();
    },
    blur() {
      var e;
      (e = this.inputRef) == null || e.blur();
    }
  }
});
function ny(e, t, n, o, i, r) {
  const l = J("icon-eye"), s = J("icon-eye-invisible"), u = J("a-icon-hover"), f = J("a-input");
  return v(), oe(f, {
    ref: "inputRef",
    type: e.mergedVisible ? "password" : "text"
  }, kt({ _: 2 }, [
    e.$slots.prepend ? {
      name: "prepend",
      fn: ue(() => [
        _(e.$slots, "prepend")
      ]),
      key: "0"
    } : void 0,
    e.$slots.prefix ? {
      name: "prefix",
      fn: ue(() => [
        _(e.$slots, "prefix")
      ]),
      key: "1"
    } : void 0,
    e.invisibleButton || e.$slots.suffix ? {
      name: "suffix",
      fn: ue(() => [
        e.invisibleButton ? (v(), oe(u, {
          key: 0,
          onClick: e.handleInvisible,
          onMousedown: t[0] || (t[0] = an(() => {
          }, ["prevent"])),
          onMouseup: t[1] || (t[1] = an(() => {
          }, ["prevent"]))
        }, {
          default: ue(() => [
            e.mergedVisible ? (v(), oe(s, { key: 1 })) : (v(), oe(l, { key: 0 }))
          ]),
          _: 1
        }, 8, ["onClick"])) : te("v-if", !0),
        _(e.$slots, "suffix")
      ]),
      key: "2"
    } : void 0,
    e.$slots.append ? {
      name: "append",
      fn: ue(() => [
        _(e.$slots, "append")
      ]),
      key: "3"
    } : void 0
  ]), 1032, ["type"]);
}
var oi = /* @__PURE__ */ N(ty, [["render", ny]]);
const ly = S({
  name: "InputGroup",
  setup() {
    return {
      prefixCls: B("input-group")
    };
  }
});
function oy(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    _(e.$slots, "default")
  ], 2);
}
var xl = /* @__PURE__ */ N(ly, [["render", oy]]);
const cl = Object.assign(co, {
  Search: li,
  Password: oi,
  Group: xl,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + co.name, co), e.component(n + xl.name, xl), e.component(n + li.name, li), e.component(n + oi.name, oi);
  }
}), iy = () => {
  const { height: e, width: t } = om();
  return {
    width: Math.min(t, window.innerWidth),
    height: Math.min(e, window.innerHeight)
  };
}, F0 = (e, t) => {
  var n, o;
  const i = e.getBoundingClientRect();
  return {
    top: i.top,
    bottom: i.bottom,
    left: i.left,
    right: i.right,
    scrollTop: i.top - t.top,
    scrollBottom: i.bottom - t.top,
    scrollLeft: i.left - t.left,
    scrollRight: i.right - t.left,
    width: (n = e.offsetWidth) != null ? n : e.clientWidth,
    height: (o = e.offsetHeight) != null ? o : e.clientHeight
  };
}, ry = (e) => {
  switch (e) {
    case "top":
    case "tl":
    case "tr":
      return "top";
    case "bottom":
    case "bl":
    case "br":
      return "bottom";
    case "left":
    case "lt":
    case "lb":
      return "left";
    case "right":
    case "rt":
    case "rb":
      return "right";
    default:
      return "top";
  }
}, Yo = (e, t) => {
  switch (t) {
    case "top":
      switch (e) {
        case "bottom":
          return "top";
        case "bl":
          return "tl";
        case "br":
          return "tr";
        default:
          return e;
      }
    case "bottom":
      switch (e) {
        case "top":
          return "bottom";
        case "tl":
          return "bl";
        case "tr":
          return "br";
        default:
          return e;
      }
    case "left":
      switch (e) {
        case "right":
          return "left";
        case "rt":
          return "lt";
        case "rb":
          return "lb";
        default:
          return e;
      }
    case "right":
      switch (e) {
        case "left":
          return "right";
        case "lt":
          return "rt";
        case "lb":
          return "rb";
        default:
          return e;
      }
    default:
      return e;
  }
}, ay = (e, t, {
  containerRect: n,
  triggerRect: o,
  popupRect: i,
  offset: r,
  translate: l
}) => {
  const s = ry(e), u = iy(), f = {
    top: n.top + t.top,
    bottom: u.height - (n.top + t.top + i.height),
    left: n.left + t.left,
    right: u.width - (n.left + t.left + i.width)
  };
  let d = e;
  if (s === "top" && f.top < 0)
    if (o.top > i.height)
      t.top = -n.top;
    else {
      const p = ao("bottom", o, i, {
        offset: r,
        translate: l
      });
      u.height - (n.top + p.top + i.height) > 0 && (d = Yo(e, "bottom"), t.top = p.top);
    }
  if (s === "bottom" && f.bottom < 0)
    if (u.height - o.bottom > i.height)
      t.top = -n.top + (u.height - i.height);
    else {
      const p = ao("top", o, i, {
        offset: r,
        translate: l
      });
      n.top + p.top > 0 && (d = Yo(e, "top"), t.top = p.top);
    }
  if (s === "left" && f.left < 0)
    if (o.left > i.width)
      t.left = -n.left;
    else {
      const p = ao("right", o, i, {
        offset: r,
        translate: l
      });
      u.width - (n.left + p.left + i.width) > 0 && (d = Yo(e, "right"), t.left = p.left);
    }
  if (s === "right" && f.right < 0)
    if (u.width - o.right > i.width)
      t.left = -n.left + (u.width - i.width);
    else {
      const p = ao("left", o, i, {
        offset: r,
        translate: l
      });
      n.left + p.left > 0 && (d = Yo(e, "left"), t.left = p.left);
    }
  return (s === "top" || s === "bottom") && (f.left < 0 ? t.left = -n.left : f.right < 0 && (t.left = -n.left + (u.width - i.width))), (s === "left" || s === "right") && (f.top < 0 ? t.top = -n.top : f.bottom < 0 && (t.top = -n.top + (u.height - i.height))), {
    popupPosition: t,
    position: d
  };
}, ao = (e, t, n, {
  offset: o = 0,
  translate: i = [0, 0]
} = {}) => {
  var r;
  const l = (r = He(i) ? i : i[e]) != null ? r : [0, 0];
  switch (e) {
    case "top":
      return {
        left: t.scrollLeft + Math.round(t.width / 2) - Math.round(n.width / 2) + l[0],
        top: t.scrollTop - n.height - o + l[1]
      };
    case "tl":
      return {
        left: t.scrollLeft + l[0],
        top: t.scrollTop - n.height - o + l[1]
      };
    case "tr":
      return {
        left: t.scrollRight - n.width + l[0],
        top: t.scrollTop - n.height - o + l[1]
      };
    case "bottom":
      return {
        left: t.scrollLeft + Math.round(t.width / 2) - Math.round(n.width / 2) + l[0],
        top: t.scrollBottom + o + l[1]
      };
    case "bl":
      return {
        left: t.scrollLeft + l[0],
        top: t.scrollBottom + o + l[1]
      };
    case "br":
      return {
        left: t.scrollRight - n.width + l[0],
        top: t.scrollBottom + o + l[1]
      };
    case "left":
      return {
        left: t.scrollLeft - n.width - o + l[0],
        top: t.scrollTop + Math.round(t.height / 2) - Math.round(n.height / 2) + l[1]
      };
    case "lt":
      return {
        left: t.scrollLeft - n.width - o + l[0],
        top: t.scrollTop + l[1]
      };
    case "lb":
      return {
        left: t.scrollLeft - n.width - o + l[0],
        top: t.scrollBottom - n.height + l[1]
      };
    case "right":
      return {
        left: t.scrollRight + o + l[0],
        top: t.scrollTop + Math.round(t.height / 2) - Math.round(n.height / 2) + l[1]
      };
    case "rt":
      return {
        left: t.scrollRight + o + l[0],
        top: t.scrollTop + l[1]
      };
    case "rb":
      return {
        left: t.scrollRight + o + l[0],
        top: t.scrollBottom - n.height + l[1]
      };
    default:
      return {
        left: 0,
        top: 0
      };
  }
}, sy = (e) => {
  let t = "0";
  ["top", "bottom"].includes(e) ? t = "50%" : ["left", "lt", "lb", "tr", "br"].includes(e) && (t = "100%");
  let n = "0";
  return ["left", "right"].includes(e) ? n = "50%" : ["top", "tl", "tr", "lb", "rb"].includes(e) && (n = "100%"), `${t} ${n}`;
}, uy = (e, t, n, o, {
  offset: i = 0,
  translate: r = [0, 0],
  customStyle: l = {},
  autoFitPosition: s = !1
} = {}) => {
  let u = e, f = ao(e, n, o, {
    offset: i,
    translate: r
  });
  if (s) {
    const p = ay(e, f, {
      containerRect: t,
      popupRect: o,
      triggerRect: n,
      offset: i,
      translate: r
    });
    f = p.popupPosition, u = p.position;
  }
  return {
    style: {
      left: `${f.left}px`,
      top: `${f.top}px`,
      ...l
    },
    position: u
  };
}, cy = (e, t, n, {
  customStyle: o = {}
}) => {
  if (["top", "tl", "tr", "bottom", "bl", "br"].includes(e)) {
    let r = Math.abs(
      t.scrollLeft + t.width / 2 - n.scrollLeft
    );
    return r > n.width - 8 && (t.width > n.width ? r = n.width / 2 : r = n.width - 8), ["top", "tl", "tr"].includes(e) ? {
      left: `${r}px`,
      bottom: "0",
      transform: "translate(-50%,50%) rotate(45deg)",
      ...o
    } : {
      left: `${r}px`,
      top: "0",
      transform: "translate(-50%,-50%) rotate(45deg)",
      ...o
    };
  }
  let i = Math.abs(
    t.scrollTop + t.height / 2 - n.scrollTop
  );
  return i > n.height - 8 && (t.height > n.height ? i = n.height / 2 : i = n.height - 8), ["left", "lt", "lb"].includes(e) ? {
    top: `${i}px`,
    right: "0",
    transform: "translate(50%,-50%) rotate(45deg)",
    ...o
  } : {
    top: `${i}px`,
    left: "0",
    transform: "translate(-50%,-50%) rotate(45deg)",
    ...o
  };
}, dy = (e) => e.scrollHeight > e.offsetHeight || e.scrollWidth > e.offsetWidth, D0 = (e) => {
  var t;
  const n = [];
  let o = e;
  for (; o && o !== document.documentElement; )
    dy(o) && n.push(o), o = (t = o.parentElement) != null ? t : void 0;
  return n;
}, vm = () => {
  const e = {}, t = V(), n = () => {
    const o = Jp(e.value);
    o !== t.value && (t.value = o);
  };
  return Je(() => n()), fn(() => n()), {
    children: e,
    firstElement: t
  };
};
var al = S({
  name: "ResizeObserver",
  props: {
    watchOnUpdated: Boolean
  },
  emits: [
    "resize"
  ],
  setup(e, { emit: t, slots: n }) {
    const { children: o, firstElement: i } = vm();
    let r;
    const l = (u) => {
      u && (r = new wr((f) => {
        const d = f[0];
        t("resize", d);
      }), r.observe(u));
    }, s = () => {
      r && (r.disconnect(), r = null);
    };
    return ze(i, (u) => {
      r && s(), u && l(u);
    }), _t(() => {
      r && s();
    }), () => {
      var u;
      return o.value = (u = n.default) == null ? void 0 : u.call(n), o.value;
    };
  }
});
function Sn(e, t) {
  const n = V(e[t]);
  return fn(() => {
    const o = e[t];
    n.value !== o && (n.value = o);
  }), n;
}
const x0 = Symbol("ArcoTrigger"), fy = 1e3, vy = 5e3, py = 1;
class my {
  constructor() {
    this.popupStack = {
      popup: /* @__PURE__ */ new Set(),
      dialog: /* @__PURE__ */ new Set(),
      message: /* @__PURE__ */ new Set()
    }, this.getNextZIndex = (t) => (t === "message" ? Array.from(this.popupStack.message).pop() || vy : Array.from(this.popupStack.popup).pop() || fy) + py, this.add = (t) => {
      const n = this.getNextZIndex(t);
      return this.popupStack[t].add(n), t === "dialog" && this.popupStack.popup.add(n), n;
    }, this.delete = (t, n) => {
      this.popupStack[n].delete(t), n === "dialog" && this.popupStack.popup.delete(t);
    }, this.isLastDialog = (t) => this.popupStack.dialog.size > 1 ? t === Array.from(this.popupStack.dialog).pop() : !0;
  }
}
const wa = new my();
function Ql(e, {
  visible: t,
  runOnMounted: n
} = {}) {
  const o = V(0), i = () => {
    o.value = wa.add(e);
  }, r = () => {
    wa.delete(o.value, e);
  }, l = () => e === "dialog" ? wa.isLastDialog(o.value) : !1;
  return ze(
    () => t == null ? void 0 : t.value,
    (s) => {
      s ? i() : r();
    },
    {
      immediate: !0
    }
  ), n && (Je(() => {
    i();
  }), _t(() => {
    r();
  })), {
    zIndex: _2(o),
    open: i,
    close: r,
    isLastDialog: l
  };
}
const hy = ({
  elementRef: e,
  onResize: t
}) => {
  let n;
  return {
    createResizeObserver: () => {
      e.value && (n = new wr((r) => {
        const l = r[0];
        Ne(t) && t(l);
      }), n.observe(e.value));
    },
    destroyResizeObserver: () => {
      n && (n.disconnect(), n = null);
    }
  };
};
var Mv = S({
  name: "ClientOnly",
  setup(e, {
    slots: t
  }) {
    const n = V(!1);
    return Je(() => n.value = !0), () => {
      var o;
      return n.value ? (o = t.default) == null ? void 0 : o.call(t) : null;
    };
  }
});
const Nv = ({
  popupContainer: e,
  visible: t,
  defaultContainer: n = "body",
  documentContainer: o
}) => {
  const i = V(e.value), r = V(), l = () => {
    const s = Tn(e.value), u = s ? e.value : n, f = s ?? (o ? document.documentElement : Tn(n));
    u !== i.value && (i.value = u), f !== r.value && (r.value = f);
  };
  return Je(() => l()), ze(t, (s) => {
    i.value !== e.value && s && l();
  }), {
    teleportContainer: i,
    containerRef: r
  };
}, ky = ["onClick", "onMouseenter", "onMouseleave", "onFocusin", "onFocusout", "onContextmenu"];
var Sa = S({
  name: "Trigger",
  inheritAttrs: !1,
  props: {
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean,
      default: !1
    },
    trigger: {
      type: [String, Array],
      default: "hover"
    },
    position: {
      type: String,
      default: "bottom"
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    popupOffset: {
      type: Number,
      default: 0
    },
    popupTranslate: {
      type: [Array, Object]
    },
    showArrow: {
      type: Boolean,
      default: !1
    },
    alignPoint: {
      type: Boolean,
      default: !1
    },
    popupHoverStay: {
      type: Boolean,
      default: !0
    },
    blurToClose: {
      type: Boolean,
      default: !0
    },
    clickToClose: {
      type: Boolean,
      default: !0
    },
    clickOutsideToClose: {
      type: Boolean,
      default: !0
    },
    unmountOnClose: {
      type: Boolean,
      default: !0
    },
    contentClass: {
      type: [String, Array, Object]
    },
    contentStyle: {
      type: Object
    },
    arrowClass: {
      type: [String, Array, Object]
    },
    arrowStyle: {
      type: Object
    },
    popupStyle: {
      type: Object
    },
    animationName: {
      type: String,
      default: "fade-in"
    },
    duration: {
      type: [Number, Object]
    },
    mouseEnterDelay: {
      type: Number,
      default: 100
    },
    mouseLeaveDelay: {
      type: Number,
      default: 100
    },
    focusDelay: {
      type: Number,
      default: 0
    },
    autoFitPopupWidth: {
      type: Boolean,
      default: !1
    },
    autoFitPopupMinWidth: {
      type: Boolean,
      default: !1
    },
    autoFixPosition: {
      type: Boolean,
      default: !0
    },
    popupContainer: {
      type: [String, Object]
    },
    updateAtScroll: {
      type: Boolean,
      default: !1
    },
    autoFitTransformOrigin: {
      type: Boolean,
      default: !1
    },
    hideEmpty: {
      type: Boolean,
      default: !1
    },
    openedClass: {
      type: [String, Array, Object]
    },
    autoFitPosition: {
      type: Boolean,
      default: !0
    },
    renderToBody: {
      type: Boolean,
      default: !0
    },
    preventFocus: {
      type: Boolean,
      default: !1
    },
    scrollToClose: {
      type: Boolean,
      default: !1
    },
    scrollToCloseDistance: {
      type: Number,
      default: 0
    }
  },
  emits: {
    "update:popupVisible": (e) => !0,
    popupVisibleChange: (e) => !0,
    show: () => !0,
    hide: () => !0,
    resize: () => !0
  },
  setup(e, {
    emit: t,
    slots: n,
    attrs: o
  }) {
    const {
      popupContainer: i
    } = ve(e), r = B("trigger"), l = a(() => Ft(o, ky)), s = Ge(Kt, void 0), u = a(() => [].concat(e.trigger)), f = /* @__PURE__ */ new Set(), d = Ge(x0, void 0), {
      children: p,
      firstElement: h
    } = vm(), k = V(), y = V(e.defaultPopupVisible), w = V(e.position), g = V({}), C = V({}), P = V({}), z = V(), j = V({
      top: 0,
      left: 0
    });
    let I = null, L = null;
    const M = a(() => {
      var ce;
      return (ce = e.popupVisible) != null ? ce : y.value;
    }), {
      teleportContainer: E,
      containerRef: K
    } = Nv({
      popupContainer: i,
      visible: M,
      documentContainer: !0
    }), {
      zIndex: q
    } = Ql("popup", {
      visible: M
    });
    let T = 0, X = !1, Y = !1;
    const Z = () => {
      T && (window.clearTimeout(T), T = 0);
    }, U = (ce) => {
      if (e.alignPoint) {
        const {
          pageX: Ce,
          pageY: qe
        } = ce;
        j.value = {
          top: qe,
          left: Ce
        };
      }
    }, H = () => {
      if (!h.value || !k.value || !K.value)
        return;
      const ce = K.value.getBoundingClientRect(), Ce = e.alignPoint ? {
        top: j.value.top,
        bottom: j.value.top,
        left: j.value.left,
        right: j.value.left,
        scrollTop: j.value.top,
        scrollBottom: j.value.top,
        scrollLeft: j.value.left,
        scrollRight: j.value.left,
        width: 0,
        height: 0
      } : F0(h.value, ce), qe = () => F0(k.value, ce), Lt = qe(), {
        style: bt,
        position: en
      } = uy(e.position, ce, Ce, Lt, {
        offset: e.popupOffset,
        translate: e.popupTranslate,
        customStyle: e.popupStyle,
        autoFitPosition: e.autoFitPosition
      });
      e.autoFitTransformOrigin && (C.value = {
        transformOrigin: sy(en)
      }), e.autoFitPopupMinWidth ? bt.minWidth = `${Ce.width}px` : e.autoFitPopupWidth && (bt.width = `${Ce.width}px`), w.value !== en && (w.value = en), g.value = bt, e.showArrow && at(() => {
        P.value = cy(en, Ce, qe(), {
          customStyle: e.arrowStyle
        });
      });
    }, D = (ce, Ce) => {
      if (ce === M.value && T === 0)
        return;
      const qe = () => {
        y.value = ce, t("update:popupVisible", ce), t("popupVisibleChange", ce), ce && at(() => {
          H();
        });
      };
      ce || (I = null, L = null), Ce ? (Z(), ce !== M.value && (T = window.setTimeout(qe, Ce))) : qe();
    }, R = (ce) => {
      var Ce;
      (Ce = o.onClick) == null || Ce.call(o, ce), !(e.disabled || M.value && !e.clickToClose) && (u.value.includes("click") ? (U(ce), D(!M.value)) : u.value.includes("contextMenu") && M.value && D(!1));
    }, W = (ce) => {
      var Ce;
      (Ce = o.onMouseenter) == null || Ce.call(o, ce), !(e.disabled || !u.value.includes("hover")) && (U(ce), D(!0, e.mouseEnterDelay));
    }, O = (ce) => {
      d == null || d.onMouseenter(ce), W(ce);
    }, x = (ce) => {
      var Ce;
      (Ce = o.onMouseleave) == null || Ce.call(o, ce), !(e.disabled || !u.value.includes("hover")) && D(!1, e.mouseLeaveDelay);
    }, G = (ce) => {
      d == null || d.onMouseleave(ce), x(ce);
    }, ne = (ce) => {
      var Ce;
      (Ce = o.onFocusin) == null || Ce.call(o, ce), !(e.disabled || !u.value.includes("focus")) && D(!0, e.focusDelay);
    }, ee = (ce) => {
      var Ce;
      (Ce = o.onFocusout) == null || Ce.call(o, ce), !(e.disabled || !u.value.includes("focus")) && e.blurToClose && D(!1);
    }, Q = (ce) => {
      var Ce;
      (Ce = o.onContextmenu) == null || Ce.call(o, ce), !(e.disabled || !u.value.includes("contextMenu") || M.value && !e.clickToClose) && (U(ce), D(!M.value), ce.preventDefault());
    };
    it(x0, me({
      onMouseenter: O,
      onMouseleave: G,
      addChildRef: (ce) => {
        f.add(ce), d == null || d.addChildRef(ce);
      },
      removeChildRef: (ce) => {
        f.delete(ce), d == null || d.removeChildRef(ce);
      }
    }));
    const Se = () => {
      ct(document.documentElement, "mousedown", pe), X = !1;
    }, be = Sn(n, "content"), Le = a(() => {
      var ce;
      return e.hideEmpty && Mk((ce = be.value) == null ? void 0 : ce.call(be));
    }), pe = (ce) => {
      var Ce, qe, Lt;
      if (!((Ce = h.value) != null && Ce.contains(ce.target) || (qe = k.value) != null && qe.contains(ce.target))) {
        for (const bt of f)
          if ((Lt = bt.value) != null && Lt.contains(ce.target))
            return;
        Se(), D(!1);
      }
    }, Me = (ce, Ce) => {
      const [qe, Lt] = ce, {
        scrollTop: bt,
        scrollLeft: en
      } = Ce;
      return Math.abs(bt - qe) >= e.scrollToCloseDistance || Math.abs(en - Lt) >= e.scrollToCloseDistance;
    }, ke = wl((ce) => {
      if (M.value)
        if (e.scrollToClose || s != null && s.scrollToClose) {
          const Ce = ce.target;
          I || (I = [Ce.scrollTop, Ce.scrollLeft]), Me(I, Ce) ? D(!1) : H();
        } else
          H();
    }), le = () => {
      ct(window, "scroll", re), Y = !1;
    }, re = wl((ce) => {
      const Ce = ce.target.documentElement;
      L || (L = [Ce.scrollTop, Ce.scrollLeft]), Me(L, Ce) && (D(!1), le());
    }), fe = () => {
      M.value && H();
    }, Oe = () => {
      fe(), t("resize");
    }, Be = (ce) => {
      e.preventFocus && ce.preventDefault();
    };
    d == null || d.addChildRef(k);
    const $e = a(() => M.value ? e.openedClass : void 0);
    let he;
    ze(M, (ce) => {
      if (e.clickOutsideToClose && (!ce && X ? Se() : ce && !X && (rt(document.documentElement, "mousedown", pe), X = !0)), (e.scrollToClose || s != null && s.scrollToClose) && (rt(window, "scroll", re), Y = !0), e.updateAtScroll || s != null && s.updateAtScroll) {
        if (ce) {
          he = D0(h.value);
          for (const Ce of he)
            Ce.addEventListener("scroll", ke);
        } else if (he) {
          for (const Ce of he)
            Ce.removeEventListener("scroll", ke);
          he = void 0;
        }
      }
      ce && (tt.value = !0);
    }), ze(() => [e.autoFitPopupWidth, e.autoFitPopupMinWidth], () => {
      M.value && H();
    });
    const {
      createResizeObserver: Ue,
      destroyResizeObserver: et
    } = hy({
      elementRef: K,
      onResize: fe
    });
    Je(() => {
      if (Ue(), M.value && (H(), e.clickOutsideToClose && !X && (rt(document.documentElement, "mousedown", pe), X = !0), e.updateAtScroll || s != null && s.updateAtScroll)) {
        he = D0(h.value);
        for (const ce of he)
          ce.addEventListener("scroll", ke);
      }
    }), fn(() => {
      M.value && H();
    }), J2(() => {
      D(!1);
    }), _t(() => {
      if (d == null || d.removeChildRef(k), et(), X && Se(), Y && le(), he) {
        for (const ce of he)
          ce.removeEventListener("scroll", ke);
        he = void 0;
      }
    });
    const tt = V(M.value), st = V(!1), $t = () => {
      st.value = !0;
    }, vn = () => {
      st.value = !1, M.value && t("show");
    }, ye = () => {
      st.value = !1, M.value || (tt.value = !1, t("hide"));
    };
    return () => {
      var ce, Ce;
      return p.value = (Ce = (ce = n.default) == null ? void 0 : ce.call(n)) != null ? Ce : [], Qp(p.value, {
        class: $e.value,
        onClick: R,
        onMouseenter: W,
        onMouseleave: x,
        onFocusin: ne,
        onFocusout: ee,
        onContextmenu: Q
      }), c(Ae, null, [e.autoFixPosition ? c(al, {
        onResize: Oe
      }, {
        default: () => [p.value]
      }) : p.value, c(Mv, null, {
        default: () => [c(br, {
          to: E.value,
          disabled: !e.renderToBody
        }, {
          default: () => [(!e.unmountOnClose || M.value || tt.value) && !Le.value && c(al, {
            onResize: fe
          }, {
            default: () => [c("div", se({
              ref: k,
              class: [`${r}-popup`, `${r}-position-${w.value}`],
              style: {
                ...g.value,
                zIndex: q.value,
                pointerEvents: st.value ? "none" : "auto"
              },
              "trigger-placement": w.value,
              onMouseenter: O,
              onMouseleave: G,
              onMousedown: Be
            }, l.value), [c(on, {
              name: e.animationName,
              duration: e.duration,
              appear: !0,
              onBeforeEnter: $t,
              onAfterEnter: vn,
              onBeforeLeave: $t,
              onAfterLeave: ye
            }, {
              default: () => {
                var qe;
                return [hn(c("div", {
                  class: `${r}-popup-wrapper`,
                  style: C.value
                }, [c("div", {
                  class: [`${r}-content`, e.contentClass],
                  style: e.contentStyle
                }, [(qe = n.content) == null ? void 0 : qe.call(n)]), e.showArrow && c("div", {
                  ref: z,
                  class: [`${r}-arrow`, e.arrowClass],
                  style: P.value
                }, null)]), [[kn, M.value]])];
              }
            })])]
          })]
        })]
      })]);
    };
  }
});
const Tt = Object.assign(Sa, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Sa.name, Sa);
  }
}), gy = S({
  name: "IconEmpty",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-empty`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), yy = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function by(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 5v6m7 1 4-4m-18 4-4-4m28.5 22H28s-1 3-4 3-4-3-4-3H6.5M40 41H8a2 2 0 0 1-2-2v-8.46a2 2 0 0 1 .272-1.007l6.15-10.54A2 2 0 0 1 14.148 18H33.85a2 2 0 0 1 1.728.992l6.149 10.541A2 2 0 0 1 42 30.541V39a2 2 0 0 1-2 2Z" }, null, -1)
  ]), 14, yy);
}
var za = /* @__PURE__ */ N(gy, [["render", by]]);
const pm = Object.assign(za, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + za.name, za);
  }
});
var ii = S({
  name: "Empty",
  inheritAttrs: !1,
  props: {
    description: String,
    imgSrc: String,
    inConfigProvider: {
      type: Boolean,
      default: !1
    }
  },
  setup(e, {
    slots: t,
    attrs: n
  }) {
    const o = B("empty"), {
      t: i
    } = gt(), r = Ge(Kt, void 0);
    return () => {
      var l, s, u, f;
      return !e.inConfigProvider && (r != null && r.slots.empty) && !(t.image || e.imgSrc || e.description) ? r.slots.empty({
        component: "empty"
      }) : c("div", se({
        class: o
      }, n), [c("div", {
        class: `${o}-image`
      }, [(s = (l = t.image) == null ? void 0 : l.call(t)) != null ? s : e.imgSrc ? c("img", {
        src: e.imgSrc,
        alt: e.description || "empty"
      }, null) : c(pm, null, null)]), c("div", {
        class: `${o}-description`
      }, [(f = (u = t.default) == null ? void 0 : u.call(t)) != null ? f : e.description || i("empty.description")])]);
    };
  }
});
const Gn = Object.assign(ii, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ii.name, ii);
  }
}), Cy = 5;
var $y = S({
  name: "DotLoading",
  props: {
    size: {
      type: Number
    }
  },
  setup(e) {
    const t = B("dot-loading");
    return () => {
      const n = e.size ? {
        width: `${e.size}px`,
        height: `${e.size}px`
      } : {};
      return c("div", {
        class: t,
        style: {
          width: e.size ? `${e.size * 7}px` : void 0,
          height: e.size ? `${e.size}px` : void 0
        }
      }, [Array(Cy).fill(1).map((o, i) => c("div", {
        class: `${t}-item`,
        key: i,
        style: n
      }, null))]);
    };
  }
}), La = S({
  name: "Spin",
  props: {
    size: {
      type: Number
    },
    loading: Boolean,
    dot: Boolean,
    tip: String,
    hideIcon: {
      type: Boolean,
      default: !1
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("spin"), o = Ge(Kt, void 0), i = a(() => [n, {
      [`${n}-loading`]: e.loading,
      [`${n}-with-tip`]: e.tip && !t.default
    }]), r = () => {
      if (t.icon) {
        const s = Fl(t.icon());
        if (s)
          return Kl(s, {
            spin: !0
          });
      }
      return t.element ? t.element() : e.dot ? c($y, {
        size: e.size
      }, null) : o != null && o.slots.loading ? o.slots.loading() : c(Yt, {
        spin: !0,
        size: e.size
      }, null);
    }, l = () => {
      var s, u, f;
      const d = e.size ? {
        fontSize: `${e.size}px`
      } : void 0, p = !!((s = t.tip) != null ? s : e.tip);
      return c(Ae, null, [!e.hideIcon && c("div", {
        class: `${n}-icon`,
        style: d
      }, [r()]), p && c("div", {
        class: `${n}-tip`
      }, [(f = (u = t.tip) == null ? void 0 : u.call(t)) != null ? f : e.tip])]);
    };
    return () => c("div", {
      class: i.value
    }, [t.default ? c(Ae, null, [t.default(), e.loading && c("div", {
      class: `${n}-mask`
    }, [c("div", {
      class: `${n}-mask-icon`
    }, [l()])])]) : l()]);
  }
});
const Pn = Object.assign(La, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + La.name, La);
  }
}), wy = S({
  name: "Thumb",
  props: {
    data: {
      type: Object
    },
    direction: {
      type: String,
      default: "horizontal"
    },
    alwaysShow: {
      type: Boolean,
      default: !1
    },
    both: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["scroll"],
  setup(e, { emit: t }) {
    const n = B("scrollbar"), o = V(!1), i = V(), r = V(), l = a(() => e.direction === "horizontal" ? {
      size: "width",
      direction: "left",
      offset: "offsetWidth",
      client: "clientX"
    } : {
      size: "height",
      direction: "top",
      offset: "offsetHeight",
      client: "clientY"
    }), s = V(0), u = V(!1), f = V(0), d = a(() => {
      var P, z;
      return {
        [l.value.size]: `${(z = (P = e.data) == null ? void 0 : P.thumbSize) != null ? z : 0}px`,
        [l.value.direction]: `${s.value}px`
      };
    }), p = (P) => {
      P.preventDefault(), r.value && (f.value = P[l.value.client] - r.value.getBoundingClientRect()[l.value.direction], u.value = !0, rt(window, "mousemove", y), rt(window, "mouseup", w), rt(window, "contextmenu", w));
    }, h = (P) => {
      var z, j, I, L;
      if (P.preventDefault(), r.value) {
        const M = k(
          P[l.value.client] > r.value.getBoundingClientRect()[l.value.direction] ? s.value + ((j = (z = e.data) == null ? void 0 : z.thumbSize) != null ? j : 0) : s.value - ((L = (I = e.data) == null ? void 0 : I.thumbSize) != null ? L : 0)
        );
        M !== s.value && (s.value = M, t("scroll", M));
      }
    }, k = (P) => P < 0 ? 0 : e.data && P > e.data.max ? e.data.max : P, y = (P) => {
      if (i.value && r.value) {
        const z = k(
          P[l.value.client] - i.value.getBoundingClientRect()[l.value.direction] - f.value
        );
        z !== s.value && (s.value = z, t("scroll", z));
      }
    }, w = () => {
      u.value = !1, ct(window, "mousemove", y), ct(window, "mouseup", w);
    }, g = (P) => {
      u.value || (P = k(P), P !== s.value && (s.value = P));
    }, C = a(() => [
      `${n}-thumb`,
      `${n}-thumb-direction-${e.direction}`,
      {
        [`${n}-thumb-dragging`]: u.value
      }
    ]);
    return {
      visible: o,
      trackRef: i,
      thumbRef: r,
      prefixCls: n,
      thumbCls: C,
      thumbStyle: d,
      handleThumbMouseDown: p,
      handleTrackClick: h,
      setOffset: g
    };
  }
});
function Sy(e, t, n, o, i, r) {
  return v(), oe(on, null, {
    default: ue(() => [
      $("div", {
        ref: "trackRef",
        class: m([
          `${e.prefixCls}-track`,
          `${e.prefixCls}-track-direction-${e.direction}`
        ]),
        onMousedown: t[1] || (t[1] = an((...l) => e.handleTrackClick && e.handleTrackClick(...l), ["self"]))
      }, [
        $("div", {
          ref: "thumbRef",
          class: m(e.thumbCls),
          style: F(e.thumbStyle),
          onMousedown: t[0] || (t[0] = (...l) => e.handleThumbMouseDown && e.handleThumbMouseDown(...l))
        }, [
          $("div", {
            class: m(`${e.prefixCls}-thumb-bar`)
          }, null, 2)
        ], 38)
      ], 34)
    ]),
    _: 1
  });
}
var zy = /* @__PURE__ */ N(wy, [["render", Sy]]);
const R0 = 20, Uo = 15, Ly = S({
  name: "Scrollbar",
  components: {
    ResizeObserver: al,
    Thumb: zy
  },
  inheritAttrs: !1,
  props: {
    type: {
      type: String,
      default: "embed"
    },
    outerClass: [String, Object, Array],
    outerStyle: {
      type: [String, Object, Array]
    },
    hide: {
      type: Boolean,
      default: !1
    },
    disableHorizontal: {
      type: Boolean,
      default: !1
    },
    disableVertical: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    scroll: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("scrollbar"), o = V(), i = V(), r = V(), l = V(), s = V(), u = V(!1), f = V(!1), d = a(
      () => u.value && !e.disableHorizontal
    ), p = a(
      () => f.value && !e.disableVertical
    ), h = V(!1), k = () => {
      var j, I, L, M, E, K;
      if (o.value) {
        const {
          clientWidth: q,
          clientHeight: T,
          offsetWidth: X,
          offsetHeight: Y,
          scrollWidth: Z,
          scrollHeight: U,
          scrollTop: H,
          scrollLeft: D
        } = o.value;
        u.value = Z > q, f.value = U > T, h.value = d.value && p.value;
        const R = e.type === "embed" && h.value ? X - Uo : X, W = e.type === "embed" && h.value ? Y - Uo : Y, O = Math.round(
          R / Math.min(
            Z / q,
            R / R0
          )
        ), x = R - O, G = (Z - q) / x, ne = Math.round(
          W / Math.min(
            U / T,
            W / R0
          )
        ), ee = W - ne, Q = (U - T) / ee;
        if (i.value = {
          ratio: G,
          thumbSize: O,
          max: x
        }, r.value = {
          ratio: Q,
          thumbSize: ne,
          max: ee
        }, H > 0) {
          const ae = Math.round(
            H / ((I = (j = r.value) == null ? void 0 : j.ratio) != null ? I : 1)
          );
          (L = s.value) == null || L.setOffset(ae);
        }
        if (D > 0) {
          const ae = Math.round(
            D / ((E = (M = r.value) == null ? void 0 : M.ratio) != null ? E : 1)
          );
          (K = l.value) == null || K.setOffset(ae);
        }
      }
    };
    Je(() => {
      k();
    });
    const y = () => {
      k();
    }, w = (j) => {
      var I, L, M, E, K, q;
      if (o.value) {
        if (d.value && !e.disableHorizontal) {
          const T = Math.round(
            o.value.scrollLeft / ((L = (I = i.value) == null ? void 0 : I.ratio) != null ? L : 1)
          );
          (M = l.value) == null || M.setOffset(T);
        }
        if (p.value && !e.disableVertical) {
          const T = Math.round(
            o.value.scrollTop / ((K = (E = r.value) == null ? void 0 : E.ratio) != null ? K : 1)
          );
          (q = s.value) == null || q.setOffset(T);
        }
      }
      t("scroll", j);
    }, g = (j) => {
      var I, L;
      o.value && o.value.scrollTo({
        left: j * ((L = (I = i.value) == null ? void 0 : I.ratio) != null ? L : 1)
      });
    }, C = (j) => {
      var I, L;
      o.value && o.value.scrollTo({
        top: j * ((L = (I = r.value) == null ? void 0 : I.ratio) != null ? L : 1)
      });
    }, P = a(() => {
      const j = {};
      return e.type === "track" && (d.value && (j.paddingBottom = `${Uo}px`), p.value && (j.paddingRight = `${Uo}px`)), [j, e.outerStyle];
    }), z = a(() => [
      `${n}`,
      `${n}-type-${e.type}`,
      {
        [`${n}-both`]: h.value
      },
      e.outerClass
    ]);
    return {
      prefixCls: n,
      cls: z,
      style: P,
      containerRef: o,
      horizontalThumbRef: l,
      verticalThumbRef: s,
      horizontalData: i,
      verticalData: r,
      isBoth: h,
      hasHorizontalScrollbar: d,
      hasVerticalScrollbar: p,
      handleResize: y,
      handleScroll: w,
      handleHorizontalScroll: g,
      handleVerticalScroll: C
    };
  },
  methods: {
    scrollTo(e, t) {
      var n, o;
      Qe(e) ? (n = this.$refs.containerRef) == null || n.scrollTo(e) : (e || t) && ((o = this.$refs.containerRef) == null || o.scrollTo(
        e,
        t
      ));
    },
    scrollTop(e) {
      var t;
      (t = this.$refs.containerRef) == null || t.scrollTo({
        top: e
      });
    },
    scrollLeft(e) {
      var t;
      (t = this.$refs.containerRef) == null || t.scrollTo({
        left: e
      });
    }
  }
});
function jy(e, t, n, o, i, r) {
  const l = J("ResizeObserver"), s = J("thumb");
  return v(), b("div", {
    class: m(e.cls),
    style: F(e.style)
  }, [
    c(l, { onResize: e.handleResize }, {
      default: ue(() => [
        $("div", se({
          ref: "containerRef",
          class: `${e.prefixCls}-container`
        }, e.$attrs, {
          onScroll: t[0] || (t[0] = (...u) => e.handleScroll && e.handleScroll(...u))
        }), [
          c(l, { onResize: e.handleResize }, {
            default: ue(() => [
              _(e.$slots, "default")
            ]),
            _: 3
          }, 8, ["onResize"])
        ], 16)
      ]),
      _: 3
    }, 8, ["onResize"]),
    !e.hide && e.hasHorizontalScrollbar ? (v(), oe(s, {
      key: 0,
      ref: "horizontalThumbRef",
      data: e.horizontalData,
      direction: "horizontal",
      both: e.isBoth,
      onScroll: e.handleHorizontalScroll
    }, null, 8, ["data", "both", "onScroll"])) : te("v-if", !0),
    !e.hide && e.hasVerticalScrollbar ? (v(), oe(s, {
      key: 1,
      ref: "verticalThumbRef",
      data: e.verticalData,
      direction: "vertical",
      both: e.isBoth,
      onScroll: e.handleVerticalScroll
    }, null, 8, ["data", "both", "onScroll"])) : te("v-if", !0)
  ], 6);
}
var ja = /* @__PURE__ */ N(Ly, [["render", jy]]);
const In = Object.assign(ja, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ja.name, ja);
  }
}), Wl = (e) => {
  const t = V(), n = () => Zp(t.value) ? t.value.$refs[e] : t.value, o = V();
  return Je(() => {
    o.value = n();
  }), ze([t], () => {
    o.value = n();
  }), {
    componentRef: t,
    elementRef: o
  };
}, Br = (e) => {
  const t = a(() => !!e.value), n = a(() => {
    if (e.value)
      return {
        type: "embed",
        ...Xt(e.value) ? void 0 : e.value
      };
  });
  return {
    displayScrollbar: t,
    scrollbarProps: n
  };
}, Py = S({
  name: "SelectDropdown",
  components: {
    ScrollbarComponent: In,
    Empty: Gn,
    Spin: Pn
  },
  props: {
    loading: Boolean,
    empty: Boolean,
    virtualList: Boolean,
    bottomOffset: {
      type: Number,
      default: 0
    },
    scrollbar: {
      type: [Boolean, Object],
      default: !0
    },
    onScroll: {
      type: [Function, Array]
    },
    onReachBottom: {
      type: [Function, Array]
    },
    showHeaderOnEmpty: {
      type: Boolean,
      default: !1
    },
    showFooterOnEmpty: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["scroll", "reachBottom"],
  setup(e, { emit: t, slots: n }) {
    var o, i, r;
    const { scrollbar: l } = ve(e), s = B("select-dropdown"), u = Ge(Kt, void 0), f = (r = (i = u == null ? void 0 : (o = u.slots).empty) == null ? void 0 : i.call(o, { component: "select" })) == null ? void 0 : r[0], { componentRef: d, elementRef: p } = Wl("containerRef"), { displayScrollbar: h, scrollbarProps: k } = Br(l), y = (g) => {
      const { scrollTop: C, scrollHeight: P, offsetHeight: z } = g.target;
      P - (C + z) <= e.bottomOffset && t("reachBottom", g), t("scroll", g);
    }, w = a(() => [
      s,
      {
        [`${s}-has-header`]: !!n.header,
        [`${s}-has-footer`]: !!n.footer
      }
    ]);
    return {
      prefixCls: s,
      SelectEmpty: f,
      cls: w,
      wrapperRef: p,
      wrapperComRef: d,
      handleScroll: y,
      displayScrollbar: h,
      scrollbarProps: k
    };
  }
});
function Iy(e, t, n, o, i, r) {
  const l = J("spin");
  return v(), b("div", {
    class: m(e.cls)
  }, [
    e.$slots.header && (!e.empty || e.showHeaderOnEmpty) ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-header`)
    }, [
      _(e.$slots, "header")
    ], 2)) : te("v-if", !0),
    e.loading ? (v(), oe(l, {
      key: 1,
      class: m(`${e.prefixCls}-loading`)
    }, null, 8, ["class"])) : e.empty ? (v(), b("div", {
      key: 2,
      class: m(`${e.prefixCls}-empty`)
    }, [
      _(e.$slots, "empty", {}, () => [
        (v(), oe(sn(e.SelectEmpty ? e.SelectEmpty : "Empty")))
      ])
    ], 2)) : te("v-if", !0),
    e.virtualList && !e.loading && !e.empty ? _(e.$slots, "virtual-list", { key: 3 }) : te("v-if", !0),
    e.virtualList ? te("v-if", !0) : hn((v(), oe(sn(e.displayScrollbar ? "ScrollbarComponent" : "div"), se({
      key: 4,
      ref: "wrapperComRef",
      class: `${e.prefixCls}-list-wrapper`
    }, e.scrollbarProps, { onScroll: e.handleScroll }), {
      default: ue(() => [
        $("ul", {
          class: m(`${e.prefixCls}-list`)
        }, [
          _(e.$slots, "default")
        ], 2)
      ]),
      _: 3
    }, 16, ["class", "onScroll"])), [
      [kn, !e.loading && !e.empty]
    ]),
    e.$slots.footer && (!e.empty || e.showFooterOnEmpty) ? (v(), b("div", {
      key: 5,
      class: m(`${e.prefixCls}-footer`)
    }, [
      _(e.$slots, "footer")
    ], 2)) : te("v-if", !0)
  ], 2);
}
var Ov = /* @__PURE__ */ N(Py, [["render", Iy]]), H0 = S({
  name: "IconCheck",
  render() {
    return c("svg", {
      "aria-hidden": "true",
      focusable: "false",
      viewBox: "0 0 1024 1024",
      width: "200",
      height: "200",
      fill: "currentColor"
    }, [c("path", {
      d: "M877.44815445 206.10060629a64.72691371 64.72691371 0 0 0-95.14856334 4.01306852L380.73381888 685.46812814 235.22771741 533.48933518a64.72691371 64.72691371 0 0 0-92.43003222-1.03563036l-45.82665557 45.82665443a64.72691371 64.72691371 0 0 0-0.90617629 90.61767965l239.61903446 250.10479331a64.72691371 64.72691371 0 0 0 71.19960405 15.14609778 64.33855261 64.33855261 0 0 0 35.08198741-21.23042702l36.24707186-42.71976334 40.5190474-40.77795556-3.36579926-3.49525333 411.40426297-486.74638962a64.72691371 64.72691371 0 0 0-3.88361443-87.64024149l-45.3088404-45.43829334z",
      "p-id": "840"
    }, null)]);
  }
});
const mm = Symbol("ArcoCheckboxGroup");
var ri = S({
  name: "Checkbox",
  components: {
    IconCheck: H0,
    IconHover: pt
  },
  props: {
    modelValue: {
      type: [Boolean, Array],
      default: void 0
    },
    defaultChecked: {
      type: Boolean,
      default: !1
    },
    value: {
      type: [String, Number, Boolean]
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    indeterminate: {
      type: Boolean,
      default: !1
    },
    uninjectGroupContext: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e, t) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      disabled: o,
      modelValue: i
    } = ve(e), r = B("checkbox"), l = V(), s = e.uninjectGroupContext ? void 0 : Ge(mm, void 0), u = (s == null ? void 0 : s.name) === "ArcoCheckboxGroup", {
      mergedDisabled: f,
      eventHandlers: d
    } = mt({
      disabled: o
    }), p = V(e.defaultChecked), h = a(() => {
      var j;
      return u ? s == null ? void 0 : s.computedValue : (j = e.modelValue) != null ? j : p.value;
    }), k = a(() => {
      var j;
      return He(h.value) ? h.value.includes((j = e.value) != null ? j : !0) : h.value;
    }), y = a(() => (s == null ? void 0 : s.disabled) || (f == null ? void 0 : f.value) || !k.value && (s == null ? void 0 : s.isMaxed)), w = (j) => {
      j.stopPropagation();
    }, g = (j) => {
      var I, L, M, E;
      const {
        checked: K
      } = j.target;
      let q = K;
      if (He(h.value)) {
        const T = new Set(h.value);
        K ? T.add((I = e.value) != null ? I : !0) : T.delete((L = e.value) != null ? L : !0), q = Array.from(T);
      }
      p.value = K, u && He(q) ? s == null || s.handleChange(q, j) : (t("update:modelValue", q), t("change", q, j), (E = (M = d.value) == null ? void 0 : M.onChange) == null || E.call(M, j)), at(() => {
        l.value && l.value.checked !== k.value && (l.value.checked = k.value);
      });
    }, C = a(() => [r, {
      [`${r}-checked`]: k.value,
      [`${r}-indeterminate`]: e.indeterminate,
      [`${r}-disabled`]: y.value
    }]), P = (j) => {
      var I, L;
      (L = (I = d.value) == null ? void 0 : I.onFocus) == null || L.call(I, j);
    }, z = (j) => {
      var I, L;
      (L = (I = d.value) == null ? void 0 : I.onBlur) == null || L.call(I, j);
    };
    return ze(i, (j) => {
      (Ve(j) || Jt(j)) && (p.value = !1);
    }), ze(h, (j) => {
      var I;
      let L;
      He(j) ? L = j.includes((I = e.value) != null ? I : !0) : L = j, p.value !== L && (p.value = L), l.value && l.value.checked !== L && (l.value.checked = L);
    }), () => {
      var j, I, L, M;
      return c("label", {
        "aria-disabled": y.value,
        class: C.value
      }, [c("input", {
        ref: l,
        type: "checkbox",
        checked: k.value,
        value: e.value,
        class: `${r}-target`,
        disabled: y.value,
        onClick: w,
        onChange: g,
        onFocus: P,
        onBlur: z
      }, null), (M = (L = (I = n.checkbox) != null ? I : (j = s == null ? void 0 : s.slots) == null ? void 0 : j.checkbox) == null ? void 0 : L({
        checked: k.value,
        disabled: y.value
      })) != null ? M : c(pt, {
        class: `${r}-icon-hover`,
        disabled: y.value || k.value
      }, {
        default: () => [c("div", {
          class: `${r}-icon`
        }, [k.value && c(H0, {
          class: `${r}-icon-check`
        }, null)])]
      }), n.default && c("span", {
        class: `${r}-label`
      }, [n.default()])]);
    };
  }
}), ai = S({
  name: "CheckboxGroup",
  props: {
    modelValue: {
      type: Array,
      default: void 0
    },
    defaultValue: {
      type: Array,
      default: () => []
    },
    max: {
      type: Number
    },
    options: {
      type: Array
    },
    direction: {
      type: String,
      default: "horizontal"
    },
    disabled: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e, t) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      disabled: o
    } = ve(e), i = B("checkbox-group"), {
      mergedDisabled: r,
      eventHandlers: l
    } = mt({
      disabled: o
    }), s = V(e.defaultValue), u = a(() => He(e.modelValue) ? e.modelValue : s.value), f = a(() => e.max === void 0 ? !1 : u.value.length >= e.max), d = a(() => {
      var y;
      return ((y = e.options) != null ? y : []).map((w) => zt(w) || A(w) ? {
        label: w,
        value: w
      } : w);
    });
    it(mm, me({
      name: "ArcoCheckboxGroup",
      computedValue: u,
      disabled: r,
      isMaxed: f,
      slots: n,
      handleChange: (y, w) => {
        var g, C;
        s.value = y, t("update:modelValue", y), t("change", y, w), (C = (g = l.value) == null ? void 0 : g.onChange) == null || C.call(g, w);
      }
    }));
    const h = a(() => [i, `${i}-direction-${e.direction}`]);
    ze(() => e.modelValue, (y) => {
      He(y) ? s.value = [...y] : s.value = [];
    });
    const k = () => d.value.map((y) => {
      const w = u.value.includes(y.value);
      return c(ri, {
        key: y.value,
        value: y.value,
        disabled: y.disabled || !w && f.value,
        indeterminate: y.indeterminate,
        modelValue: w
      }, {
        default: () => [n.label ? n.label({
          data: y
        }) : Ne(y.label) ? y.label() : y.label]
      });
    });
    return () => {
      var y;
      return c("span", {
        class: h.value
      }, [d.value.length > 0 ? k() : (y = n.default) == null ? void 0 : y.call(n)]);
    };
  }
});
const Ln = Object.assign(ri, {
  Group: ai,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ri.name, ri), e.component(n + ai.name, ai);
  }
}), hm = Symbol("ArcoSelectContext"), By = (e) => Qe(e) && "isGroup" in e, km = (e) => Qe(e) && "isGroup" in e, My = (e, t = "value") => String(Qe(e) ? e[t] : e), Sl = (e, t = "value") => Qe(e) ? `__arco__option__object__${e[t]}` : e || A(e) || zt(e) || Xt(e) ? `__arco__option__${typeof e}-${e}` : "", Ny = (e) => e.has("__arco__option__string-"), Oy = (e, {
  valueKey: t,
  fieldNames: n,
  origin: o,
  index: i = -1
}) => {
  var r;
  if (Qe(e)) {
    const s = e[n.value];
    return {
      raw: e,
      index: i,
      key: Sl(s, t),
      origin: o,
      value: s,
      label: (r = e[n.label]) != null ? r : My(s, t),
      render: e[n.render],
      disabled: !!e[n.disabled],
      tagProps: e[n.tagProps]
    };
  }
  const l = {
    value: e,
    label: String(e),
    disabled: !1
  };
  return {
    raw: l,
    index: i,
    key: Sl(e, t),
    origin: o,
    ...l
  };
}, ev = (e, {
  valueKey: t,
  fieldNames: n,
  origin: o,
  optionInfoMap: i
}) => {
  var r;
  const l = [];
  for (const s of e)
    if (By(s)) {
      const u = ev((r = s.options) != null ? r : [], {
        valueKey: t,
        fieldNames: n,
        origin: o,
        optionInfoMap: i
      });
      u.length > 0 && l.push({
        ...s,
        key: `__arco__group__${s.label}`,
        options: u
      });
    } else {
      const u = Oy(s, {
        valueKey: t,
        fieldNames: n,
        origin: o
      });
      l.push(u), i.get(u.key) || i.set(u.key, u);
    }
  return l;
}, q0 = (e, {
  inputValue: t,
  filterOption: n
}) => {
  const o = (i) => {
    var r;
    const l = [];
    for (const s of i)
      if (km(s)) {
        const u = o((r = s.options) != null ? r : []);
        u.length > 0 && l.push({ ...s, options: u });
      } else Mr(s, { inputValue: t, filterOption: n }) && l.push(s);
    return l;
  };
  return o(e);
}, Mr = (e, {
  inputValue: t,
  filterOption: n
}) => Ne(n) ? !t || n(t, e.raw) : n ? e.label.toLowerCase().includes((t ?? "").toLowerCase()) : !0, Vy = (e, t) => {
  if (!e || !t || e.length !== t.length)
    return !1;
  for (const n of Object.keys(e))
    if (!_l(e[n], t[n]))
      return !1;
  return !0;
}, Ty = (e, t) => {
  if (!e || !t)
    return !1;
  const { length: n } = e;
  if (n !== t.length)
    return !1;
  for (let o = 0; o < n; o++)
    if (!_l(e[o], t[o]))
      return !1;
  return !0;
}, _l = (e, t) => {
  const n = Object.prototype.toString.call(e);
  return n !== Object.prototype.toString.call(t) ? !1 : n === "[object Object]" ? Vy(
    e,
    t
  ) : n === "[object Array]" ? Ty(e, t) : n === "[object Function]" ? e === t ? !0 : e.toString() === t.toString() : e === t;
}, Ay = S({
  name: "Option",
  components: {
    Checkbox: Ln
  },
  props: {
    value: {
      type: [String, Number, Boolean, Object],
      default: void 0
    },
    label: String,
    disabled: Boolean,
    tagProps: {
      type: Object
    },
    extra: {
      type: Object
    },
    index: {
      type: Number
    },
    internal: Boolean
  },
  setup(e) {
    const { disabled: t, tagProps: n, index: o } = ve(e), i = B("select-option"), r = Ge(hm, void 0), l = dn(), s = V(), u = V(n.value);
    ze(n, (L, M) => {
      _l(L, M) || (u.value = L);
    });
    const f = V(""), d = a(
      () => {
        var L, M;
        return (M = (L = e.value) != null ? L : e.label) != null ? M : f.value;
      }
    ), p = a(() => {
      var L;
      return (L = e.label) != null ? L : f.value;
    }), h = a(
      () => Sl(d.value, r == null ? void 0 : r.valueKey)
    ), k = a(() => {
      var L;
      return (L = r == null ? void 0 : r.component) != null ? L : "li";
    }), y = () => {
      var L;
      if (!e.label && s.value) {
        const M = (L = s.value.textContent) != null ? L : "";
        f.value !== M && (f.value = M);
      }
    };
    Je(() => y()), fn(() => y());
    const w = a(
      () => {
        var L;
        return (L = r == null ? void 0 : r.valueKeys.includes(h.value)) != null ? L : !1;
      }
    ), g = a(
      () => (r == null ? void 0 : r.activeKey) === h.value
    );
    let C = V(!0);
    if (!e.internal) {
      const L = me({
        raw: {
          value: d,
          label: p,
          disabled: t,
          tagProps: u
        },
        ref: s,
        index: o,
        key: h,
        origin: "slot",
        value: d,
        label: p,
        disabled: t,
        tagProps: u
      });
      C = a(
        () => Mr(L, {
          inputValue: r == null ? void 0 : r.inputValue,
          filterOption: r == null ? void 0 : r.filterOption
        })
      ), l && (r == null || r.addSlotOptionInfo(l.uid, L)), _t(() => {
        l && (r == null || r.removeSlotOptionInfo(l.uid));
      });
    }
    const P = (L) => {
      e.disabled || r == null || r.onSelect(h.value, L);
    }, z = () => {
      e.disabled || r == null || r.setActiveKey(h.value);
    }, j = () => {
      e.disabled || r == null || r.setActiveKey();
    }, I = a(() => [
      i,
      {
        [`${i}-disabled`]: e.disabled,
        [`${i}-selected`]: w.value,
        [`${i}-active`]: g.value,
        [`${i}-multiple`]: r == null ? void 0 : r.multiple
      }
    ]);
    return {
      prefixCls: i,
      cls: I,
      selectCtx: r,
      itemRef: s,
      component: k,
      isSelected: w,
      isValid: C,
      handleClick: P,
      handleMouseEnter: z,
      handleMouseLeave: j
    };
  }
});
function Ey(e, t, n, o, i, r) {
  const l = J("checkbox");
  return hn((v(), oe(sn(e.component), {
    ref: "itemRef",
    class: m([e.cls, { [`${e.prefixCls}-has-suffix`]: !!e.$slots.suffix }]),
    onClick: e.handleClick,
    onMouseenter: e.handleMouseEnter,
    onMouseleave: e.handleMouseLeave
  }, {
    default: ue(() => [
      e.$slots.icon ? (v(), b("span", {
        key: 0,
        class: m(`${e.prefixCls}-icon`)
      }, [
        _(e.$slots, "icon")
      ], 2)) : te("v-if", !0),
      e.selectCtx && e.selectCtx.multiple ? (v(), oe(l, {
        key: 1,
        class: m(`${e.prefixCls}-checkbox`),
        "model-value": e.isSelected,
        disabled: e.disabled,
        "uninject-group-context": ""
      }, {
        default: ue(() => [
          _(e.$slots, "default", {}, () => [
            Re(Pe(e.label), 1)
          ])
        ]),
        _: 3
      }, 8, ["class", "model-value", "disabled"])) : (v(), b("span", {
        key: 2,
        class: m(`${e.prefixCls}-content`)
      }, [
        _(e.$slots, "default", {}, () => [
          Re(Pe(e.label), 1)
        ])
      ], 2)),
      e.$slots.suffix ? (v(), b("span", {
        key: 3,
        class: m(`${e.prefixCls}-suffix`)
      }, [
        _(e.$slots, "suffix")
      ], 2)) : te("v-if", !0)
    ]),
    _: 3
  }, 40, ["class", "onClick", "onMouseenter", "onMouseleave"])), [
    [kn, e.isValid]
  ]);
}
var kl = /* @__PURE__ */ N(Ay, [["render", Ey]]);
const Wy = {
  value: "value",
  label: "label",
  disabled: "disabled",
  tagProps: "tagProps",
  render: "render"
}, Fy = ({
  options: e,
  extraOptions: t,
  inputValue: n,
  filterOption: o,
  showExtraOptions: i,
  valueKey: r,
  fieldNames: l
}) => {
  const s = a(() => ({
    ...Wy,
    ...l == null ? void 0 : l.value
  })), u = me(/* @__PURE__ */ new Map()), f = a(
    () => Array.from(u.values()).sort((z, j) => A(z.index) && A(j.index) ? z.index - j.index : 0)
  ), d = a(() => {
    var z, j;
    const I = /* @__PURE__ */ new Map();
    return {
      optionInfos: ev((z = e == null ? void 0 : e.value) != null ? z : [], {
        valueKey: (j = r == null ? void 0 : r.value) != null ? j : "value",
        fieldNames: s.value,
        origin: "options",
        optionInfoMap: I
      }),
      optionInfoMap: I
    };
  }), p = a(() => {
    var z, j;
    const I = /* @__PURE__ */ new Map();
    return {
      optionInfos: ev((z = t == null ? void 0 : t.value) != null ? z : [], {
        valueKey: (j = r == null ? void 0 : r.value) != null ? j : "value",
        fieldNames: s.value,
        origin: "extraOptions",
        optionInfoMap: I
      }),
      optionInfoMap: I
    };
  }), h = me(/* @__PURE__ */ new Map());
  ze(
    [
      f,
      e ?? V([]),
      t ?? V([]),
      r ?? V("value")
    ],
    () => {
      h.clear(), f.value.forEach((z, j) => {
        h.set(z.key, { ...z, index: j });
      }), d.value.optionInfoMap.forEach((z) => {
        h.has(z.key) || (z.index = h.size, h.set(z.key, z));
      }), p.value.optionInfoMap.forEach((z) => {
        h.has(z.key) || (z.index = h.size, h.set(z.key, z));
      });
    },
    { immediate: !0, deep: !0 }
  );
  const k = a(() => {
    var z;
    const j = q0(d.value.optionInfos, {
      inputValue: n == null ? void 0 : n.value,
      filterOption: o == null ? void 0 : o.value
    });
    return ((z = i == null ? void 0 : i.value) == null || z) && j.push(
      ...q0(p.value.optionInfos, {
        inputValue: n == null ? void 0 : n.value,
        filterOption: o == null ? void 0 : o.value
      })
    ), j;
  }), y = a(
    () => Array.from(h.values()).filter((z) => z.origin === "extraOptions" && (i == null ? void 0 : i.value) === !1 ? !1 : Mr(z, {
      inputValue: n == null ? void 0 : n.value,
      filterOption: o == null ? void 0 : o.value
    }))
  ), w = a(
    () => y.value.filter((z) => !z.disabled).map((z) => z.key)
  );
  return {
    validOptions: k,
    optionInfoMap: h,
    validOptionInfos: y,
    enabledOptionKeys: w,
    getNextSlotOptionIndex: () => u.size,
    addSlotOptionInfo: (z, j) => {
      u.set(z, j);
    },
    removeSlotOptionInfo: (z) => {
      u.delete(z);
    }
  };
}, yt = {
  ENTER: "Enter",
  ESC: "Escape",
  SPACE: " ",
  ARROW_UP: "ArrowUp",
  ARROW_DOWN: "ArrowDown",
  ARROW_LEFT: "ArrowLeft",
  ARROW_RIGHT: "ArrowRight"
}, Z0 = (e) => JSON.stringify({
  key: e.key,
  ctrl: !!e.ctrl,
  shift: !!e.shift,
  alt: !!e.alt,
  meta: !!e.meta
}), Nr = (e) => {
  const t = {};
  return e.forEach((n, o) => {
    const i = zt(o) ? { key: o } : o;
    t[Z0(i)] = n;
  }), (n) => {
    const o = Z0({
      key: n.key,
      ctrl: n.ctrlKey,
      shift: n.shiftKey,
      alt: n.altKey,
      meta: n.metaKey
    }), i = t[o];
    i && (n.stopPropagation(), i(n));
  };
}, Vv = ({
  multiple: e,
  options: t,
  extraOptions: n,
  inputValue: o,
  filterOption: i,
  showExtraOptions: r,
  component: l,
  valueKey: s,
  fieldNames: u,
  loading: f,
  popupVisible: d,
  valueKeys: p,
  dropdownRef: h,
  optionRefs: k,
  virtualListRef: y,
  onSelect: w,
  onPopupVisibleChange: g,
  enterToOpen: C = !0,
  defaultActiveFirstOption: P
}) => {
  const {
    validOptions: z,
    optionInfoMap: j,
    validOptionInfos: I,
    enabledOptionKeys: L,
    getNextSlotOptionIndex: M,
    addSlotOptionInfo: E,
    removeSlotOptionInfo: K
  } = Fy({
    options: t,
    extraOptions: n,
    inputValue: o,
    filterOption: i,
    showExtraOptions: r,
    valueKey: s,
    fieldNames: u
  }), q = V();
  ze(L, (U) => {
    (!q.value || !U.includes(q.value)) && (q.value = U[0]);
  });
  const T = (U) => {
    q.value = U;
  }, X = (U) => {
    const H = L.value.length;
    if (H === 0)
      return;
    if (!q.value)
      return U === "down" ? L.value[0] : L.value[H - 1];
    const D = L.value.indexOf(q.value), R = (H + D + (U === "up" ? -1 : 1)) % H;
    return L.value[R];
  }, Y = (U) => {
    var H, D;
    y != null && y.value && y.value.scrollTo({ key: U });
    const R = j.get(U), W = (H = h == null ? void 0 : h.value) == null ? void 0 : H.wrapperRef, O = (D = k == null ? void 0 : k.value[U]) != null ? D : R == null ? void 0 : R.ref;
    if (!W || !O || W.scrollHeight === W.offsetHeight)
      return;
    const x = Vk(O, W), G = W.scrollTop;
    x.top < 0 ? W.scrollTo(0, G + x.top) : x.bottom < 0 && W.scrollTo(0, G - x.bottom);
  };
  ze(d, (U) => {
    var H;
    if (U) {
      const D = p.value[p.value.length - 1];
      let R = (H = P == null ? void 0 : P.value) == null || H ? L.value[0] : void 0;
      L.value.includes(D) && (R = D), R !== q.value && (q.value = R), at(() => {
        q.value && Y(q.value);
      });
    }
  });
  const Z = Nr(
    /* @__PURE__ */ new Map([
      [
        yt.ENTER,
        (U) => {
          !(f != null && f.value) && !U.isComposing && (d.value ? q.value && (w(q.value, U), U.preventDefault()) : C && (g(!0), U.preventDefault()));
        }
      ],
      [
        yt.ESC,
        (U) => {
          d.value && (g(!1), U.preventDefault());
        }
      ],
      [
        yt.ARROW_DOWN,
        (U) => {
          if (d.value) {
            const H = X("down");
            H && (q.value = H, Y(H)), U.preventDefault();
          }
        }
      ],
      [
        yt.ARROW_UP,
        (U) => {
          if (d.value) {
            const H = X("up");
            H && (q.value = H, Y(H)), U.preventDefault();
          }
        }
      ]
    ])
  );
  return it(
    hm,
    me({
      multiple: e,
      valueKey: s,
      inputValue: o,
      filterOption: i,
      component: l,
      valueKeys: p,
      activeKey: q,
      setActiveKey: T,
      onSelect: w,
      getNextSlotOptionIndex: M,
      addSlotOptionInfo: E,
      removeSlotOptionInfo: K
    })
  ), {
    validOptions: z,
    optionInfoMap: j,
    validOptionInfos: I,
    enabledOptionKeys: L,
    activeKey: q,
    setActiveKey: T,
    addSlotOptionInfo: E,
    removeSlotOptionInfo: K,
    getNextActiveKey: X,
    scrollIntoView: Y,
    handleKeyDown: Z
  };
}, Dy = ({
  dataKeys: e,
  contentRef: t,
  fixedSize: n,
  estimatedSize: o,
  buffer: i
}) => {
  const r = V(0), l = /* @__PURE__ */ new Map(), s = a(() => e.value.length), u = V(0), f = a(() => {
    const M = u.value + i.value * 3;
    return M > s.value ? s.value : M;
  }), d = a(() => {
    const M = s.value - i.value * 3;
    return M < 0 ? 0 : M;
  }), p = (M) => {
    M < 0 ? u.value = 0 : M > d.value ? u.value = d.value : u.value = M;
  }, h = V(n.value), k = a(() => o.value !== 30 ? o.value : r.value || o.value), y = (M, E) => {
    l.set(M, E);
  }, w = (M) => {
    var E;
    if (h.value)
      return k.value;
    const K = e.value[M];
    return (E = l.get(K)) != null ? E : k.value;
  }, g = (M) => l.has(M);
  Je(() => {
    const M = Array.from(l.values()).reduce(
      (E, K) => E + K,
      0
    );
    M > 0 && (r.value = M / l.size);
  });
  const C = (M) => h.value ? k.value * M : P(0, M), P = (M, E) => {
    let K = 0;
    for (let q = M; q < E; q++)
      K += w(q);
    return K;
  }, z = a(() => h.value ? k.value * u.value : P(0, u.value)), j = (M) => {
    const E = M >= z.value;
    let K = Math.abs(M - z.value);
    const q = E ? u.value : u.value - 1;
    let T = 0;
    for (; K > 0; )
      K -= w(q + T), E ? T++ : T--;
    return T;
  }, I = (M) => {
    const E = j(M), K = u.value + E - i.value;
    return K < 0 ? 0 : K > d.value ? d.value : K;
  }, L = a(() => h.value ? k.value * (s.value - f.value) : P(f.value, s.value));
  return {
    frontPadding: z,
    behindPadding: L,
    start: u,
    end: f,
    getStartByScroll: I,
    setItemSize: y,
    hasItemSize: g,
    setStart: p,
    getScrollOffset: C
  };
};
var xy = S({
  name: "VirtualListItem",
  props: {
    hasItemSize: {
      type: Function,
      required: !0
    },
    setItemSize: {
      type: Function,
      required: !0
    }
  },
  setup(e, {
    slots: t
  }) {
    var n;
    const o = (n = dn()) == null ? void 0 : n.vnode.key, i = V(), r = () => {
      var l, s, u, f;
      const d = (s = (l = i.value) == null ? void 0 : l.$el) != null ? s : i.value, p = (f = (u = d == null ? void 0 : d.getBoundingClientRect) == null ? void 0 : u.call(d).height) != null ? f : d == null ? void 0 : d.offsetHeight;
      p && e.setItemSize(o, p);
    };
    return Je(() => r()), _t(() => r()), () => {
      var l;
      const s = Fl((l = t.default) == null ? void 0 : l.call(t));
      return s ? Kl(s, {
        ref: i
      }, !0) : null;
    };
  }
});
const Ry = S({
  name: "VirtualList",
  components: { VirtualListItem: xy },
  props: {
    height: {
      type: [Number, String],
      default: 200
    },
    data: {
      type: Array,
      default: () => []
    },
    threshold: {
      type: Number,
      default: 0
    },
    itemKey: {
      type: String,
      default: "key"
    },
    fixedSize: {
      type: Boolean,
      default: !1
    },
    estimatedSize: {
      type: Number,
      default: 30
    },
    buffer: {
      type: Number,
      default: 10
    },
    component: {
      type: [String, Object],
      default: "div"
    },
    listAttrs: {
      type: Object
    },
    contentAttrs: {
      type: Object
    },
    paddingPosition: {
      type: String,
      default: "content"
    }
  },
  emits: {
    scroll: (e) => !0,
    reachBottom: (e) => !0
  },
  setup(e, { emit: t }) {
    const { data: n, itemKey: o, fixedSize: i, estimatedSize: r, buffer: l, height: s } = ve(e), u = B("virtual-list"), f = a(() => Qe(e.component) ? {
      container: "div",
      list: "div",
      content: "div",
      ...e.component
    } : {
      container: e.component,
      list: "div",
      content: "div"
    }), d = V(), p = V(), h = a(() => ({
      height: A(s.value) ? `${s.value}px` : s.value,
      overflow: "auto"
    })), k = a(
      () => n.value.map((q, T) => {
        var X;
        return (X = q[o.value]) != null ? X : T;
      })
    ), {
      frontPadding: y,
      behindPadding: w,
      start: g,
      end: C,
      getStartByScroll: P,
      setItemSize: z,
      hasItemSize: j,
      setStart: I,
      getScrollOffset: L
    } = Dy({
      dataKeys: k,
      contentRef: p,
      fixedSize: i,
      estimatedSize: r,
      buffer: l
    }), M = a(() => e.threshold && n.value.length <= e.threshold ? n.value : n.value.slice(g.value, C.value)), E = (q) => {
      const { scrollTop: T, scrollHeight: X, offsetHeight: Y } = q.target, Z = P(T);
      Z !== g.value && (I(Z), at(() => {
        K(T);
      })), t("scroll", q), Math.floor(X - (T + Y)) <= 0 && t("reachBottom", q);
    }, K = (q) => {
      var T, X;
      if (d.value)
        if (A(q))
          d.value.scrollTop = q;
        else {
          const Y = (X = q.index) != null ? X : k.value.indexOf((T = q.key) != null ? T : "");
          I(Y - l.value), d.value.scrollTop = L(Y), at(() => {
            if (d.value) {
              const Z = L(Y);
              Z !== d.value.scrollTop && (d.value.scrollTop = Z);
            }
          });
        }
    };
    return {
      prefixCls: u,
      containerRef: d,
      contentRef: p,
      frontPadding: y,
      currentList: M,
      behindPadding: w,
      onScroll: E,
      setItemSize: z,
      hasItemSize: j,
      start: g,
      scrollTo: K,
      style: h,
      mergedComponent: f
    };
  }
});
function Hy(e, t, n, o, i, r) {
  const l = J("VirtualListItem");
  return v(), oe(sn(e.mergedComponent.container), {
    ref: "containerRef",
    class: m(e.prefixCls),
    style: F(e.style),
    onScroll: e.onScroll
  }, {
    default: ue(() => [
      (v(), oe(sn(e.mergedComponent.list), se(e.listAttrs, {
        style: e.paddingPosition === "list" ? {
          paddingTop: `${e.frontPadding}px`,
          paddingBottom: `${e.behindPadding}px`
        } : {}
      }), {
        default: ue(() => [
          (v(), oe(sn(e.mergedComponent.content), se({ ref: "contentRef" }, e.contentAttrs, {
            style: e.paddingPosition === "content" ? {
              paddingTop: `${e.frontPadding}px`,
              paddingBottom: `${e.behindPadding}px`
            } : {}
          }), {
            default: ue(() => [
              (v(!0), b(Ae, null, St(e.currentList, (s, u) => {
                var f;
                return v(), oe(l, {
                  key: (f = s[e.itemKey]) != null ? f : e.start + u,
                  "has-item-size": e.hasItemSize,
                  "set-item-size": e.setItemSize
                }, {
                  default: ue(() => [
                    _(e.$slots, "item", {
                      item: s,
                      index: e.start + u
                    })
                  ]),
                  _: 2
                }, 1032, ["has-item-size", "set-item-size"]);
              }), 128))
            ]),
            _: 3
          }, 16, ["style"]))
        ]),
        _: 3
      }, 16, ["style"]))
    ]),
    _: 3
  }, 40, ["class", "style", "onScroll"]);
}
var Jl = /* @__PURE__ */ N(Ry, [["render", Hy]]), Pa = S({
  name: "AutoComplete",
  inheritAttrs: !1,
  props: {
    modelValue: {
      type: String,
      default: void 0
    },
    defaultValue: {
      type: String,
      default: ""
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    data: {
      type: Array,
      default: () => []
    },
    popupContainer: {
      type: [String, Object]
    },
    strict: {
      type: Boolean,
      default: !1
    },
    filterOption: {
      type: [Boolean, Function],
      default: !0
    },
    triggerProps: {
      type: Object
    },
    allowClear: {
      type: Boolean,
      default: !1
    },
    virtualListProps: {
      type: Object
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0,
    search: (e) => !0,
    select: (e) => !0,
    clear: (e) => !0,
    dropdownScroll: (e) => !0,
    dropdownReachBottom: (e) => !0
  },
  setup(e, {
    emit: t,
    attrs: n,
    slots: o
  }) {
    const {
      modelValue: i
    } = ve(e), r = B("auto-complete"), {
      mergedDisabled: l,
      eventHandlers: s
    } = mt({
      disabled: un(e, "disabled")
    }), u = V(e.defaultValue), f = V(), d = a(() => {
      var O;
      return (O = e.modelValue) != null ? O : u.value;
    });
    ze(i, (O) => {
      (Ve(O) || Jt(O)) && (u.value = "");
    });
    const p = a(() => d.value ? [Sl(d.value)] : []), {
      data: h
    } = ve(e), k = V(), y = V({}), w = V(!1), g = a(() => w.value && Z.value.length > 0), C = V(), P = a(() => e.virtualListProps ? "div" : "li"), z = (O) => {
      w.value = O;
    }, j = (O, x) => {
      var G;
      return !!((G = x.label) != null && G.includes(O));
    }, I = a(() => Ne(e.filterOption) ? e.filterOption : e.filterOption && e.strict ? j : e.filterOption), L = (O) => {
      var x, G;
      u.value = O, t("update:modelValue", O), t("change", O), (G = (x = s.value) == null ? void 0 : x.onChange) == null || G.call(x);
    }, M = (O) => {
      var x, G;
      u.value = "", t("update:modelValue", ""), t("change", ""), (G = (x = s.value) == null ? void 0 : x.onChange) == null || G.call(x), t("clear", O);
    }, E = (O, x) => {
      var G, ne;
      const ee = (G = Y.get(O)) == null ? void 0 : G.value;
      t("select", ee), L(ee), (ne = f.value) == null || ne.blur();
    }, K = (O) => {
      t("search", O), L(O);
    }, q = (O) => {
      t("dropdownScroll", O);
    }, T = (O) => {
      t("dropdownReachBottom", O);
    }, {
      validOptions: X,
      optionInfoMap: Y,
      validOptionInfos: Z,
      handleKeyDown: U
    } = Vv({
      options: h,
      inputValue: d,
      filterOption: I,
      popupVisible: g,
      valueKeys: p,
      component: P,
      dropdownRef: k,
      optionRefs: y,
      onSelect: E,
      onPopupVisibleChange: z
    }), H = (O) => {
      if (Ne(o.option) && O.value) {
        const x = Y.get(O.key), G = o.option;
        return () => G({
          data: x
        });
      }
      return () => O.label;
    }, D = (O) => c(kl, {
      ref: (x) => {
        x != null && x.$el && (y.value[O.key] = x.$el);
      },
      key: O.key,
      value: O.value,
      disabled: O.disabled,
      internal: !0
    }, {
      default: H(O)
    }), R = () => c(Ov, {
      ref: k,
      class: `${r}-dropdown`,
      virtualList: !!e.virtualListProps,
      onScroll: q,
      onReachBottom: T
    }, {
      default: () => [...X.value.map((O) => D(O))],
      "virtual-list": () => c(Jl, se(e.virtualListProps, {
        ref: C,
        data: X.value
      }), {
        item: ({
          item: O
        }) => D(O)
      }),
      footer: o.footer
    });
    return {
      inputRef: f,
      render: () => c(Tt, se({
        trigger: "focus",
        position: "bl",
        animationName: "slide-dynamic-origin",
        autoFitTransformOrigin: !0,
        popupVisible: g.value,
        clickToClose: !1,
        preventFocus: !0,
        popupOffset: 4,
        disabled: l.value,
        autoFitPopupWidth: !0
      }, e.triggerProps, {
        onPopupVisibleChange: z
      }), {
        default: () => [c(cl, se({
          ref: f
        }, n, {
          allowClear: e.allowClear,
          modelValue: d.value,
          disabled: l.value,
          onInput: K,
          onClear: M,
          onKeydown: U
        }), o)],
        content: R
      })
    };
  },
  methods: {
    focus() {
      var e;
      (e = this.inputRef) == null || e.focus();
    },
    blur() {
      var e;
      (e = this.inputRef) == null || e.blur();
    }
  },
  render() {
    return this.render();
  }
});
const qy = Object.assign(Pa, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Pa.name, Pa);
  }
}), Tv = ({
  itemRef: e,
  selector: t,
  index: n,
  parentClassName: o
}) => {
  const i = V(-1), r = a(() => {
    var f;
    return (f = n == null ? void 0 : n.value) != null ? f : i.value;
  }), l = V(), s = () => {
    var f, d, p;
    let h = (d = (f = e.value) == null ? void 0 : f.parentElement) != null ? d : void 0;
    if (o)
      for (; h && !h.className.includes(o); )
        h = (p = h.parentElement) != null ? p : void 0;
    return h;
  }, u = () => {
    if (Ve(n == null ? void 0 : n.value) && l.value && e.value) {
      const f = Array.from(l.value.querySelectorAll(t)).indexOf(
        e.value
      );
      f !== i.value && (i.value = f);
    }
  };
  return ze(e, () => {
    e.value && !l.value && (l.value = s());
  }), Je(() => {
    e.value && (l.value = s()), u();
  }), fn(() => u()), {
    computedIndex: r
  };
}, gm = Symbol("ArcoAvatarGroup"), Zy = S({
  name: "IconImageClose",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-image-close`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Ky = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Yy(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    Cr('<path d="M41 26V9a2 2 0 0 0-2-2H9a2 2 0 0 0-2 2v30a2 2 0 0 0 2 2h17"></path><path d="m24 33 9-8.5V27s-2 1-3.5 2.5C27.841 31.159 27 33 27 33h-3Zm0 0-3.5-4.5L17 33h7Z"></path><path d="M20.5 28.5 17 33h7l-3.5-4.5ZM33 24.5 24 33h3s.841-1.841 2.5-3.5C31 28 33 27 33 27v-2.5Z" fill="currentColor" stroke="none"></path><path fill-rule="evenodd" clip-rule="evenodd" d="M46 38a8 8 0 1 1-16 0 8 8 0 0 1 16 0Zm-4.95-4.782 1.74 1.74-3.045 3.046 3.046 3.046-1.74 1.74-3.047-3.045-3.046 3.046-1.74-1.74 3.046-3.047-3.046-3.046 1.74-1.74 3.046 3.046 3.046-3.046Z" fill="currentColor" stroke="none"></path><path d="M17 15h-2v2h2v-2Z"></path>', 5)
  ]), 14, Ky);
}
var Ia = /* @__PURE__ */ N(Zy, [["render", Yy]]);
const Or = Object.assign(Ia, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ia.name, Ia);
  }
}), Uy = S({
  name: "Avatar",
  components: {
    ResizeObserver: al,
    IconImageClose: Or,
    IconLoading: Yt
  },
  props: {
    shape: {
      type: String,
      default: "circle"
    },
    imageUrl: String,
    size: Number,
    autoFixFontSize: {
      type: Boolean,
      default: !0
    },
    triggerType: {
      type: String,
      default: "button"
    },
    triggerIconStyle: {
      type: Object
    },
    objectFit: {
      type: String
    }
  },
  emits: {
    click: (e) => !0,
    error: () => !0,
    load: () => !0
  },
  setup(e, { slots: t, emit: n, attrs: o }) {
    const { shape: i, size: r, autoFixFontSize: l, triggerType: s, triggerIconStyle: u } = ve(e), f = B("avatar"), d = Ge(gm, void 0), p = V(), h = V(), k = a(() => {
      var Z;
      return (Z = d == null ? void 0 : d.shape) != null ? Z : i.value;
    }), y = a(() => {
      var Z;
      return (Z = d == null ? void 0 : d.size) != null ? Z : r.value;
    }), w = a(
      () => {
        var Z;
        return (Z = d == null ? void 0 : d.autoFixFontSize) != null ? Z : l.value;
      }
    ), g = V(!1), C = V(!1), P = V(!0), z = V(!1), j = d ? Tv({
      itemRef: p,
      selector: `.${f}`
    }).computedIndex : V(-1), I = a(() => {
      var Z;
      const U = A(y.value) ? {
        width: `${y.value}px`,
        height: `${y.value}px`,
        fontSize: `${y.value / 2}px`
      } : {};
      return d && (U.zIndex = d.zIndexAscend ? j.value + 1 : d.total - j.value, U.marginLeft = j.value !== 0 ? `-${((Z = y.value) != null ? Z : 40) / 4}px` : "0"), U;
    }), L = Gy({
      triggerIconStyle: u == null ? void 0 : u.value,
      inlineStyle: o.style,
      triggerType: s.value
    }), M = () => {
      !g.value && !e.imageUrl && at(() => {
        var Z;
        if (!h.value || !p.value)
          return;
        const U = h.value.clientWidth, H = (Z = y.value) != null ? Z : p.value.offsetWidth, D = H / (U + 8);
        H && D < 1 && (h.value.style.transform = `scale(${D}) translateX(-50%)`), P.value = !0;
      });
    };
    Je(() => {
      var Z;
      (Z = h.value) != null && Z.firstElementChild && ["IMG", "PICTURE"].includes(h.value.firstElementChild.tagName) && (g.value = !0), w.value && M();
    }), ze(r, () => {
      w.value && M();
    });
    const E = a(() => [
      f,
      `${f}-${k.value}`
    ]), K = a(
      () => g.value || e.imageUrl ? `${f}-image` : `${f}-text`
    );
    return {
      prefixCls: f,
      itemRef: p,
      cls: E,
      outerStyle: I,
      wrapperRef: h,
      wrapperCls: K,
      computedTriggerIconStyle: L,
      isImage: g,
      shouldLoad: P,
      isLoaded: z,
      hasError: C,
      onClick: (Z) => {
        n("click", Z);
      },
      handleResize: () => {
        w.value && M();
      },
      handleImgLoad: () => {
        z.value = !0, n("load");
      },
      handleImgError: () => {
        C.value = !0, n("error");
      }
    };
  }
}), Gy = ({
  triggerType: e,
  inlineStyle: t = {},
  triggerIconStyle: n = {}
}) => {
  let o = {};
  return e === "button" && (!n || n && !n.color) && t && t.backgroundColor && (o = { color: t.backgroundColor }), {
    ...n,
    ...o
  };
}, Xy = ["src"];
function Qy(e, t, n, o, i, r) {
  const l = J("IconImageClose"), s = J("IconLoading"), u = J("resize-observer");
  return v(), b("div", {
    ref: "itemRef",
    style: F(e.outerStyle),
    class: m([
      e.cls,
      {
        [`${e.prefixCls}-with-trigger-icon`]: !!e.$slots["trigger-icon"]
      }
    ]),
    onClick: t[2] || (t[2] = (...f) => e.onClick && e.onClick(...f))
  }, [
    c(u, { onResize: e.handleResize }, {
      default: ue(() => [
        $("span", {
          ref: "wrapperRef",
          class: m(e.wrapperCls)
        }, [
          e.imageUrl ? (v(), b(Ae, { key: 0 }, [
            e.hasError ? _(e.$slots, "error", { key: 0 }, () => [
              $("div", {
                class: m(`${e.prefixCls}-image-icon`)
              }, [
                c(l)
              ], 2)
            ]) : te("v-if", !0),
            !(e.hasError || !e.shouldLoad) && !e.isLoaded ? _(e.$slots, "default", { key: 1 }, () => [
              $("div", {
                class: m(`${e.prefixCls}-image-icon`)
              }, [
                c(s)
              ], 2)
            ]) : te("v-if", !0),
            e.hasError || !e.shouldLoad ? te("v-if", !0) : (v(), b("img", {
              key: 2,
              src: e.imageUrl,
              style: F({
                width: e.size + "px",
                height: e.size + "px",
                objectFit: e.objectFit
              }),
              alt: "avatar",
              onLoad: t[0] || (t[0] = (...f) => e.handleImgLoad && e.handleImgLoad(...f)),
              onError: t[1] || (t[1] = (...f) => e.handleImgError && e.handleImgError(...f))
            }, null, 44, Xy))
          ], 64)) : _(e.$slots, "default", { key: 1 })
        ], 2)
      ]),
      _: 3
    }, 8, ["onResize"]),
    e.$slots["trigger-icon"] ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-trigger-icon-${e.triggerType}`),
      style: F(e.computedTriggerIconStyle)
    }, [
      _(e.$slots, "trigger-icon")
    ], 6)) : te("v-if", !0)
  ], 6);
}
var si = /* @__PURE__ */ N(Uy, [["render", Qy]]);
const _y = S({
  name: "Popover",
  components: {
    Trigger: Tt
  },
  props: {
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean,
      default: !1
    },
    title: String,
    content: String,
    trigger: {
      type: [String, Array],
      default: "hover"
    },
    position: {
      type: String,
      default: "top"
    },
    contentClass: {
      type: [String, Array, Object]
    },
    contentStyle: {
      type: Object
    },
    arrowClass: {
      type: [String, Array, Object]
    },
    arrowStyle: {
      type: Object
    },
    popupContainer: {
      type: [String, Object]
    }
  },
  emits: {
    "update:popupVisible": (e) => !0,
    popupVisibleChange: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("popover"), o = V(e.defaultPopupVisible), i = a(
      () => {
        var u;
        return (u = e.popupVisible) != null ? u : o.value;
      }
    ), r = (u) => {
      o.value = u, t("update:popupVisible", u), t("popupVisibleChange", u);
    }, l = a(() => [
      `${n}-popup-content`,
      e.contentClass
    ]), s = a(() => [
      `${n}-popup-arrow`,
      e.arrowClass
    ]);
    return {
      prefixCls: n,
      computedPopupVisible: i,
      contentCls: l,
      arrowCls: s,
      handlePopupVisibleChange: r
    };
  }
});
function Jy(e, t, n, o, i, r) {
  const l = J("trigger");
  return v(), oe(l, {
    class: m(e.prefixCls),
    trigger: e.trigger,
    position: e.position,
    "popup-visible": e.computedPopupVisible,
    "popup-offset": 10,
    "content-class": e.contentCls,
    "content-style": e.contentStyle,
    "arrow-class": e.arrowCls,
    "arrow-style": e.arrowStyle,
    "show-arrow": "",
    "popup-container": e.popupContainer,
    "animation-name": "zoom-in-fade-out",
    "auto-fit-transform-origin": "",
    onPopupVisibleChange: e.handlePopupVisibleChange
  }, {
    content: ue(() => [
      $("div", {
        class: m(`${e.prefixCls}-title`)
      }, [
        _(e.$slots, "title", {}, () => [
          Re(Pe(e.title), 1)
        ])
      ], 2),
      $("div", {
        class: m(`${e.prefixCls}-content`)
      }, [
        _(e.$slots, "content", {}, () => [
          Re(Pe(e.content), 1)
        ])
      ], 2)
    ]),
    default: ue(() => [
      _(e.$slots, "default")
    ]),
    _: 3
  }, 8, ["class", "trigger", "position", "popup-visible", "content-class", "content-style", "arrow-class", "arrow-style", "popup-container", "onPopupVisibleChange"]);
}
var Ba = /* @__PURE__ */ N(_y, [["render", Jy]]);
const Av = Object.assign(Ba, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ba.name, Ba);
  }
}), ui = S({
  name: "AvatarGroup",
  props: {
    shape: {
      type: String,
      default: "circle"
    },
    size: Number,
    autoFixFontSize: {
      type: Boolean,
      default: !0
    },
    maxCount: {
      type: Number,
      default: 0
    },
    zIndexAscend: {
      type: Boolean,
      default: !1
    },
    maxStyle: {
      type: Object
    },
    maxPopoverTriggerProps: {
      type: Object
    }
  },
  setup(e, {
    slots: t
  }) {
    const {
      shape: n,
      size: o,
      autoFixFontSize: i,
      zIndexAscend: r
    } = ve(e), l = B("avatar-group"), s = V(0);
    return it(gm, me({
      shape: n,
      size: o,
      autoFixFontSize: i,
      zIndexAscend: r,
      total: s
    })), () => {
      var u, f;
      const d = En((f = (u = t.default) == null ? void 0 : u.call(t)) != null ? f : []), p = e.maxCount > 0 ? d.slice(0, e.maxCount) : d, h = e.maxCount > 0 ? d.slice(e.maxCount) : [];
      return s.value !== d.length && (s.value = d.length), c("div", {
        class: l
      }, [p, h.length > 0 && c(Av, e.maxPopoverTriggerProps, {
        default: () => [c(si, {
          class: `${l}-max-count-avatar`,
          style: e.maxStyle
        }, {
          default: () => [Re("+"), h.length]
        })],
        content: () => c("div", null, [h])
      })]);
    };
  }
}), e4 = Object.assign(si, {
  Group: ui,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + si.name, si), e.component(n + ui.name, ui);
  }
}), t4 = S({
  name: "IconToTop",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-to-top`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), n4 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function l4(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M43 7H5M24 20v23M24 13.96 30.453 21H17.546L24 13.96Zm.736-.804Z" }, null, -1),
    $("path", {
      d: "m24 14-6 7h12l-6-7Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, n4);
}
var Ma = /* @__PURE__ */ N(t4, [["render", l4]]);
const ym = Object.assign(Ma, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ma.name, Ma);
  }
}), o4 = S({
  name: "BackTop",
  components: {
    IconToTop: ym
  },
  props: {
    visibleHeight: {
      type: Number,
      default: 200
    },
    targetContainer: {
      type: [String, Object]
    },
    easing: {
      type: String,
      default: "quartOut"
    },
    duration: {
      type: Number,
      default: 200
    }
  },
  setup(e) {
    const t = B("back-top"), n = V(!1), o = V(), i = !e.targetContainer, r = wl(() => {
      if (o.value) {
        const { visibleHeight: u } = e, { scrollTop: f } = o.value;
        n.value = f >= u;
      }
    }), l = (u) => zt(u) ? document.querySelector(u) : u;
    return Je(() => {
      o.value = i ? document == null ? void 0 : document.documentElement : l(e.targetContainer), o.value && (rt(i ? window : o.value, "scroll", r), r());
    }), Zt(() => {
      r.cancel(), o.value && ct(i ? window : o.value, "scroll", r);
    }), {
      prefixCls: t,
      visible: n,
      scrollToTop: () => {
        if (o.value) {
          const { scrollTop: u } = o.value;
          new Pl({
            from: { scrollTop: u },
            to: { scrollTop: 0 },
            easing: e.easing,
            duration: e.duration,
            onUpdate: (d) => {
              o.value && (o.value.scrollTop = d.scrollTop);
            }
          }).start();
        }
      }
    };
  }
});
function i4(e, t, n, o, i, r) {
  const l = J("icon-to-top");
  return v(), oe(on, { name: "fade-in" }, {
    default: ue(() => [
      e.visible ? (v(), b("div", {
        key: 0,
        class: m(e.prefixCls),
        onClick: t[0] || (t[0] = (...s) => e.scrollToTop && e.scrollToTop(...s))
      }, [
        _(e.$slots, "default", {}, () => [
          $("button", {
            class: m(`${e.prefixCls}-btn`)
          }, [
            c(l)
          ], 2)
        ])
      ], 2)) : te("v-if", !0)
    ]),
    _: 3
  });
}
var Na = /* @__PURE__ */ N(o4, [["render", i4]]);
const r4 = Object.assign(Na, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Na.name, Na);
  }
}), a4 = ["red", "orangered", "orange", "gold", "lime", "green", "cyan", "arcoblue", "purple", "pinkpurple", "magenta", "gray"], s4 = ["normal", "processing", "success", "warning", "danger"];
var Oa = S({
  name: "Badge",
  props: {
    text: {
      type: String
    },
    dot: {
      type: Boolean
    },
    dotStyle: {
      type: Object
    },
    maxCount: {
      type: Number,
      default: 99
    },
    offset: {
      type: Array,
      default: () => []
    },
    color: {
      type: String
    },
    status: {
      type: String,
      validator: (e) => s4.includes(e)
    },
    count: {
      type: Number
    }
  },
  setup(e, {
    slots: t
  }) {
    const {
      status: n,
      color: o,
      dotStyle: i,
      offset: r,
      text: l,
      dot: s,
      maxCount: u,
      count: f
    } = ve(e), d = B("badge"), p = u4(d, n == null ? void 0 : n.value, t == null ? void 0 : t.default), h = a(() => {
      const y = {
        ...(i == null ? void 0 : i.value) || {}
      }, [w, g] = (r == null ? void 0 : r.value) || [];
      w && (y.marginRight = `${-w}px`), g && (y.marginTop = `${g}px`);
      const C = !(o != null && o.value) || a4.includes(o == null ? void 0 : o.value) ? {} : {
        backgroundColor: o.value
      };
      return {
        mergedStyle: {
          ...C,
          ...y
        },
        computedDotStyle: y,
        computedColorStyle: C
      };
    }), k = () => {
      const y = l == null ? void 0 : l.value, w = o == null ? void 0 : o.value, g = n == null ? void 0 : n.value, C = s == null ? void 0 : s.value, P = Number(f == null ? void 0 : f.value), z = (f == null ? void 0 : f.value) != null, {
        computedDotStyle: j,
        mergedStyle: I
      } = h.value;
      return t.content ? c("span", {
        class: `${d}-custom-dot`,
        style: j
      }, [t.content()]) : y && !w && !g ? c("span", {
        class: `${d}-text`,
        style: j
      }, [y]) : g || w && !z ? c("span", {
        class: `${d}-status-wrapper`
      }, [c("span", {
        class: [`${d}-status-dot`, {
          [`${d}-status-${g}`]: g,
          [`${d}-color-${w}`]: w
        }],
        style: I
      }, null), y && c("span", {
        class: `${d}-status-text`
      }, [y])]) : (C || w) && P > 0 ? c("span", {
        class: [`${d}-dot`, {
          [`${d}-color-${w}`]: w
        }],
        style: I
      }, null) : P === 0 ? null : c("span", {
        class: `${d}-number`,
        style: I
      }, [c("span", null, [u.value && P > u.value ? `${u.value}+` : P])]);
    };
    return () => c("span", {
      class: p.value
    }, [t.default && t.default(), k()]);
  }
});
const u4 = (e, t, n) => a(() => [e, {
  [`${e}-status`]: t,
  [`${e}-no-children`]: !n
}]), c4 = Object.assign(Oa, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Oa.name, Oa);
  }
}), bm = Symbol("ArcoBreadcrumb"), d4 = S({
  name: "IconMore",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-more`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), f4 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function v4(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M38 25v-2h2v2h-2ZM23 25v-2h2v2h-2ZM8 25v-2h2v2H8Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M38 25v-2h2v2h-2ZM23 25v-2h2v2h-2ZM8 25v-2h2v2H8Z" }, null, -1)
  ]), 14, f4);
}
var Va = /* @__PURE__ */ N(d4, [["render", v4]]);
const Vr = Object.assign(Va, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Va.name, Va);
  }
}), p4 = S({
  name: "IconDown",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-down`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), m4 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function h4(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M39.6 17.443 24.043 33 8.487 17.443" }, null, -1)
  ]), 14, m4);
}
var Ta = /* @__PURE__ */ N(p4, [["render", h4]]);
const Il = Object.assign(Ta, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ta.name, Ta);
  }
}), k4 = S({
  name: "IconObliqueLine",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-oblique-line`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), g4 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function y4(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M29.506 6.502 18.493 41.498" }, null, -1)
  ]), 14, g4);
}
var Aa = /* @__PURE__ */ N(k4, [["render", y4]]);
const Cm = Object.assign(Aa, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Aa.name, Aa);
  }
}), Ev = Symbol("ArcoDropdown"), b4 = S({
  name: "DropdownPanel",
  components: {
    Scrollbar: In,
    Empty: Gn
  },
  props: {
    loading: {
      type: Boolean,
      default: !1
    },
    isEmpty: {
      type: Boolean,
      default: !1
    },
    bottomOffset: {
      type: Number,
      default: 0
    },
    onScroll: {
      type: [Function, Array]
    },
    onReachBottom: {
      type: [Function, Array]
    }
  },
  emits: ["scroll", "reachBottom"],
  setup(e, { emit: t, slots: n }) {
    const o = B("dropdown"), i = Ge(
      Ev,
      {}
    ), r = V(), l = (f) => {
      const { scrollTop: d, scrollHeight: p, offsetHeight: h } = f.target;
      p - (d + h) <= e.bottomOffset && t("reachBottom", f), t("scroll", f);
    }, s = a(() => {
      if (A(i.popupMaxHeight))
        return {
          maxHeight: `${i.popupMaxHeight}px`
        };
      if (!i.popupMaxHeight)
        return {
          maxHeight: "none",
          overflowY: "hidden"
        };
    }), u = a(() => [
      o,
      {
        [`${o}-has-footer`]: !!n.footer
      }
    ]);
    return {
      prefixCls: o,
      cls: u,
      style: s,
      wrapperRef: r,
      handleScroll: l
    };
  }
});
function C4(e, t, n, o, i, r) {
  const l = J("empty"), s = J("Scrollbar");
  return v(), b("div", {
    class: m(e.cls)
  }, [
    e.isEmpty ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-empty`)
    }, [
      _(e.$slots, "empty", {}, () => [
        c(l)
      ])
    ], 2)) : te("v-if", !0),
    c(s, {
      ref: "wrapperRef",
      class: m(`${e.prefixCls}-list-wrapper`),
      style: F(e.style),
      onScroll: e.handleScroll
    }, {
      default: ue(() => [
        $("ul", {
          class: m(`${e.prefixCls}-list`)
        }, [
          _(e.$slots, "default")
        ], 2)
      ]),
      _: 3
    }, 8, ["class", "style", "onScroll"]),
    e.$slots.footer && !e.isEmpty ? (v(), b("div", {
      key: 1,
      class: m(`${e.prefixCls}-footer`)
    }, [
      _(e.$slots, "footer")
    ], 2)) : te("v-if", !0)
  ], 2);
}
var $m = /* @__PURE__ */ N(b4, [["render", C4]]);
const Tr = ({
  popupVisible: e,
  defaultPopupVisible: t,
  emit: n
}) => {
  var o;
  const i = V((o = t == null ? void 0 : t.value) != null ? o : !1), r = a(
    () => {
      var s;
      return (s = e == null ? void 0 : e.value) != null ? s : i.value;
    }
  ), l = (s) => {
    s !== r.value && (i.value = s, n("update:popupVisible", s), n("popupVisibleChange", s));
  };
  return ze(r, (s) => {
    i.value !== s && (i.value = s);
  }), {
    computedPopupVisible: r,
    handlePopupVisibleChange: l
  };
}, $4 = S({
  name: "Dropdown",
  components: {
    Trigger: Tt,
    DropdownPanel: $m
  },
  props: {
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean,
      default: !1
    },
    trigger: {
      type: [String, Array],
      default: "click"
    },
    position: {
      type: String,
      default: "bottom"
    },
    popupContainer: {
      type: [String, Object]
    },
    popupMaxHeight: {
      type: [Boolean, Number],
      default: !0
    },
    hideOnSelect: {
      type: Boolean,
      default: !0
    }
  },
  emits: {
    "update:popupVisible": (e) => !0,
    popupVisibleChange: (e) => !0,
    select: (e, t) => !0
  },
  setup(e, { emit: t }) {
    const { defaultPopupVisible: n, popupVisible: o, popupMaxHeight: i } = ve(e), r = B("dropdown"), { computedPopupVisible: l, handlePopupVisibleChange: s } = Tr({
      defaultPopupVisible: n,
      popupVisible: o,
      emit: t
    });
    return it(
      Ev,
      me({
        popupMaxHeight: i,
        onOptionClick: (f, d) => {
          t("select", f, d), e.hideOnSelect && s(!1);
        }
      })
    ), {
      prefixCls: r,
      computedPopupVisible: l,
      handlePopupVisibleChange: s
    };
  }
});
function w4(e, t, n, o, i, r) {
  const l = J("DropdownPanel"), s = J("Trigger");
  return v(), oe(s, {
    "popup-visible": e.computedPopupVisible,
    "animation-name": "slide-dynamic-origin",
    "auto-fit-transform-origin": "",
    trigger: e.trigger,
    position: e.position,
    "popup-offset": 4,
    "popup-container": e.popupContainer,
    "opened-class": `${e.prefixCls}-open`,
    onPopupVisibleChange: e.handlePopupVisibleChange
  }, {
    content: ue(() => [
      c(l, null, kt({
        default: ue(() => [
          _(e.$slots, "content")
        ]),
        _: 2
      }, [
        e.$slots.footer ? {
          name: "footer",
          fn: ue(() => [
            _(e.$slots, "footer")
          ]),
          key: "0"
        } : void 0
      ]), 1024)
    ]),
    default: ue(() => [
      _(e.$slots, "default")
    ]),
    _: 3
  }, 8, ["popup-visible", "trigger", "position", "popup-container", "opened-class", "onPopupVisibleChange"]);
}
var ci = /* @__PURE__ */ N($4, [["render", w4]]);
const S4 = S({
  name: "Doption",
  props: {
    value: {
      type: [String, Number, Object]
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    active: Boolean,
    uninjectContext: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("dropdown-option"), o = V(), i = a(
      () => {
        var u, f, d;
        return (d = (f = e.value) != null ? f : (u = o.value) == null ? void 0 : u.textContent) != null ? d : void 0;
      }
    ), r = e.uninjectContext ? void 0 : Ge(Ev, void 0), l = (u) => {
      e.disabled || (t("click", u), r == null || r.onOptionClick(i.value, u));
    }, s = a(() => [
      n,
      {
        [`${n}-disabled`]: e.disabled,
        [`${n}-active`]: e.active
      }
    ]);
    return {
      prefixCls: n,
      cls: s,
      liRef: o,
      handleClick: l
    };
  }
});
function z4(e, t, n, o, i, r) {
  return v(), b("li", {
    ref: "liRef",
    class: m([e.cls, { [`${e.prefixCls}-has-suffix`]: !!e.$slots.suffix }]),
    onClick: t[0] || (t[0] = (...l) => e.handleClick && e.handleClick(...l))
  }, [
    e.$slots.icon ? (v(), b("span", {
      key: 0,
      class: m(`${e.prefixCls}-icon`)
    }, [
      _(e.$slots, "icon")
    ], 2)) : te("v-if", !0),
    $("span", {
      class: m(`${e.prefixCls}-content`)
    }, [
      _(e.$slots, "default")
    ], 2),
    e.$slots.suffix ? (v(), b("span", {
      key: 1,
      class: m(`${e.prefixCls}-suffix`)
    }, [
      _(e.$slots, "suffix")
    ], 2)) : te("v-if", !0)
  ], 2);
}
var Rl = /* @__PURE__ */ N(S4, [["render", z4]]);
const L4 = S({
  name: "Dgroup",
  props: {
    title: String
  },
  setup() {
    return {
      prefixCls: B("dropdown-group")
    };
  }
});
function j4(e, t, n, o, i, r) {
  return v(), b(Ae, null, [
    $("li", {
      class: m(`${e.prefixCls}-title`)
    }, [
      _(e.$slots, "title", {}, () => [
        Re(Pe(e.title), 1)
      ])
    ], 2),
    _(e.$slots, "default")
  ], 64);
}
var di = /* @__PURE__ */ N(L4, [["render", j4]]);
const P4 = S({
  name: "IconRight",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-right`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), I4 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function B4(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m16 39.513 15.556-15.557L16 8.4" }, null, -1)
  ]), 14, I4);
}
var Ea = /* @__PURE__ */ N(P4, [["render", B4]]);
const bn = Object.assign(Ea, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ea.name, Ea);
  }
}), M4 = S({
  name: "Dsubmenu",
  components: {
    Trigger: Tt,
    DropdownPanel: $m,
    DropdownOption: Rl,
    IconRight: bn
  },
  props: {
    value: {
      type: [String, Number]
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    trigger: {
      type: [String, Array],
      default: "click"
    },
    position: {
      type: String,
      default: "rt"
    },
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean,
      default: !1
    },
    optionProps: {
      type: Object
    }
  },
  emits: {
    "update:popupVisible": (e) => !0,
    popupVisibleChange: (e) => !0
  },
  setup(e, { emit: t }) {
    const { defaultPopupVisible: n, popupVisible: o } = ve(e), i = B("dropdown"), { computedPopupVisible: r, handlePopupVisibleChange: l } = Tr({
      defaultPopupVisible: n,
      popupVisible: o,
      emit: t
    });
    return {
      prefixCls: i,
      computedPopupVisible: r,
      handlePopupVisibleChange: l
    };
  }
});
function N4(e, t, n, o, i, r) {
  const l = J("IconRight"), s = J("dropdown-option"), u = J("dropdown-panel"), f = J("Trigger");
  return v(), oe(f, {
    "popup-visible": e.computedPopupVisible,
    trigger: e.trigger,
    position: e.position,
    disabled: e.disabled,
    "popup-offset": 4,
    onPopupVisibleChange: e.handlePopupVisibleChange
  }, {
    content: ue(() => [
      c(u, {
        class: m(`${e.prefixCls}-submenu`)
      }, kt({
        default: ue(() => [
          _(e.$slots, "content")
        ]),
        _: 2
      }, [
        e.$slots.footer ? {
          name: "footer",
          fn: ue(() => [
            _(e.$slots, "footer")
          ]),
          key: "0"
        } : void 0
      ]), 1032, ["class"])
    ]),
    default: ue(() => [
      c(s, se(e.optionProps, {
        active: e.computedPopupVisible,
        "uninject-context": ""
      }), kt({
        suffix: ue(() => [
          _(e.$slots, "suffix", {}, () => [
            c(l)
          ])
        ]),
        default: ue(() => [
          _(e.$slots, "default")
        ]),
        _: 2
      }, [
        e.$slots.icon ? {
          name: "icon",
          fn: ue(() => [
            _(e.$slots, "icon")
          ]),
          key: "0"
        } : void 0
      ]), 1040, ["active"])
    ]),
    _: 3
  }, 8, ["popup-visible", "trigger", "position", "disabled", "onPopupVisibleChange"]);
}
var fi = /* @__PURE__ */ N(M4, [["render", N4]]);
const O4 = S({
  name: "DropdownButton",
  components: {
    IconMore: Vr,
    Button: Qt,
    ButtonGroup: fo,
    Dropdown: ci
  },
  props: {
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean,
      default: !1
    },
    trigger: {
      type: [String, Array],
      default: "click"
    },
    position: {
      type: String,
      default: "br"
    },
    popupContainer: {
      type: [String, Object]
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    type: {
      type: String
    },
    size: {
      type: String
    },
    buttonProps: {
      type: Object
    },
    hideOnSelect: {
      type: Boolean,
      default: !0
    }
  },
  emits: {
    "update:popupVisible": (e) => !0,
    popupVisibleChange: (e) => !0,
    click: (e) => !0,
    select: (e, t) => !0
  },
  setup(e, { emit: t }) {
    const { defaultPopupVisible: n, popupVisible: o } = ve(e), i = B("dropdown"), { computedPopupVisible: r, handlePopupVisibleChange: l } = Tr({
      defaultPopupVisible: n,
      popupVisible: o,
      emit: t
    });
    return {
      prefixCls: i,
      computedPopupVisible: r,
      handleClick: (f) => {
        t("click", f);
      },
      handleSelect: (f, d) => {
        t("select", f, d);
      },
      handlePopupVisibleChange: l
    };
  }
});
function V4(e, t, n, o, i, r) {
  const l = J("Button"), s = J("IconMore"), u = J("Dropdown"), f = J("ButtonGroup");
  return v(), oe(f, null, {
    default: ue(() => [
      c(l, se({
        size: e.size,
        type: e.type,
        disabled: e.disabled
      }, e.buttonProps, { onClick: e.handleClick }), {
        default: ue(() => [
          _(e.$slots, "default")
        ]),
        _: 3
      }, 16, ["size", "type", "disabled", "onClick"]),
      c(u, {
        "popup-visible": e.computedPopupVisible,
        trigger: e.trigger,
        position: e.position,
        "popup-container": e.popupContainer,
        "hide-on-select": e.hideOnSelect,
        onSelect: e.handleSelect,
        onPopupVisibleChange: e.handlePopupVisibleChange
      }, {
        content: ue(() => [
          _(e.$slots, "content")
        ]),
        default: ue(() => [
          c(l, {
            size: e.size,
            type: e.type,
            disabled: e.disabled
          }, {
            icon: ue(() => [
              _(e.$slots, "icon", { popupVisible: e.computedPopupVisible }, () => [
                c(s)
              ])
            ]),
            _: 3
          }, 8, ["size", "type", "disabled"])
        ]),
        _: 3
      }, 8, ["popup-visible", "trigger", "position", "popup-container", "hide-on-select", "onSelect", "onPopupVisibleChange"])
    ]),
    _: 3
  });
}
var vi = /* @__PURE__ */ N(O4, [["render", V4]]);
const wm = Object.assign(ci, {
  Option: Rl,
  Group: di,
  Submenu: fi,
  Button: vi,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ci.name, ci), e.component(n + Rl.name, Rl), e.component(n + di.name, di), e.component(n + fi.name, fi), e.component(n + vi.name, vi);
  }
});
var vo = S({
  name: "BreadcrumbItem",
  inheritAttrs: !1,
  props: {
    separator: {
      type: [String, Number]
    },
    droplist: {
      type: Array
    },
    dropdownProps: {
      type: Object
    },
    index: {
      type: Number,
      default: 0
    }
  },
  setup(e, {
    slots: t,
    attrs: n
  }) {
    const o = B("breadcrumb-item"), i = Ge(bm, void 0), r = V(!1), l = a(() => !(i && i.needHide && e.index > 1 && e.index <= i.total - i.maxCount)), s = a(() => i && i.needHide ? e.index === 1 : !1), u = a(() => i ? e.index < i.total - 1 : !0), f = (y) => {
      r.value = y;
    }, d = () => {
      var y, w, g, C, P, z, j;
      if (!u.value)
        return null;
      const I = (j = (z = (P = (w = (y = t.separator) == null ? void 0 : y.call(t)) != null ? w : e.separator) != null ? P : (C = i == null ? void 0 : (g = i.slots).separator) == null ? void 0 : C.call(g)) != null ? z : i == null ? void 0 : i.separator) != null ? j : c(Cm, null, null);
      return c("div", {
        "aria-hidden": "true",
        class: `${o}-separator`
      }, [I]);
    }, p = () => {
      var y, w, g, C;
      return c("div", se({
        role: "listitem",
        class: [o, {
          [`${o}-with-dropdown`]: e.droplist || t.droplist
        }]
      }, s.value ? {
        "aria-label": "ellipses of breadcrumb items"
      } : void 0, n), [s.value ? (g = (w = i == null ? void 0 : (y = i.slots)["more-icon"]) == null ? void 0 : w.call(y)) != null ? g : c(Vr, null, null) : (C = t.default) == null ? void 0 : C.call(t), (e.droplist || t.droplist) && c("span", {
        "aria-hidden": !0,
        class: [`${o}-dropdown-icon`, {
          [`${o}-dropdown-icon-active`]: r.value
        }]
      }, [c(Il, null, null)])]);
    }, h = () => {
      var y, w, g;
      return (g = (y = t.droplist) == null ? void 0 : y.call(t)) != null ? g : (w = e.droplist) == null ? void 0 : w.map((C) => c(Rl, {
        value: C.path
      }, {
        default: () => [C.label]
      }));
    }, k = () => c(wm, se({
      popupVisible: r.value,
      onPopupVisibleChange: f
    }, e.dropdownProps), {
      default: () => [p()],
      content: h
    });
    return () => l.value ? c(Ae, null, [t.droplist || e.droplist ? k() : p(), d()]) : null;
  }
}), Wa = S({
  name: "Breadcrumb",
  props: {
    maxCount: {
      type: Number,
      default: 0
    },
    routes: {
      type: Array
    },
    separator: {
      type: [String, Number]
    },
    customUrl: {
      type: Function
    }
  },
  setup(e, {
    slots: t
  }) {
    const {
      maxCount: n,
      separator: o,
      routes: i
    } = ve(e), r = B("breadcrumb"), l = V(0), s = a(() => n.value > 0 && l.value > n.value + 1);
    it(bm, me({
      total: l,
      maxCount: n,
      separator: o,
      needHide: s,
      slots: t
    }));
    const u = (p, h, k) => {
      var y, w;
      if (h.indexOf(p) === h.length - 1)
        return c("span", null, [p.label]);
      const g = (w = (y = e.customUrl) == null ? void 0 : y.call(e, k)) != null ? w : `#/${k.join("/").replace(/^\//, "")}`;
      return c("a", {
        href: g
      }, [p.label]);
    }, f = () => {
      var p;
      if (!((p = i.value) != null && p.length))
        return null;
      l.value !== i.value.length && (l.value = i.value.length);
      const h = [];
      return i.value.map((k, y, w) => {
        h.push((k.path || "").replace(/^\//, ""));
        const g = [...h];
        return c(vo, {
          key: k.path || k.label,
          index: y,
          droplist: k.children
        }, {
          default: () => {
            var C, P;
            return [(P = (C = t["item-render"]) == null ? void 0 : C.call(t, {
              route: k,
              routes: w,
              paths: g
            })) != null ? P : u(k, w, g)];
          }
        });
      });
    }, d = () => {
      var p, h;
      const k = En((h = (p = t.default) == null ? void 0 : p.call(t)) != null ? h : []);
      return l.value !== k.length && (l.value = k.length), k.map((y, w) => {
        var g;
        return y.props = se((g = y.props) != null ? g : {}, {
          index: w
        }), y;
      });
    };
    return () => c("div", {
      role: "list",
      class: r
    }, [t.default ? d() : f()]);
  }
});
const T4 = Object.assign(Wa, {
  Item: vo,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Wa.name, Wa), e.component(n + vo.name, vo);
  }
});
function Bl(e) {
  return e && e.__esModule && Object.prototype.hasOwnProperty.call(e, "default") ? e.default : e;
}
var pi = { exports: {} }, A4 = pi.exports, K0;
function Sm() {
  return K0 || (K0 = 1, function(e, t) {
    (function(n, o) {
      e.exports = o();
    })(A4, function() {
      var n = 1e3, o = 6e4, i = 36e5, r = "millisecond", l = "second", s = "minute", u = "hour", f = "day", d = "week", p = "month", h = "quarter", k = "year", y = "date", w = "Invalid Date", g = /^(\d{4})[-/]?(\d{1,2})?[-/]?(\d{0,2})[Tt\s]*(\d{1,2})?:?(\d{1,2})?:?(\d{1,2})?[.:]?(\d+)?$/, C = /\[([^\]]+)]|Y{1,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a|A|m{1,2}|s{1,2}|Z{1,2}|SSS/g, P = { name: "en", weekdays: "Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"), months: "January_February_March_April_May_June_July_August_September_October_November_December".split("_"), ordinal: function(Z) {
        var U = ["th", "st", "nd", "rd"], H = Z % 100;
        return "[" + Z + (U[(H - 20) % 10] || U[H] || U[0]) + "]";
      } }, z = function(Z, U, H) {
        var D = String(Z);
        return !D || D.length >= U ? Z : "" + Array(U + 1 - D.length).join(H) + Z;
      }, j = { s: z, z: function(Z) {
        var U = -Z.utcOffset(), H = Math.abs(U), D = Math.floor(H / 60), R = H % 60;
        return (U <= 0 ? "+" : "-") + z(D, 2, "0") + ":" + z(R, 2, "0");
      }, m: function Z(U, H) {
        if (U.date() < H.date()) return -Z(H, U);
        var D = 12 * (H.year() - U.year()) + (H.month() - U.month()), R = U.clone().add(D, p), W = H - R < 0, O = U.clone().add(D + (W ? -1 : 1), p);
        return +(-(D + (H - R) / (W ? R - O : O - R)) || 0);
      }, a: function(Z) {
        return Z < 0 ? Math.ceil(Z) || 0 : Math.floor(Z);
      }, p: function(Z) {
        return { M: p, y: k, w: d, d: f, D: y, h: u, m: s, s: l, ms: r, Q: h }[Z] || String(Z || "").toLowerCase().replace(/s$/, "");
      }, u: function(Z) {
        return Z === void 0;
      } }, I = "en", L = {};
      L[I] = P;
      var M = "$isDayjsObject", E = function(Z) {
        return Z instanceof X || !(!Z || !Z[M]);
      }, K = function Z(U, H, D) {
        var R;
        if (!U) return I;
        if (typeof U == "string") {
          var W = U.toLowerCase();
          L[W] && (R = W), H && (L[W] = H, R = W);
          var O = U.split("-");
          if (!R && O.length > 1) return Z(O[0]);
        } else {
          var x = U.name;
          L[x] = U, R = x;
        }
        return !D && R && (I = R), R || !D && I;
      }, q = function(Z, U) {
        if (E(Z)) return Z.clone();
        var H = typeof U == "object" ? U : {};
        return H.date = Z, H.args = arguments, new X(H);
      }, T = j;
      T.l = K, T.i = E, T.w = function(Z, U) {
        return q(Z, { locale: U.$L, utc: U.$u, x: U.$x, $offset: U.$offset });
      };
      var X = function() {
        function Z(H) {
          this.$L = K(H.locale, null, !0), this.parse(H), this.$x = this.$x || H.x || {}, this[M] = !0;
        }
        var U = Z.prototype;
        return U.parse = function(H) {
          this.$d = function(D) {
            var R = D.date, W = D.utc;
            if (R === null) return /* @__PURE__ */ new Date(NaN);
            if (T.u(R)) return /* @__PURE__ */ new Date();
            if (R instanceof Date) return new Date(R);
            if (typeof R == "string" && !/Z$/i.test(R)) {
              var O = R.match(g);
              if (O) {
                var x = O[2] - 1 || 0, G = (O[7] || "0").substring(0, 3);
                return W ? new Date(Date.UTC(O[1], x, O[3] || 1, O[4] || 0, O[5] || 0, O[6] || 0, G)) : new Date(O[1], x, O[3] || 1, O[4] || 0, O[5] || 0, O[6] || 0, G);
              }
            }
            return new Date(R);
          }(H), this.init();
        }, U.init = function() {
          var H = this.$d;
          this.$y = H.getFullYear(), this.$M = H.getMonth(), this.$D = H.getDate(), this.$W = H.getDay(), this.$H = H.getHours(), this.$m = H.getMinutes(), this.$s = H.getSeconds(), this.$ms = H.getMilliseconds();
        }, U.$utils = function() {
          return T;
        }, U.isValid = function() {
          return this.$d.toString() !== w;
        }, U.isSame = function(H, D) {
          var R = q(H);
          return this.startOf(D) <= R && R <= this.endOf(D);
        }, U.isAfter = function(H, D) {
          return q(H) < this.startOf(D);
        }, U.isBefore = function(H, D) {
          return this.endOf(D) < q(H);
        }, U.$g = function(H, D, R) {
          return T.u(H) ? this[D] : this.set(R, H);
        }, U.unix = function() {
          return Math.floor(this.valueOf() / 1e3);
        }, U.valueOf = function() {
          return this.$d.getTime();
        }, U.startOf = function(H, D) {
          var R = this, W = !!T.u(D) || D, O = T.p(H), x = function(be, Le) {
            var pe = T.w(R.$u ? Date.UTC(R.$y, Le, be) : new Date(R.$y, Le, be), R);
            return W ? pe : pe.endOf(f);
          }, G = function(be, Le) {
            return T.w(R.toDate()[be].apply(R.toDate("s"), (W ? [0, 0, 0, 0] : [23, 59, 59, 999]).slice(Le)), R);
          }, ne = this.$W, ee = this.$M, Q = this.$D, ae = "set" + (this.$u ? "UTC" : "");
          switch (O) {
            case k:
              return W ? x(1, 0) : x(31, 11);
            case p:
              return W ? x(1, ee) : x(0, ee + 1);
            case d:
              var ge = this.$locale().weekStart || 0, Se = (ne < ge ? ne + 7 : ne) - ge;
              return x(W ? Q - Se : Q + (6 - Se), ee);
            case f:
            case y:
              return G(ae + "Hours", 0);
            case u:
              return G(ae + "Minutes", 1);
            case s:
              return G(ae + "Seconds", 2);
            case l:
              return G(ae + "Milliseconds", 3);
            default:
              return this.clone();
          }
        }, U.endOf = function(H) {
          return this.startOf(H, !1);
        }, U.$set = function(H, D) {
          var R, W = T.p(H), O = "set" + (this.$u ? "UTC" : ""), x = (R = {}, R[f] = O + "Date", R[y] = O + "Date", R[p] = O + "Month", R[k] = O + "FullYear", R[u] = O + "Hours", R[s] = O + "Minutes", R[l] = O + "Seconds", R[r] = O + "Milliseconds", R)[W], G = W === f ? this.$D + (D - this.$W) : D;
          if (W === p || W === k) {
            var ne = this.clone().set(y, 1);
            ne.$d[x](G), ne.init(), this.$d = ne.set(y, Math.min(this.$D, ne.daysInMonth())).$d;
          } else x && this.$d[x](G);
          return this.init(), this;
        }, U.set = function(H, D) {
          return this.clone().$set(H, D);
        }, U.get = function(H) {
          return this[T.p(H)]();
        }, U.add = function(H, D) {
          var R, W = this;
          H = Number(H);
          var O = T.p(D), x = function(ee) {
            var Q = q(W);
            return T.w(Q.date(Q.date() + Math.round(ee * H)), W);
          };
          if (O === p) return this.set(p, this.$M + H);
          if (O === k) return this.set(k, this.$y + H);
          if (O === f) return x(1);
          if (O === d) return x(7);
          var G = (R = {}, R[s] = o, R[u] = i, R[l] = n, R)[O] || 1, ne = this.$d.getTime() + H * G;
          return T.w(ne, this);
        }, U.subtract = function(H, D) {
          return this.add(-1 * H, D);
        }, U.format = function(H) {
          var D = this, R = this.$locale();
          if (!this.isValid()) return R.invalidDate || w;
          var W = H || "YYYY-MM-DDTHH:mm:ssZ", O = T.z(this), x = this.$H, G = this.$m, ne = this.$M, ee = R.weekdays, Q = R.months, ae = R.meridiem, ge = function(Le, pe, Me, ke) {
            return Le && (Le[pe] || Le(D, W)) || Me[pe].slice(0, ke);
          }, Se = function(Le) {
            return T.s(x % 12 || 12, Le, "0");
          }, be = ae || function(Le, pe, Me) {
            var ke = Le < 12 ? "AM" : "PM";
            return Me ? ke.toLowerCase() : ke;
          };
          return W.replace(C, function(Le, pe) {
            return pe || function(Me) {
              switch (Me) {
                case "YY":
                  return String(D.$y).slice(-2);
                case "YYYY":
                  return T.s(D.$y, 4, "0");
                case "M":
                  return ne + 1;
                case "MM":
                  return T.s(ne + 1, 2, "0");
                case "MMM":
                  return ge(R.monthsShort, ne, Q, 3);
                case "MMMM":
                  return ge(Q, ne);
                case "D":
                  return D.$D;
                case "DD":
                  return T.s(D.$D, 2, "0");
                case "d":
                  return String(D.$W);
                case "dd":
                  return ge(R.weekdaysMin, D.$W, ee, 2);
                case "ddd":
                  return ge(R.weekdaysShort, D.$W, ee, 3);
                case "dddd":
                  return ee[D.$W];
                case "H":
                  return String(x);
                case "HH":
                  return T.s(x, 2, "0");
                case "h":
                  return Se(1);
                case "hh":
                  return Se(2);
                case "a":
                  return be(x, G, !0);
                case "A":
                  return be(x, G, !1);
                case "m":
                  return String(G);
                case "mm":
                  return T.s(G, 2, "0");
                case "s":
                  return String(D.$s);
                case "ss":
                  return T.s(D.$s, 2, "0");
                case "SSS":
                  return T.s(D.$ms, 3, "0");
                case "Z":
                  return O;
              }
              return null;
            }(Le) || O.replace(":", "");
          });
        }, U.utcOffset = function() {
          return 15 * -Math.round(this.$d.getTimezoneOffset() / 15);
        }, U.diff = function(H, D, R) {
          var W, O = this, x = T.p(D), G = q(H), ne = (G.utcOffset() - this.utcOffset()) * o, ee = this - G, Q = function() {
            return T.m(O, G);
          };
          switch (x) {
            case k:
              W = Q() / 12;
              break;
            case p:
              W = Q();
              break;
            case h:
              W = Q() / 3;
              break;
            case d:
              W = (ee - ne) / 6048e5;
              break;
            case f:
              W = (ee - ne) / 864e5;
              break;
            case u:
              W = ee / i;
              break;
            case s:
              W = ee / o;
              break;
            case l:
              W = ee / n;
              break;
            default:
              W = ee;
          }
          return R ? W : T.a(W);
        }, U.daysInMonth = function() {
          return this.endOf(p).$D;
        }, U.$locale = function() {
          return L[this.$L];
        }, U.locale = function(H, D) {
          if (!H) return this.$L;
          var R = this.clone(), W = K(H, D, !0);
          return W && (R.$L = W), R;
        }, U.clone = function() {
          return T.w(this.$d, this);
        }, U.toDate = function() {
          return new Date(this.valueOf());
        }, U.toJSON = function() {
          return this.isValid() ? this.toISOString() : null;
        }, U.toISOString = function() {
          return this.$d.toISOString();
        }, U.toString = function() {
          return this.$d.toUTCString();
        }, Z;
      }(), Y = X.prototype;
      return q.prototype = Y, [["$ms", r], ["$s", l], ["$m", s], ["$H", u], ["$W", f], ["$M", p], ["$y", k], ["$D", y]].forEach(function(Z) {
        Y[Z[1]] = function(U) {
          return this.$g(U, Z[0], Z[1]);
        };
      }), q.extend = function(Z, U) {
        return Z.$i || (Z(U, X, q), Z.$i = !0), q;
      }, q.locale = K, q.isDayjs = E, q.unix = function(Z) {
        return q(1e3 * Z);
      }, q.en = L[I], q.Ls = L, q.p = {}, q;
    });
  }(pi)), pi.exports;
}
var E4 = Sm();
const Ut = /* @__PURE__ */ Bl(E4);
var mi = { exports: {} }, W4 = mi.exports, Y0;
function F4() {
  return Y0 || (Y0 = 1, function(e, t) {
    (function(n, o) {
      e.exports = o();
    })(W4, function() {
      var n = { LTS: "h:mm:ss A", LT: "h:mm A", L: "MM/DD/YYYY", LL: "MMMM D, YYYY", LLL: "MMMM D, YYYY h:mm A", LLLL: "dddd, MMMM D, YYYY h:mm A" }, o = /(\[[^[]*\])|([-_:/.,()\s]+)|(A|a|Q|YYYY|YY?|ww?|MM?M?M?|Do|DD?|hh?|HH?|mm?|ss?|S{1,3}|z|ZZ?)/g, i = /\d/, r = /\d\d/, l = /\d\d?/, s = /\d*[^-_:/,()\s\d]+/, u = {}, f = function(g) {
        return (g = +g) + (g > 68 ? 1900 : 2e3);
      }, d = function(g) {
        return function(C) {
          this[g] = +C;
        };
      }, p = [/[+-]\d\d:?(\d\d)?|Z/, function(g) {
        (this.zone || (this.zone = {})).offset = function(C) {
          if (!C || C === "Z") return 0;
          var P = C.match(/([+-]|\d\d)/g), z = 60 * P[1] + (+P[2] || 0);
          return z === 0 ? 0 : P[0] === "+" ? -z : z;
        }(g);
      }], h = function(g) {
        var C = u[g];
        return C && (C.indexOf ? C : C.s.concat(C.f));
      }, k = function(g, C) {
        var P, z = u.meridiem;
        if (z) {
          for (var j = 1; j <= 24; j += 1) if (g.indexOf(z(j, 0, C)) > -1) {
            P = j > 12;
            break;
          }
        } else P = g === (C ? "pm" : "PM");
        return P;
      }, y = { A: [s, function(g) {
        this.afternoon = k(g, !1);
      }], a: [s, function(g) {
        this.afternoon = k(g, !0);
      }], Q: [i, function(g) {
        this.month = 3 * (g - 1) + 1;
      }], S: [i, function(g) {
        this.milliseconds = 100 * +g;
      }], SS: [r, function(g) {
        this.milliseconds = 10 * +g;
      }], SSS: [/\d{3}/, function(g) {
        this.milliseconds = +g;
      }], s: [l, d("seconds")], ss: [l, d("seconds")], m: [l, d("minutes")], mm: [l, d("minutes")], H: [l, d("hours")], h: [l, d("hours")], HH: [l, d("hours")], hh: [l, d("hours")], D: [l, d("day")], DD: [r, d("day")], Do: [s, function(g) {
        var C = u.ordinal, P = g.match(/\d+/);
        if (this.day = P[0], C) for (var z = 1; z <= 31; z += 1) C(z).replace(/\[|\]/g, "") === g && (this.day = z);
      }], w: [l, d("week")], ww: [r, d("week")], M: [l, d("month")], MM: [r, d("month")], MMM: [s, function(g) {
        var C = h("months"), P = (h("monthsShort") || C.map(function(z) {
          return z.slice(0, 3);
        })).indexOf(g) + 1;
        if (P < 1) throw new Error();
        this.month = P % 12 || P;
      }], MMMM: [s, function(g) {
        var C = h("months").indexOf(g) + 1;
        if (C < 1) throw new Error();
        this.month = C % 12 || C;
      }], Y: [/[+-]?\d+/, d("year")], YY: [r, function(g) {
        this.year = f(g);
      }], YYYY: [/\d{4}/, d("year")], Z: p, ZZ: p };
      function w(g) {
        var C, P;
        C = g, P = u && u.formats;
        for (var z = (g = C.replace(/(\[[^\]]+])|(LTS?|l{1,4}|L{1,4})/g, function(q, T, X) {
          var Y = X && X.toUpperCase();
          return T || P[X] || n[X] || P[Y].replace(/(\[[^\]]+])|(MMMM|MM|DD|dddd)/g, function(Z, U, H) {
            return U || H.slice(1);
          });
        })).match(o), j = z.length, I = 0; I < j; I += 1) {
          var L = z[I], M = y[L], E = M && M[0], K = M && M[1];
          z[I] = K ? { regex: E, parser: K } : L.replace(/^\[|\]$/g, "");
        }
        return function(q) {
          for (var T = {}, X = 0, Y = 0; X < j; X += 1) {
            var Z = z[X];
            if (typeof Z == "string") Y += Z.length;
            else {
              var U = Z.regex, H = Z.parser, D = q.slice(Y), R = U.exec(D)[0];
              H.call(T, R), q = q.replace(R, "");
            }
          }
          return function(W) {
            var O = W.afternoon;
            if (O !== void 0) {
              var x = W.hours;
              O ? x < 12 && (W.hours += 12) : x === 12 && (W.hours = 0), delete W.afternoon;
            }
          }(T), T;
        };
      }
      return function(g, C, P) {
        P.p.customParseFormat = !0, g && g.parseTwoDigitYear && (f = g.parseTwoDigitYear);
        var z = C.prototype, j = z.parse;
        z.parse = function(I) {
          var L = I.date, M = I.utc, E = I.args;
          this.$u = M;
          var K = E[1];
          if (typeof K == "string") {
            var q = E[2] === !0, T = E[3] === !0, X = q || T, Y = E[2];
            T && (Y = E[2]), u = this.$locale(), !q && Y && (u = P.Ls[Y]), this.$d = function(D, R, W, O) {
              try {
                if (["x", "X"].indexOf(R) > -1) return new Date((R === "X" ? 1e3 : 1) * D);
                var x = w(R)(D), G = x.year, ne = x.month, ee = x.day, Q = x.hours, ae = x.minutes, ge = x.seconds, Se = x.milliseconds, be = x.zone, Le = x.week, pe = /* @__PURE__ */ new Date(), Me = ee || (G || ne ? 1 : pe.getDate()), ke = G || pe.getFullYear(), le = 0;
                G && !ne || (le = ne > 0 ? ne - 1 : pe.getMonth());
                var re, fe = Q || 0, Oe = ae || 0, Be = ge || 0, $e = Se || 0;
                return be ? new Date(Date.UTC(ke, le, Me, fe, Oe, Be, $e + 60 * be.offset * 1e3)) : W ? new Date(Date.UTC(ke, le, Me, fe, Oe, Be, $e)) : (re = new Date(ke, le, Me, fe, Oe, Be, $e), Le && (re = O(re).week(Le).toDate()), re);
              } catch {
                return /* @__PURE__ */ new Date("");
              }
            }(L, K, M, P), this.init(), Y && Y !== !0 && (this.$L = this.locale(Y).$L), X && L != this.format(K) && (this.$d = /* @__PURE__ */ new Date("")), u = {};
          } else if (K instanceof Array) for (var Z = K.length, U = 1; U <= Z; U += 1) {
            E[1] = K[U - 1];
            var H = P.apply(this, E);
            if (H.isValid()) {
              this.$d = H.$d, this.$L = H.$L, this.init();
              break;
            }
            U === Z && (this.$d = /* @__PURE__ */ new Date(""));
          }
          else j.call(this, I);
        };
      };
    });
  }(mi)), mi.exports;
}
var D4 = F4();
const x4 = /* @__PURE__ */ Bl(D4);
var hi = { exports: {} }, R4 = hi.exports, U0;
function H4() {
  return U0 || (U0 = 1, function(e, t) {
    (function(n, o) {
      e.exports = o();
    })(R4, function() {
      return function(n, o, i) {
        o.prototype.isBetween = function(r, l, s, u) {
          var f = i(r), d = i(l), p = (u = u || "()")[0] === "(", h = u[1] === ")";
          return (p ? this.isAfter(f, s) : !this.isBefore(f, s)) && (h ? this.isBefore(d, s) : !this.isAfter(d, s)) || (p ? this.isBefore(f, s) : !this.isAfter(f, s)) && (h ? this.isAfter(d, s) : !this.isBefore(d, s));
        };
      };
    });
  }(hi)), hi.exports;
}
var q4 = H4();
const Z4 = /* @__PURE__ */ Bl(q4);
var ki = { exports: {} }, K4 = ki.exports, G0;
function Y4() {
  return G0 || (G0 = 1, function(e, t) {
    (function(n, o) {
      e.exports = o();
    })(K4, function() {
      var n = "week", o = "year";
      return function(i, r, l) {
        var s = r.prototype;
        s.week = function(u) {
          if (u === void 0 && (u = null), u !== null) return this.add(7 * (u - this.week()), "day");
          var f = this.$locale().yearStart || 1;
          if (this.month() === 11 && this.date() > 25) {
            var d = l(this).startOf(o).add(1, o).date(f), p = l(this).endOf(n);
            if (d.isBefore(p)) return 1;
          }
          var h = l(this).startOf(o).date(f).startOf(n).subtract(1, "millisecond"), k = this.diff(h, n, !0);
          return k < 0 ? l(this).startOf("week").week() : Math.ceil(k);
        }, s.weeks = function(u) {
          return u === void 0 && (u = null), this.week(u);
        };
      };
    });
  }(ki)), ki.exports;
}
var U4 = Y4();
const G4 = /* @__PURE__ */ Bl(U4);
var gi = { exports: {} }, X4 = gi.exports, X0;
function Q4() {
  return X0 || (X0 = 1, function(e, t) {
    (function(n, o) {
      e.exports = o();
    })(X4, function() {
      return function(n, o) {
        var i = o.prototype, r = i.format;
        i.format = function(l) {
          var s = this, u = this.$locale();
          if (!this.isValid()) return r.bind(this)(l);
          var f = this.$utils(), d = (l || "YYYY-MM-DDTHH:mm:ssZ").replace(/\[([^\]]+)]|Q|wo|ww|w|WW|W|zzz|z|gggg|GGGG|Do|X|x|k{1,2}|S/g, function(p) {
            switch (p) {
              case "Q":
                return Math.ceil((s.$M + 1) / 3);
              case "Do":
                return u.ordinal(s.$D);
              case "gggg":
                return s.weekYear();
              case "GGGG":
                return s.isoWeekYear();
              case "wo":
                return u.ordinal(s.week(), "W");
              case "w":
              case "ww":
                return f.s(s.week(), p === "w" ? 1 : 2, "0");
              case "W":
              case "WW":
                return f.s(s.isoWeek(), p === "W" ? 1 : 2, "0");
              case "k":
              case "kk":
                return f.s(String(s.$H === 0 ? 24 : s.$H), p === "k" ? 1 : 2, "0");
              case "X":
                return Math.floor(s.$d.getTime() / 1e3);
              case "x":
                return s.$d.getTime();
              case "z":
                return "[" + s.offsetName() + "]";
              case "zzz":
                return "[" + s.offsetName("long") + "]";
              default:
                return p;
            }
          });
          return r.bind(this)(d);
        };
      };
    });
  }(gi)), gi.exports;
}
var _4 = Q4();
const J4 = /* @__PURE__ */ Bl(_4);
var yi = { exports: {} }, eb = yi.exports, Q0;
function tb() {
  return Q0 || (Q0 = 1, function(e, t) {
    (function(n, o) {
      e.exports = o();
    })(eb, function() {
      return function(n, o) {
        o.prototype.weekYear = function() {
          var i = this.month(), r = this.week(), l = this.year();
          return r === 1 && i === 11 ? l + 1 : i === 0 && r >= 52 ? l - 1 : l;
        };
      };
    });
  }(yi)), yi.exports;
}
var nb = tb();
const lb = /* @__PURE__ */ Bl(nb);
var bi = { exports: {} }, ob = bi.exports, _0;
function ib() {
  return _0 || (_0 = 1, function(e, t) {
    (function(n, o) {
      e.exports = o();
    })(ob, function() {
      var n = "month", o = "quarter";
      return function(i, r) {
        var l = r.prototype;
        l.quarter = function(f) {
          return this.$utils().u(f) ? Math.ceil((this.month() + 1) / 3) : this.month(this.month() % 3 + 3 * (f - 1));
        };
        var s = l.add;
        l.add = function(f, d) {
          return f = Number(f), this.$utils().p(d) === o ? this.add(3 * f, n) : s.bind(this)(f, d);
        };
        var u = l.startOf;
        l.startOf = function(f, d) {
          var p = this.$utils(), h = !!p.u(d) || d;
          if (p.p(f) === o) {
            var k = this.quarter() - 1;
            return h ? this.month(3 * k).startOf(n).startOf("day") : this.month(3 * k + 2).endOf(n).endOf("day");
          }
          return u.bind(this)(f, d);
        };
      };
    });
  }(bi)), bi.exports;
}
var rb = ib();
const ab = /* @__PURE__ */ Bl(rb);
var Ci = { exports: {} }, sb = Ci.exports, J0;
function ub() {
  return J0 || (J0 = 1, function(e, t) {
    (function(n, o) {
      e.exports = o(Sm());
    })(sb, function(n) {
      function o(l) {
        return l && typeof l == "object" && "default" in l ? l : { default: l };
      }
      var i = o(n), r = { name: "zh-cn", weekdays: "星期日_星期一_星期二_星期三_星期四_星期五_星期六".split("_"), weekdaysShort: "周日_周一_周二_周三_周四_周五_周六".split("_"), weekdaysMin: "日_一_二_三_四_五_六".split("_"), months: "一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月".split("_"), monthsShort: "1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"), ordinal: function(l, s) {
        return s === "W" ? l + "周" : l + "日";
      }, weekStart: 1, yearStart: 4, formats: { LT: "HH:mm", LTS: "HH:mm:ss", L: "YYYY/MM/DD", LL: "YYYY年M月D日", LLL: "YYYY年M月D日Ah点mm分", LLLL: "YYYY年M月D日ddddAh点mm分", l: "YYYY/M/D", ll: "YYYY年M月D日", lll: "YYYY年M月D日 HH:mm", llll: "YYYY年M月D日dddd HH:mm" }, relativeTime: { future: "%s内", past: "%s前", s: "几秒", m: "1 分钟", mm: "%d 分钟", h: "1 小时", hh: "%d 小时", d: "1 天", dd: "%d 天", M: "1 个月", MM: "%d 个月", y: "1 年", yy: "%d 年" }, meridiem: function(l, s) {
        var u = 100 * l + s;
        return u < 600 ? "凌晨" : u < 900 ? "早上" : u < 1100 ? "上午" : u < 1300 ? "中午" : u < 1800 ? "下午" : "晚上";
      } };
      return i.default.locale(r, null, !0), r;
    });
  }(Ci)), Ci.exports;
}
ub();
const cb = (e, t, n) => {
  n = function(r, l) {
    if (gn(r))
      return r.clone();
    const s = typeof l == "object" ? l : {};
    return s.date = r, s.args = arguments, new t(s);
  };
  const o = t.prototype, i = o.$utils;
  o.$utils = () => {
    const r = i();
    return r.i = gn, r;
  }, n.isDayjs = gn;
};
Ut.extend(cb);
Ut.extend(x4);
Ut.extend(Z4);
Ut.extend(G4);
Ut.extend(J4);
Ut.extend(lb);
Ut.extend(ab);
const Pt = Ut, Bt = {
  add(e, t, n) {
    return e.add(t, n);
  },
  subtract(e, t, n) {
    return e.subtract(t, n);
  },
  startOf(e, t) {
    return e.startOf(t);
  },
  startOfWeek(e, t) {
    const n = e.day();
    let o = e.subtract(n - t, "day");
    return o.isAfter(e) && (o = o.subtract(7, "day")), o;
  },
  endOf(e, t) {
    return e.endOf(t);
  },
  set(e, t, n) {
    return e.set(t, n);
  },
  isSameWeek(e, t, n) {
    const o = (i) => {
      const r = i.day(), l = r - n + (r < n ? 7 : 0);
      return i.subtract(l, "day").week();
    };
    return o(e) === o(t);
  }
};
function qt() {
  return Pt();
}
function wo(e) {
  return [...e].sort((t, n) => t.valueOf() - n.valueOf());
}
function Wv(e, t) {
  const n = (o, i) => o === void 0 && i === void 0 ? !1 : o && !i || !o && i ? !0 : (o == null ? void 0 : o.valueOf()) !== (i == null ? void 0 : i.valueOf());
  return t === void 0 && e === void 0 ? !1 : He(t) && He(e) ? n(t[0], e[0]) || n(t[1], e[1]) : !He(t) && !He(e) ? n(t, e) : !0;
}
function cn(e, t) {
  const n = (i) => {
    const r = /(Q1)|(Q2)|(Q3)|(Q4)/, l = {
      Q1: "01",
      Q2: "04",
      Q3: "07",
      Q4: "10"
    }, [s] = r.exec(i);
    return i.replace(r, l[s]);
  }, o = (i) => {
    if (i) {
      if (typeof i == "string") {
        if (rk(t))
          return Pt(n(i), t.replace(/\[Q]Q/, "MM"));
        if (Pt(i, t).isValid())
          return Pt(i, t);
      }
      return Pt(i);
    }
  };
  return He(e) ? e.map(o) : o(e);
}
function rn(e) {
  const t = (n) => n ? n.toDate() : void 0;
  return He(e) ? e.map(t) : t(e);
}
function zm(e, t) {
  Pt.locale({ ...Pt.Ls[e.toLocaleLowerCase()], weekStart: t });
}
function db(e) {
  const t = {};
  return e && Object.keys(e).forEach((n) => {
    const o = String(n);
    o.indexOf("data-") === 0 && (t[o] = e[o]), o.indexOf("aria-") === 0 && (t[o] = e[o]);
  }), t;
}
function gl(e, t, n = " ") {
  const o = String(e), i = o.length < t ? `${n}${o}` : o;
  return i.length < t ? gl(i, t, n) : i;
}
var fb = S({
  name: "Week",
  props: {
    mode: {
      type: String
    },
    dayStartOfWeek: {
      type: Number
    },
    isWeek: {
      type: Boolean
    },
    panel: {
      type: Boolean
    },
    value: {
      type: Object,
      required: !0
    },
    selectHandler: {
      type: Function
    },
    pageShowData: {
      type: Object,
      required: !0
    },
    pageData: {
      type: Array
    }
  },
  setup(e) {
    const {
      dayStartOfWeek: t,
      isWeek: n,
      panel: o,
      mode: i
    } = ve(e), r = B("calendar-week-list"), {
      t: l
    } = gt(), s = ["monday", "tuesday", "wednesday", "thursday", "friday", "saturday"];
    return t.value === 0 ? s.unshift("sunday") : s.push("sunday"), n.value && s.unshift("self"), () => c("div", {
      class: r
    }, [s.map((u) => c("div", {
      class: `${r}-item`,
      key: u
    }, [l(`calendar.week.${o.value || i.value === "year" ? "short" : "long"}.${u}`)]))]);
  }
});
function Go(e, t) {
  if (e && He(e))
    return e[t];
}
function Lm({
  prefixCls: e,
  mergedValue: t,
  rangeValues: n,
  hoverRangeValues: o,
  panel: i,
  isSameTime: r,
  innerMode: l
}) {
  return function(u, f) {
    const d = Go(n, 0), p = Go(n, 1), h = Go(o, 0), k = Go(o, 1), y = !u.isPrev && !u.isNext, w = y && i, g = w, C = w;
    h && d && h.isBefore(d);
    const z = p && k && k.isAfter(p) && C;
    let j = r(u.time, qt());
    return l === "year" && (j = qt().isSame(u.time, "date")), [
      `${e}-cell`,
      {
        [`${e}-cell-in-view`]: y,
        [`${e}-cell-today`]: j,
        [`${e}-cell-selected`]: t && r(u.time, t),
        [`${e}-cell-range-start`]: g,
        [`${e}-cell-range-end`]: C,
        [`${e}-cell-in-range`]: w,
        [`${e}-cell-in-range-near-hover`]: z,
        [`${e}-cell-hover-range-start`]: w,
        [`${e}-cell-hover-range-end`]: w,
        [`${e}-cell-hover-in-range`]: w,
        [`${e}-cell-disabled`]: f
      }
    ];
  };
}
const ep = 6 * 7, cr = (e) => ({
  year: e.year(),
  month: e.month() + 1,
  date: e.date(),
  day: e.day(),
  time: e
}), vb = (e) => ({
  start: cr(Bt.startOf(e, "month")),
  end: cr(Bt.endOf(e, "month")),
  days: e.daysInMonth()
});
function jm(e, {
  dayStartOfWeek: t = 0,
  isWeek: n
}) {
  const o = vb(e), i = Array(ep).fill(null).map(() => ({})), r = t === 0 ? o.start.day : (o.start.day || 7) - 1;
  i[r] = {
    ...o.start,
    isCurrent: !0
  };
  for (let s = 0; s < r; s++)
    i[r - s - 1] = {
      ...cr(Bt.subtract(o.start.time, s + 1, "day")),
      isPrev: !0
    };
  for (let s = 0; s < ep - r - 1; s++)
    i[r + s + 1] = {
      ...cr(Bt.add(o.start.time, s + 1, "day")),
      isCurrent: s < o.days,
      isNext: s >= o.days - 1
    };
  const l = Array(6).fill(null).map(() => []);
  for (let s = 0; s < 6; s++)
    if (l[s] = i.slice(s * 7, 7 * (s + 1)), n) {
      const u = l[s][0].time, f = [...l[s]];
      l[s].unshift({
        weekRows: f,
        weekOfYear: u.week()
      });
    }
  return l;
}
var Pm = S({
  name: "Month",
  props: {
    cell: {
      type: Boolean
    },
    pageData: {
      type: Array
    },
    current: {
      type: Number
    },
    value: {
      type: Object,
      required: !0
    },
    selectHandler: {
      type: Function,
      required: !0
    },
    mode: {
      type: String
    },
    pageShowDate: {
      type: Object,
      required: !0
    },
    panel: {
      type: Boolean
    },
    dayStartOfWeek: {
      type: Number,
      required: !0
    },
    isWeek: {
      type: Boolean,
      required: !0
    }
  },
  setup(e, {
    slots: t
  }) {
    const {
      pageData: n
    } = ve(e), o = B("calendar"), i = e.pageShowDate.year(), r = a(() => Lm({
      prefixCls: o,
      mergedValue: e.value,
      panel: !1,
      innerMode: e.mode,
      rangeValues: [],
      hoverRangeValues: [],
      isSameTime: (u, f) => u.isSame(f, "day")
    }));
    function l(u) {
      return u.map((f, d) => {
        var p;
        if (f.time) {
          const h = () => e.selectHandler(f.time, !1), k = e.isWeek ? {
            onClick: h
          } : {}, y = e.isWeek ? {} : {
            onClick: h
          };
          return c("div", se({
            key: d,
            class: r.value(f, !1)
          }, k), [t.default ? (p = t.default) == null ? void 0 : p.call(t, {
            year: f.year,
            month: f.month,
            date: f.date
          }) : c("div", se({
            class: `${o}-date`
          }, y), [c("div", {
            class: `${o}-date-value`
          }, [e.panel ? f.date : c("div", {
            class: `${o}-date-circle`
          }, [f.date])])])]);
        }
        if ("weekOfYear" in f) {
          const h = e.value.year(), k = e.value.month() + 1, y = e.value.week(), w = e.value && f.weekRows.find((g) => g.year === h && g.month === k) && y === f.weekOfYear;
          return c("div", {
            key: d,
            class: [`${o}-cell`, `${o}-cell-week`, {
              [`${o}-cell-selected-week`]: w,
              [`${o}-cell-in-range`]: w
            }]
          }, [c("div", {
            class: `${o}-date`
          }, [c("div", {
            class: `${o}-date-value`
          }, [f.weekOfYear])])]);
        }
        return null;
      });
    }
    let s = n.value;
    return typeof e.current == "number" && (s = jm(Pt(`${i}-${gl(e.current + 1, 2, "0")}-01`), {
      dayStartOfWeek: e.dayStartOfWeek,
      isWeek: e.isWeek
    })), () => c("div", {
      class: e.cell ? `${o}-month-cell` : `${o}-month`
    }, [c(fb, {
      value: e.value,
      selectHandler: e.selectHandler,
      dayStartOfWeek: e.dayStartOfWeek,
      isWeek: e.isWeek,
      panel: e.panel,
      mode: e.mode,
      pageShowData: e.pageShowDate,
      pageData: e.pageData
    }, null), c("div", {
      class: `${o}-month-cell-body`
    }, [s == null ? void 0 : s.map((u, f) => c("div", {
      key: f,
      class: [`${o}-month-row`, {
        [`${o}-row-week`]: e.isWeek
      }]
    }, [l(u)]))])]);
  }
});
const Im = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"].map((e, t) => ({
  name: e,
  value: t
})), Bm = Array(3);
for (let e = 0; e < 3; e++)
  Bm[e] = Im.slice(e * 4, 4 * (e + 1));
const Mm = Array(4);
for (let e = 0; e < 4; e++)
  Mm[e] = Im.slice(e * 3, 3 * (e + 1));
var pb = S({
  name: "Year",
  props: {
    mode: {
      type: String,
      required: !0
    },
    dayStartOfWeek: {
      type: Number,
      required: !0
    },
    value: {
      type: Object,
      required: !0
    },
    isWeek: {
      type: Boolean
    },
    panel: {
      type: Boolean,
      default: !1
    },
    pageShowData: {
      type: Object,
      required: !0
    },
    pageData: {
      type: Array
    },
    selectHandler: {
      type: Function,
      required: !0
    }
  },
  setup(e) {
    const t = B("calendar"), n = a(() => Lm({
      prefixCls: t,
      mergedValue: e.value,
      panel: !1,
      innerMode: e.mode,
      rangeValues: [],
      hoverRangeValues: [],
      isSameTime: (l, s) => l.isSame(s, "month")
    })), {
      t: o
    } = gt(), i = a(() => e.pageShowData.year()), r = e.panel ? Mm : Bm;
    return () => c("div", {
      class: `${t}-year`
    }, [r.map((l, s) => c("div", {
      class: `${t}-year-row`,
      key: s
    }, [l.map((u) => {
      const f = Pt(`${i.value}-${gl(u.value + 1, 2, "0")}-01`), d = e.panel ? {
        onClick: () => e.selectHandler(f, !1)
      } : {};
      return c("div", {
        key: u.value,
        class: n.value({
          ...u,
          time: f
        }, !1)
      }, [e.panel ? c("div", se({
        class: `${t}-date`
      }, d), [c("div", {
        class: `${t}-date-value`
      }, [o(`calendar.month.short.${u.name}`)])]) : c("div", {
        class: `${t}-month-with-days`
      }, [c("div", {
        class: `${t}-month-title`
      }, [o(`calendar.month.long.${u.name}`)]), c(Pm, {
        pageShowDate: e.pageShowData,
        pageData: e.pageData,
        dayStartOfWeek: e.dayStartOfWeek,
        selectHandler: e.selectHandler,
        isWeek: e.isWeek,
        cell: !0,
        current: u.value,
        value: e.value,
        mode: e.mode
      }, null)])]);
    })]))]);
  }
});
const mb = ({
  defaultValue: e,
  modelValue: t,
  emit: n,
  eventName: o = "input",
  updateEventName: i = "update:modelValue",
  eventHandlers: r
}) => {
  var l;
  const s = V(), u = V((l = e == null ? void 0 : e.value) != null ? l : ""), f = V(!1), d = V(!1), p = V("");
  let h;
  const k = a(() => {
    var L;
    return (L = t == null ? void 0 : t.value) != null ? L : u.value;
  }), y = (L, M) => {
    u.value = L, n(i, L), n(o, L, M);
  }, w = (L) => {
    const { value: M } = L.target;
    d.value || (y(M, L), at(() => {
      s.value && k.value !== s.value.value && (s.value.value = k.value);
    }));
  }, g = (L) => {
    o === "input" && k.value !== h && (h = k.value, n("change", k.value, L));
  }, C = (L) => {
    var M;
    const { value: E } = L.target;
    L.type === "compositionend" ? (d.value = !1, p.value = "", y(E, L), at(() => {
      s.value && k.value !== s.value.value && (s.value.value = k.value);
    })) : (d.value = !0, p.value = k.value + ((M = L.data) != null ? M : ""));
  }, P = (L) => {
    var M, E;
    f.value = !0, h = k.value, n("focus", L), (E = (M = r == null ? void 0 : r.value) == null ? void 0 : M.onFocus) == null || E.call(M, L);
  }, z = (L) => {
    var M, E;
    f.value = !1, n("blur", L), (E = (M = r == null ? void 0 : r.value) == null ? void 0 : M.onBlur) == null || E.call(M, L), g(L);
  }, j = (L) => {
    const M = L.key || L.code;
    !d.value && M === Pv.key && (n("pressEnter", L), g(L));
  }, I = (L) => {
    s.value && L.target !== s.value && (L.preventDefault(), s.value.focus());
  };
  return ze(k, (L) => {
    s.value && L !== s.value.value && (s.value.value = L);
  }), {
    inputRef: s,
    _value: u,
    _focused: f,
    isComposition: d,
    compositionValue: p,
    computedValue: k,
    handleInput: w,
    handleComposition: C,
    handleFocus: P,
    handleBlur: z,
    handleKeyDown: j,
    handleMousedown: I
  };
};
var hb = S({
  name: "InputLabel",
  inheritAttrs: !1,
  props: {
    modelValue: Object,
    inputValue: {
      type: String,
      default: ""
    },
    enabledInput: Boolean,
    formatLabel: Function,
    placeholder: String,
    retainInputValue: Boolean,
    disabled: Boolean,
    baseCls: String,
    size: String,
    error: Boolean,
    focused: Boolean,
    uninjectFormItemContext: Boolean
  },
  emits: ["update:inputValue", "inputValueChange", "focus", "blur"],
  setup(e, {
    attrs: t,
    emit: n,
    slots: o
  }) {
    var i;
    const {
      size: r,
      disabled: l,
      error: s,
      inputValue: u,
      uninjectFormItemContext: f
    } = ve(e), d = (i = e.baseCls) != null ? i : B("input-label"), {
      mergedSize: p,
      mergedDisabled: h,
      mergedError: k,
      eventHandlers: y
    } = mt({
      size: r,
      disabled: l,
      error: s,
      uninject: f == null ? void 0 : f.value
    }), {
      mergedSize: w
    } = xt(p), {
      inputRef: g,
      _focused: C,
      computedValue: P,
      handleInput: z,
      handleComposition: j,
      handleFocus: I,
      handleBlur: L,
      handleMousedown: M
    } = mb({
      modelValue: u,
      emit: n,
      eventName: "inputValueChange",
      updateEventName: "update:inputValue",
      eventHandlers: y
    }), E = a(() => {
      var D;
      return (D = e.focused) != null ? D : C.value;
    }), K = a(() => e.enabledInput && C.value || !e.modelValue), q = () => {
      var D, R;
      return e.modelValue ? (R = (D = e.formatLabel) == null ? void 0 : D.call(e, e.modelValue)) != null ? R : e.modelValue.label : "";
    }, T = a(() => e.enabledInput && e.modelValue ? q() : e.placeholder), X = () => {
      var D, R;
      return e.modelValue ? (R = (D = o.default) == null ? void 0 : D.call(o, {
        data: e.modelValue
      })) != null ? R : q() : null;
    }, Y = a(() => [d, `${d}-size-${w.value}`, {
      [`${d}-search`]: e.enabledInput,
      [`${d}-focus`]: E.value,
      [`${d}-disabled`]: h.value,
      [`${d}-error`]: k.value
    }]), Z = a(() => Ft(t, rl)), U = a(() => Wn(t, rl));
    return {
      inputRef: g,
      render: () => c("span", se(Z.value, {
        class: Y.value,
        title: q(),
        onMousedown: M
      }), [o.prefix && c("span", {
        class: `${d}-prefix`
      }, [o.prefix()]), c("input", se(U.value, {
        ref: g,
        class: [`${d}-input`, {
          [`${d}-input-hidden`]: !K.value
        }],
        value: P.value,
        readonly: !e.enabledInput,
        placeholder: T.value,
        disabled: h.value,
        onInput: z,
        onFocus: I,
        onBlur: L,
        onCompositionstart: j,
        onCompositionupdate: j,
        onCompositionend: j
      }), null), c("span", {
        class: [`${d}-value`, {
          [`${d}-value-hidden`]: K.value
        }]
      }, [X()]), o.suffix && c("span", {
        class: `${d}-suffix`
      }, [o.suffix()])])
    };
  },
  methods: {
    focus() {
      var e;
      (e = this.inputRef) == null || e.focus();
    },
    blur() {
      var e;
      (e = this.inputRef) == null || e.blur();
    }
  },
  render() {
    return this.render();
  }
});
const kb = (e, t) => {
  const n = [];
  for (const o of e)
    if (Qe(o))
      n.push({
        raw: o,
        value: o[t.value],
        label: o[t.label],
        closable: o[t.closable],
        tagProps: o[t.tagProps]
      });
    else if (e || A(e)) {
      const i = {
        value: o,
        label: String(o),
        closable: !0
      };
      n.push({
        raw: i,
        ...i
      });
    }
  return n;
}, tp = [
  "red",
  "orangered",
  "orange",
  "gold",
  "lime",
  "green",
  "cyan",
  "blue",
  "arcoblue",
  "purple",
  "pinkpurple",
  "magenta",
  "gray"
], gb = S({
  name: "Tag",
  components: {
    IconHover: pt,
    IconClose: Dt,
    IconLoading: Yt
  },
  props: {
    color: {
      type: String
    },
    size: {
      type: String
    },
    bordered: {
      type: Boolean,
      default: !1
    },
    visible: {
      type: Boolean,
      default: void 0
    },
    defaultVisible: {
      type: Boolean,
      default: !0
    },
    loading: {
      type: Boolean,
      default: !1
    },
    closable: {
      type: Boolean,
      default: !1
    },
    checkable: {
      type: Boolean,
      default: !1
    },
    checked: {
      type: Boolean,
      default: void 0
    },
    defaultChecked: {
      type: Boolean,
      default: !0
    },
    nowrap: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:visible": (e) => !0,
    "update:checked": (e) => !0,
    close: (e) => !0,
    check: (e, t) => !0
  },
  setup(e, { emit: t }) {
    const { size: n } = ve(e), o = B("tag"), i = a(
      () => e.color && tp.includes(e.color)
    ), r = a(
      () => e.color && !tp.includes(e.color)
    ), l = V(e.defaultVisible), s = V(e.defaultChecked), u = a(() => {
      var g;
      return (g = e.visible) != null ? g : l.value;
    }), f = a(
      () => {
        var g;
        return e.checkable ? (g = e.checked) != null ? g : s.value : !0;
      }
    ), { mergedSize: d } = xt(n), p = a(() => d.value === "mini" ? "small" : d.value), h = (g) => {
      l.value = !1, t("update:visible", !1), t("close", g);
    }, k = (g) => {
      if (e.checkable) {
        const C = !f.value;
        s.value = C, t("update:checked", C), t("check", C, g);
      }
    }, y = a(() => [
      o,
      `${o}-size-${p.value}`,
      {
        [`${o}-loading`]: e.loading,
        [`${o}-hide`]: !u.value,
        [`${o}-${e.color}`]: i.value,
        [`${o}-bordered`]: e.bordered,
        [`${o}-checkable`]: e.checkable,
        [`${o}-checked`]: f.value,
        [`${o}-custom-color`]: r.value
      }
    ]), w = a(() => {
      if (r.value)
        return {
          backgroundColor: e.color
        };
    });
    return {
      prefixCls: o,
      cls: y,
      style: w,
      computedVisible: u,
      computedChecked: f,
      handleClick: k,
      handleClose: h
    };
  }
});
function yb(e, t, n, o, i, r) {
  const l = J("icon-close"), s = J("icon-hover"), u = J("icon-loading");
  return e.computedVisible ? (v(), b("span", {
    key: 0,
    class: m(e.cls),
    style: F(e.style),
    onClick: t[0] || (t[0] = (...f) => e.handleClick && e.handleClick(...f))
  }, [
    e.$slots.icon ? (v(), b("span", {
      key: 0,
      class: m(`${e.prefixCls}-icon`)
    }, [
      _(e.$slots, "icon")
    ], 2)) : te("v-if", !0),
    e.nowrap ? (v(), b("span", {
      key: 1,
      class: m(`${e.prefixCls}-text`)
    }, [
      _(e.$slots, "default")
    ], 2)) : _(e.$slots, "default", { key: 2 }),
    e.closable ? (v(), oe(s, {
      key: 3,
      role: "button",
      "aria-label": "Close",
      prefix: e.prefixCls,
      class: m(`${e.prefixCls}-close-btn`),
      onClick: an(e.handleClose, ["stop"])
    }, {
      default: ue(() => [
        _(e.$slots, "close-icon", {}, () => [
          c(l)
        ])
      ]),
      _: 3
    }, 8, ["prefix", "class", "onClick"])) : te("v-if", !0),
    e.loading ? (v(), b("span", {
      key: 4,
      class: m(`${e.prefixCls}-loading-icon`)
    }, [
      c(u)
    ], 2)) : te("v-if", !0)
  ], 6)) : te("v-if", !0);
}
var Fa = /* @__PURE__ */ N(gb, [["render", yb]]);
const Fv = Object.assign(Fa, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Fa.name, Fa);
  }
}), bb = {
  value: "value",
  label: "label",
  closable: "closable",
  tagProps: "tagProps"
};
var Da = S({
  name: "InputTag",
  inheritAttrs: !1,
  props: {
    modelValue: {
      type: Array
    },
    defaultValue: {
      type: Array,
      default: () => []
    },
    inputValue: String,
    defaultInputValue: {
      type: String,
      default: ""
    },
    placeholder: String,
    disabled: {
      type: Boolean,
      default: !1
    },
    error: {
      type: Boolean,
      default: !1
    },
    readonly: {
      type: Boolean,
      default: !1
    },
    allowClear: {
      type: Boolean,
      default: !1
    },
    size: {
      type: String
    },
    maxTagCount: {
      type: Number,
      default: 0
    },
    retainInputValue: {
      type: [Boolean, Object],
      default: !1
    },
    formatTag: {
      type: Function
    },
    uniqueValue: {
      type: Boolean,
      default: !1
    },
    fieldNames: {
      type: Object
    },
    tagNowrap: {
      type: Boolean,
      default: !1
    },
    baseCls: String,
    focused: Boolean,
    disabledInput: Boolean,
    uninjectFormItemContext: Boolean
  },
  emits: {
    "update:modelValue": (e) => !0,
    "update:inputValue": (e) => !0,
    change: (e, t) => !0,
    inputValueChange: (e, t) => !0,
    pressEnter: (e, t) => !0,
    remove: (e, t) => !0,
    clear: (e) => !0,
    focus: (e) => !0,
    blur: (e) => !0
  },
  setup(e, {
    emit: t,
    slots: n,
    attrs: o
  }) {
    const {
      size: i,
      disabled: r,
      error: l,
      uninjectFormItemContext: s,
      modelValue: u
    } = ve(e), f = e.baseCls || B("input-tag"), d = V(), p = V(), {
      mergedSize: h,
      mergedDisabled: k,
      mergedError: y,
      feedback: w,
      eventHandlers: g
    } = mt({
      size: i,
      disabled: r,
      error: l,
      uninject: s == null ? void 0 : s.value
    }), {
      mergedSize: C
    } = xt(h), P = a(() => ({
      ...bb,
      ...e.fieldNames
    })), z = V(!1), j = V(e.defaultValue), I = V(e.defaultInputValue), L = V(!1), M = V(""), E = a(() => Qe(e.retainInputValue) ? {
      create: !1,
      blur: !1,
      ...e.retainInputValue
    } : {
      create: e.retainInputValue,
      blur: e.retainInputValue
    }), K = me({
      width: "12px"
    }), q = a(() => e.focused || z.value), T = (le, re) => {
      I.value = le, t("update:inputValue", le), t("inputValueChange", le, re);
    }, X = (le) => {
      var re;
      const {
        value: fe
      } = le.target;
      le.type === "compositionend" ? (L.value = !1, M.value = "", T(fe, le), at(() => {
        d.value && Z.value !== d.value.value && (d.value.value = Z.value);
      })) : (L.value = !0, M.value = Z.value + ((re = le.data) != null ? re : ""));
    }, Y = a(() => {
      var le;
      return (le = e.modelValue) != null ? le : j.value;
    }), Z = a(() => {
      var le;
      return (le = e.inputValue) != null ? le : I.value;
    });
    ze(u, (le) => {
      (Ve(le) || Jt(le)) && (j.value = []);
    });
    const U = (le) => {
      d.value && le.target !== d.value && (le.preventDefault(), d.value.focus());
    }, H = (le) => {
      const {
        value: re
      } = le.target;
      L.value || (T(re, le), at(() => {
        d.value && Z.value !== d.value.value && (d.value.value = Z.value);
      }));
    }, D = a(() => kb(Y.value, P.value)), R = a(() => {
      if (e.maxTagCount > 0) {
        const le = D.value.length - e.maxTagCount;
        if (le > 0) {
          const re = D.value.slice(0, e.maxTagCount), fe = {
            value: "__arco__more",
            label: `+${le}...`,
            closable: !1
          };
          return re.push({
            raw: fe,
            ...fe
          }), re;
        }
      }
      return D.value;
    }), W = (le, re) => {
      var fe, Oe;
      j.value = le, t("update:modelValue", le), t("change", le, re), (Oe = (fe = g.value) == null ? void 0 : fe.onChange) == null || Oe.call(fe, re);
    }, O = (le, re, fe) => {
      var Oe;
      const Be = (Oe = Y.value) == null ? void 0 : Oe.filter(($e, he) => he !== re);
      W(Be, fe), t("remove", le, fe);
    }, x = (le) => {
      W([], le), t("clear", le);
    }, G = a(() => !k.value && !e.readonly && e.allowClear && !!Y.value.length), ne = (le) => {
      var re;
      if (Z.value) {
        if (le.preventDefault(), e.uniqueValue && ((re = Y.value) != null && re.includes(Z.value))) {
          t("pressEnter", Z.value, le);
          return;
        }
        const fe = Y.value.concat(Z.value);
        W(fe, le), t("pressEnter", Z.value, le), E.value.create || T("", le);
      }
    }, ee = (le) => {
      var re, fe;
      z.value = !0, t("focus", le), (fe = (re = g.value) == null ? void 0 : re.onFocus) == null || fe.call(re, le);
    }, Q = (le) => {
      var re, fe;
      z.value = !1, !E.value.blur && Z.value && T("", le), t("blur", le), (fe = (re = g.value) == null ? void 0 : re.onBlur) == null || fe.call(re, le);
    }, ae = () => {
      for (let le = D.value.length - 1; le >= 0; le--)
        if (D.value[le].closable)
          return le;
      return -1;
    }, ge = (le) => {
      if (k.value || e.readonly)
        return;
      const re = le.key || le.code;
      if (!L.value && Z.value && re === Pv.key && ne(le), !L.value && R.value.length > 0 && !Z.value && re === um.key) {
        const fe = ae();
        fe >= 0 && O(D.value[fe].value, fe, le);
      }
    }, Se = (le) => {
      le > 12 ? K.width = `${le}px` : K.width = "12px";
    };
    Je(() => {
      p.value && Se(p.value.offsetWidth);
    });
    const be = () => {
      p.value && Se(p.value.offsetWidth);
    };
    ze(Z, (le) => {
      d.value && !L.value && le !== d.value.value && (d.value.value = le);
    });
    const Le = a(() => [f, `${f}-size-${C.value}`, {
      [`${f}-disabled`]: k.value,
      [`${f}-disabled-input`]: e.disabledInput,
      [`${f}-error`]: y.value,
      [`${f}-focus`]: q.value,
      [`${f}-readonly`]: e.readonly,
      [`${f}-has-tag`]: R.value.length > 0,
      [`${f}-has-prefix`]: !!n.prefix,
      [`${f}-has-suffix`]: !!n.suffix || G.value || w.value,
      [`${f}-has-placeholder`]: !Y.value.length
    }]), pe = a(() => Ft(o, rl)), Me = a(() => Wn(o, rl));
    return {
      inputRef: d,
      render: () => {
        var le;
        return c("span", se({
          class: Le.value,
          onMousedown: U
        }, pe.value), [c(jn, {
          onResize: be
        }, {
          default: () => [c("span", {
            ref: p,
            class: `${f}-mirror`
          }, [R.value.length > 0 ? M.value || Z.value : M.value || Z.value || e.placeholder])]
        }), n.prefix && c("span", {
          class: `${f}-prefix`
        }, [n.prefix()]), c(jo, {
          tag: "span",
          name: "input-tag-zoom",
          class: [`${f}-inner`, {
            [`${f}-nowrap`]: e.tagNowrap
          }]
        }, {
          default: () => [R.value.map((re, fe) => c(Fv, se({
            key: `tag-${re.value}`,
            class: `${f}-tag`,
            closable: !k.value && !e.readonly && re.closable,
            visible: !0,
            nowrap: e.tagNowrap
          }, re.tagProps, {
            onClose: (Oe) => O(re.value, fe, Oe)
          }), {
            default: () => {
              var Oe, Be, $e, he;
              return [(he = ($e = (Oe = n.tag) == null ? void 0 : Oe.call(n, {
                data: re.raw
              })) != null ? $e : (Be = e.formatTag) == null ? void 0 : Be.call(e, re.raw)) != null ? he : re.label];
            }
          })), c("input", se(Me.value, {
            ref: d,
            key: "input-tag-input",
            class: `${f}-input`,
            style: K,
            placeholder: R.value.length === 0 ? e.placeholder : void 0,
            disabled: k.value,
            readonly: e.readonly || e.disabledInput,
            onInput: H,
            onKeydown: ge,
            onFocus: ee,
            onBlur: Q,
            onCompositionstart: X,
            onCompositionupdate: X,
            onCompositionend: X
          }), null)]
        }), G.value && c(pt, {
          class: `${f}-clear-btn`,
          onClick: x,
          onMousedown: (re) => re.stopPropagation()
        }, {
          default: () => [c(Dt, null, null)]
        }), (n.suffix || !!w.value) && c("span", {
          class: `${f}-suffix`
        }, [(le = n.suffix) == null ? void 0 : le.call(n), !!w.value && c(No, {
          type: w.value
        }, null)])]);
      }
    };
  },
  methods: {
    focus() {
      var e;
      (e = this.inputRef) == null || e.focus();
    },
    blur() {
      var e;
      (e = this.inputRef) == null || e.blur();
    }
  },
  render() {
    return this.render();
  }
});
const Nm = Object.assign(Da, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Da.name, Da);
  }
});
var dr = S({
  name: "SelectView",
  props: {
    modelValue: {
      type: Array,
      required: !0
    },
    inputValue: String,
    placeholder: String,
    disabled: {
      type: Boolean,
      default: !1
    },
    error: {
      type: Boolean,
      default: !1
    },
    loading: {
      type: Boolean,
      default: !1
    },
    opened: {
      type: Boolean,
      default: !1
    },
    size: {
      type: String
    },
    bordered: {
      type: Boolean,
      default: !0
    },
    multiple: {
      type: Boolean,
      default: !1
    },
    allowClear: {
      type: Boolean,
      default: !1
    },
    allowCreate: {
      type: Boolean,
      default: !1
    },
    allowSearch: {
      type: Boolean,
      default: (e) => He(e.modelValue)
    },
    maxTagCount: {
      type: Number,
      default: 0
    },
    tagNowrap: {
      type: Boolean,
      default: !1
    },
    retainInputValue: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["remove", "clear", "focus", "blur"],
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      size: o,
      disabled: i,
      error: r
    } = ve(e), l = B("select-view"), {
      feedback: s,
      eventHandlers: u,
      mergedDisabled: f,
      mergedSize: d,
      mergedError: p
    } = mt({
      size: o,
      disabled: i,
      error: r
    }), {
      mergedSize: h
    } = xt(d), {
      opened: k
    } = ve(e), y = V(), w = a(
      () => {
        var T;
        return (T = y.value) == null ? void 0 : T.inputRef;
      }
    ), g = a(() => e.modelValue.length === 0), C = a(() => e.allowSearch || e.allowCreate), P = a(() => e.allowClear && !e.disabled && !g.value), z = (T) => {
      var X, Y;
      t("focus", T), (Y = (X = u.value) == null ? void 0 : X.onFocus) == null || Y.call(X, T);
    }, j = (T) => {
      var X, Y;
      t("blur", T), (Y = (X = u.value) == null ? void 0 : X.onBlur) == null || Y.call(X, T);
    }, I = (T) => {
      t("remove", T);
    }, L = (T) => {
      t("clear", T);
    }, M = () => {
      var T, X, Y, Z;
      return e.loading ? (X = (T = n["loading-icon"]) == null ? void 0 : T.call(n)) != null ? X : c(Yt, null, null) : e.allowSearch && e.opened ? (Z = (Y = n["search-icon"]) == null ? void 0 : Y.call(n)) != null ? Z : c(ur, null, null) : n["arrow-icon"] ? n["arrow-icon"]() : c(Il, {
        class: `${l}-arrow-icon`
      }, null);
    }, E = () => c(Ae, null, [P.value && c(pt, {
      class: `${l}-clear-btn`,
      onClick: L,
      onMousedown: (T) => T.stopPropagation()
    }, {
      default: () => [c(Dt, null, null)]
    }), c("span", {
      class: `${l}-icon`
    }, [M()]), !!s.value && c(No, {
      type: s.value
    }, null)]);
    ze(k, (T) => {
      !T && w.value && w.value.isSameNode(document.activeElement) && w.value.blur();
    });
    const K = a(() => [`${l}-${e.multiple ? "multiple" : "single"}`, {
      [`${l}-opened`]: e.opened,
      [`${l}-borderless`]: !e.bordered
    }]);
    return {
      inputRef: w,
      handleFocus: z,
      handleBlur: j,
      render: () => e.multiple ? c(Nm, {
        ref: y,
        baseCls: l,
        class: K.value,
        modelValue: e.modelValue,
        inputValue: e.inputValue,
        focused: e.opened,
        placeholder: e.placeholder,
        disabled: f.value,
        size: h.value,
        error: p.value,
        maxTagCount: e.maxTagCount,
        disabledInput: !e.allowSearch && !e.allowCreate,
        tagNowrap: e.tagNowrap,
        retainInputValue: !0,
        uninjectFormItemContext: !0,
        onRemove: I,
        onFocus: z,
        onBlur: j
      }, {
        prefix: n.prefix,
        suffix: E,
        tag: n.label
      }) : c(hb, {
        ref: y,
        baseCls: l,
        class: K.value,
        modelValue: e.modelValue[0],
        inputValue: e.inputValue,
        focused: e.opened,
        placeholder: e.placeholder,
        disabled: f.value,
        size: h.value,
        error: p.value,
        enabledInput: C.value,
        uninjectFormItemContext: !0,
        onFocus: z,
        onBlur: j
      }, {
        default: n.label,
        prefix: n.prefix,
        suffix: E
      })
    };
  },
  methods: {
    focus() {
      this.inputRef && this.inputRef.focus();
    },
    blur() {
      this.inputRef && this.inputRef.blur();
    }
  },
  render() {
    return this.render();
  }
});
const Cb = S({
  name: "Optgroup",
  props: {
    label: {
      type: String
    }
  },
  setup() {
    return {
      prefixCls: B("select-group")
    };
  }
});
function $b(e, t, n, o, i, r) {
  return v(), b(Ae, null, [
    $("li", {
      class: m(`${e.prefixCls}-title`)
    }, [
      _(e.$slots, "label", {}, () => [
        Re(Pe(e.label), 1)
      ])
    ], 2),
    _(e.$slots, "default")
  ], 64);
}
var po = /* @__PURE__ */ N(Cb, [["render", $b]]);
const np = typeof window > "u" ? global : window;
function So(e, t) {
  let n = 0;
  return (...o) => {
    n && np.clearTimeout(n), n = np.setTimeout(() => {
      n = 0, e(...o);
    }, t);
  };
}
function wb(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
const Sb = {
  value: "value",
  label: "label",
  disabled: "disabled",
  tagProps: "tagProps",
  render: "render"
};
var xa = S({
  name: "Select",
  components: {
    Trigger: Tt,
    SelectView: dr
  },
  inheritAttrs: !1,
  props: {
    multiple: {
      type: Boolean,
      default: !1
    },
    modelValue: {
      type: [String, Number, Boolean, Object, Array],
      default: void 0
    },
    defaultValue: {
      type: [String, Number, Boolean, Object, Array],
      default: (e) => Ve(e.multiple) ? "" : []
    },
    inputValue: {
      type: String
    },
    defaultInputValue: {
      type: String,
      default: ""
    },
    size: {
      type: String
    },
    placeholder: String,
    loading: {
      type: Boolean,
      default: !1
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    error: {
      type: Boolean,
      default: !1
    },
    allowClear: {
      type: Boolean,
      default: !1
    },
    allowSearch: {
      type: [Boolean, Object],
      default: (e) => !!e.multiple
    },
    allowCreate: {
      type: Boolean,
      default: !1
    },
    maxTagCount: {
      type: Number,
      default: 0
    },
    popupContainer: {
      type: [String, Object]
    },
    bordered: {
      type: Boolean,
      default: !0
    },
    defaultActiveFirstOption: {
      type: Boolean,
      default: !0
    },
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean,
      default: !1
    },
    unmountOnClose: {
      type: Boolean,
      default: !1
    },
    filterOption: {
      type: [Boolean, Function],
      default: !0
    },
    options: {
      type: Array,
      default: () => []
    },
    virtualListProps: {
      type: Object
    },
    triggerProps: {
      type: Object
    },
    formatLabel: {
      type: Function
    },
    fallbackOption: {
      type: [Boolean, Function],
      default: !0
    },
    showExtraOptions: {
      type: Boolean,
      default: !0
    },
    valueKey: {
      type: String,
      default: "value"
    },
    searchDelay: {
      type: Number,
      default: 500
    },
    limit: {
      type: Number,
      default: 0
    },
    fieldNames: {
      type: Object
    },
    scrollbar: {
      type: [Boolean, Object],
      default: !0
    },
    showHeaderOnEmpty: {
      type: Boolean,
      default: !1
    },
    showFooterOnEmpty: {
      type: Boolean,
      default: !1
    },
    tagNowrap: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    "update:inputValue": (e) => !0,
    "update:popupVisible": (e) => !0,
    change: (e) => !0,
    inputValueChange: (e) => !0,
    popupVisibleChange: (e) => !0,
    clear: (e) => !0,
    remove: (e) => !0,
    search: (e) => !0,
    dropdownScroll: (e) => !0,
    dropdownReachBottom: (e) => !0,
    exceedLimit: (e, t) => !0
  },
  setup(e, {
    slots: t,
    emit: n,
    attrs: o
  }) {
    const {
      size: i,
      disabled: r,
      error: l,
      options: s,
      filterOption: u,
      valueKey: f,
      multiple: d,
      popupVisible: p,
      defaultPopupVisible: h,
      showExtraOptions: k,
      modelValue: y,
      fieldNames: w,
      loading: g,
      defaultActiveFirstOption: C
    } = ve(e), P = B("select"), {
      mergedSize: z,
      mergedDisabled: j,
      mergedError: I,
      eventHandlers: L
    } = mt({
      size: i,
      disabled: r,
      error: l
    }), M = a(() => e.virtualListProps ? "div" : "li"), E = a(() => Qe(e.allowSearch) && !!e.allowSearch.retainInputValue);
    a(() => {
      if (Ne(e.formatLabel))
        return (ye) => {
          const ce = Be.get(ye.value);
          return e.formatLabel(ce);
        };
    });
    const K = V(), q = V({}), T = V(), {
      computedPopupVisible: X,
      handlePopupVisibleChange: Y
    } = Tr({
      popupVisible: p,
      defaultPopupVisible: h,
      emit: n
    }), Z = V(e.defaultValue), U = a(() => {
      var ye;
      const ce = (ye = e.modelValue) != null ? ye : Z.value;
      return (He(ce) ? ce : ce || A(ce) || zt(ce) || Xt(ce) ? [ce] : []).map((qe) => ({
        value: qe,
        key: Sl(qe, e.valueKey)
      }));
    });
    ze(y, (ye) => {
      (Ve(ye) || Jt(ye)) && (Z.value = d.value ? [] : ye);
    });
    const H = a(() => U.value.map((ye) => ye.key)), D = a(() => ({
      ...Sb,
      ...w == null ? void 0 : w.value
    })), R = V(), W = (ye) => {
      const ce = {};
      return ye.forEach((Ce) => {
        ce[Ce] = Be.get(Ce);
      }), ce;
    }, O = (ye) => {
      R.value = W(ye);
    }, x = (ye) => Ne(e.fallbackOption) ? e.fallbackOption(ye) : {
      [D.value.value]: ye,
      [D.value.label]: String(Qe(ye) ? ye[f == null ? void 0 : f.value] : ye)
    }, G = () => {
      const ye = [], ce = [];
      if (e.allowCreate || e.fallbackOption) {
        for (const Ce of U.value)
          if (!ce.includes(Ce.key) && Ce.value !== "") {
            const qe = Be.get(Ce.key);
            (!qe || qe.origin === "extraOptions") && (ye.push(Ce), ce.push(Ce.key));
          }
      }
      if (e.allowCreate && ae.value) {
        const Ce = Sl(ae.value);
        if (!ce.includes(Ce)) {
          const qe = Be.get(Ce);
          (!qe || qe.origin === "extraOptions") && ye.push({
            value: ae.value,
            key: Ce
          });
        }
      }
      return ye;
    }, ne = V([]), ee = a(() => ne.value.map((ye) => {
      var ce;
      let Ce = x(ye.value);
      const qe = (ce = R.value) == null ? void 0 : ce[ye.key];
      return !Ve(qe) && !ik(qe) && (Ce = {
        ...Ce,
        ...qe
      }), Ce;
    }));
    at(() => {
      Wt(() => {
        var ye;
        const ce = G();
        if (ce.length !== ne.value.length)
          ne.value = ce;
        else if (ce.length > 0) {
          for (let Ce = 0; Ce < ce.length; Ce++)
            if (ce[Ce].key !== ((ye = ne.value[Ce]) == null ? void 0 : ye.key)) {
              ne.value = ce;
              break;
            }
        }
      });
    });
    const Q = V(""), ae = a(() => {
      var ye;
      return (ye = e.inputValue) != null ? ye : Q.value;
    });
    ze(X, (ye) => {
      !ye && !E.value && ae.value && be("");
    });
    const ge = (ye) => {
      var ce, Ce;
      return e.multiple ? ye.map((qe) => {
        var Lt, bt;
        return (bt = (Lt = Be.get(qe)) == null ? void 0 : Lt.value) != null ? bt : "";
      }) : (Ce = (ce = Be.get(ye[0])) == null ? void 0 : ce.value) != null ? Ce : Ny(Be) ? void 0 : "";
    }, Se = (ye) => {
      var ce, Ce;
      const qe = ge(ye);
      Z.value = qe, n("update:modelValue", qe), n("change", qe), (Ce = (ce = L.value) == null ? void 0 : ce.onChange) == null || Ce.call(ce), O(ye);
    }, be = (ye) => {
      Q.value = ye, n("update:inputValue", ye), n("inputValueChange", ye);
    }, Le = (ye, ce) => {
      if (e.multiple) {
        if (H.value.includes(ye)) {
          const Ce = H.value.filter((qe) => qe !== ye);
          Se(Ce);
        } else if (he.value.includes(ye))
          if (e.limit > 0 && H.value.length >= e.limit) {
            const Ce = Be.get(ye);
            n("exceedLimit", Ce == null ? void 0 : Ce.value, ce);
          } else {
            const Ce = H.value.concat(ye);
            Se(Ce);
          }
        E.value || be("");
      } else {
        if (ye !== H.value[0] && Se([ye]), E.value) {
          const Ce = Be.get(ye);
          Ce && be(Ce.label);
        }
        Y(!1);
      }
    }, pe = So((ye) => {
      n("search", ye);
    }, e.searchDelay), Me = (ye) => {
      ye !== ae.value && (X.value || Y(!0), be(ye), e.allowSearch && pe(ye));
    }, ke = (ye) => {
      const ce = Be.get(ye), Ce = H.value.filter((qe) => qe !== ye);
      Se(Ce), n("remove", ce == null ? void 0 : ce.value);
    }, le = (ye) => {
      ye == null || ye.stopPropagation();
      const ce = H.value.filter((Ce) => {
        var qe;
        return (qe = Be.get(Ce)) == null ? void 0 : qe.disabled;
      });
      Se(ce), be(""), n("clear", ye);
    }, re = (ye) => {
      n("dropdownScroll", ye);
    }, fe = (ye) => {
      n("dropdownReachBottom", ye);
    }, {
      validOptions: Oe,
      optionInfoMap: Be,
      validOptionInfos: $e,
      enabledOptionKeys: he,
      handleKeyDown: Ue
    } = Vv({
      multiple: d,
      options: s,
      extraOptions: ee,
      inputValue: ae,
      filterOption: u,
      showExtraOptions: k,
      component: M,
      valueKey: f,
      fieldNames: w,
      loading: g,
      popupVisible: X,
      valueKeys: H,
      dropdownRef: K,
      optionRefs: q,
      virtualListRef: T,
      defaultActiveFirstOption: C,
      onSelect: Le,
      onPopupVisibleChange: Y
    }), et = a(() => {
      var ye;
      const ce = [];
      for (const Ce of U.value) {
        const qe = Be.get(Ce.key);
        qe && ce.push({
          ...qe,
          value: Ce.key,
          label: (ye = qe == null ? void 0 : qe.label) != null ? ye : String(Qe(Ce.value) ? Ce.value[f == null ? void 0 : f.value] : Ce.value),
          closable: !(qe != null && qe.disabled),
          tagProps: qe == null ? void 0 : qe.tagProps
        });
      }
      return ce;
    }), tt = (ye) => {
      if (Ne(t.option)) {
        const ce = t.option;
        return () => ce({
          data: ye.raw
        });
      }
      return Ne(ye.render) ? ye.render : () => ye.label;
    }, st = (ye) => {
      if (km(ye)) {
        let ce;
        return c(po, {
          key: ye.key,
          label: ye.label
        }, wb(ce = ye.options.map((Ce) => st(Ce))) ? ce : {
          default: () => [ce]
        });
      }
      return Mr(ye, {
        inputValue: ae.value,
        filterOption: u == null ? void 0 : u.value
      }) ? c(kl, {
        ref: (ce) => {
          ce != null && ce.$el && (q.value[ye.key] = ce.$el);
        },
        key: ye.key,
        value: ye.value,
        label: ye.label,
        disabled: ye.disabled,
        internal: !0
      }, {
        default: tt(ye)
      }) : null;
    }, $t = () => c(Ov, {
      ref: K,
      loading: e.loading,
      empty: $e.value.length === 0,
      virtualList: !!e.virtualListProps,
      scrollbar: e.scrollbar,
      showHeaderOnEmpty: e.showHeaderOnEmpty,
      showFooterOnEmpty: e.showFooterOnEmpty,
      onScroll: re,
      onReachBottom: fe
    }, {
      default: () => {
        var ye, ce;
        return [...(ce = (ye = t.default) == null ? void 0 : ye.call(t)) != null ? ce : [], ...Oe.value.map(st)];
      },
      "virtual-list": () => c(Jl, se(e.virtualListProps, {
        ref: T,
        data: Oe.value
      }), {
        item: ({
          item: ye
        }) => st(ye)
      }),
      empty: t.empty,
      header: t.header,
      footer: t.footer
    }), vn = ({
      data: ye
    }) => {
      var ce, Ce, qe, Lt;
      if ((t.label || Ne(e.formatLabel)) && ye) {
        const bt = Be.get(ye.value);
        if (bt != null && bt.raw)
          return (qe = (ce = t.label) == null ? void 0 : ce.call(t, {
            data: bt.raw
          })) != null ? qe : (Ce = e.formatLabel) == null ? void 0 : Ce.call(e, bt.raw);
      }
      return (Lt = ye == null ? void 0 : ye.label) != null ? Lt : "";
    };
    return () => c(Tt, se({
      trigger: "click",
      position: "bl",
      popupOffset: 4,
      animationName: "slide-dynamic-origin",
      hideEmpty: !0,
      preventFocus: !0,
      autoFitPopupWidth: !0,
      autoFitTransformOrigin: !0,
      disabled: j.value,
      popupVisible: X.value,
      unmountOnClose: e.unmountOnClose,
      clickToClose: !(e.allowSearch || e.allowCreate),
      popupContainer: e.popupContainer,
      onPopupVisibleChange: Y
    }, e.triggerProps), {
      default: () => {
        var ye, ce;
        return [(ce = (ye = t.trigger) == null ? void 0 : ye.call(t)) != null ? ce : c(dr, se({
          class: P,
          modelValue: et.value,
          inputValue: ae.value,
          multiple: e.multiple,
          disabled: j.value,
          error: I.value,
          loading: e.loading,
          allowClear: e.allowClear,
          allowCreate: e.allowCreate,
          allowSearch: !!e.allowSearch,
          opened: X.value,
          maxTagCount: e.maxTagCount,
          placeholder: e.placeholder,
          bordered: e.bordered,
          size: z.value,
          tagNowrap: e.tagNowrap,
          onInputValueChange: Me,
          onRemove: ke,
          onClear: le,
          onKeydown: Ue
        }, o), {
          label: vn,
          prefix: t.prefix,
          "arrow-icon": t["arrow-icon"],
          "loading-icon": t["loading-icon"],
          "search-icon": t["search-icon"]
        })];
      },
      content: $t
    });
  }
});
const zo = Object.assign(xa, {
  Option: kl,
  OptGroup: po,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + xa.name, xa), e.component(n + kl.name, kl), e.component(n + po.name, po);
  }
}), Om = Symbol("RadioGroup");
var $i = S({
  name: "Radio",
  components: {
    IconHover: pt
  },
  props: {
    modelValue: {
      type: [String, Number, Boolean],
      default: void 0
    },
    defaultChecked: {
      type: Boolean,
      default: !1
    },
    value: {
      type: [String, Number, Boolean],
      default: !0
    },
    type: {
      type: String,
      default: "radio"
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    uninjectGroupContext: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e, t) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const o = B("radio"), {
      modelValue: i
    } = ve(e), r = e.uninjectGroupContext ? void 0 : Ge(Om, void 0), {
      mergedDisabled: l,
      eventHandlers: s
    } = mt({
      disabled: un(e, "disabled")
    }), u = V(null), f = V(e.defaultChecked), d = a(() => (r == null ? void 0 : r.name) === "ArcoRadioGroup"), p = a(() => {
      var j;
      return (j = r == null ? void 0 : r.type) != null ? j : e.type;
    }), h = a(() => (r == null ? void 0 : r.disabled) || l.value), k = a(() => {
      var j, I;
      return d.value ? (r == null ? void 0 : r.value) === ((j = e.value) != null ? j : !0) : Ve(e.modelValue) ? f.value : e.modelValue === ((I = e.value) != null ? I : !0);
    });
    ze(i, (j) => {
      (Ve(j) || Jt(j)) && (f.value = !1);
    }), ze(k, (j, I) => {
      j !== I && (f.value = j, u.value && (u.value.checked = j));
    });
    const y = (j) => {
      var I, L;
      (L = (I = s.value) == null ? void 0 : I.onFocus) == null || L.call(I, j);
    }, w = (j) => {
      var I, L;
      (L = (I = s.value) == null ? void 0 : I.onBlur) == null || L.call(I, j);
    }, g = (j) => {
      j.stopPropagation();
    }, C = (j) => {
      var I, L, M, E, K;
      f.value = !0, d.value ? r == null || r.handleChange((I = e.value) != null ? I : !0, j) : (t("update:modelValue", (L = e.value) != null ? L : !0), t("change", (M = e.value) != null ? M : !0, j), (K = (E = s.value) == null ? void 0 : E.onChange) == null || K.call(E, j)), at(() => {
        u.value && u.value.checked !== k.value && (u.value.checked = k.value);
      });
    }, P = a(() => [`${p.value === "button" ? `${o}-button` : o}`, {
      [`${o}-checked`]: k.value,
      [`${o}-disabled`]: h.value
    }]), z = () => c(Ae, null, [c(J("icon-hover"), {
      class: `${o}-icon-hover`,
      disabled: h.value || k.value
    }, {
      default: () => [c("span", {
        class: `${o}-icon`
      }, null)]
    }), n.default && c("span", {
      class: `${o}-label`
    }, [n.default()])]);
    return () => {
      var j, I, L, M;
      return c("label", {
        class: P.value
      }, [c("input", {
        ref: u,
        type: "radio",
        checked: k.value,
        value: e.value,
        class: `${o}-target`,
        disabled: h.value,
        onClick: g,
        onChange: C,
        onFocus: y,
        onBlur: w
      }, null), p.value === "radio" ? (M = (L = (I = n.radio) != null ? I : (j = r == null ? void 0 : r.slots) == null ? void 0 : j.radio) == null ? void 0 : L({
        checked: k.value,
        disabled: h.value
      })) != null ? M : z() : c("span", {
        class: `${o}-button-content`
      }, [n.default && n.default()])]);
    };
  }
}), wi = S({
  name: "RadioGroup",
  props: {
    modelValue: {
      type: [String, Number, Boolean],
      default: void 0
    },
    defaultValue: {
      type: [String, Number, Boolean],
      default: ""
    },
    type: {
      type: String,
      default: "radio"
    },
    size: {
      type: String
    },
    options: {
      type: Array
    },
    direction: {
      type: String,
      default: "horizontal"
    },
    disabled: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e, t) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const o = B("radio-group"), {
      size: i,
      type: r,
      disabled: l,
      modelValue: s
    } = ve(e), {
      mergedDisabled: u,
      mergedSize: f,
      eventHandlers: d
    } = mt({
      size: i,
      disabled: l
    }), {
      mergedSize: p
    } = xt(f), h = V(e.defaultValue), k = a(() => {
      var P;
      return (P = e.modelValue) != null ? P : h.value;
    }), y = a(() => {
      var P;
      return ((P = e.options) != null ? P : []).map((z) => zt(z) || A(z) ? {
        label: z,
        value: z
      } : z);
    });
    it(Om, me({
      name: "ArcoRadioGroup",
      value: k,
      size: p,
      type: r,
      disabled: u,
      slots: n,
      handleChange: (P, z) => {
        var j, I;
        h.value = P, t("update:modelValue", P), t("change", P, z), (I = (j = d.value) == null ? void 0 : j.onChange) == null || I.call(j, z);
      }
    })), ze(k, (P) => {
      h.value !== P && (h.value = P);
    }), ze(s, (P) => {
      (Ve(P) || Jt(P)) && (h.value = "");
    });
    const g = a(() => [`${o}${e.type === "button" ? "-button" : ""}`, `${o}-size-${p.value}`, `${o}-direction-${e.direction}`, {
      [`${o}-disabled`]: u.value
    }]), C = () => y.value.map((P) => c($i, {
      key: P.value,
      value: P.value,
      disabled: P.disabled,
      modelValue: k.value === P.value
    }, {
      default: () => [n.label ? n.label({
        data: P
      }) : Ne(P.label) ? P.label() : P.label]
    }));
    return () => {
      var P;
      return c("span", {
        class: g.value
      }, [y.value.length > 0 ? C() : (P = n.default) == null ? void 0 : P.call(n)]);
    };
  }
});
const Ul = Object.assign($i, {
  Group: wi,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + $i.name, $i), e.component(n + wi.name, wi);
  }
}), zb = S({
  name: "IconLeft",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-left`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Lb = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function jb(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M32 8.4 16.444 23.956 32 39.513" }, null, -1)
  ]), 14, Lb);
}
var Ra = /* @__PURE__ */ N(zb, [["render", jb]]);
const xn = Object.assign(Ra, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ra.name, Ra);
  }
});
function Pb(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
function lp(e) {
  return e.parentElement;
}
var Ib = S({
  name: "Header",
  props: {
    mode: {
      type: String
    },
    dayStartOfWeek: {
      type: Number
    },
    isWeek: {
      type: Boolean
    },
    panel: {
      type: Boolean
    },
    modes: {
      type: Array
    },
    headerType: {
      type: String
    },
    pageShowData: {
      type: Object,
      required: !0
    },
    move: {
      type: Function,
      required: !0
    },
    onYearChange: {
      type: Function,
      required: !0
    },
    onMonthChange: {
      type: Function,
      required: !0
    },
    changePageShowDate: {
      type: Function,
      required: !0
    },
    onModeChange: {
      type: Function,
      required: !0
    },
    headerValueFormat: {
      type: String,
      required: !0
    }
  },
  emits: ["yearChange", "monthChange"],
  setup(e, {
    slots: t
  }) {
    const n = B("calendar"), {
      t: o
    } = gt(), i = He(e.modes) ? e.modes.map((d) => ({
      label: o(`datePicker.view.${d}`),
      value: d
    })) : [], r = e.headerType === "select", l = a(() => e.pageShowData.year()), s = a(() => e.pageShowData.month() + 1), u = a(() => {
      const d = [l.value];
      for (let p = 1; p <= 10; p++)
        d.unshift(l.value - p);
      for (let p = 1; p < 10; p++)
        d.push(l.value + p);
      return d;
    }), f = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12];
    return () => {
      let d;
      return c("div", {
        class: `${n}-header`
      }, [c("div", {
        class: `${n}-header-left`
      }, [r ? c(Ae, null, [c(zo, {
        size: "small",
        class: `${n}-header-value-year`,
        value: l,
        options: u.value,
        onChange: e.onYearChange,
        getPopupContainer: lp
      }, null), e.mode === "month" && c(zo, {
        size: "small",
        class: `${n}-header-value-month`,
        value: s,
        options: f,
        onChange: e.onMonthChange,
        getPopupContainer: lp
      }, null)]) : c(Ae, null, [c("div", {
        class: `${n}-header-icon`,
        role: "button",
        tabIndex: 0,
        onClick: () => e.changePageShowDate("prev", e.mode)
      }, [c(xn, null, null)]), c("div", {
        class: `${n}-header-value`
      }, [t.default ? t.default({
        year: l,
        month: s
      }) : e.pageShowData.format(e.headerValueFormat)]), c("div", {
        role: "button",
        tabIndex: 0,
        class: `${n}-header-icon`,
        onClick: () => e.changePageShowDate("next", e.mode)
      }, [c(bn, null, null)])]), c(Qt, {
        size: "small",
        onClick: () => e.move(qt())
      }, Pb(d = o("datePicker.today")) ? d : {
        default: () => [d]
      })]), c("div", {
        class: `${n}-header-right`
      }, [c(Ul.Group, {
        size: "small",
        type: "button",
        options: i,
        onChange: e.onModeChange,
        modelValue: e.mode
      }, null)])]);
    };
  }
});
function Bb(e, t) {
  return e === "month" || e === "year" && !t ? "YYYY-MM-DD" : "YYYY-MM";
}
var Ha = S({
  name: "Calendar",
  props: {
    modelValue: {
      type: Date,
      default: void 0
    },
    defaultValue: {
      type: Date
    },
    mode: {
      type: String
    },
    defaultMode: {
      type: String,
      default: "month"
    },
    modes: {
      type: Array,
      default: () => ["month", "year"]
    },
    allowSelect: {
      type: Boolean,
      default: !0
    },
    panel: {
      type: Boolean,
      default: !1
    },
    panelWidth: {
      type: Number
    },
    panelTodayBtn: {
      type: Boolean,
      default: !1
    },
    dayStartOfWeek: {
      type: Number,
      default: 0
    },
    isWeek: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0,
    panelChange: (e) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      dayStartOfWeek: o,
      isWeek: i
    } = ve(e), r = B("calendar"), l = V(e.defaultMode), {
      t: s
    } = gt(), u = a(() => e.mode ? e.mode : l.value), f = Bb(u.value, e.panel), d = V(cn(e.defaultValue || Date.now(), f)), p = a(() => e.modelValue ? cn(e.modelValue, f) : d.value), h = V(p.value || qt()), k = a(() => jm(h.value, {
      dayStartOfWeek: o.value,
      isWeek: i.value
    }));
    function y(E) {
      h.value = E, t("panelChange", E.toDate());
    }
    function w(E) {
      d.value = E, t("change", E.toDate()), t("update:modelValue", E.toDate()), y(E);
    }
    function g(E, K = !1) {
      K || w(E);
    }
    let C = "";
    u.value === "month" ? C = s("calendar.formatMonth") : u.value === "year" && (C = s("calendar.formatYear"));
    function P(E, K) {
      E === "prev" && (h.value = Bt.subtract(h.value, 1, K)), E === "next" && (h.value = Bt.add(h.value, 1, K)), t("panelChange", h.value.toDate());
    }
    function z(E) {
      const K = Bt.set(h.value, "year", E);
      h.value = K, t("panelChange", K.toDate());
    }
    function j(E) {
      const K = Bt.set(h.value, "month", E - 1);
      h.value = K, t("panelChange", K.toDate());
    }
    function I(E) {
      l.value = E;
    }
    const L = a(() => [r, u.value === "month" ? `${r}-mode-month` : `${r}-mode-year`, {
      [`${r}-panel`]: e.panel && (u.value === "month" || u.value === "year")
    }]), M = e.panel ? {
      width: e.panelWidth
    } : {};
    return () => c("div", se({
      class: L.value,
      style: M
    }, db(e)), [c(Ib, {
      move: w,
      headerValueFormat: C,
      modes: e.modes,
      mode: u.value,
      pageShowData: h.value,
      dayStartOfWeek: e.dayStartOfWeek,
      isWeek: e.isWeek,
      onModeChange: I,
      onYearChange: z,
      onMonthChange: j,
      changePageShowDate: P
    }, {
      default: n.header
    }), u.value === "month" && c("div", {
      class: `${r}-body`
    }, [c(Pm, {
      key: h.value.month(),
      pageData: k.value,
      value: p.value,
      mode: u.value,
      selectHandler: g,
      isWeek: e.isWeek,
      dayStartOfWeek: e.dayStartOfWeek,
      pageShowDate: h.value
    }, {
      default: n.default
    })]), u.value === "year" && c("div", {
      class: `${r}-body`
    }, [c(pb, {
      key: h.value.year(),
      pageData: k.value,
      pageShowData: h.value,
      mode: u.value,
      isWeek: e.isWeek,
      value: p.value,
      dayStartOfWeek: e.dayStartOfWeek,
      selectHandler: g
    }, null)]), e.panel && e.panelTodayBtn && c("div", {
      class: `${r}-footer-btn-wrapper`
    }, [s("today")])]);
  }
});
const Vm = Object.assign(Ha, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ha.name, Ha);
  }
}), Dv = Symbol("ArcoCard");
var qa = S({
  name: "Card",
  components: {
    Spin: Pn
  },
  props: {
    bordered: {
      type: Boolean,
      default: !0
    },
    loading: {
      type: Boolean,
      default: !1
    },
    hoverable: {
      type: Boolean,
      default: !1
    },
    size: {
      type: String
    },
    headerStyle: {
      type: Object,
      default: () => ({})
    },
    bodyStyle: {
      type: Object,
      default: () => ({})
    },
    title: {
      type: String
    },
    extra: {
      type: String
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("card"), {
      size: o
    } = ve(e), {
      mergedSize: i
    } = xt(o), r = a(() => i.value === "small" || i.value === "mini" ? "small" : "medium"), l = (f) => {
      const d = En(f);
      return c("div", {
        class: `${n}-actions`
      }, [c("div", {
        class: `${n}-actions-right`
      }, [d.map((p, h) => c("span", {
        key: `action-${h}`,
        class: `${n}-actions-item`
      }, [p]))])]);
    }, s = me({
      hasMeta: !1,
      hasGrid: !1,
      slots: t,
      renderActions: l
    });
    it(Dv, s);
    const u = a(() => [n, `${n}-size-${r.value}`, {
      [`${n}-loading`]: e.loading,
      [`${n}-bordered`]: e.bordered,
      [`${n}-hoverable`]: e.hoverable,
      [`${n}-contain-grid`]: s.hasGrid
    }]);
    return () => {
      var f, d, p, h, k, y, w;
      const g = !!((f = t.title) != null ? f : e.title), C = !!((d = t.extra) != null ? d : e.extra);
      return c("div", {
        class: u.value
      }, [(g || C) && c("div", {
        class: [`${n}-header`, {
          [`${n}-header-no-title`]: !g
        }],
        style: e.headerStyle
      }, [g && c("div", {
        class: `${n}-header-title`
      }, [(h = (p = t.title) == null ? void 0 : p.call(t)) != null ? h : e.title]), C && c("div", {
        class: `${n}-header-extra`
      }, [(y = (k = t.extra) == null ? void 0 : k.call(t)) != null ? y : e.extra])]), t.cover && c("div", {
        class: `${n}-cover`
      }, [t.cover()]), c("div", {
        class: `${n}-body`,
        style: e.bodyStyle
      }, [e.loading ? c(Pn, null, null) : (w = t.default) == null ? void 0 : w.call(t), t.actions && !s.hasMeta && l(t.actions())])]);
    };
  }
}), Si = S({
  name: "CardMeta",
  props: {
    title: {
      type: String
    },
    description: {
      type: String
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("card-meta"), o = Ge(Dv);
    return Je(() => {
      o && (o.hasMeta = !0);
    }), () => {
      var i, r, l, s, u, f;
      const d = !!((i = t.title) != null ? i : e.title), p = !!((r = t.description) != null ? r : e.description);
      return c("div", {
        class: n
      }, [(d || p) && c("div", {
        class: `${n}-content`
      }, [d && c("div", {
        class: `${n}-title`
      }, [(s = (l = t.title) == null ? void 0 : l.call(t)) != null ? s : e.title]), p && c("div", {
        class: `${n}-description`
      }, [(f = (u = t.description) == null ? void 0 : u.call(t)) != null ? f : e.description])]), (t.avatar || (o == null ? void 0 : o.slots.actions)) && c("div", {
        class: [`${n}-footer `, {
          [`${n}-footer-only-actions`]: !t.avatar
        }]
      }, [t.avatar && c("div", {
        class: `${n}-avatar`
      }, [t.avatar()]), o && o.slots.actions && o.renderActions(o.slots.actions())])]);
    };
  }
});
const Mb = S({
  name: "CardGrid",
  props: {
    hoverable: {
      type: Boolean,
      default: !1
    }
  },
  setup(e) {
    const t = B("card-grid"), n = Ge(Dv);
    return Je(() => {
      n && (n.hasGrid = !0);
    }), {
      cls: a(() => [
        t,
        {
          [`${t}-hoverable`]: e.hoverable
        }
      ])
    };
  }
});
function Nb(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.cls)
  }, [
    _(e.$slots, "default")
  ], 2);
}
var zi = /* @__PURE__ */ N(Mb, [["render", Nb]]);
const Ob = Object.assign(qa, {
  Meta: Si,
  Grid: zi,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + qa.name, qa), e.component(n + Si.name, Si), e.component(n + zi.name, zi);
  }
}), Vb = S({
  name: "Indicator",
  props: {
    count: {
      type: Number,
      default: 2
    },
    activeIndex: {
      type: Number,
      default: 0
    },
    type: {
      type: String,
      default: "line"
    },
    position: {
      type: String,
      default: "bottom"
    },
    trigger: {
      type: String,
      default: "click"
    }
  },
  emits: ["select"],
  setup(e, { emit: t }) {
    const n = B("carousel-indicator"), o = (s) => {
      var u;
      if (s.preventDefault(), e.type === "slider") {
        const f = s.offsetX, d = s.currentTarget.clientWidth;
        if (s.target === s.currentTarget) {
          const p = Math.floor(f / d * e.count);
          p !== e.activeIndex && t("select", p);
        }
      } else {
        const f = Number.parseInt(
          (u = s.target.getAttribute("data-index")) != null ? u : "",
          10
        );
        !Number.isNaN(f) && f !== e.activeIndex && t("select", f);
      }
    }, i = a(() => e.trigger === "click" ? { onClick: o } : { onMouseover: o }), r = a(() => [
      `${n}`,
      `${n}-${e.type}`,
      `${n}-${e.position}`
    ]), l = a(() => {
      const s = 100 / e.count;
      return { width: `${s}%`, left: `${e.activeIndex * s}%` };
    });
    return {
      prefixCls: n,
      eventHandlers: i,
      cls: r,
      sliderStyle: l
    };
  }
}), Tb = ["data-index"];
function Ab(e, t, n, o, i, r) {
  return v(), b("div", se({ class: e.cls }, e.eventHandlers), [
    e.type === "slider" ? (v(), b("span", {
      key: 0,
      style: F(e.sliderStyle),
      class: m([`${e.prefixCls}-item`, `${e.prefixCls}-item-active`])
    }, null, 6)) : (v(!0), b(Ae, { key: 1 }, St(Array(e.count), (l, s) => (v(), b("span", {
      key: s,
      "data-index": s,
      class: m([
        `${e.prefixCls}-item`,
        { [`${e.prefixCls}-item-active`]: s === e.activeIndex }
      ])
    }, null, 10, Tb))), 128))
  ], 16);
}
var Eb = /* @__PURE__ */ N(Vb, [["render", Ab]]);
const Wb = S({
  name: "IconUp",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-up`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Fb = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Db(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M39.6 30.557 24.043 15 8.487 30.557" }, null, -1)
  ]), 14, Fb);
}
var Za = /* @__PURE__ */ N(Wb, [["render", Db]]);
const Ar = Object.assign(Za, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Za.name, Za);
  }
}), xb = S({
  name: "Arrow",
  components: {
    IconUp: Ar,
    IconDown: Il,
    IconLeft: xn,
    IconRight: bn
  },
  props: {
    direction: {
      type: String,
      default: "horizontal"
    },
    showArrow: {
      type: String,
      default: "always"
    }
  },
  emits: ["previousClick", "nextClick"],
  setup(e, { emit: t }) {
    const n = B("carousel"), o = (l) => {
      t("previousClick", l);
    }, i = (l) => {
      t("nextClick", l);
    }, r = a(() => [
      `${n}-arrow`,
      {
        [`${n}-arrow-hover`]: e.showArrow === "hover"
      }
    ]);
    return {
      prefixCls: n,
      cls: r,
      onPreviousClick: o,
      onNextClick: i
    };
  }
});
function Rb(e, t, n, o, i, r) {
  const l = J("IconLeft"), s = J("IconUp"), u = J("IconRight"), f = J("IconDown");
  return v(), b("div", {
    class: m(e.cls)
  }, [
    $("div", {
      class: m(`${e.prefixCls}-arrow-${e.direction === "vertical" ? "top" : "left"}`),
      onClick: t[0] || (t[0] = (...d) => e.onPreviousClick && e.onPreviousClick(...d))
    }, [
      e.direction === "horizontal" ? (v(), oe(l, { key: 0 })) : (v(), oe(s, { key: 1 }))
    ], 2),
    $("div", {
      class: m(`${e.prefixCls}-arrow-${e.direction === "vertical" ? "bottom" : "right"}`),
      onClick: t[1] || (t[1] = (...d) => e.onNextClick && e.onNextClick(...d))
    }, [
      e.direction === "horizontal" ? (v(), oe(u, { key: 0 })) : (v(), oe(f, { key: 1 }))
    ], 2)
  ], 2);
}
var Hb = /* @__PURE__ */ N(xb, [["render", Rb]]);
const Tm = Symbol("ArcoCarousel"), Oo = (e) => {
  const t = {}, n = V([]), o = () => {
    if (t.value) {
      const i = tm(t.value, e);
      (i.length !== n.value.length || i.toString() !== n.value.toString()) && (n.value = i);
    }
  };
  return Je(() => o()), fn(() => o()), {
    children: t,
    components: n
  };
}, op = {
  interval: 3e3,
  hoverToPause: !0
};
function Ka(e, t) {
  const n = +e;
  return typeof n == "number" && !Number.isNaN(n) ? (n + t) % t : e;
}
var Ya = S({
  name: "Carousel",
  props: {
    current: {
      type: Number
    },
    defaultCurrent: {
      type: Number,
      default: 1
    },
    autoPlay: {
      type: [Boolean, Object],
      default: !1
    },
    moveSpeed: {
      type: Number,
      default: 500
    },
    animationName: {
      type: String,
      default: "slide"
    },
    trigger: {
      type: String,
      default: "click"
    },
    direction: {
      type: String,
      default: "horizontal"
    },
    showArrow: {
      type: String,
      default: "always"
    },
    arrowClass: {
      type: String,
      default: ""
    },
    indicatorType: {
      type: String,
      default: "dot"
    },
    indicatorPosition: {
      type: String,
      default: "bottom"
    },
    indicatorClass: {
      type: String,
      default: ""
    },
    transitionTimingFunction: {
      type: String,
      default: "cubic-bezier(0.34, 0.69, 0.1, 1)"
    }
  },
  emits: {
    "update:current": (e) => !0,
    change: (e, t, n) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      current: o,
      animationName: i,
      moveSpeed: r,
      transitionTimingFunction: l
    } = ve(e), s = B("carousel"), u = V(!1), f = V(), d = V(), p = a(() => Qe(e.autoPlay) ? {
      ...op,
      ...e.autoPlay
    } : e.autoPlay ? op : {});
    let h = 0, k = 0;
    const {
      children: y,
      components: w
    } = Oo("CarouselItem"), g = V(e.defaultCurrent - 1), C = a(() => {
      const Z = w.value.length, U = A(o.value) ? Ka(o.value - 1, Z) : g.value, H = Ka(U - 1, Z), D = Ka(U + 1, Z);
      return {
        mergedIndex: U,
        mergedPrevIndex: H,
        mergedNextIndex: D
      };
    }), P = me({
      items: w,
      slideTo: j,
      mergedIndexes: C,
      previousIndex: f,
      animationName: i,
      slideDirection: d,
      transitionTimingFunction: l,
      moveSpeed: r
    });
    it(Tm, P);
    const z = () => {
      h && window.clearInterval(h);
    };
    Wt(() => {
      var Z;
      const {
        interval: U
      } = p.value || {}, {
        mergedNextIndex: H
      } = C.value, D = ((Z = w.value) == null ? void 0 : Z.length) > 1 && !u.value && !!U;
      z(), D && (h = window.setInterval(() => {
        j({
          targetIndex: H
        });
      }, U));
    }), _t(() => {
      z();
    });
    function j({
      targetIndex: Z,
      isNegative: U = !1,
      isManual: H = !1
    }) {
      !k && Z !== C.value.mergedIndex && (f.value = g.value, g.value = Z, d.value = U ? "negative" : "positive", k = window.setTimeout(() => {
        k = 0;
      }, r.value), t("update:current", g.value + 1), t("change", g.value + 1, f.value + 1, H));
    }
    const I = () => j({
      targetIndex: C.value.mergedPrevIndex,
      isNegative: !0,
      isManual: !0
    }), L = () => j({
      targetIndex: C.value.mergedNextIndex,
      isManual: !0
    }), M = (Z) => j({
      targetIndex: Z,
      isNegative: Z < C.value.mergedIndex,
      isManual: !0
    }), E = a(() => p.value.hoverToPause ? {
      onMouseenter: () => {
        u.value = !0;
      },
      onMouseleave: () => {
        u.value = !1;
      }
    } : {}), K = a(() => e.indicatorType !== "never" && w.value.length > 1), q = a(() => e.showArrow !== "never" && w.value.length > 1), T = a(() => [s, `${s}-indicator-position-${e.indicatorPosition}`]), X = a(() => [`${s}-${e.animationName}`, `${s}-${e.direction}`, {
      [`${s}-negative`]: d.value === "negative"
    }]), Y = a(() => [`${s}-indicator-wrapper`, `${s}-indicator-wrapper-${e.indicatorPosition}`]);
    return () => {
      var Z;
      return y.value = (Z = n.default) == null ? void 0 : Z.call(n), c("div", se({
        class: T.value
      }, E.value), [c("div", {
        class: X.value
      }, [y.value]), K.value && c("div", {
        class: Y.value
      }, [c(Eb, {
        class: e.indicatorClass,
        type: e.indicatorType,
        count: w.value.length,
        activeIndex: C.value.mergedIndex,
        position: e.indicatorPosition,
        trigger: e.trigger,
        onSelect: M
      }, null)]), q.value && c(Hb, {
        class: e.arrowClass,
        direction: e.direction,
        showArrow: e.showArrow,
        onPreviousClick: I,
        onNextClick: L
      }, null)]);
    };
  }
});
const qb = S({
  name: "CarouselItem",
  setup() {
    const e = B("carousel-item"), t = dn(), n = Ge(Tm, {}), o = a(
      () => {
        var s, u, f;
        return (f = (u = n.items) == null ? void 0 : u.indexOf((s = t == null ? void 0 : t.uid) != null ? s : -1)) != null ? f : -1;
      }
    ), i = a(
      () => {
        var s;
        return ((s = n.mergedIndexes) == null ? void 0 : s.mergedIndex) === o.value;
      }
    ), r = a(() => {
      const { previousIndex: s, animationName: u, slideDirection: f, mergedIndexes: d } = n;
      return {
        [`${e}-prev`]: o.value === (d == null ? void 0 : d.mergedPrevIndex),
        [`${e}-next`]: o.value === (d == null ? void 0 : d.mergedNextIndex),
        [`${e}-current`]: i.value,
        [`${e}-slide-in`]: u === "slide" && f && i.value,
        [`${e}-slide-out`]: u === "slide" && f && o.value === s
      };
    }), l = a(() => {
      const { transitionTimingFunction: s, moveSpeed: u } = n;
      return {
        transitionTimingFunction: s,
        transitionDuration: `${u}ms`,
        animationTimingFunction: s,
        animationDuration: `${u}ms`
      };
    });
    return {
      cls: r,
      animationStyle: l,
      isCurrent: i
    };
  }
}), Zb = ["aria-hidden"];
function Kb(e, t, n, o, i, r) {
  return v(), b("div", {
    "aria-hidden": !e.isCurrent,
    class: m(e.cls),
    style: F(e.animationStyle)
  }, [
    _(e.$slots, "default")
  ], 14, Zb);
}
var Li = /* @__PURE__ */ N(qb, [["render", Kb]]);
const Yb = Object.assign(Ya, {
  Item: Li,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ya.name, Ya), e.component(n + Li.name, Li);
  }
}), Am = (e, {
  optionMap: t,
  leafOptionMap: n,
  leafOptionSet: o,
  leafOptionValueMap: i,
  totalLevel: r,
  checkStrictly: l,
  enabledLazyLoad: s,
  lazyLoadOptions: u,
  valueKey: f,
  fieldNames: d
}) => {
  let p = 0;
  const h = (y, w, g) => {
    var C;
    const P = (C = w == null ? void 0 : w.path) != null ? C : [];
    return p = Math.max(p, g ?? 1), y.map((z, j) => {
      var I;
      const L = z[d.value], M = {
        raw: z,
        value: L,
        label: (I = z[d.label]) != null ? I : String(L),
        disabled: !!z[d.disabled],
        selectionDisabled: !1,
        render: z[d.render],
        tagProps: z[d.tagProps],
        isLeaf: z[d.isLeaf],
        level: P.length,
        index: j,
        key: "",
        valueKey: String(Qe(L) ? L[f.value] : L),
        parent: w,
        path: [],
        pathValue: []
      }, E = P.concat(M), K = [], q = E.map((T) => (K.push(T.value), T.valueKey)).join("-");
      return M.path = E, M.pathValue = K, M.key = q, z[d.children] ? (M.isLeaf = !1, M.children = h(
        z[d.children],
        M,
        (g ?? 1) + 1
      )) : s && !M.isLeaf ? (M.isLeaf = !1, u[q] && (M.children = h(
        u[q],
        M,
        (g ?? 1) + 1
      ))) : M.isLeaf = !0, M.children && !M.disabled && (M.totalLeafOptions = M.children.reduce((T, X) => A(X.totalLeafOptions) ? T + X.totalLeafOptions : X.disabled || X.selectionDisabled ? T : T + (X.isLeaf ? 1 : 0), 0), M.totalLeafOptions === 0 && !l.value && (M.selectionDisabled = !0)), t.set(M.key, M), (M.isLeaf || l.value) && (o.add(M), n.set(M.key, M), i.has(M.valueKey) || i.set(M.valueKey, M.key)), M;
    });
  }, k = h(e);
  return r.value = p, k;
}, xv = (e, t) => {
  var n, o;
  let i = !1, r = !1;
  if (e.isLeaf)
    t != null && t.has(e.key) && (i = !0);
  else {
    const l = new RegExp(`^${e.key}(-|$)`), s = Array.from((n = t == null ? void 0 : t.keys()) != null ? n : []).reduce(
      (u, f) => l.test(f) ? u + 1 : u,
      0
    );
    s > 0 && s >= ((o = e.totalLeafOptions) != null ? o : 1) ? i = !0 : s > 0 && (r = !0);
  }
  return {
    checked: i,
    indeterminate: r
  };
}, Rv = (e) => {
  const t = [];
  if (e.isLeaf)
    t.push(e.key);
  else if (e.children)
    for (const n of e.children)
      t.push(...Rv(n));
  return t;
}, Hv = (e) => {
  const t = [];
  if (e.disabled || e.selectionDisabled)
    return t;
  if (e.isLeaf)
    t.push(e);
  else if (e.children)
    for (const n of e.children)
      t.push(...Hv(n));
  return t;
}, Em = (e, {
  valueKey: t,
  leafOptionValueMap: n
}) => {
  var o;
  if (He(e))
    return e.map((r) => Qe(r) ? r[t] : r).join("-");
  const i = Qe(e) ? e[t] : e;
  return (o = n.get(String(i))) != null ? o : String(i);
}, Wm = (e, { multiple: t, pathMode: n }) => He(e) ? n && !t && e.length > 0 && !He(e[0]) ? [e] : e : Ve(e) || Jt(e) || e === "" ? [] : [e], Fm = (e) => e.path.map((t) => t.label).join(" / "), qv = Symbol("ArcoCascader");
var tv = S({
  name: "CascaderOption",
  props: {
    option: {
      type: Object,
      required: !0
    },
    active: Boolean,
    multiple: Boolean,
    checkStrictly: Boolean,
    searchOption: Boolean,
    pathLabel: Boolean
  },
  setup(e) {
    const t = B("cascader-option"), n = Ge(qv, {}), o = V(!1), i = {}, r = (d) => {
      var p;
      if (Ne(n.loadMore) && !e.option.isLeaf) {
        const {
          isLeaf: h,
          children: k,
          key: y
        } = e.option;
        !h && !k && (o.value = !0, new Promise((w) => {
          var g;
          (g = n.loadMore) == null || g.call(n, e.option.raw, w);
        }).then((w) => {
          var g;
          o.value = !1, w && ((g = n.addLazyLoadOptions) == null || g.call(n, w, y));
        }));
      }
      (p = n.setSelectedPath) == null || p.call(n, e.option.key);
    };
    e.option.disabled || (i.onMouseenter = [() => {
      var d;
      return (d = n.setActiveKey) == null ? void 0 : d.call(n, e.option.key);
    }], i.onMouseleave = () => {
      var d;
      return (d = n.setActiveKey) == null ? void 0 : d.call(n);
    }, i.onClick = [], n.expandTrigger === "hover" ? i.onMouseenter.push((d) => r()) : i.onClick.push((d) => r()), e.option.isLeaf && !e.multiple && i.onClick.push((d) => {
      var p;
      r(), (p = n.onClickOption) == null || p.call(n, e.option);
    }));
    const l = a(() => [t, {
      [`${t}-active`]: e.active,
      [`${t}-disabled`]: e.option.disabled
    }]), s = a(() => {
      var d;
      return e.checkStrictly ? {
        checked: (d = n.valueMap) == null ? void 0 : d.has(e.option.key),
        indeterminate: !1
      } : xv(e.option, n.valueMap);
    }), u = () => {
      var d, p, h;
      return e.pathLabel ? (p = (d = n == null ? void 0 : n.formatLabel) == null ? void 0 : d.call(n, e.option.path.map((k) => k.raw))) != null ? p : Fm(e.option) : (h = n.slots) != null && h.option ? n.slots.option({
        data: e.option
      }) : Ne(e.option.render) ? e.option.render() : e.option.label;
    }, f = () => o.value ? c(Yt, null, null) : !e.searchOption && !e.option.isLeaf ? c(bn, null, null) : null;
    return () => {
      var d;
      return c("li", se({
        tabindex: "0",
        role: "menuitem",
        "aria-disabled": e.option.disabled,
        "aria-haspopup": !e.option.isLeaf,
        "aria-expanded": !e.option.isLeaf && e.active,
        title: e.option.label,
        class: l.value
      }, i), [e.multiple && c(Ln, {
        modelValue: s.value.checked,
        indeterminate: s.value.indeterminate,
        disabled: e.option.disabled || e.option.selectionDisabled,
        uninjectGroupContext: !0,
        onChange: (p, h) => {
          var k;
          h.stopPropagation(), r(), (k = n.onClickOption) == null || k.call(n, e.option, !s.value.checked);
        },
        onClick: (p) => p.stopPropagation()
      }, null), e.checkStrictly && !e.multiple && c(Ul, {
        modelValue: (d = n.valueMap) == null ? void 0 : d.has(e.option.key),
        disabled: e.option.disabled,
        uninjectGroupContext: !0,
        onChange: (p, h) => {
          var k;
          h.stopPropagation(), r(), (k = n.onClickOption) == null || k.call(n, e.option, !0);
        },
        onClick: (p) => p.stopPropagation()
      }, null), c("div", {
        class: `${t}-label`
      }, [u(), f()])]);
    };
  }
}), Ub = S({
  name: "CascaderColumn",
  props: {
    column: {
      type: Array,
      required: !0
    },
    level: {
      type: Number,
      default: 0
    },
    selectedPath: {
      type: Array,
      required: !0
    },
    activeKey: String,
    totalLevel: {
      type: Number,
      required: !0
    },
    multiple: Boolean,
    checkStrictly: Boolean,
    virtualListProps: {
      type: Object
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("cascader"), o = Ge(Kt, void 0), i = V(), r = V(!!e.virtualListProps), l = () => {
      var s, u, f, d, p;
      return (p = (d = (s = t.empty) == null ? void 0 : s.call(t)) != null ? d : (f = o == null ? void 0 : (u = o.slots).empty) == null ? void 0 : f.call(u, {
        component: "cascader"
      })) != null ? p : c(Gn, null, null);
    };
    return () => {
      var s;
      return c("div", {
        class: `${n}-panel-column`,
        style: {
          zIndex: e.totalLevel - e.level
        }
      }, [e.column.length === 0 ? c(In, {
        class: `${n}-column-content`
      }, {
        default: () => [c("div", {
          class: `${n}-list-empty`
        }, [l()])]
      }) : r.value ? c(Jl, se({
        key: (s = e.column) == null ? void 0 : s.length
      }, e.virtualListProps, {
        ref: i,
        data: e.column
      }), {
        item: ({
          item: u
        }) => c(tv, {
          key: u.key,
          option: u,
          active: e.selectedPath.includes(u.key) || u.key === e.activeKey,
          multiple: e.multiple,
          checkStrictly: e.checkStrictly
        }, null)
      }) : c(In, {
        class: `${n}-column-content`
      }, {
        default: () => [c("ul", {
          role: "menu",
          class: [`${n}-list`, {
            [`${n}-list-multiple`]: !!(e != null && e.multiple),
            [`${n}-list-strictly`]: !!(e != null && e.checkStrictly)
          }]
        }, [e.column.map((u) => c(tv, {
          key: u.key,
          option: u,
          active: e.selectedPath.includes(u.key) || u.key === e.activeKey,
          multiple: e.multiple,
          checkStrictly: e.checkStrictly
        }, null))])]
      })]);
    };
  }
});
function Gb(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var Dm = S({
  name: "BaseCascaderPanel",
  props: {
    displayColumns: {
      type: Array,
      required: !0
    },
    selectedPath: {
      type: Array,
      required: !0
    },
    activeKey: String,
    totalLevel: {
      type: Number,
      required: !0
    },
    multiple: Boolean,
    checkStrictly: Boolean,
    loading: Boolean,
    dropdown: Boolean,
    virtualListProps: {
      type: Object
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("cascader"), o = Ge(Kt, void 0), i = () => {
      var l, s, u, f, d;
      return (d = (f = (l = t.empty) == null ? void 0 : l.call(t)) != null ? f : (u = o == null ? void 0 : (s = o.slots).empty) == null ? void 0 : u.call(s, {
        component: "cascader"
      })) != null ? d : c(Gn, null, null);
    }, r = () => e.loading ? c("div", {
      key: "panel-column-loading",
      class: [`${n}-panel-column`, `${n}-panel-column-loading`]
    }, [c(Pn, null, null)]) : e.displayColumns.length === 0 ? c("div", {
      key: "panel-column-empty",
      class: `${n}-panel-column`
    }, [c("div", {
      class: `${n}-list-empty`
    }, [i()])]) : e.displayColumns.map((l, s) => c(Ub, {
      key: `column-${s}`,
      column: l,
      level: s,
      selectedPath: e.selectedPath,
      activeKey: e.activeKey,
      totalLevel: e.totalLevel,
      multiple: e.multiple,
      checkStrictly: e.checkStrictly,
      virtualListProps: e.virtualListProps
    }, {
      empty: t.empty
    }));
    return () => {
      let l;
      return c(jo, {
        tag: "div",
        name: "cascader-slide",
        class: [`${n}-panel`, {
          [`${n}-dropdown-panel`]: e.dropdown
        }]
      }, Gb(l = r()) ? l : {
        default: () => [l]
      });
    };
  }
});
function Xb(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var Qb = S({
  name: "CascaderSearchPanel",
  props: {
    options: {
      type: Array,
      required: !0
    },
    loading: Boolean,
    activeKey: String,
    multiple: Boolean,
    checkStrictly: Boolean,
    pathLabel: Boolean
  },
  setup(e, {
    slots: t
  }) {
    const n = B("cascader"), o = Ge(Kt, void 0), i = () => {
      var r, l, s, u, f;
      return e.loading ? c(Pn, null, null) : e.options.length === 0 ? c("div", {
        class: `${n}-list-empty`
      }, [(f = (u = (r = t.empty) == null ? void 0 : r.call(t)) != null ? u : (s = o == null ? void 0 : (l = o.slots).empty) == null ? void 0 : s.call(l, {
        component: "cascader"
      })) != null ? f : c(Gn, null, null)]) : c("ul", {
        role: "menu",
        class: [`${n}-list`, `${n}-search-list`, {
          [`${n}-list-multiple`]: e.multiple
        }]
      }, [e.options.map((d) => c(tv, {
        key: d.key,
        class: `${n}-search-option`,
        option: d,
        active: d.key === e.activeKey,
        multiple: e.multiple,
        checkStrictly: e.checkStrictly,
        pathLabel: e.pathLabel,
        searchOption: !0
      }, null))]);
    };
    return () => {
      let r;
      return c(In, {
        class: [`${n}-panel`, `${n}-search-panel`]
      }, Xb(r = i()) ? r : {
        default: () => [r]
      });
    };
  }
});
const xm = (e, {
  optionMap: t,
  filteredLeafOptions: n,
  showSearchPanel: o,
  expandChild: i
}) => {
  const r = V(), l = a(() => {
    if (r.value)
      return t.get(r.value);
  }), s = V([]), u = a(() => {
    const y = [e.value];
    for (const w of s.value) {
      const g = t.get(w);
      g != null && g.children && y.push(g.children);
    }
    return y;
  }), f = (y) => {
    var w;
    const g = h(y);
    s.value = (w = g == null ? void 0 : g.path.map((C) => C.key)) != null ? w : [];
  }, d = (y) => {
    r.value = y;
  }, p = a(() => {
    var y;
    return o != null && o.value ? n.value.filter((w) => !w.disabled) : l.value && l.value.parent ? (y = l.value.parent.children) == null ? void 0 : y.filter(
      (w) => !w.disabled
    ) : e.value.filter((w) => !w.disabled);
  }), h = (y) => {
    let w = y ? t.get(y) : void 0;
    if (i.value)
      for (; w && w.children && w.children.length > 0; )
        w = w.children[0];
    return w;
  };
  return {
    activeKey: r,
    activeOption: l,
    selectedPath: s,
    displayColumns: u,
    setActiveKey: d,
    setSelectedPath: f,
    getNextActiveNode: (y) => {
      var w, g, C, P, z, j, I;
      const L = (g = (w = p.value) == null ? void 0 : w.length) != null ? g : 0;
      if (r.value) {
        const M = (P = (C = p.value) == null ? void 0 : C.findIndex(
          (E) => E.key === r.value
        )) != null ? P : 0;
        return y === "next" ? (z = p.value) == null ? void 0 : z[(L + M + 1) % L] : (j = p.value) == null ? void 0 : j[(L + M - 1) % L];
      }
      return (I = p.value) == null ? void 0 : I[0];
    }
  };
}, _b = S({
  name: "Cascader",
  components: {
    Trigger: Tt,
    SelectView: dr,
    BaseCascaderPanel: Dm,
    CascaderSearchPanel: Qb
  },
  inheritAttrs: !1,
  props: {
    pathMode: {
      type: Boolean,
      default: !1
    },
    multiple: {
      type: Boolean,
      default: !1
    },
    modelValue: {
      type: [String, Number, Object, Array]
    },
    defaultValue: {
      type: [String, Number, Object, Array],
      default: (e) => e.multiple ? [] : e.pathMode ? void 0 : ""
    },
    options: {
      type: Array,
      default: () => []
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    error: {
      type: Boolean,
      default: !1
    },
    size: {
      type: String
    },
    allowSearch: {
      type: Boolean,
      default: (e) => !!e.multiple
    },
    allowClear: {
      type: Boolean,
      default: !1
    },
    inputValue: {
      type: String,
      default: void 0
    },
    defaultInputValue: {
      type: String,
      default: ""
    },
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    expandTrigger: {
      type: String,
      default: "click"
    },
    defaultPopupVisible: {
      type: Boolean,
      default: !1
    },
    placeholder: String,
    filterOption: {
      type: Function
    },
    popupContainer: {
      type: [String, Object]
    },
    maxTagCount: {
      type: Number,
      default: 0
    },
    formatLabel: {
      type: Function
    },
    triggerProps: {
      type: Object
    },
    checkStrictly: {
      type: Boolean,
      default: !1
    },
    loadMore: {
      type: Function
    },
    loading: {
      type: Boolean,
      default: !1
    },
    searchOptionOnlyLabel: {
      type: Boolean,
      default: !1
    },
    searchDelay: {
      type: Number,
      default: 500
    },
    fieldNames: {
      type: Object
    },
    valueKey: {
      type: String,
      default: "value"
    },
    fallback: {
      type: [Boolean, Function],
      default: !0
    },
    expandChild: {
      type: Boolean,
      default: !1
    },
    virtualListProps: {
      type: Object
    },
    tagNowrap: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    "update:popupVisible": (e) => !0,
    change: (e) => !0,
    inputValueChange: (e) => !0,
    clear: () => !0,
    search: (e) => !0,
    popupVisibleChange: (e) => !0,
    focus: (e) => !0,
    blur: (e) => !0
  },
  setup(e, { emit: t, slots: n }) {
    const {
      options: o,
      checkStrictly: i,
      loadMore: r,
      formatLabel: l,
      modelValue: s,
      disabled: u,
      valueKey: f,
      expandTrigger: d,
      expandChild: p,
      pathMode: h,
      multiple: k
    } = ve(e), y = V(e.defaultValue), w = V(e.defaultInputValue), g = V(e.defaultPopupVisible), { mergedDisabled: C, eventHandlers: P } = mt({ disabled: u });
    ze(s, ($e) => {
      (Ve($e) || Jt($e)) && (y.value = e.multiple ? [] : void 0);
    });
    const z = V([]), j = V(1), I = me(/* @__PURE__ */ new Map()), L = me(/* @__PURE__ */ new Map()), M = me(/* @__PURE__ */ new Map()), E = me(/* @__PURE__ */ new Set()), K = me({}), q = ($e, he) => {
      K[he] = $e;
    }, T = {
      value: "value",
      label: "label",
      disabled: "disabled",
      children: "children",
      tagProps: "tagProps",
      render: "render",
      isLeaf: "isLeaf"
    }, X = a(() => ({
      ...T,
      ...e.fieldNames
    }));
    ze(
      [o, K, X],
      ([$e, he, Ue]) => {
        I.clear(), L.clear(), M.clear(), E.clear(), z.value = Am($e ?? [], {
          enabledLazyLoad: !!e.loadMore,
          lazyLoadOptions: K,
          optionMap: I,
          leafOptionSet: E,
          leafOptionMap: L,
          leafOptionValueMap: M,
          totalLevel: j,
          checkStrictly: i,
          valueKey: f,
          fieldNames: Ue
        });
      },
      {
        immediate: !0,
        deep: !0
      }
    );
    const Y = a(() => {
      var $e;
      const he = Wm(($e = e.modelValue) != null ? $e : y.value, {
        multiple: e.multiple,
        pathMode: e.pathMode
      });
      return new Map(
        he.map((Ue) => [
          Em(Ue, {
            valueKey: e.valueKey,
            leafOptionValueMap: M
          }),
          Ue
        ])
      );
    }), Z = a(
      () => {
        var $e;
        return ($e = e.inputValue) != null ? $e : w.value;
      }
    ), U = a(
      () => {
        var $e;
        return ($e = e.popupVisible) != null ? $e : g.value;
      }
    ), H = ($e) => {
      var he;
      return $e == null ? void 0 : $e.toLocaleLowerCase().includes((he = Z.value) == null ? void 0 : he.toLocaleLowerCase());
    }, D = a(() => (e.checkStrictly ? Array.from(I.values()) : Array.from(E)).filter((he) => {
      var Ue;
      return Ne(e.filterOption) ? e.filterOption(Z.value, he.raw) : e.checkStrictly ? H(he.label) : (Ue = he.path) == null ? void 0 : Ue.find((et) => H(et.label));
    })), R = ($e) => {
      var he, Ue, et;
      const tt = e.multiple ? $e : (he = $e[0]) != null ? he : "";
      $e.length === 0 && (re(), le()), y.value = tt, t("update:modelValue", tt), t("change", tt), (et = (Ue = P.value) == null ? void 0 : Ue.onChange) == null || et.call(Ue);
    };
    ze([k, h], () => {
      const $e = [];
      Y.value.forEach((he, Ue) => {
        const et = L.get(Ue);
        et && $e.push(h.value ? et.pathValue : et.value);
      }), R($e);
    });
    const W = ($e) => {
      U.value !== $e && (g.value = $e, t("popupVisibleChange", $e));
    }, O = ($e) => {
      if (e.multiple) {
        const he = L.get($e);
        if (he)
          G(he, !1);
        else {
          const Ue = [];
          Y.value.forEach((et, tt) => {
            tt !== $e && Ue.push(et);
          }), R(Ue);
        }
      }
    }, x = ($e) => {
      R([e.pathMode ? $e.pathValue : $e.value]), W(!1);
    }, G = ($e, he) => {
      if (he) {
        const Ue = e.checkStrictly ? [$e] : Hv($e);
        R([
          ...Y.value.values(),
          ...Ue.filter((et) => !Y.value.has(et.key)).map((et) => e.pathMode ? et.pathValue : et.value)
        ]);
      } else {
        const Ue = e.checkStrictly ? [$e.key] : Rv($e), et = [];
        Y.value.forEach((tt, st) => {
          Ue.includes(st) || et.push(tt);
        }), R(et);
      }
      Q("", "optionChecked");
    }, ne = ($e, he) => {
      e.multiple ? G($e, he ?? !0) : x($e);
    }, ee = So(($e) => {
      t("search", $e);
    }, e.searchDelay), Q = ($e, he) => {
      $e !== Z.value && (he === "manual" && !U.value && (g.value = !0, t("popupVisibleChange", !0)), w.value = $e, t("inputValueChange", $e), e.allowSearch && ee($e));
    };
    ze(U, ($e) => {
      if ($e) {
        if (Y.value.size > 0) {
          const he = Array.from(Y.value.keys()), Ue = he[he.length - 1], et = L.get(Ue);
          et && et.key !== Le.value && (re(et.key), le(et.key));
        }
      } else
        Y.value.size === 0 && (re(), le()), Q("", "optionListHide");
    });
    const ae = ($e) => {
      if ($e.stopPropagation(), e.multiple) {
        const he = [];
        Y.value.forEach((Ue, et) => {
          const tt = L.get(et);
          tt != null && tt.disabled && he.push(e.pathMode ? tt.pathValue : tt.value);
        }), R(he);
      } else
        R([]);
      Q("", "manual"), t("clear");
    }, ge = a(
      () => e.allowSearch && Z.value.length > 0
    ), Se = ($e) => {
      t("focus", $e);
    }, be = ($e) => {
      t("blur", $e);
    }, {
      activeKey: Le,
      activeOption: pe,
      selectedPath: Me,
      displayColumns: ke,
      setActiveKey: le,
      setSelectedPath: re,
      getNextActiveNode: fe
    } = xm(z, {
      optionMap: I,
      filteredLeafOptions: D,
      showSearchPanel: ge,
      expandChild: p
    });
    it(
      qv,
      me({
        onClickOption: ne,
        setActiveKey: le,
        setSelectedPath: re,
        loadMore: r,
        expandTrigger: d,
        addLazyLoadOptions: q,
        formatLabel: l,
        slots: n,
        valueMap: Y
      })
    );
    const Oe = Nr(
      /* @__PURE__ */ new Map([
        [
          yt.ENTER,
          ($e) => {
            if (U.value) {
              if (pe.value) {
                let he;
                e.checkStrictly || pe.value.isLeaf ? he = !Y.value.has(pe.value.key) : he = !xv(
                  pe.value,
                  Y.value
                ).checked, re(pe.value.key), ne(pe.value, he);
              }
            } else
              W(!0);
          }
        ],
        [
          yt.ESC,
          ($e) => {
            W(!1);
          }
        ],
        [
          yt.ARROW_DOWN,
          ($e) => {
            $e.preventDefault();
            const he = fe("next");
            le(he == null ? void 0 : he.key);
          }
        ],
        [
          yt.ARROW_UP,
          ($e) => {
            $e.preventDefault();
            const he = fe("preview");
            le(he == null ? void 0 : he.key);
          }
        ],
        [
          yt.ARROW_RIGHT,
          ($e) => {
            var he, Ue;
            ge.value || ($e.preventDefault(), (he = pe.value) != null && he.children && (re(pe.value.key), le((Ue = pe.value.children[0]) == null ? void 0 : Ue.key)));
          }
        ],
        [
          yt.ARROW_LEFT,
          ($e) => {
            var he;
            ge.value || ($e.preventDefault(), (he = pe.value) != null && he.parent && (re(pe.value.parent.key), le(pe.value.parent.key)));
          }
        ]
      ])
    ), Be = a(() => {
      const $e = [];
      return Y.value.forEach((he, Ue) => {
        var et, tt;
        const st = L.get(Ue);
        if (st)
          $e.push({
            value: Ue,
            label: (tt = (et = e.formatLabel) == null ? void 0 : et.call(e, st.path.map(($t) => $t.raw))) != null ? tt : Fm(st),
            closable: !st.disabled,
            tagProps: st.tagProps
          });
        else if (e.fallback) {
          const $t = Ne(e.fallback) ? e.fallback(he) : He(he) ? he.join(" / ") : String(he);
          $e.push({
            value: Ue,
            label: $t,
            closable: !0
          });
        }
      }), $e;
    });
    return {
      optionInfos: z,
      filteredLeafOptions: D,
      selectedPath: Me,
      activeKey: Le,
      displayColumns: ke,
      computedInputValue: Z,
      computedPopupVisible: U,
      handleClear: ae,
      selectViewValue: Be,
      handleInputValueChange: Q,
      showSearchPanel: ge,
      handlePopupVisibleChange: W,
      handleFocus: Se,
      handleBlur: be,
      handleRemove: O,
      mergedDisabled: C,
      handleKeyDown: Oe,
      totalLevel: j
    };
  }
});
function Jb(e, t, n, o, i, r) {
  const l = J("select-view"), s = J("cascader-search-panel"), u = J("base-cascader-panel"), f = J("trigger");
  return v(), oe(f, se(e.triggerProps, {
    trigger: "click",
    "animation-name": "slide-dynamic-origin",
    "auto-fit-transform-origin": "",
    "popup-visible": e.computedPopupVisible,
    position: "bl",
    disabled: e.mergedDisabled,
    "popup-offset": 4,
    "auto-fit-popup-width": e.showSearchPanel,
    "popup-container": e.popupContainer,
    "prevent-focus": !0,
    "click-to-close": !e.allowSearch,
    onPopupVisibleChange: e.handlePopupVisibleChange
  }), {
    content: ue(() => [
      e.showSearchPanel ? (v(), oe(s, {
        key: 0,
        options: e.filteredLeafOptions,
        "active-key": e.activeKey,
        multiple: e.multiple,
        "check-strictly": e.checkStrictly,
        loading: e.loading,
        "path-label": !e.searchOptionOnlyLabel
      }, kt({ _: 2 }, [
        e.$slots.empty ? {
          name: "empty",
          fn: ue(() => [
            _(e.$slots, "empty")
          ]),
          key: "0"
        } : void 0
      ]), 1032, ["options", "active-key", "multiple", "check-strictly", "loading", "path-label"])) : (v(), oe(u, {
        key: 1,
        "display-columns": e.displayColumns,
        "selected-path": e.selectedPath,
        "active-key": e.activeKey,
        multiple: e.multiple,
        "total-level": e.totalLevel,
        "check-strictly": e.checkStrictly,
        loading: e.loading,
        "virtual-list-props": e.virtualListProps,
        dropdown: ""
      }, kt({ _: 2 }, [
        e.$slots.empty ? {
          name: "empty",
          fn: ue(() => [
            _(e.$slots, "empty")
          ]),
          key: "0"
        } : void 0
      ]), 1032, ["display-columns", "selected-path", "active-key", "multiple", "total-level", "check-strictly", "loading", "virtual-list-props"]))
    ]),
    default: ue(() => [
      c(l, se({
        "model-value": e.selectViewValue,
        "input-value": e.computedInputValue,
        disabled: e.mergedDisabled,
        error: e.error,
        multiple: e.multiple,
        "allow-clear": e.allowClear,
        "allow-search": e.allowSearch,
        size: e.size,
        opened: e.computedPopupVisible,
        placeholder: e.placeholder,
        loading: e.loading,
        "max-tag-count": e.maxTagCount,
        "tag-nowrap": e.tagNowrap
      }, e.$attrs, {
        onInputValueChange: e.handleInputValueChange,
        onClear: e.handleClear,
        onFocus: e.handleFocus,
        onBlur: e.handleBlur,
        onRemove: e.handleRemove,
        onKeydown: e.handleKeyDown
      }), kt({ _: 2 }, [
        e.$slots.label ? {
          name: "label",
          fn: ue((d) => [
            _(e.$slots, "label", dt(Gt(d)))
          ]),
          key: "0"
        } : void 0,
        e.$slots.prefix ? {
          name: "prefix",
          fn: ue(() => [
            _(e.$slots, "prefix")
          ]),
          key: "1"
        } : void 0,
        e.$slots["arrow-icon"] ? {
          name: "arrow-icon",
          fn: ue(() => [
            _(e.$slots, "arrow-icon")
          ]),
          key: "2"
        } : void 0,
        e.$slots["loading-icon"] ? {
          name: "loading-icon",
          fn: ue(() => [
            _(e.$slots, "loading-icon")
          ]),
          key: "3"
        } : void 0,
        e.$slots["search-icon"] ? {
          name: "search-icon",
          fn: ue(() => [
            _(e.$slots, "search-icon")
          ]),
          key: "4"
        } : void 0
      ]), 1040, ["model-value", "input-value", "disabled", "error", "multiple", "allow-clear", "allow-search", "size", "opened", "placeholder", "loading", "max-tag-count", "tag-nowrap", "onInputValueChange", "onClear", "onFocus", "onBlur", "onRemove", "onKeydown"])
    ]),
    _: 3
  }, 16, ["popup-visible", "disabled", "auto-fit-popup-width", "popup-container", "click-to-close", "onPopupVisibleChange"]);
}
var Ua = /* @__PURE__ */ N(_b, [["render", Jb]]);
const e3 = S({
  name: "CascaderPanel",
  components: {
    BaseCascaderPanel: Dm
  },
  props: {
    pathMode: {
      type: Boolean,
      default: !1
    },
    multiple: {
      type: Boolean,
      default: !1
    },
    modelValue: {
      type: [String, Number, Array]
    },
    defaultValue: {
      type: [String, Number, Array],
      default: (e) => e.multiple ? [] : e.pathMode ? void 0 : ""
    },
    options: {
      type: Array,
      default: () => []
    },
    expandTrigger: {
      type: String,
      default: "click"
    },
    checkStrictly: {
      type: Boolean,
      default: !1
    },
    loadMore: {
      type: Function
    },
    fieldNames: {
      type: Object
    },
    valueKey: {
      type: String,
      default: "value"
    },
    expandChild: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0
  },
  setup(e, { emit: t, slots: n }) {
    const {
      options: o,
      checkStrictly: i,
      loadMore: r,
      modelValue: l,
      valueKey: s,
      expandChild: u,
      expandTrigger: f
    } = ve(e), d = V(e.defaultValue);
    ze(l, (W) => {
      (Ve(W) || Jt(W)) && (d.value = e.multiple ? [] : void 0);
    });
    const p = V([]), h = V(1), k = me(/* @__PURE__ */ new Map()), y = me(/* @__PURE__ */ new Map()), w = me(/* @__PURE__ */ new Map()), g = me(/* @__PURE__ */ new Set()), C = me({}), P = (W, O) => {
      C[O] = W;
    }, z = {
      value: "value",
      label: "label",
      disabled: "disabled",
      children: "children",
      tagProps: "tagProps",
      render: "render",
      isLeaf: "isLeaf"
    }, j = a(() => ({
      ...z,
      ...e.fieldNames
    }));
    ze(
      [o, C, j],
      ([W, O, x]) => {
        k.clear(), y.clear(), w.clear(), g.clear(), p.value = Am(W ?? [], {
          enabledLazyLoad: !!e.loadMore,
          lazyLoadOptions: O,
          optionMap: k,
          leafOptionSet: g,
          leafOptionMap: y,
          leafOptionValueMap: w,
          totalLevel: h,
          checkStrictly: i,
          fieldNames: x,
          valueKey: s
        });
      },
      {
        immediate: !0
      }
    );
    const I = a(() => {
      var W;
      const O = Wm((W = e.modelValue) != null ? W : d.value, {
        multiple: e.multiple,
        pathMode: e.pathMode
      });
      return new Map(
        O.map((x) => [
          Em(x, {
            valueKey: e.valueKey,
            leafOptionValueMap: w
          }),
          x
        ])
      );
    }), L = a(
      () => e.checkStrictly ? Array.from(k.values()) : Array.from(g)
    ), M = (W) => {
      var O;
      const x = e.multiple ? W : (O = W[0]) != null ? O : "";
      W.length === 0 && (H(), U()), d.value = x, t("update:modelValue", x), t("change", x);
    }, E = (W) => {
      M([e.pathMode ? W.pathValue : W.value]);
    }, K = (W, O) => {
      if (O) {
        const x = e.checkStrictly ? [W] : Hv(W);
        M([
          ...I.value.values(),
          ...x.filter((G) => !I.value.has(G.key)).map((G) => e.pathMode ? G.pathValue : G.value)
        ]);
      } else {
        const x = e.checkStrictly ? [W.key] : Rv(W), G = [];
        I.value.forEach((ne, ee) => {
          x.includes(ee) || G.push(ne);
        }), M(G);
      }
    }, q = (W, O) => {
      e.multiple ? K(W, O ?? !0) : E(W);
    }, {
      activeKey: T,
      activeOption: X,
      selectedPath: Y,
      displayColumns: Z,
      setActiveKey: U,
      setSelectedPath: H,
      getNextActiveNode: D
    } = xm(p, {
      optionMap: k,
      filteredLeafOptions: L,
      expandChild: u
    });
    it(
      qv,
      me({
        onClickOption: q,
        setActiveKey: U,
        setSelectedPath: H,
        loadMore: r,
        addLazyLoadOptions: P,
        slots: n,
        valueMap: I,
        expandTrigger: f
      })
    );
    const R = Nr(
      /* @__PURE__ */ new Map([
        [
          yt.ENTER,
          (W) => {
            if (X.value) {
              let O;
              e.checkStrictly || X.value.isLeaf ? O = !I.value.has(X.value.key) : O = !xv(
                X.value,
                I.value
              ).checked, H(X.value.key), q(X.value, O);
            }
          }
        ],
        [
          yt.ARROW_DOWN,
          (W) => {
            W.preventDefault();
            const O = D("next");
            U(O == null ? void 0 : O.key);
          }
        ],
        [
          yt.ARROW_UP,
          (W) => {
            W.preventDefault();
            const O = D("preview");
            U(O == null ? void 0 : O.key);
          }
        ],
        [
          yt.ARROW_RIGHT,
          (W) => {
            var O, x;
            W.preventDefault(), (O = X.value) != null && O.children && (H(X.value.key), U((x = X.value.children[0]) == null ? void 0 : x.key));
          }
        ],
        [
          yt.ARROW_LEFT,
          (W) => {
            var O;
            W.preventDefault(), (O = X.value) != null && O.parent && (H(X.value.parent.key), U(X.value.parent.key));
          }
        ]
      ])
    );
    return {
      optionInfos: p,
      filteredLeafOptions: L,
      selectedPath: Y,
      activeKey: T,
      displayColumns: Z,
      handleKeyDown: R,
      totalLevel: h
    };
  }
});
function t3(e, t, n, o, i, r) {
  const l = J("base-cascader-panel");
  return v(), oe(l, {
    "display-columns": e.displayColumns,
    "selected-path": e.selectedPath,
    "active-key": e.activeKey,
    multiple: e.multiple,
    "total-level": e.totalLevel,
    "check-strictly": e.checkStrictly,
    onKeydown: e.handleKeyDown
  }, kt({ _: 2 }, [
    e.$slots.empty ? {
      name: "empty",
      fn: ue(() => [
        _(e.$slots, "empty")
      ]),
      key: "0"
    } : void 0
  ]), 1032, ["display-columns", "selected-path", "active-key", "multiple", "total-level", "check-strictly", "onKeydown"]);
}
var ji = /* @__PURE__ */ N(e3, [["render", t3]]);
const n3 = Object.assign(Ua, {
  CascaderPanel: ji,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ua.name, Ua), e.component(n + ji.name, ji);
  }
}), Rm = Symbol("collapseCtx"), l3 = S({
  name: "Collapse",
  props: {
    activeKey: {
      type: Array,
      default: void 0
    },
    defaultActiveKey: {
      type: Array,
      default: () => []
    },
    accordion: {
      type: Boolean,
      default: !1
    },
    showExpandIcon: {
      type: Boolean,
      default: void 0
    },
    expandIconPosition: {
      type: String,
      default: "left"
    },
    bordered: {
      type: Boolean,
      default: !0
    },
    destroyOnHide: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:activeKey": (e) => !0,
    change: (e, t) => !0
  },
  setup(e, { emit: t, slots: n }) {
    const { expandIconPosition: o, destroyOnHide: i, showExpandIcon: r } = ve(e), l = B("collapse"), s = V(e.defaultActiveKey), u = a(() => {
      var p;
      const h = (p = e.activeKey) != null ? p : s.value;
      return He(h) ? h : [h];
    });
    it(
      Rm,
      me({
        activeKeys: u,
        slots: n,
        showExpandIcon: r,
        expandIconPosition: o,
        destroyOnHide: i,
        handleClick: (p, h) => {
          let k = [];
          if (e.accordion)
            u.value.includes(p) || (k = [p]), s.value = k;
          else {
            k = [...u.value];
            const y = k.indexOf(p);
            y > -1 ? k.splice(y, 1) : e.accordion ? k = [p] : k.push(p), s.value = k;
          }
          t("update:activeKey", k), t("change", k, h);
        }
      })
    );
    const d = a(() => [
      l,
      {
        [`${l}-borderless`]: !e.bordered
      }
    ]);
    return {
      prefixCls: l,
      cls: d
    };
  }
});
function o3(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.cls)
  }, [
    _(e.$slots, "default")
  ], 2);
}
var Ga = /* @__PURE__ */ N(l3, [["render", o3]]);
const i3 = S({
  name: "IconCaretRight",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-caret-right`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), r3 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function a3(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M34.829 23.063c.6.48.6 1.394 0 1.874L17.949 38.44c-.785.629-1.949.07-1.949-.937V10.497c0-1.007 1.164-1.566 1.95-.937l16.879 13.503Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, r3);
}
var Xa = /* @__PURE__ */ N(i3, [["render", a3]]);
const Hm = Object.assign(Xa, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Xa.name, Xa);
  }
}), s3 = S({
  name: "IconCaretLeft",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-caret-left`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), u3 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function c3(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M13.171 24.937a1.2 1.2 0 0 1 0-1.874L30.051 9.56c.785-.629 1.949-.07 1.949.937v27.006c0 1.006-1.164 1.566-1.95.937L13.171 24.937Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, u3);
}
var Qa = /* @__PURE__ */ N(s3, [["render", c3]]);
const qm = Object.assign(Qa, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Qa.name, Qa);
  }
});
var Pi = S({
  name: "CollapseItem",
  components: {
    IconHover: pt,
    IconCaretRight: Hm,
    IconCaretLeft: qm
  },
  props: {
    header: String,
    disabled: {
      type: Boolean,
      default: !1
    },
    showExpandIcon: {
      type: Boolean,
      default: !0
    },
    destroyOnHide: {
      type: Boolean,
      default: !1
    }
  },
  setup(e, {
    slots: t
  }) {
    var n;
    const o = dn(), i = B("collapse-item"), r = Ge(Rm, {}), l = o && A(o == null ? void 0 : o.vnode.key) ? o.vnode.key : String((n = o == null ? void 0 : o.vnode.key) != null ? n : ""), s = a(() => {
      var j;
      return (j = r.activeKeys) == null ? void 0 : j.includes(l);
    }), u = a(() => r.destroyOnHide || e.destroyOnHide), f = a(() => {
      var j;
      return (j = r == null ? void 0 : r.showExpandIcon) != null ? j : e.showExpandIcon;
    }), d = V(u.value ? s.value : !0), p = a(() => {
      var j;
      return (j = r == null ? void 0 : r.expandIconPosition) != null ? j : "left";
    }), h = (j) => {
      var I;
      e.disabled || (I = r.handleClick) == null || I.call(r, l, j);
    };
    ze(s, (j) => {
      j && !d.value && (d.value = !0);
    });
    const k = {
      onEnter: (j) => {
        j.style.height = `${j.scrollHeight}px`;
      },
      onAfterEnter: (j) => {
        j.style.height = "auto";
      },
      onBeforeLeave: (j) => {
        j.style.height = `${j.scrollHeight}px`;
      },
      onLeave: (j) => {
        j.style.height = "0";
      },
      onAfterLeave: () => {
        u.value && (d.value = !1);
      }
    }, y = a(() => [i, {
      [`${i}-active`]: s.value
    }]), w = a(() => [`${i}-header`, `${i}-header-${r == null ? void 0 : r.expandIconPosition}`, {
      [`${i}-header-disabled`]: e.disabled
    }]), g = a(() => [{
      [`${i}-icon-right`]: (r == null ? void 0 : r.expandIconPosition) === "right"
    }]), C = a(() => [`${i}-content`, {
      [`${i}-content-expend`]: s.value
    }]), P = () => p.value === "right" ? c(J("icon-caret-left"), {
      class: `${i}-expand-icon`
    }, null) : c(J("icon-caret-right"), {
      class: `${i}-expand-icon`
    }, null), z = () => f.value && c(J("icon-hover"), {
      prefix: i,
      class: g.value,
      disabled: e.disabled
    }, {
      default: () => {
        var j, I, L, M;
        return [(M = (L = (I = t["expand-icon"]) != null ? I : (j = r == null ? void 0 : r.slots) == null ? void 0 : j["expand-icon"]) == null ? void 0 : L({
          active: s.value,
          disabled: e.disabled,
          position: p.value
        })) != null ? M : P()];
      }
    });
    return () => {
      var j, I, L;
      return c("div", {
        class: y.value
      }, [c("div", {
        role: "button",
        "aria-disabled": e.disabled,
        "aria-expanded": s.value,
        tabindex: "0",
        class: w.value,
        onClick: h
      }, [z(), c("div", {
        class: `${i}-header-title`
      }, [(I = (j = t.header) == null ? void 0 : j.call(t)) != null ? I : e.header]), t.extra && c("div", {
        class: `${i}-header-extra`
      }, [(L = t.extra) == null ? void 0 : L.call(t)])]), c(on, se({
        name: "collapse-slider"
      }, k), {
        default: () => {
          var M;
          return [hn(c("div", {
            role: "region",
            class: C.value
          }, [d.value && c("div", {
            ref: "contentBoxRef",
            class: `${i}-content-box`
          }, [(M = t.default) == null ? void 0 : M.call(t)])]), [[kn, s.value]])];
        }
      })]);
    };
  }
});
const d3 = Object.assign(Ga, {
  Item: Pi,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ga.name, Ga), e.component(n + Pi.name, Pi);
  }
}), f3 = [
  "#00B42A",
  "#3C7EFF",
  "#FF7D00",
  "#F76965",
  "#F7BA1E",
  "#F5319D",
  "#D91AD9",
  "#9FDB1D",
  "#FADC19",
  "#722ED1",
  "#3491FA",
  "#7BE188",
  "#93BEFF",
  "#FFCF8B",
  "#FBB0A7",
  "#FCE996",
  "#FB9DC7",
  "#F08EE6",
  "#DCF190",
  "#FDFA94",
  "#C396ED",
  "#9FD4FD"
], Zm = (e, t, n) => {
  const o = Math.floor(e * 6), i = e * 6 - o, r = n * (1 - t), l = n * (1 - i * t), s = n * (1 - (1 - i) * t), u = o % 6, f = [n, l, r, r, s, n][u], d = [s, n, n, l, r, r][u], p = [r, r, s, n, n, l][u];
  return {
    r: Math.round(f * 255),
    g: Math.round(d * 255),
    b: Math.round(p * 255)
  };
}, Er = (e, t, n) => {
  e /= 255, t /= 255, n /= 255;
  const o = Math.max(e, t, n), i = Math.min(e, t, n);
  let r = 0;
  const l = o, s = o - i, u = o === 0 ? 0 : s / o;
  if (o === i)
    r = 0;
  else {
    switch (o) {
      case e:
        r = (t - n) / s + (t < n ? 6 : 0);
        break;
      case t:
        r = (n - e) / s + 2;
        break;
      case n:
        r = (e - t) / s + 4;
        break;
    }
    r /= 6;
  }
  return { h: r, s: u, v: l };
}, v3 = "[-\\+]?\\d+%?", p3 = "[-\\+]?\\d*\\.\\d+%?", hl = `(?:${p3})|(?:${v3})`, m3 = `[\\s|\\(]+(${hl})[,|\\s]+(${hl})[,|\\s]+(${hl})\\s*\\)?`, h3 = `[\\s|\\(]+(${hl})[,|\\s]+(${hl})[,|\\s]+(${hl})[,|\\s]+(${hl})\\s*\\)?`, nl = {
  rgb: new RegExp(`rgb${m3}`),
  rgba: new RegExp(`rgba${h3}`),
  hex3: /^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,
  hex6: /^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,
  hex4: /^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,
  hex8: /^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/
}, Ot = (e) => parseInt(e, 16), ip = (e) => Ot(e) / 255, k3 = (e) => {
  let t = nl.rgb.exec(e);
  return t ? {
    r: parseInt(t[1], 10),
    g: parseInt(t[2], 10),
    b: parseInt(t[3], 10)
  } : (t = nl.rgba.exec(e), t ? {
    r: parseInt(t[1], 10),
    g: parseInt(t[2], 10),
    b: parseInt(t[3], 10),
    a: parseFloat(t[4])
  } : (t = nl.hex8.exec(e), t ? {
    r: Ot(t[1]),
    g: Ot(t[2]),
    b: Ot(t[3]),
    a: ip(t[4])
  } : (t = nl.hex6.exec(e), t ? {
    r: Ot(t[1]),
    g: Ot(t[2]),
    b: Ot(t[3])
  } : (t = nl.hex4.exec(e), t ? {
    r: Ot(t[1] + t[1]),
    g: Ot(t[2] + t[2]),
    b: Ot(t[3] + t[3]),
    a: ip(t[4] + t[4])
  } : (t = nl.hex3.exec(e), t ? {
    r: Ot(t[1] + t[1]),
    g: Ot(t[2] + t[2]),
    b: Ot(t[3] + t[3])
  } : !1)))));
}, g3 = (e) => {
  var t;
  const n = k3(e);
  return n ? {
    ...Er(n.r, n.g, n.b),
    a: (t = n.a) != null ? t : 1
  } : {
    h: 0,
    s: 1,
    v: 1,
    a: 1
  };
}, Km = (e) => {
  if (e = e.trim().toLowerCase(), e.length === 0)
    return !1;
  let t = nl.hex6.exec(e);
  return t ? {
    r: Ot(t[1]),
    g: Ot(t[2]),
    b: Ot(t[3])
  } : (t = nl.hex3.exec(e), t ? {
    r: Ot(t[1] + t[1]),
    g: Ot(t[2] + t[2]),
    b: Ot(t[3] + t[3])
  } : !1);
}, rp = (e, t, n) => [
  Math.round(e).toString(16).padStart(2, "0"),
  Math.round(t).toString(16).padStart(2, "0"),
  Math.round(n).toString(16).padStart(2, "0")
].join("").toUpperCase(), y3 = (e, t, n, o) => [
  Math.round(e).toString(16).padStart(2, "0"),
  Math.round(t).toString(16).padStart(2, "0"),
  Math.round(n).toString(16).padStart(2, "0"),
  Math.round(o * 255).toString(16).padStart(2, "0")
].join("").toUpperCase(), Ym = ({ value: e, onChange: t }) => {
  const n = V(!1), o = V(), i = V(), r = (d, p) => d < 0 ? 0 : d > p ? 1 : d / p, l = (d) => {
    if (!o.value)
      return;
    const { clientX: p, clientY: h } = d, k = o.value.getBoundingClientRect(), y = [
      r(p - k.x, k.width),
      r(h - k.y, k.height)
    ];
    (y[0] !== e[0] || y[1] !== e[1]) && (t == null || t(y));
  }, s = () => {
    n.value = !1, window.removeEventListener("mousemove", f), window.removeEventListener("mouseup", s), window.removeEventListener("contextmenu", s);
  }, u = (d) => {
    n.value = !0, l(d), window.addEventListener("mousemove", f), window.addEventListener("mouseup", s), window.addEventListener("contextmenu", s);
  };
  function f(d) {
    d.preventDefault(), d.buttons > 0 ? l(d) : s();
  }
  return {
    active: n,
    blockRef: o,
    handlerRef: i,
    onMouseDown: u
  };
};
var ap = S({
  name: "ControlBar",
  props: {
    x: {
      type: Number,
      required: !0
    },
    color: {
      type: Object,
      required: !0
    },
    colorString: String,
    type: String,
    onChange: Function
  },
  setup(e) {
    const t = B("color-picker"), n = a(() => e.color.rgb), {
      blockRef: o,
      handlerRef: i,
      onMouseDown: r
    } = Ym({
      value: [e.x, 0],
      onChange: (s) => {
        var u;
        return (u = e.onChange) == null ? void 0 : u.call(e, s[0]);
      }
    }), l = () => c("div", {
      ref: i,
      class: `${t}-handler`,
      style: {
        left: `${e.x * 100}%`,
        color: e.colorString
      }
    }, null);
    return () => e.type === "alpha" ? c("div", {
      class: `${t}-control-bar-bg`
    }, [c("div", {
      ref: o,
      class: [`${t}-control-bar`, `${t}-control-bar-alpha`],
      style: {
        background: `linear-gradient(to right, rgba(0, 0, 0, 0), rgb(${n.value.r}, ${n.value.g}, ${n.value.b}))`
      },
      onMousedown: r
    }, [l()])]) : c("div", {
      ref: o,
      class: [`${t}-control-bar`, `${t}-control-bar-hue`],
      onMousedown: r
    }, [l()]);
  }
}), b3 = S({
  name: "Palette",
  props: {
    color: {
      type: Object,
      required: !0
    },
    onChange: Function
  },
  setup(e) {
    const t = B("color-picker"), n = a(() => e.color.hsv), {
      blockRef: o,
      handlerRef: i,
      onMouseDown: r
    } = Ym({
      value: [n.value.s, 1 - n.value.v],
      onChange: (s) => {
        var u;
        return (u = e.onChange) == null ? void 0 : u.call(e, s[0], 1 - s[1]);
      }
    }), l = a(() => {
      const s = Zm(n.value.h, 1, 1);
      return `rgb(${s.r}, ${s.g}, ${s.b})`;
    });
    return () => c("div", {
      ref: o,
      class: `${t}-palette`,
      style: {
        backgroundColor: l.value
      },
      onMousedown: r
    }, [c("div", {
      ref: i,
      class: `${t}-handler`,
      style: {
        top: `${(1 - n.value.v) * 100}%`,
        left: `${n.value.s * 100}%`
      }
    }, null)]);
  }
});
function Zv(e, t) {
  return t === void 0 && (t = 15), +parseFloat(Number(e).toPrecision(t));
}
function Fn(e) {
  var t = e.toString().split(/[eE]/), n = (t[0].split(".")[1] || "").length - +(t[1] || 0);
  return n > 0 ? n : 0;
}
function Lo(e) {
  if (e.toString().indexOf("e") === -1)
    return Number(e.toString().replace(".", ""));
  var t = Fn(e);
  return t > 0 ? Zv(Number(e) * Math.pow(10, t)) : Number(e);
}
function nv(e) {
  Gm && (e > Number.MAX_SAFE_INTEGER || e < Number.MIN_SAFE_INTEGER) && console.warn(e + " is beyond boundary when transfer to integer, the results may not be accurate");
}
function Wr(e) {
  return function() {
    for (var t = [], n = 0; n < arguments.length; n++)
      t[n] = arguments[n];
    var o = t[0], i = t.slice(1);
    return i.reduce(function(r, l) {
      return e(r, l);
    }, o);
  };
}
var sl = Wr(function(e, t) {
  var n = Lo(e), o = Lo(t), i = Fn(e) + Fn(t), r = n * o;
  return nv(r), r / Math.pow(10, i);
}), C3 = Wr(function(e, t) {
  var n = Math.pow(10, Math.max(Fn(e), Fn(t)));
  return (sl(e, n) + sl(t, n)) / n;
}), $3 = Wr(function(e, t) {
  var n = Math.pow(10, Math.max(Fn(e), Fn(t)));
  return (sl(e, n) - sl(t, n)) / n;
}), Um = Wr(function(e, t) {
  var n = Lo(e), o = Lo(t);
  return nv(n), nv(o), sl(n / o, Zv(Math.pow(10, Fn(t) - Fn(e))));
});
function w3(e, t) {
  var n = Math.pow(10, t), o = Um(Math.round(Math.abs(sl(e, n))), n);
  return e < 0 && o !== 0 && (o = sl(o, -1)), o;
}
var Gm = !0;
function S3(e) {
  e === void 0 && (e = !0), Gm = e;
}
var ln = {
  strip: Zv,
  plus: C3,
  minus: $3,
  times: sl,
  divide: Um,
  round: w3,
  digitLength: Fn,
  float2Fixed: Lo,
  enableBoundaryChecking: S3
};
const z3 = S({
  name: "IconPlus",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-plus`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), L3 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function j3(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M5 24h38M24 5v38" }, null, -1)
  ]), 14, L3);
}
var _a = /* @__PURE__ */ N(z3, [["render", j3]]);
const zl = Object.assign(_a, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + _a.name, _a);
  }
}), P3 = S({
  name: "IconMinus",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-minus`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), I3 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function B3(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M5 24h38" }, null, -1)
  ]), 14, I3);
}
var Ja = /* @__PURE__ */ N(P3, [["render", B3]]);
const Fr = Object.assign(Ja, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ja.name, Ja);
  }
}), M3 = 800, N3 = 150;
ln.enableBoundaryChecking(!1);
var es = S({
  name: "InputNumber",
  props: {
    modelValue: Number,
    defaultValue: Number,
    mode: {
      type: String,
      default: "embed"
    },
    precision: Number,
    step: {
      type: Number,
      default: 1
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    error: {
      type: Boolean,
      default: !1
    },
    max: {
      type: Number,
      default: 1 / 0
    },
    min: {
      type: Number,
      default: -1 / 0
    },
    formatter: {
      type: Function
    },
    parser: {
      type: Function
    },
    placeholder: String,
    hideButton: {
      type: Boolean,
      default: !1
    },
    size: {
      type: String
    },
    allowClear: {
      type: Boolean,
      default: !1
    },
    modelEvent: {
      type: String,
      default: "change"
    },
    readOnly: {
      type: Boolean,
      default: !1
    },
    inputAttrs: {
      type: Object
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e, t) => !0,
    focus: (e) => !0,
    blur: (e) => !0,
    clear: (e) => !0,
    input: (e, t, n) => !0,
    keydown: (e) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    var o;
    const {
      size: i,
      disabled: r
    } = ve(e), l = B("input-number"), s = V(), {
      mergedSize: u,
      mergedDisabled: f,
      eventHandlers: d
    } = mt({
      size: i,
      disabled: r
    }), {
      mergedSize: p
    } = xt(u), h = a(() => {
      if (A(e.precision)) {
        const x = `${e.step}`.split(".")[1], G = x && x.length || 0;
        return Math.max(G, e.precision);
      }
    }), k = (x) => {
      var G, ne;
      if (!A(x))
        return "";
      const ee = h.value ? x.toFixed(h.value) : String(x);
      return (ne = (G = e.formatter) == null ? void 0 : G.call(e, ee)) != null ? ne : ee;
    }, y = V(k((o = e.modelValue) != null ? o : e.defaultValue)), w = a(() => {
      var x, G;
      if (!y.value)
        return;
      const ne = Number((G = (x = e.parser) == null ? void 0 : x.call(e, y.value)) != null ? G : y.value);
      return Number.isNaN(ne) ? void 0 : ne;
    }), g = V(A(w.value) && w.value <= e.min), C = V(A(w.value) && w.value >= e.max);
    let P = 0;
    const z = () => {
      P && (window.clearTimeout(P), P = 0);
    }, j = (x) => {
      if (!Ve(x))
        return A(e.min) && x < e.min && (x = e.min), A(e.max) && x > e.max && (x = e.max), A(h.value) ? ln.round(x, h.value) : x;
    }, I = (x) => {
      let G = !1, ne = !1;
      A(x) && (x <= e.min && (G = !0), x >= e.max && (ne = !0)), C.value !== ne && (C.value = ne), g.value !== G && (g.value = G);
    }, L = () => {
      const x = j(w.value), G = k(x);
      (x !== w.value || y.value !== G) && (y.value = G), t("update:modelValue", x);
    };
    ze(() => [e.max, e.min], () => {
      L(), I(w.value);
    });
    const M = (x, G) => {
      if (f.value || x === "plus" && C.value || x === "minus" && g.value)
        return;
      let ne;
      A(w.value) ? ne = j(ln[x](w.value, e.step)) : ne = e.min === -1 / 0 ? 0 : e.min, y.value = k(ne), I(ne), t("update:modelValue", ne), t("change", ne, G);
    }, E = (x, G, ne = !1) => {
      var ee;
      x.preventDefault(), !e.readOnly && ((ee = s.value) == null || ee.focus(), M(G, x), ne && (P = window.setTimeout(() => x.target.dispatchEvent(x), P ? N3 : M3)));
    }, K = (x, G) => {
      var ne, ee, Q, ae;
      x = x.trim().replace(/。/g, "."), x = (ee = (ne = e.parser) == null ? void 0 : ne.call(e, x)) != null ? ee : x, (A(Number(x)) || /^(\.|-)$/.test(x)) && (y.value = (ae = (Q = e.formatter) == null ? void 0 : Q.call(e, x)) != null ? ae : x, I(w.value), t("input", w.value, y.value, G), e.modelEvent === "input" && (t("update:modelValue", w.value), t("change", w.value, G)));
    }, q = (x) => {
      t("focus", x);
    }, T = (x, G) => {
      G instanceof MouseEvent && !x || (L(), t("change", w.value, G));
    }, X = (x) => {
      t("blur", x);
    }, Y = (x) => {
      var G, ne;
      y.value = "", t("update:modelValue", void 0), t("change", void 0, x), (ne = (G = d.value) == null ? void 0 : G.onChange) == null || ne.call(G, x), t("clear", x);
    }, Z = Nr(/* @__PURE__ */ new Map([[yt.ARROW_UP, (x) => {
      x.preventDefault(), !e.readOnly && M("plus", x);
    }], [yt.ARROW_DOWN, (x) => {
      x.preventDefault(), !e.readOnly && M("minus", x);
    }]])), U = (x) => {
      t("keydown", x), x.defaultPrevented || Z(x);
    };
    ze(() => e.modelValue, (x) => {
      x !== w.value && (y.value = k(x), I(x));
    });
    const H = () => {
      var x, G, ne;
      return e.readOnly ? null : c(Ae, null, [n.suffix && c("div", {
        class: `${l}-suffix`
      }, [(x = n.suffix) == null ? void 0 : x.call(n)]), c("div", {
        class: `${l}-step`
      }, [c("button", {
        class: [`${l}-step-button`, {
          [`${l}-step-button-disabled`]: f.value || C.value
        }],
        type: "button",
        tabindex: "-1",
        disabled: f.value || C.value,
        onMousedown: (ee) => E(ee, "plus", !0),
        onMouseup: z,
        onMouseleave: z
      }, [n.plus ? (G = n.plus) == null ? void 0 : G.call(n) : c(Ar, null, null)]), c("button", {
        class: [`${l}-step-button`, {
          [`${l}-step-button-disabled`]: f.value || g.value
        }],
        type: "button",
        tabindex: "-1",
        disabled: f.value || g.value,
        onMousedown: (ee) => E(ee, "minus", !0),
        onMouseup: z,
        onMouseleave: z
      }, [n.minus ? (ne = n.minus) == null ? void 0 : ne.call(n) : c(Il, null, null)])])]);
    }, D = a(() => [l, `${l}-mode-${e.mode}`, `${l}-size-${p.value}`, {
      [`${l}-readonly`]: e.readOnly
    }]), R = () => c(Qt, {
      size: p.value,
      tabindex: "-1",
      class: `${l}-step-button`,
      disabled: f.value || g.value,
      onMousedown: (x) => E(x, "minus", !0),
      onMouseup: z,
      onMouseleave: z
    }, {
      icon: () => c(Fr, null, null)
    }), W = () => c(Qt, {
      size: p.value,
      tabindex: "-1",
      class: `${l}-step-button`,
      disabled: f.value || C.value,
      onMousedown: (x) => E(x, "plus", !0),
      onMouseup: z,
      onMouseleave: z
    }, {
      icon: () => c(zl, null, null)
    });
    return {
      inputRef: s,
      render: () => {
        const x = e.mode === "embed" ? {
          prepend: n.prepend,
          prefix: n.prefix,
          suffix: e.hideButton ? n.suffix : H,
          append: n.append
        } : {
          prepend: e.hideButton ? n.prepend : R,
          prefix: n.prefix,
          suffix: n.suffix,
          append: e.hideButton ? n.append : W
        };
        return c(cl, {
          key: `__arco__${e.mode}`,
          ref: s,
          class: D.value,
          type: "text",
          allowClear: e.allowClear,
          size: p.value,
          modelValue: y.value,
          placeholder: e.placeholder,
          disabled: f.value,
          readonly: e.readOnly,
          error: e.error,
          inputAttrs: {
            role: "spinbutton",
            "aria-valuemax": e.max,
            "aria-valuemin": e.min,
            "aria-valuenow": y.value,
            ...e.inputAttrs
          },
          onInput: K,
          onFocus: q,
          onBlur: X,
          onClear: Y,
          onChange: T,
          onKeydown: U
        }, x);
      }
    };
  },
  methods: {
    focus() {
      var e;
      (e = this.inputRef) == null || e.focus();
    },
    blur() {
      var e;
      (e = this.inputRef) == null || e.blur();
    }
  },
  render() {
    return this.render();
  }
});
const Vo = Object.assign(es, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + es.name, es);
  }
});
var Xm = S({
  name: "InputAlpha",
  props: {
    value: {
      type: Number,
      required: !0
    },
    disabled: Boolean,
    onChange: Function
  },
  setup(e) {
    const t = B("color-picker");
    return () => c(Vo, {
      class: `${t}-input-alpha`,
      size: "mini",
      min: 0,
      max: 100,
      disabled: e.disabled,
      modelValue: Math.round(e.value * 100),
      onChange: (n = 100) => {
        var o;
        return (o = e.onChange) == null ? void 0 : o.call(e, n / 100);
      }
    }, {
      suffix: () => "%"
    });
  }
}), O3 = S({
  name: "InputRgb",
  props: {
    color: {
      type: Object,
      required: !0
    },
    alpha: {
      type: Number,
      required: !0
    },
    disabled: Boolean,
    disabledAlpha: Boolean,
    onHsvChange: Function,
    onAlphaChange: Function
  },
  setup(e) {
    const t = B("color-picker"), {
      color: n
    } = ve(e), o = (i) => {
      var r;
      const l = {
        ...n.value.rgb,
        ...i
      }, s = Er(l.r, l.g, l.b);
      (r = e.onHsvChange) == null || r.call(e, s);
    };
    return () => c(xl, {
      class: `${t}-input-group`
    }, {
      default: () => [["r", "g", "b"].map((i) => c(Vo, {
        key: i,
        size: "mini",
        min: 0,
        max: 255,
        disabled: e.disabled,
        modelValue: n.value.rgb[i],
        hideButton: !0,
        onChange: (r = 0) => o({
          [i]: r
        })
      }, null)), !e.disabledAlpha && c(Xm, {
        disabled: e.disabled,
        value: e.alpha,
        onChange: e.onAlphaChange
      }, null)]
    });
  }
}), V3 = S({
  name: "InputHex",
  props: {
    color: {
      type: Object,
      required: !0
    },
    alpha: {
      type: Number,
      required: !0
    },
    disabled: Boolean,
    disabledAlpha: Boolean,
    onHsvChange: Function,
    onAlphaChange: Function
  },
  setup(e) {
    const t = B("color-picker"), {
      color: n
    } = ve(e), [o, i] = Ht(n.value.hex), r = (u) => {
      var f;
      const d = Km(u) || {
        r: 255,
        g: 0,
        b: 0
      }, p = Er(d.r, d.g, d.b);
      (f = e.onHsvChange) == null || f.call(e, p);
    }, l = (u) => {
      var f, d;
      const p = (d = (f = u.match(/[a-fA-F0-9]*/g)) == null ? void 0 : f.join("")) != null ? d : "";
      p !== n.value.hex && r(p.toUpperCase());
    }, s = (u) => {
      if (!u.clipboardData)
        return;
      let f = u.clipboardData.getData("Text");
      f.startsWith("#") && (f = f.slice(1)), l(f), u.preventDefault();
    };
    return ze(n, () => {
      n.value.hex !== o.value && i(n.value.hex);
    }), () => c(xl, {
      class: `${t}-input-group`
    }, {
      default: () => [c(cl, {
        class: `${t}-input-hex`,
        size: "mini",
        maxLength: 6,
        disabled: e.disabled,
        modelValue: o.value,
        onInput: i,
        onChange: l,
        onBlur: () => r,
        onPressEnter: () => r,
        onPaste: s
      }, {
        prefix: () => "#"
      }), !e.disabledAlpha && c(Xm, {
        disabled: e.disabled,
        value: e.alpha,
        onChange: e.onAlphaChange
      }, null)]
    });
  }
}), T3 = S({
  name: "Panel",
  props: {
    color: {
      type: Object,
      required: !0
    },
    alpha: {
      type: Number,
      required: !0
    },
    colorString: String,
    disabled: Boolean,
    disabledAlpha: Boolean,
    showHistory: Boolean,
    showPreset: Boolean,
    format: String,
    historyColors: Array,
    presetColors: Array,
    onAlphaChange: Function,
    onHsvChange: Function
  },
  setup(e) {
    const {
      t
    } = gt(), n = B("color-picker"), o = a(() => e.color.hsv), [i, r] = Ht(e.format || "hex"), l = (h) => {
      r(h);
    };
    V(!1);
    const s = (h) => {
      var k;
      const y = Km(h) || {
        r: 255,
        g: 0,
        b: 0
      }, w = Er(y.r, y.g, y.b);
      (k = e.onHsvChange) == null || k.call(e, w);
    }, u = () => {
      const h = {
        color: e.color,
        alpha: e.alpha,
        disabled: e.disabled,
        disabledAlpha: e.disabledAlpha,
        onHsvChange: e.onHsvChange,
        onAlphaChange: e.onAlphaChange
      };
      return i.value === "rgb" ? c(O3, h, null) : c(V3, h, null);
    }, f = (h) => c("div", {
      key: h,
      class: `${n}-color-block`,
      style: {
        backgroundColor: h
      },
      onClick: () => s(h)
    }, [c("div", {
      class: `${n}-block`,
      style: {
        backgroundColor: h
      }
    }, null)]), d = (h, k) => c("div", {
      class: `${n}-colors-section`
    }, [c("div", {
      class: `${n}-colors-text`
    }, [h]), c("div", {
      class: `${n}-colors-wrapper`
    }, [k != null && k.length ? c("div", {
      class: `${n}-colors-list`
    }, [k.map(f)]) : c("span", {
      class: `${n}-colors-empty`
    }, [t("colorPicker.empty")])])]), p = () => e.showHistory || e.showPreset ? c("div", {
      class: `${n}-panel-colors`
    }, [e.showHistory && d(t("colorPicker.history"), e.historyColors), e.showPreset && d(t("colorPicker.preset"), e.presetColors)]) : null;
    return () => c("div", {
      class: {
        [`${n}-panel`]: !0,
        [`${n}-panel-disabled`]: e.disabled
      }
    }, [c(b3, {
      color: e.color,
      onChange: (h, k) => {
        var y;
        return (y = e.onHsvChange) == null ? void 0 : y.call(e, {
          h: o.value.h,
          s: h,
          v: k
        });
      }
    }, null), c("div", {
      class: `${n}-panel-control`
    }, [c("div", {
      class: `${n}-control-wrapper`
    }, [c("div", null, [c(ap, {
      type: "hue",
      x: o.value.h,
      color: e.color,
      colorString: e.colorString,
      onChange: (h) => {
        var k;
        return (k = e.onHsvChange) == null ? void 0 : k.call(e, {
          h,
          s: o.value.s,
          v: o.value.v
        });
      }
    }, null), !e.disabledAlpha && c(ap, {
      type: "alpha",
      x: e.alpha,
      color: e.color,
      colorString: e.colorString,
      onChange: e.onAlphaChange
    }, null)]), c("div", {
      class: `${n}-preview`,
      style: {
        backgroundColor: e.colorString
      }
    }, null)]), c("div", {
      class: `${n}-input-wrapper`
    }, [c(zo, {
      class: `${n}-select`,
      size: "mini",
      "trigger-props": {
        class: `${n}-select-popup`
      },
      options: [{
        value: "hex",
        label: "Hex"
      }, {
        value: "rgb",
        label: "RGB"
      }],
      modelValue: i.value,
      onChange: l
    }, null), c("div", {
      class: `${n}-group-wrapper`
    }, [u()])])]), p()]);
  }
}), ts = S({
  name: "ColorPicker",
  props: {
    modelValue: String,
    defaultValue: {
      type: String
    },
    format: {
      type: String
    },
    size: {
      type: String,
      default: "medium"
    },
    showText: {
      type: Boolean,
      default: !1
    },
    showHistory: {
      type: Boolean,
      default: !1
    },
    showPreset: {
      type: Boolean,
      default: !1
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    disabledAlpha: {
      type: Boolean,
      default: !1
    },
    hideTrigger: {
      type: Boolean
    },
    triggerProps: {
      type: Object
    },
    historyColors: {
      type: Array
    },
    presetColors: {
      type: Array,
      default: () => f3
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0,
    "popup-visible-change": (e, t) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const o = B("color-picker"), i = a(() => {
      var P;
      return (P = e.modelValue) != null ? P : e.defaultValue;
    }), r = a(() => g3(i.value || "")), [l, s] = Ht(r.value.a), [u, f] = Ht({
      h: r.value.h,
      s: r.value.s,
      v: r.value.v
    });
    ze(() => r.value, (P) => {
      i.value !== h.value && (s(P.a), f({
        h: P.h,
        s: P.s,
        v: P.v
      }));
    });
    const d = a(() => {
      const P = Zm(u.value.h, u.value.s, u.value.v), z = rp(P.r, P.g, P.b);
      return {
        hsv: u.value,
        rgb: P,
        hex: z
      };
    }), p = a(() => {
      const {
        r: P,
        g: z,
        b: j
      } = d.value.rgb;
      return `rgba(${P}, ${z}, ${j}, ${l.value.toFixed(2)})`;
    }), h = a(() => {
      const {
        r: P,
        g: z,
        b: j
      } = d.value.rgb;
      return e.format === "rgb" ? l.value < 1 && !e.disabledAlpha ? `rgba(${P}, ${z}, ${j}, ${l.value.toFixed(2)})` : `rgb(${P}, ${z}, ${j})` : l.value < 1 && !e.disabledAlpha ? `#${y3(P, z, j, l.value)}` : `#${rp(P, z, j)}`;
    });
    ze(h, (P) => {
      t("update:modelValue", P), t("change", P);
    });
    const k = (P) => {
      !e.disabled && f(P);
    }, y = (P) => {
      !e.disabled && s(P);
    }, w = (P) => {
      t("popup-visible-change", P, h.value);
    }, g = () => c("div", {
      class: {
        [o]: !0,
        [`${o}-size-${e.size}`]: e.size,
        [`${o}-disabled`]: e.disabled
      }
    }, [c("div", {
      class: `${o}-preview`,
      style: {
        backgroundColor: h.value
      }
    }, null), e.showText && c("div", {
      class: `${o}-value`
    }, [h.value]), c("input", {
      class: `${o}-input`,
      value: h.value,
      disabled: e.disabled
    }, null)]), C = () => c(T3, {
      color: d.value,
      alpha: l.value,
      colorString: p.value,
      historyColors: e.historyColors,
      presetColors: e.presetColors,
      showHistory: e.showHistory,
      showPreset: e.showPreset,
      disabled: e.disabled,
      disabledAlpha: e.disabledAlpha,
      format: e.format,
      onHsvChange: k,
      onAlphaChange: y
    }, null);
    return () => e.hideTrigger ? C() : c(Tt, se({
      trigger: "click",
      position: "bl",
      animationName: "slide-dynamic-origin",
      popupOffset: 4,
      disabled: e.disabled,
      onPopupVisibleChange: w
    }, e.triggerProps), {
      default: () => [n.default ? n.default() : g()],
      content: C
    });
  }
});
const A3 = Object.assign(ts, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ts.name, ts);
  }
});
function Qm(e, t, n) {
  return a(() => !!(e[n] || t[n]));
}
const E3 = S({
  name: "Comment",
  props: {
    author: {
      type: String
    },
    avatar: {
      type: String
    },
    content: {
      type: String
    },
    datetime: {
      type: String
    },
    align: {
      type: [String, Object],
      default: "left"
    }
  },
  setup(e, { slots: t }) {
    const n = B("comment"), [o, i, r, l] = [
      "author",
      "avatar",
      "content",
      "datetime"
    ].map((u) => Qm(e, t, u)), s = a(() => {
      const { align: u } = e;
      return {
        ...zt(u) ? {
          datetime: u,
          actions: u
        } : u
      };
    });
    return {
      prefixCls: n,
      hasAuthor: o,
      hasAvatar: i,
      hasContent: r,
      hasDatetime: l,
      computedAlign: s
    };
  }
}), W3 = ["src"], F3 = { key: 0 }, D3 = { key: 0 }, x3 = { key: 0 };
function R3(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    e.hasAvatar ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-avatar`)
    }, [
      e.avatar ? (v(), b("img", {
        key: 0,
        src: e.avatar,
        alt: "comment-avatar"
      }, null, 8, W3)) : _(e.$slots, "avatar", { key: 1 })
    ], 2)) : te("v-if", !0),
    $("div", {
      class: m(`${e.prefixCls}-inner`)
    }, [
      $("div", {
        class: m(`${e.prefixCls}-inner-content`)
      }, [
        e.hasAuthor || e.hasDatetime ? (v(), b("div", {
          key: 0,
          class: m(`${e.prefixCls}-title ${e.prefixCls}-title-align-${e.computedAlign.datetime}`)
        }, [
          e.hasAuthor ? (v(), b("span", {
            key: 0,
            class: m(`${e.prefixCls}-author`)
          }, [
            e.author ? (v(), b("span", F3, Pe(e.author), 1)) : _(e.$slots, "author", { key: 1 })
          ], 2)) : te("v-if", !0),
          e.hasDatetime ? (v(), b("span", {
            key: 1,
            class: m(`${e.prefixCls}-datetime`)
          }, [
            e.datetime ? (v(), b("span", D3, Pe(e.datetime), 1)) : _(e.$slots, "datetime", { key: 1 })
          ], 2)) : te("v-if", !0)
        ], 2)) : te("v-if", !0),
        e.hasContent ? (v(), b("div", {
          key: 1,
          class: m(`${e.prefixCls}-content`)
        }, [
          e.content ? (v(), b("span", x3, Pe(e.content), 1)) : _(e.$slots, "content", { key: 1 })
        ], 2)) : te("v-if", !0),
        e.$slots.actions ? (v(), b("div", {
          key: 2,
          class: m(`${e.prefixCls}-actions ${e.prefixCls}-actions-align-${e.computedAlign.actions}`)
        }, [
          _(e.$slots, "actions")
        ], 2)) : te("v-if", !0)
      ], 2),
      e.$slots.default ? (v(), b("div", {
        key: 0,
        class: m(`${e.prefixCls}-inner-comment`)
      }, [
        _(e.$slots, "default")
      ], 2)) : te("v-if", !0)
    ], 2)
  ], 2);
}
var ns = /* @__PURE__ */ N(E3, [["render", R3]]);
const H3 = Object.assign(ns, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ns.name, ns);
  }
}), q3 = S({
  name: "ConfigProvider",
  props: {
    prefixCls: {
      type: String,
      default: "arco"
    },
    locale: {
      type: Object
    },
    size: {
      type: String
    },
    global: {
      type: Boolean,
      default: !1
    },
    updateAtScroll: {
      type: Boolean,
      default: !1
    },
    scrollToClose: {
      type: Boolean,
      default: !1
    },
    exchangeTime: {
      type: Boolean,
      default: !0
    }
  },
  setup(e, { slots: t }) {
    const {
      prefixCls: n,
      locale: o,
      size: i,
      updateAtScroll: r,
      scrollToClose: l,
      exchangeTime: s
    } = ve(e), u = me({
      slots: t,
      prefixCls: n,
      locale: o,
      size: i,
      updateAtScroll: r,
      scrollToClose: l,
      exchangeTime: s
    });
    if (e.global) {
      const f = dn();
      f && f.appContext.app.provide(Kt, u);
    } else
      it(Kt, u);
  }
});
function Z3(e, t, n, o, i, r) {
  return _(e.$slots, "default");
}
var ls = /* @__PURE__ */ N(q3, [["render", Z3]]);
const K3 = Object.assign(ls, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ls.name, ls);
  }
});
function Y3(e) {
  const { modelValue: t, defaultValue: n, format: o } = ve(e), i = a(() => cn(t.value, o.value)), r = a(() => cn(n.value, o.value)), [l, s] = Ht(
    Ve(i.value) ? Ve(r.value) ? void 0 : r.value : i.value
  );
  return ze(i, () => {
    Ve(i.value) && s(void 0);
  }), {
    value: a(
      () => i.value || l.value
    ),
    setValue: s
  };
}
const U3 = S({
  name: "DateInput",
  components: {
    IconHover: pt,
    IconClose: Dt,
    FeedbackIcon: No
  },
  props: {
    size: {
      type: String
    },
    focused: {
      type: Boolean
    },
    disabled: {
      type: Boolean
    },
    readonly: {
      type: Boolean
    },
    error: {
      type: Boolean
    },
    allowClear: {
      type: Boolean
    },
    placeholder: {
      type: String
    },
    inputValue: {
      type: String
    },
    value: {
      type: Object
    },
    format: {
      type: [String, Function],
      required: !0
    }
  },
  emits: ["clear", "press-enter", "change", "blur"],
  setup(e, { emit: t, slots: n }) {
    const { error: o, focused: i, disabled: r, size: l, value: s, format: u, inputValue: f } = ve(e), {
      mergedSize: d,
      mergedDisabled: p,
      mergedError: h,
      feedback: k
    } = mt({ size: l, disabled: r, error: o }), { mergedSize: y } = xt(d), w = B("picker"), g = a(() => [
      w,
      `${w}-size-${y.value}`,
      {
        [`${w}-focused`]: i.value,
        [`${w}-disabled`]: p.value,
        [`${w}-error`]: h.value,
        [`${w}-has-prefix`]: n.prefix
      }
    ]), C = a(() => {
      if (f != null && f.value)
        return f == null ? void 0 : f.value;
      if (s != null && s.value && gn(s.value))
        return Ne(u.value) ? u.value(s.value) : s.value.format(u.value);
    }), P = V();
    return {
      feedback: k,
      prefixCls: w,
      classNames: g,
      displayValue: C,
      mergedDisabled: p,
      refInput: P,
      onPressEnter() {
        t("press-enter");
      },
      onChange(z) {
        t("change", z);
      },
      onClear(z) {
        t("clear", z);
      },
      onBlur(z) {
        t("blur", z);
      }
    };
  },
  methods: {
    focus() {
      this.refInput && this.refInput.focus && this.refInput.focus();
    },
    blur() {
      this.refInput && this.refInput.blur && this.refInput.blur();
    }
  }
}), G3 = ["disabled", "placeholder", "value"];
function X3(e, t, n, o, i, r) {
  const l = J("IconClose"), s = J("IconHover"), u = J("FeedbackIcon");
  return v(), b("div", {
    class: m(e.classNames)
  }, [
    e.$slots.prefix ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-prefix`)
    }, [
      _(e.$slots, "prefix")
    ], 2)) : te("v-if", !0),
    $("div", {
      class: m(`${e.prefixCls}-input`)
    }, [
      $("input", se({
        ref: "refInput",
        disabled: e.mergedDisabled,
        placeholder: e.placeholder,
        class: `${e.prefixCls}-start-time`,
        value: e.displayValue
      }, e.readonly ? { readonly: !0 } : {}, {
        onKeydown: t[0] || (t[0] = El((...f) => e.onPressEnter && e.onPressEnter(...f), ["enter"])),
        onInput: t[1] || (t[1] = (...f) => e.onChange && e.onChange(...f)),
        onBlur: t[2] || (t[2] = (...f) => e.onBlur && e.onBlur(...f))
      }), null, 16, G3)
    ], 2),
    $("div", {
      class: m(`${e.prefixCls}-suffix`)
    }, [
      e.allowClear && !e.mergedDisabled && e.displayValue ? (v(), oe(s, {
        key: 0,
        prefix: e.prefixCls,
        class: m(`${e.prefixCls}-clear-icon`),
        onClick: e.onClear
      }, {
        default: ue(() => [
          c(l)
        ]),
        _: 1
      }, 8, ["prefix", "class", "onClick"])) : te("v-if", !0),
      $("span", {
        class: m(`${e.prefixCls}-suffix-icon`)
      }, [
        _(e.$slots, "suffix-icon")
      ], 2),
      e.feedback ? (v(), oe(u, {
        key: 1,
        type: e.feedback
      }, null, 8, ["type"])) : te("v-if", !0)
    ], 2)
  ], 2);
}
var _m = /* @__PURE__ */ N(U3, [["render", X3]]);
function lv(e) {
  const t = ["H", "h", "m", "s", "a", "A"], n = [];
  let o = !1;
  return t.forEach((i) => {
    e.indexOf(i) !== -1 && (n.push(i), (i === "a" || i === "A") && (o = !0));
  }), {
    list: n,
    use12Hours: o
  };
}
const sp = /* @__PURE__ */ new Map();
function Q3(e, t, n) {
  const o = sp.get(e);
  Ve(o) || cancelAnimationFrame(o), n <= 0 && (e.scrollTop = t), sp.set(
    e,
    requestAnimationFrame(() => {
      new Pl({
        from: { scrollTop: e.scrollTop },
        to: { scrollTop: t },
        duration: n,
        onUpdate: (r) => {
          e.scrollTop = r.scrollTop;
        }
      }).start();
    })
  );
}
function An(e, t) {
  const n = (o) => {
    if (He(o))
      return o.map((i) => n(i));
    if (!Ve(o))
      return o.format(t);
  };
  return n(e);
}
function so(e) {
  return Ve(e) ? !0 : He(e) ? e.length === 0 || e.length === 2 && gn(e[0]) && gn(e[1]) : !1;
}
function fr(e, t) {
  return e ? typeof e == "string" && Pt(e, t).format(t) === e : !1;
}
function _3(e, {
  disabledHours: t,
  disabledMinutes: n,
  disabledSeconds: o
}) {
  if (!e)
    return !1;
  const i = e.hour(), r = e.minute(), l = e.second(), s = (t == null ? void 0 : t()) || [], u = (n == null ? void 0 : n(i)) || [], f = (o == null ? void 0 : o(i, r)) || [], d = (p, h) => !Ve(p) && h.includes(p);
  return d(i, s) || d(r, u) || d(l, f);
}
var Xn = S({
  name: "RenderFunction",
  props: {
    renderFunc: {
      type: Function,
      required: !0
    }
  },
  render() {
    return this.renderFunc(this.$attrs);
  }
});
const Jm = Symbol("PickerInjectionKey");
function To() {
  const { datePickerT: e } = Ge(Jm) || {};
  return e || ((t, ...n) => t);
}
const J3 = S({
  name: "PanelShortcuts",
  components: {
    Button: Qt,
    RenderFunction: Xn
  },
  props: {
    prefixCls: {
      type: String,
      required: !0
    },
    shortcuts: {
      type: Array,
      default: () => []
    },
    showNowBtn: {
      type: Boolean
    }
  },
  emits: ["item-click", "item-mouse-enter", "item-mouse-leave", "now-click"],
  setup(e, { emit: t }) {
    return {
      datePickerT: To(),
      onItemClick: (o) => {
        t("item-click", o);
      },
      onItemMouseEnter: (o) => {
        t("item-mouse-enter", o);
      },
      onItemMouseLeave: (o) => {
        t("item-mouse-leave", o);
      },
      onNowClick: () => {
        t("now-click");
      },
      isFunction: Ne
    };
  }
});
function eC(e, t, n, o, i, r) {
  const l = J("Button"), s = J("RenderFunction");
  return v(), b("div", {
    class: m(`${e.prefixCls}-shortcuts`)
  }, [
    e.showNowBtn ? (v(), oe(l, {
      key: 0,
      size: "mini",
      onClick: t[0] || (t[0] = () => e.onNowClick())
    }, {
      default: ue(() => [
        Re(Pe(e.datePickerT("datePicker.now")), 1)
      ]),
      _: 1
    })) : te("v-if", !0),
    (v(!0), b(Ae, null, St(e.shortcuts, (u, f) => (v(), oe(l, {
      key: f,
      size: "mini",
      onClick: () => e.onItemClick(u),
      onMouseenter: () => e.onItemMouseEnter(u),
      onMouseleave: () => e.onItemMouseLeave(u)
    }, {
      default: ue(() => [
        e.isFunction(u.label) ? (v(), oe(s, {
          key: 0,
          "render-func": u.label
        }, null, 8, ["render-func"])) : (v(), b(Ae, { key: 1 }, [
          Re(Pe(u.label), 1)
        ], 64))
      ]),
      _: 2
    }, 1032, ["onClick", "onMouseenter", "onMouseleave"]))), 128))
  ], 2);
}
var eh = /* @__PURE__ */ N(J3, [["render", eC]]);
function Gl(e) {
  return [...Array(e)];
}
function ov(e) {
  if (!Ve(e))
    return He(e) ? e : [e, void 0];
}
function tl(e) {
  return !!e && gn(e[0]) && gn(e[1]);
}
function tC(e) {
  return Ve(e) || e.length === 0 || tl(e);
}
function th(e, t, n) {
  const o = t || e;
  return (n || e).set("year", o.year()).set("month", o.month()).set("date", o.date());
}
const nC = S({
  name: "IconDoubleLeft",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-double-left`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), lC = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function oC(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M36.857 9.9 22.715 24.042l14.142 14.142M25.544 9.9 11.402 24.042l14.142 14.142" }, null, -1)
  ]), 14, lC);
}
var os = /* @__PURE__ */ N(nC, [["render", oC]]);
const nh = Object.assign(os, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + os.name, os);
  }
}), iC = S({
  name: "IconDoubleRight",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-double-right`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), rC = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function aC(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m11.143 38.1 14.142-14.142L11.143 9.816M22.456 38.1l14.142-14.142L22.456 9.816" }, null, -1)
  ]), 14, rC);
}
var is = /* @__PURE__ */ N(iC, [["render", aC]]);
const lh = Object.assign(is, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + is.name, is);
  }
}), sC = S({
  name: "PanelHeader",
  components: {
    IconLeft: xn,
    IconRight: bn,
    IconDoubleLeft: nh,
    IconDoubleRight: lh,
    RenderFunction: Xn
  },
  props: {
    prefixCls: {
      type: String,
      required: !0
    },
    title: {
      type: String,
      required: !0
    },
    mode: {
      type: String,
      default: "date"
    },
    value: {
      type: Object
    },
    icons: {
      type: Object
    },
    onPrev: {
      type: Function
    },
    onSuperPrev: {
      type: Function
    },
    onNext: {
      type: Function
    },
    onSuperNext: {
      type: Function
    },
    onLabelClick: {
      type: Function
    }
  },
  emits: ["label-click"],
  setup(e) {
    return {
      showPrev: a(() => Ne(e.onPrev)),
      showSuperPrev: a(() => Ne(e.onSuperPrev)),
      showNext: a(() => Ne(e.onNext)),
      showSuperNext: a(() => Ne(e.onSuperNext)),
      year: a(
        () => ["date", "quarter", "month", "week"].includes(e.mode) && e.value ? e.value.format("YYYY") : ""
      ),
      month: a(
        () => ["date", "week"].includes(e.mode) && e.value ? e.value.format("MM") : ""
      ),
      getIconClassName: (t) => [
        `${e.prefixCls}-header-icon`,
        {
          [`${e.prefixCls}-header-icon-hidden`]: !t
        }
      ]
    };
  }
}), uC = { key: 1 };
function cC(e, t, n, o, i, r) {
  const l = J("RenderFunction"), s = J("IconDoubleLeft"), u = J("IconLeft"), f = J("IconRight"), d = J("IconDoubleRight");
  return v(), b("div", {
    class: m(`${e.prefixCls}-header`)
  }, [
    $("div", {
      class: m(e.getIconClassName(e.showSuperPrev)),
      onClick: t[0] || (t[0] = (...p) => e.onSuperPrev && e.onSuperPrev(...p))
    }, [
      e.showSuperPrev ? (v(), b(Ae, { key: 0 }, [
        e.icons && e.icons.prevDouble ? (v(), oe(l, {
          key: 0,
          "render-func": e.icons && e.icons.prevDouble
        }, null, 8, ["render-func"])) : (v(), oe(s, { key: 1 }))
      ], 64)) : te("v-if", !0)
    ], 2),
    $("div", {
      class: m(e.getIconClassName(e.showPrev)),
      onClick: t[1] || (t[1] = (...p) => e.onPrev && e.onPrev(...p))
    }, [
      e.showPrev ? (v(), b(Ae, { key: 0 }, [
        e.icons && e.icons.prev ? (v(), oe(l, {
          key: 0,
          "render-func": e.icons && e.icons.prev
        }, null, 8, ["render-func"])) : (v(), oe(u, { key: 1 }))
      ], 64)) : te("v-if", !0)
    ], 2),
    $("div", {
      class: m(`${e.prefixCls}-header-title`)
    }, [
      e.onLabelClick && (e.year || e.month) ? (v(), b(Ae, { key: 0 }, [
        e.year ? (v(), b("span", {
          key: 0,
          class: m(`${e.prefixCls}-header-label`),
          onClick: t[2] || (t[2] = () => e.onLabelClick && e.onLabelClick("year"))
        }, Pe(e.year), 3)) : te("v-if", !0),
        e.year && e.month ? (v(), b("span", uC, "-")) : te("v-if", !0),
        e.month ? (v(), b("span", {
          key: 2,
          class: m(`${e.prefixCls}-header-label`),
          onClick: t[3] || (t[3] = () => e.onLabelClick && e.onLabelClick("month"))
        }, Pe(e.month), 3)) : te("v-if", !0)
      ], 64)) : (v(), b(Ae, { key: 1 }, [
        Re(Pe(e.title), 1)
      ], 64))
    ], 2),
    $("div", {
      class: m(e.getIconClassName(e.showNext)),
      onClick: t[4] || (t[4] = (...p) => e.onNext && e.onNext(...p))
    }, [
      e.showNext ? (v(), b(Ae, { key: 0 }, [
        e.icons && e.icons.next ? (v(), oe(l, {
          key: 0,
          "render-func": e.icons && e.icons.next
        }, null, 8, ["render-func"])) : (v(), oe(f, { key: 1 }))
      ], 64)) : te("v-if", !0)
    ], 2),
    $("div", {
      class: m(e.getIconClassName(e.showSuperNext)),
      onClick: t[5] || (t[5] = (...p) => e.onSuperNext && e.onSuperNext(...p))
    }, [
      e.showSuperNext ? (v(), b(Ae, { key: 0 }, [
        e.icons && e.icons.nextDouble ? (v(), oe(l, {
          key: 0,
          "render-func": e.icons && e.icons.nextDouble
        }, null, 8, ["render-func"])) : (v(), oe(d, { key: 1 }))
      ], 64)) : te("v-if", !0)
    ], 2)
  ], 2);
}
var Dr = /* @__PURE__ */ N(sC, [["render", cC]]);
function dC(e) {
  const { rangeValues: t } = ve(e), n = a(
    () => t != null && t.value && t.value.every(gn) ? wo(t.value) : t == null ? void 0 : t.value
  ), o = a(() => {
    var r;
    return (r = n.value) == null ? void 0 : r[0];
  }), i = a(() => {
    var r;
    return (r = n.value) == null ? void 0 : r[1];
  });
  return {
    getCellClassName: (r, l) => {
      const { value: s, isSameTime: u, mode: f, prefixCls: d } = e, p = !r.isPrev && !r.isNext, h = s && u(r.value, s);
      let k = u(r.value, qt());
      f === "week" && (k = qt().isSame(r.value, "date"));
      const y = p && o.value && u(r.value, o.value), w = p && i.value && u(r.value, i.value), g = p && o.value && i.value && (y || w || r.value.isBetween(
        o.value,
        i.value,
        null,
        "[]"
      ));
      return [
        `${d}-cell`,
        {
          [`${d}-cell-in-view`]: p,
          [`${d}-cell-today`]: k,
          [`${d}-cell-selected`]: h,
          [`${d}-cell-range-start`]: y,
          [`${d}-cell-range-end`]: w,
          [`${d}-cell-in-range`]: g,
          [`${d}-cell-disabled`]: l
        },
        r.classNames
      ];
    }
  };
}
const fC = S({
  name: "PanelBody",
  components: {
    RenderFunction: Xn
  },
  props: {
    prefixCls: {
      type: String,
      required: !0
    },
    rows: {
      type: Array,
      default: () => []
    },
    value: {
      type: Object
    },
    disabledDate: {
      type: Function
    },
    isSameTime: {
      type: Function,
      required: !0
    },
    mode: {
      type: String
    },
    rangeValues: {
      type: Array
    },
    dateRender: {
      type: Function
    }
  },
  emits: ["cell-click", "cell-mouse-enter"],
  setup(e, { emit: t }) {
    const { prefixCls: n, value: o, disabledDate: i, isSameTime: r, mode: l, rangeValues: s } = ve(e), { getCellClassName: u } = dC(
      me({
        prefixCls: n,
        value: o,
        isSameTime: r,
        mode: l,
        rangeValues: s
      })
    ), f = (d) => !!(Ne(i == null ? void 0 : i.value) && (i != null && i.value(rn(d.value))));
    return {
      isWeek: a(() => (l == null ? void 0 : l.value) === "week"),
      getCellClassName: (d) => {
        const p = f(d);
        return u(d, p);
      },
      onCellClick: (d) => {
        f(d) || t("cell-click", d);
      },
      onCellMouseEnter: (d) => {
        f(d) || t("cell-mouse-enter", d);
      },
      onCellMouseLeave: (d) => {
        f(d) || t("cell-mouse-enter", d);
      },
      getDateValue: rn
    };
  }
}), vC = ["onMouseenter", "onMouseleave", "onClick"];
function pC(e, t, n, o, i, r) {
  const l = J("RenderFunction");
  return v(), b("div", {
    class: m(`${e.prefixCls}-body`)
  }, [
    (v(!0), b(Ae, null, St(e.rows, (s, u) => (v(), b("div", {
      key: u,
      class: m([
        `${e.prefixCls}-row`,
        {
          [`${e.prefixCls}-row-week`]: e.isWeek
        }
      ])
    }, [
      (v(!0), b(Ae, null, St(s, (f, d) => (v(), b(Ae, null, [
        te(" 一年中的第几周，只在 week 模式下显示 "),
        e.isWeek && d === 0 ? (v(), b("div", {
          key: d,
          class: m([`${e.prefixCls}-cell`, `${e.prefixCls}-cell-week`])
        }, [
          $("div", {
            class: m(`${e.prefixCls}-date`)
          }, [
            $("div", {
              class: m(`${e.prefixCls}-date-value`)
            }, Pe(f.label), 3)
          ], 2)
        ], 2)) : (v(), b("div", {
          key: d,
          class: m(e.getCellClassName(f)),
          onMouseenter: () => {
            e.onCellMouseEnter(f);
          },
          onMouseleave: () => {
            e.onCellMouseLeave(f);
          },
          onClick: () => {
            e.onCellClick(f);
          }
        }, [
          e.dateRender ? (v(), oe(l, {
            key: 0,
            "render-func": e.dateRender,
            date: e.getDateValue(f.value)
          }, null, 8, ["render-func", "date"])) : (v(), b("div", {
            key: 1,
            class: m(`${e.prefixCls}-date`)
          }, [
            $("div", {
              class: m(`${e.prefixCls}-date-value`)
            }, Pe(f.label), 3)
          ], 2))
        ], 42, vC))
      ], 64))), 256))
    ], 2))), 128))
  ], 2);
}
var xr = /* @__PURE__ */ N(fC, [["render", pC]]);
const mC = S({
  name: "PanelWeekList",
  props: {
    prefixCls: {
      type: String,
      required: !0
    },
    weekList: {
      type: Array,
      required: !0
    }
  },
  setup() {
    const e = To();
    return {
      labelList: a(() => [
        "sunday",
        "monday",
        "tuesday",
        "wednesday",
        "thursday",
        "friday",
        "saturday"
      ].map((n) => e(`datePicker.week.short.${n}`)))
    };
  }
});
function hC(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(`${e.prefixCls}-week-list`)
  }, [
    (v(!0), b(Ae, null, St(e.weekList, (l) => (v(), b("div", {
      key: l,
      class: m(`${e.prefixCls}-week-list-item`)
    }, Pe(e.labelList[l] || ""), 3))), 128))
  ], 2);
}
var kC = /* @__PURE__ */ N(mC, [["render", hC]]);
const gC = S({
  name: "TimePickerColumn",
  props: {
    prefixCls: {
      type: String,
      required: !0
    },
    list: {
      type: Array,
      required: !0
    },
    value: {
      type: [Number, String]
    },
    visible: {
      type: Boolean
    }
  },
  emits: ["select"],
  setup(e, { emit: t }) {
    const { visible: n, value: o } = ve(e), i = V(/* @__PURE__ */ new Map()), r = V();
    function l(s = !1) {
      if (!r.value || Ve(o == null ? void 0 : o.value) || !(n != null && n.value))
        return;
      const u = i.value.get(o.value);
      u && Q3(r.value, u.offsetTop, s ? 100 : 0);
    }
    return ze([o, n], (s, [, u]) => {
      n.value !== u ? at(() => {
        l();
      }) : l(!0);
    }), Je(() => {
      l();
    }), {
      refWrapper: r,
      refMap: i,
      onItemRef(s, u) {
        i.value.set(u.value, s);
      },
      onItemClick(s) {
        s.disabled || t("select", s.value);
      }
    };
  }
}), yC = ["onClick"];
function bC(e, t, n, o, i, r) {
  return v(), b("div", {
    ref: "refWrapper",
    class: m(`${e.prefixCls}-column`)
  }, [
    $("ul", null, [
      (v(!0), b(Ae, null, St(e.list, (l) => (v(), b("li", {
        key: l.value,
        ref_for: !0,
        ref: (s) => {
          e.onItemRef(s, l);
        },
        class: m([
          `${e.prefixCls}-cell`,
          {
            [`${e.prefixCls}-cell-disabled`]: l.disabled,
            [`${e.prefixCls}-cell-selected`]: l.selected
          }
        ]),
        onClick: () => {
          e.onItemClick(l);
        }
      }, [
        $("div", {
          class: m(`${e.prefixCls}-cell-inner`)
        }, Pe(l.label), 3)
      ], 10, yC))), 128))
    ])
  ], 2);
}
var CC = /* @__PURE__ */ N(gC, [["render", bC]]);
function $C(e) {
  const {
    format: t,
    step: n,
    use12Hours: o,
    hideDisabledOptions: i,
    disabledHours: r,
    disabledMinutes: l,
    disabledSeconds: s,
    selectedHour: u,
    selectedMinute: f,
    selectedSecond: d,
    selectedAmpm: p,
    disabled: h
  } = ve(e), k = a(() => {
    var P;
    const { hour: z = 1 } = (n == null ? void 0 : n.value) || {}, j = ((P = r == null ? void 0 : r.value) == null ? void 0 : P.call(r)) || [];
    let I = [];
    for (let L = 0; L < (o.value ? 12 : 24); L += z)
      I.push(L);
    return o.value && (I[0] = 12), i.value && j.length && (I = I.filter((L) => j.indexOf(L) < 0)), I.map((L) => ({
      label: gl(L, 2, "0"),
      value: L,
      selected: u.value === L,
      disabled: (h == null ? void 0 : h.value) || j.includes(L)
    }));
  }), y = a(() => {
    var P;
    const { minute: z = 1 } = (n == null ? void 0 : n.value) || {}, j = ((P = l == null ? void 0 : l.value) == null ? void 0 : P.call(l, u.value)) || [];
    let I = [];
    for (let L = 0; L < 60; L += z)
      I.push(L);
    return i.value && j.length && (I = I.filter((L) => j.indexOf(L) < 0)), I.map((L) => ({
      label: gl(L, 2, "0"),
      value: L,
      selected: f.value === L,
      disabled: (h == null ? void 0 : h.value) || j.includes(L)
    }));
  }), w = a(() => {
    var P;
    const { second: z = 1 } = (n == null ? void 0 : n.value) || {}, j = ((P = s == null ? void 0 : s.value) == null ? void 0 : P.call(s, u.value, f.value)) || [];
    let I = [];
    for (let L = 0; L < 60; L += z)
      I.push(L);
    return i.value && j.length && (I = I.filter((L) => j.indexOf(L) < 0)), I.map((L) => ({
      label: gl(L, 2, "0"),
      value: L,
      selected: d.value === L,
      disabled: (h == null ? void 0 : h.value) || j.includes(L)
    }));
  }), g = ["am", "pm"], C = a(() => {
    const P = lv(t.value).list.includes("A");
    return g.map((z) => ({
      label: P ? z.toUpperCase() : z,
      value: z,
      selected: p.value === z,
      disabled: h == null ? void 0 : h.value
    }));
  });
  return {
    hours: k,
    minutes: y,
    seconds: w,
    ampmList: C
  };
}
function Kv(e) {
  const {
    format: t,
    use12Hours: n,
    defaultFormat: o
  } = ve(e), i = a(() => {
    let f = (t == null ? void 0 : t.value) || (o == null ? void 0 : o.value);
    return (!f || !lv(f).list.length) && (f = n != null && n.value ? "hh:mm:ss a" : "HH:mm:ss"), f;
  }), r = a(() => lv(i.value)), l = a(() => r.value.list), s = a(() => r.value.use12Hours), u = a(
    () => !!(n != null && n.value || s.value)
  );
  return {
    columns: l,
    use12Hours: u,
    format: i
  };
}
function oh(e) {
  const t = (n) => _3(n, {
    disabledHours: e.disabledHours,
    disabledMinutes: e.disabledMinutes,
    disabledSeconds: e.disabledSeconds
  });
  return (n) => He(n) ? n.some((o) => t(o)) : t(n);
}
const wC = S({
  name: "TimePickerPanel",
  components: {
    TimeColumn: CC,
    Button: Qt
  },
  props: {
    value: {
      type: Object
    },
    visible: {
      type: Boolean
    },
    format: {
      type: String,
      default: "HH:mm:ss"
    },
    use12Hours: {
      type: Boolean
    },
    step: {
      type: Object
    },
    disabledHours: {
      type: Function
    },
    disabledMinutes: {
      type: Function
    },
    disabledSeconds: {
      type: Function
    },
    hideDisabledOptions: {
      type: Boolean
    },
    hideFooter: {
      type: Boolean
    },
    isRange: {
      type: Boolean
    },
    disabled: {
      type: Boolean
    }
  },
  emits: {
    select: (e) => gn(e),
    confirm: (e) => gn(e)
  },
  setup(e, { emit: t }) {
    const {
      value: n,
      visible: o,
      format: i,
      step: r,
      use12Hours: l,
      hideDisabledOptions: s,
      disabledHours: u,
      disabledMinutes: f,
      disabledSeconds: d,
      disabled: p
    } = ve(e), h = B("timepicker"), { t: k } = gt(), {
      columns: y,
      use12Hours: w,
      format: g
    } = Kv(
      me({
        format: i,
        use12Hours: l
      })
    ), C = V(n == null ? void 0 : n.value), P = (H) => {
      C.value = H;
    };
    ze([o, n], () => {
      o.value && P(n == null ? void 0 : n.value);
    });
    const z = a(() => {
      var H;
      const D = (H = C.value) == null ? void 0 : H.hour();
      return Ve(D) || !w.value ? D : D > 12 ? D - 12 : D === 0 ? 12 : D;
    }), j = a(() => {
      var H;
      return (H = C.value) == null ? void 0 : H.minute();
    }), I = a(() => {
      var H;
      return (H = C.value) == null ? void 0 : H.second();
    }), L = a(() => {
      var H;
      const D = (H = C.value) == null ? void 0 : H.hour();
      return !Ve(D) && D >= 12 ? "pm" : "am";
    }), { hours: M, minutes: E, seconds: K, ampmList: q } = $C(
      me({
        format: g,
        step: r,
        use12Hours: w,
        hideDisabledOptions: s,
        disabledHours: u,
        disabledMinutes: f,
        disabledSeconds: d,
        selectedHour: z,
        selectedMinute: j,
        selectedSecond: I,
        selectedAmpm: L,
        disabled: p
      })
    ), T = oh(
      me({
        disabledHours: u,
        disabledMinutes: f,
        disabledSeconds: d
      })
    ), X = a(
      () => T(C.value)
    );
    function Y(H) {
      Ve(H) || t("confirm", H);
    }
    function Z(H) {
      P(H), t("select", H);
    }
    function U(H, D = "hour") {
      let R;
      const W = z.value || "00", O = j.value || "00", x = I.value || "00", G = L.value || "am";
      switch (D) {
        case "hour":
          R = `${H}:${O}:${x}`;
          break;
        case "minute":
          R = `${W}:${H}:${x}`;
          break;
        case "second":
          R = `${W}:${O}:${H}`;
          break;
        case "ampm":
          R = `${W}:${O}:${x} ${H}`;
          break;
        default:
          R = "00:00:00";
      }
      let ne = "HH:mm:ss";
      w.value && (ne = "HH:mm:ss a", D !== "ampm" && (R = `${R} ${G}`)), R = Pt(R, ne), Z(R);
    }
    return {
      prefixCls: h,
      t: k,
      hours: M,
      minutes: E,
      seconds: K,
      ampmList: q,
      selectedValue: C,
      selectedHour: z,
      selectedMinute: j,
      selectedSecond: I,
      selectedAmpm: L,
      computedUse12Hours: w,
      confirmBtnDisabled: X,
      columns: y,
      onSelect: U,
      onSelectNow() {
        const H = Pt(/* @__PURE__ */ new Date());
        Z(H);
      },
      onConfirm() {
        Y(C.value);
      }
    };
  }
});
function SC(e, t, n, o, i, r) {
  const l = J("TimeColumn"), s = J("Button");
  return v(), b(Ae, null, [
    $("div", {
      class: m(e.prefixCls)
    }, [
      e.columns.includes("H") || e.columns.includes("h") ? (v(), oe(l, {
        key: 0,
        value: e.selectedHour,
        list: e.hours,
        "prefix-cls": e.prefixCls,
        visible: e.visible,
        onSelect: t[0] || (t[0] = (u) => {
          e.onSelect(u, "hour");
        })
      }, null, 8, ["value", "list", "prefix-cls", "visible"])) : te("v-if", !0),
      e.columns.includes("m") ? (v(), oe(l, {
        key: 1,
        value: e.selectedMinute,
        list: e.minutes,
        "prefix-cls": e.prefixCls,
        visible: e.visible,
        onSelect: t[1] || (t[1] = (u) => {
          e.onSelect(u, "minute");
        })
      }, null, 8, ["value", "list", "prefix-cls", "visible"])) : te("v-if", !0),
      e.columns.includes("s") ? (v(), oe(l, {
        key: 2,
        value: e.selectedSecond,
        list: e.seconds,
        "prefix-cls": e.prefixCls,
        visible: e.visible,
        onSelect: t[2] || (t[2] = (u) => {
          e.onSelect(u, "second");
        })
      }, null, 8, ["value", "list", "prefix-cls", "visible"])) : te("v-if", !0),
      e.computedUse12Hours ? (v(), oe(l, {
        key: 3,
        value: e.selectedAmpm,
        list: e.ampmList,
        "prefix-cls": e.prefixCls,
        visible: e.visible,
        onSelect: t[3] || (t[3] = (u) => {
          e.onSelect(u, "ampm");
        })
      }, null, 8, ["value", "list", "prefix-cls", "visible"])) : te("v-if", !0)
    ], 2),
    e.$slots["extra-footer"] ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-footer-extra-wrapper`)
    }, [
      _(e.$slots, "extra-footer")
    ], 2)) : te("v-if", !0),
    e.hideFooter ? te("v-if", !0) : (v(), b("div", {
      key: 1,
      class: m(`${e.prefixCls}-footer-btn-wrapper`)
    }, [
      e.isRange ? te("v-if", !0) : (v(), oe(s, {
        key: 0,
        size: "mini",
        onClick: e.onSelectNow
      }, {
        default: ue(() => [
          Re(Pe(e.t("datePicker.now")), 1)
        ]),
        _: 1
      }, 8, ["onClick"])),
      c(s, {
        type: "primary",
        size: "mini",
        disabled: e.confirmBtnDisabled || !e.selectedValue,
        onClick: e.onConfirm
      }, {
        default: ue(() => [
          Re(Pe(e.t("datePicker.ok")), 1)
        ]),
        _: 1
      }, 8, ["disabled", "onClick"])
    ], 2))
  ], 64);
}
var vr = /* @__PURE__ */ N(wC, [["render", SC]]);
const zC = S({
  name: "IconCalendar",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-calendar`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), LC = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function jC(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 22h34M14 5v8m20-8v8M8 41h32a1 1 0 0 0 1-1V10a1 1 0 0 0-1-1H8a1 1 0 0 0-1 1v30a1 1 0 0 0 1 1Z" }, null, -1)
  ]), 14, LC);
}
var rs = /* @__PURE__ */ N(zC, [["render", jC]]);
const Rr = Object.assign(rs, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + rs.name, rs);
  }
}), PC = S({
  name: "IconClockCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-clock-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), IC = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function BC(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 14v10h9.5m8.5 0c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6s18 8.059 18 18Z" }, null, -1)
  ]), 14, IC);
}
var as = /* @__PURE__ */ N(PC, [["render", BC]]);
const Yv = Object.assign(as, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + as.name, as);
  }
}), ih = 6, iv = 7, MC = ih * iv;
function NC(e) {
  return {
    label: e.date(),
    value: e
  };
}
const OC = S({
  name: "DatePanel",
  components: {
    PanelHeader: Dr,
    PanelBody: xr,
    PanelWeekList: kC,
    TimePanel: vr,
    IconCalendar: Rr,
    IconClockCircle: Yv
  },
  props: {
    isRange: {
      type: Boolean
    },
    value: {
      type: Object
    },
    rangeValues: {
      type: Array
    },
    headerValue: {
      type: Object,
      required: !0
    },
    footerValue: {
      type: Object
    },
    timePickerValue: {
      type: Object
    },
    headerOperations: {
      type: Object,
      default: () => ({})
    },
    headerIcons: {
      type: Object,
      default: () => ({})
    },
    dayStartOfWeek: {
      type: Number,
      default: 0
    },
    disabledDate: {
      type: Function
    },
    disabledTime: {
      type: Function
    },
    isSameTime: {
      type: Function
    },
    mode: {
      type: String,
      default: "date"
    },
    showTime: {
      type: Boolean
    },
    timePickerProps: {
      type: Object
    },
    currentView: {
      type: String
    },
    dateRender: {
      type: Function
    },
    disabled: {
      type: Boolean
    },
    onHeaderLabelClick: {
      type: Function
    }
  },
  emits: [
    "select",
    "time-picker-select",
    "cell-mouse-enter",
    "current-view-change",
    "update:currentView"
  ],
  setup(e, { emit: t }) {
    const {
      isRange: n,
      headerValue: o,
      footerValue: i,
      dayStartOfWeek: r,
      isSameTime: l,
      mode: s,
      showTime: u,
      currentView: f,
      disabledTime: d
    } = ve(e), p = To(), h = a(() => (s == null ? void 0 : s.value) === "week"), k = a(
      () => B(h.value ? "panel-week" : "panel-date")
    ), y = B("picker"), [w, g] = Vt(
      "date",
      me({ value: f })
    ), C = a(() => u.value && n.value), P = a(
      () => !u.value || !C.value || w.value === "date"
    ), z = a(
      () => u.value && (!C.value || w.value === "time")
    ), j = a(() => [
      k.value,
      {
        [`${k.value}-with-view-tabs`]: C.value
      }
    ]), I = a(() => o.value.format("YYYY-MM")), L = a(
      () => {
        var Y;
        return u.value && ((Y = d == null ? void 0 : d.value) == null ? void 0 : Y.call(
          d,
          rn((i == null ? void 0 : i.value) || qt())
        )) || {};
      }
    ), M = a(() => {
      const Y = [0, 1, 2, 3, 4, 5, 6], Z = Math.max(r.value % 7, 0);
      return [...Y.slice(Z), ...Y.slice(0, Z)];
    }), E = a(() => {
      const Y = Bt.startOf(o.value, "month"), Z = Y.day(), U = Y.daysInMonth(), H = M.value.indexOf(Z), D = Gl(MC);
      for (let W = 0; W < D.length; W++)
        D[W] = {
          ...NC(Bt.add(Y, W - H, "day")),
          isPrev: W < H,
          isNext: W > H + U - 1
        };
      return Gl(ih).map((W, O) => {
        const x = D.slice(O * iv, (O + 1) * iv);
        if (h.value) {
          const G = x[0].value;
          x.unshift({
            label: G.week(),
            value: G
          });
        }
        return x;
      });
    }), K = a(
      () => (l == null ? void 0 : l.value) || ((Y, Z) => Y.isSame(Z, "day"))
    );
    function q(Y) {
      t("select", Y.value);
    }
    function T(Y) {
      t("time-picker-select", Y);
    }
    function X(Y) {
      t("cell-mouse-enter", Y.value);
    }
    return {
      prefixCls: k,
      classNames: j,
      pickerPrefixCls: y,
      headerTitle: I,
      rows: E,
      weekList: a(
        () => h.value ? [-1, ...M.value] : M.value
      ),
      mergedIsSameTime: K,
      disabledTimeProps: L,
      onCellClick: q,
      onCellMouseEnter: X,
      onTimePanelSelect: T,
      showViewTabs: C,
      showDateView: P,
      showTimeView: z,
      changeViewTo: (Y) => {
        t("current-view-change", Y), t("update:currentView", Y), g(Y);
      },
      datePickerT: p
    };
  }
});
function VC(e, t, n, o, i, r) {
  const l = J("PanelHeader"), s = J("PanelWeekList"), u = J("PanelBody"), f = J("TimePanel"), d = J("IconCalendar"), p = J("IconClockCircle");
  return v(), b("div", {
    class: m(e.classNames)
  }, [
    e.showDateView ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-inner`)
    }, [
      c(l, se({
        ...e.headerOperations,
        icons: e.headerIcons
      }, {
        "prefix-cls": e.pickerPrefixCls,
        title: e.headerTitle,
        mode: e.mode,
        value: e.headerValue,
        "on-label-click": e.onHeaderLabelClick
      }), null, 16, ["prefix-cls", "title", "mode", "value", "on-label-click"]),
      c(s, {
        "prefix-cls": e.pickerPrefixCls,
        "week-list": e.weekList
      }, null, 8, ["prefix-cls", "week-list"]),
      c(u, {
        mode: e.mode,
        "prefix-cls": e.pickerPrefixCls,
        rows: e.rows,
        value: e.isRange ? void 0 : e.value,
        "range-values": e.rangeValues,
        "disabled-date": e.disabledDate,
        "is-same-time": e.mergedIsSameTime,
        "date-render": e.dateRender,
        onCellClick: e.onCellClick,
        onCellMouseEnter: e.onCellMouseEnter
      }, null, 8, ["mode", "prefix-cls", "rows", "value", "range-values", "disabled-date", "is-same-time", "date-render", "onCellClick", "onCellMouseEnter"])
    ], 2)) : te("v-if", !0),
    e.showTimeView ? (v(), b("div", {
      key: 1,
      class: m(`${e.prefixCls}-timepicker`)
    }, [
      $("header", {
        class: m(`${e.prefixCls}-timepicker-title`)
      }, Pe(e.datePickerT("datePicker.selectTime")), 3),
      c(f, se({
        ...e.timePickerProps,
        ...e.disabledTimeProps
      }, {
        "hide-footer": "",
        value: e.value || e.isRange ? e.timePickerValue : void 0,
        disabled: e.disabled,
        onSelect: e.onTimePanelSelect
      }), null, 16, ["value", "disabled", "onSelect"])
    ], 2)) : te("v-if", !0),
    e.showViewTabs ? (v(), b("div", {
      key: 2,
      class: m(`${e.prefixCls}-footer`)
    }, [
      $("div", {
        class: m(`${e.prefixCls}-view-tabs`)
      }, [
        $("div", {
          class: m([
            `${e.prefixCls}-view-tab-pane`,
            { [`${e.prefixCls}-view-tab-pane-active`]: e.showDateView }
          ]),
          onClick: t[0] || (t[0] = () => e.changeViewTo("date"))
        }, [
          c(d),
          $("span", {
            class: m(`${e.prefixCls}-view-tab-pane-text`)
          }, Pe(e.footerValue && e.footerValue.format("YYYY-MM-DD")), 3)
        ], 2),
        $("div", {
          class: m([
            `${e.prefixCls}-view-tab-pane`,
            { [`${e.prefixCls}-view-tab-pane-active`]: e.showTimeView }
          ]),
          onClick: t[1] || (t[1] = () => e.changeViewTo("time"))
        }, [
          c(p),
          $("span", {
            class: m(`${e.prefixCls}-view-tab-pane-text`)
          }, Pe(e.timePickerValue && e.timePickerValue.format("HH:mm:ss")), 3)
        ], 2)
      ], 2)
    ], 2)) : te("v-if", !0)
  ], 2);
}
var Uv = /* @__PURE__ */ N(OC, [["render", VC]]);
const TC = S({
  name: "WeekPanel",
  components: {
    DatePanel: Uv
  },
  props: {
    dayStartOfWeek: {
      type: Number,
      default: 0
    }
  },
  emits: ["select", "cell-mouse-enter"],
  setup(e, { emit: t }) {
    return gt(), {
      isSameTime: (o, i) => Bt.isSameWeek(o, i, e.dayStartOfWeek),
      onSelect: (o) => {
        const i = Bt.startOfWeek(
          o,
          e.dayStartOfWeek
        );
        t("select", i);
      },
      onCellMouseEnter: (o) => {
        const i = Bt.startOfWeek(
          o,
          e.dayStartOfWeek
        );
        t("cell-mouse-enter", i);
      }
    };
  }
});
function AC(e, t, n, o, i, r) {
  const l = J("DatePanel");
  return v(), oe(l, se(e.$attrs, {
    mode: "week",
    "is-week": "",
    "day-start-of-week": e.dayStartOfWeek,
    "is-same-time": e.isSameTime,
    onSelect: e.onSelect,
    onCellMouseEnter: e.onCellMouseEnter
  }), null, 16, ["day-start-of-week", "is-same-time", "onSelect", "onCellMouseEnter"]);
}
var rh = /* @__PURE__ */ N(TC, [["render", AC]]);
const EC = [
  "January",
  "February",
  "March",
  "April",
  "May",
  "June",
  "July",
  "August",
  "September",
  "October",
  "November",
  "December"
], WC = 12, FC = 4, up = 3, DC = S({
  name: "MonthPanel",
  components: {
    PanelHeader: Dr,
    PanelBody: xr
  },
  props: {
    headerValue: {
      type: Object,
      required: !0
    },
    headerOperations: {
      type: Object,
      default: () => ({})
    },
    headerIcons: {
      type: Object,
      default: () => ({})
    },
    value: {
      type: Object
    },
    disabledDate: {
      type: Function
    },
    rangeValues: {
      type: Array
    },
    dateRender: {
      type: Function
    },
    onHeaderLabelClick: {
      type: Function
    },
    abbreviation: {
      type: Boolean,
      default: !0
    }
  },
  emits: ["select", "cell-mouse-enter"],
  setup(e, { emit: t }) {
    const n = To(), { headerValue: o } = ve(e), i = a(() => B("panel-month")), r = B("picker"), l = a(() => o.value.format("YYYY")), s = a(() => {
      const p = o.value.year(), h = e.abbreviation ? "short" : "long", k = Gl(WC).map((w, g) => ({
        label: n(`datePicker.month.${h}.${EC[g]}`),
        value: Pt(`${p}-${g + 1}`, "YYYY-M")
      }));
      return Gl(FC).map(
        (w, g) => k.slice(g * up, (g + 1) * up)
      );
    }), u = (p, h) => p.isSame(h, "month");
    function f(p) {
      t("select", p.value);
    }
    function d(p) {
      t("cell-mouse-enter", p.value);
    }
    return {
      prefixCls: i,
      pickerPrefixCls: r,
      headerTitle: l,
      rows: s,
      isSameTime: u,
      onCellClick: f,
      onCellMouseEnter: d
    };
  }
});
function xC(e, t, n, o, i, r) {
  const l = J("PanelHeader"), s = J("PanelBody");
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    $("div", {
      class: m(`${e.prefixCls}-inner`)
    }, [
      c(l, se({
        ...e.headerOperations,
        icons: e.headerIcons
      }, {
        "prefix-cls": e.pickerPrefixCls,
        title: e.headerTitle,
        mode: "month",
        value: e.headerValue,
        "on-label-click": e.onHeaderLabelClick
      }), null, 16, ["prefix-cls", "title", "value", "on-label-click"]),
      c(s, {
        mode: "month",
        "prefix-cls": e.pickerPrefixCls,
        rows: e.rows,
        value: e.value,
        "range-values": e.rangeValues,
        "disabled-date": e.disabledDate,
        "is-same-time": e.isSameTime,
        "date-render": e.dateRender,
        onCellClick: e.onCellClick,
        onCellMouseEnter: e.onCellMouseEnter
      }, null, 8, ["prefix-cls", "rows", "value", "range-values", "disabled-date", "is-same-time", "date-render", "onCellClick", "onCellMouseEnter"])
    ], 2)
  ], 2);
}
var ah = /* @__PURE__ */ N(DC, [["render", xC]]);
const rv = 4, Ii = 3, RC = rv * Ii, ss = 10, HC = S({
  name: "YearPanel",
  components: {
    PanelHeader: Dr,
    PanelBody: xr
  },
  props: {
    headerValue: {
      type: Object,
      required: !0
    },
    headerOperations: {
      type: Object,
      default: () => ({})
    },
    headerIcons: {
      type: Object,
      default: () => ({})
    },
    value: {
      type: Object
    },
    disabledDate: {
      type: Function
    },
    rangeValues: {
      type: Array
    },
    dateRender: {
      type: Function
    }
  },
  emits: ["select", "cell-mouse-enter"],
  setup(e, { emit: t }) {
    const { headerValue: n } = ve(e), o = a(() => B("panel-year")), i = B("picker"), r = a(() => {
      const d = Math.floor(n.value.year() / ss) * ss - 1, p = Gl(RC).map((k, y) => ({
        label: d + y,
        value: Pt(`${d + y}`, "YYYY"),
        isPrev: y < 1,
        isNext: y > ss
      }));
      return Gl(rv).map(
        (k, y) => p.slice(y * Ii, (y + 1) * Ii)
      );
    }), l = a(
      () => `${r.value[0][1].label}-${r.value[rv - 1][Ii - 1].label}`
    ), s = (d, p) => d.isSame(p, "year");
    function u(d) {
      t("select", d.value);
    }
    function f(d) {
      t("cell-mouse-enter", d.value);
    }
    return {
      prefixCls: o,
      pickerPrefixCls: i,
      headerTitle: l,
      rows: r,
      isSameTime: s,
      onCellClick: u,
      onCellMouseEnter: f
    };
  }
});
function qC(e, t, n, o, i, r) {
  const l = J("PanelHeader"), s = J("PanelBody");
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    $("div", {
      class: m(`${e.prefixCls}-inner`)
    }, [
      c(l, se({
        ...e.headerOperations,
        icons: e.headerIcons
      }, {
        "prefix-cls": e.pickerPrefixCls,
        title: e.headerTitle
      }), null, 16, ["prefix-cls", "title"]),
      c(s, {
        mode: "year",
        "prefix-cls": e.pickerPrefixCls,
        rows: e.rows,
        value: e.value,
        "range-values": e.rangeValues,
        "disabled-date": e.disabledDate,
        "is-same-time": e.isSameTime,
        "date-render": e.dateRender,
        onCellClick: e.onCellClick,
        onCellMouseEnter: e.onCellMouseEnter
      }, null, 8, ["prefix-cls", "rows", "value", "range-values", "disabled-date", "is-same-time", "date-render", "onCellClick", "onCellMouseEnter"])
    ], 2)
  ], 2);
}
var sh = /* @__PURE__ */ N(HC, [["render", qC]]);
const ZC = S({
  name: "QuarterPanel",
  components: {
    PanelHeader: Dr,
    PanelBody: xr
  },
  props: {
    headerValue: {
      type: Object,
      required: !0
    },
    headerOperations: {
      type: Object,
      default: () => ({})
    },
    headerIcons: {
      type: Object,
      default: () => ({})
    },
    value: {
      type: Object
    },
    disabledDate: {
      type: Function
    },
    rangeValues: {
      type: Array
    },
    dateRender: {
      type: Function
    },
    onHeaderLabelClick: {
      type: Function
    }
  },
  emits: ["select", "cell-mouse-enter"],
  setup(e, { emit: t }) {
    const { headerValue: n } = ve(e), o = a(() => B("panel-quarter")), i = B("picker"), r = a(() => n.value.format("YYYY")), l = a(() => {
      const d = n.value.year();
      return [
        [1, 2, 3, 4].map((p) => ({
          label: `Q${p}`,
          value: Pt(`${d}-${gl((p - 1) * 3 + 1, 2, "0")}-01`)
        }))
      ];
    }), s = (d, p) => d.isSame(p, "month") || d.isSame(p, "year") && Math.floor(d.month() / 3) === Math.floor(p.month() / 3);
    function u(d) {
      t("select", d.value);
    }
    function f(d) {
      t("cell-mouse-enter", d.value);
    }
    return {
      prefixCls: o,
      pickerPrefixCls: i,
      headerTitle: r,
      rows: l,
      isSameTime: s,
      onCellClick: u,
      onCellMouseEnter: f
    };
  }
});
function KC(e, t, n, o, i, r) {
  const l = J("PanelHeader"), s = J("PanelBody");
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    $("div", {
      class: m(`${e.prefixCls}-inner`)
    }, [
      c(l, se({
        ...e.headerOperations,
        icons: e.headerIcons
      }, {
        "prefix-cls": e.pickerPrefixCls,
        title: e.headerTitle,
        mode: "quarter",
        value: e.headerValue,
        "on-label-click": e.onHeaderLabelClick
      }), null, 16, ["prefix-cls", "title", "value", "on-label-click"]),
      c(s, {
        mode: "quarter",
        "prefix-cls": e.pickerPrefixCls,
        rows: e.rows,
        value: e.value,
        "range-values": e.rangeValues,
        "disabled-date": e.disabledDate,
        "is-same-time": e.isSameTime,
        "date-render": e.dateRender,
        onCellClick: e.onCellClick,
        onCellMouseEnter: e.onCellMouseEnter
      }, null, 8, ["prefix-cls", "rows", "value", "range-values", "disabled-date", "is-same-time", "date-render", "onCellClick", "onCellMouseEnter"])
    ], 2)
  ], 2);
}
var uh = /* @__PURE__ */ N(ZC, [["render", KC]]);
const YC = S({
  name: "IconLink",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-link`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), UC = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function GC(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m14.1 25.414-4.95 4.95a6 6 0 0 0 8.486 8.485l8.485-8.485a6 6 0 0 0 0-8.485m7.779.707 4.95-4.95a6 6 0 1 0-8.486-8.485l-8.485 8.485a6 6 0 0 0 0 8.485" }, null, -1)
  ]), 14, UC);
}
var us = /* @__PURE__ */ N(YC, [["render", GC]]);
const ch = Object.assign(us, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + us.name, us);
  }
}), XC = S({
  name: "Link",
  components: { IconLink: ch, IconLoading: Yt },
  props: {
    href: String,
    status: {
      type: String,
      default: "normal"
    },
    hoverable: {
      type: Boolean,
      default: !0
    },
    icon: Boolean,
    loading: Boolean,
    disabled: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { slots: t, emit: n }) {
    const o = B("link"), i = Qm(e, t, "icon"), r = (s) => {
      if (e.disabled || e.loading) {
        s.preventDefault();
        return;
      }
      n("click", s);
    };
    return {
      cls: a(() => [
        o,
        `${o}-status-${e.status}`,
        {
          [`${o}-disabled`]: e.disabled,
          [`${o}-loading`]: e.loading,
          [`${o}-hoverless`]: !e.hoverable,
          [`${o}-with-icon`]: e.loading || i.value
        }
      ]),
      prefixCls: o,
      showIcon: i,
      handleClick: r
    };
  }
}), QC = ["href"];
function _C(e, t, n, o, i, r) {
  const l = J("icon-loading"), s = J("icon-link");
  return v(), b("a", {
    href: e.disabled ? void 0 : e.href,
    class: m(e.cls),
    onClick: t[0] || (t[0] = (...u) => e.handleClick && e.handleClick(...u))
  }, [
    e.loading || e.showIcon ? (v(), b("span", {
      key: 0,
      class: m(`${e.prefixCls}-icon`)
    }, [
      e.loading ? (v(), oe(l, { key: 0 })) : _(e.$slots, "icon", { key: 1 }, () => [
        c(s)
      ])
    ], 2)) : te("v-if", !0),
    _(e.$slots, "default")
  ], 10, QC);
}
var cs = /* @__PURE__ */ N(XC, [["render", _C]]);
const dh = Object.assign(cs, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + cs.name, cs);
  }
}), JC = S({
  name: "PanelFooter",
  components: {
    Link: dh,
    Button: Qt
  },
  props: {
    prefixCls: {
      type: String,
      required: !0
    },
    showTodayBtn: {
      type: Boolean
    },
    showConfirmBtn: {
      type: Boolean
    },
    confirmBtnDisabled: {
      type: Boolean
    }
  },
  emits: ["today-btn-click", "confirm-btn-click"],
  setup(e, { emit: t }) {
    return {
      datePickerT: To(),
      onTodayClick: () => {
        t("today-btn-click");
      },
      onConfirmBtnClick: () => {
        t("confirm-btn-click");
      }
    };
  }
});
function e$(e, t, n, o, i, r) {
  const l = J("Link"), s = J("Button");
  return v(), b("div", {
    class: m(`${e.prefixCls}-footer`)
  }, [
    e.$slots.extra ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-footer-extra-wrapper`)
    }, [
      _(e.$slots, "extra")
    ], 2)) : te("v-if", !0),
    e.showTodayBtn ? (v(), b("div", {
      key: 1,
      class: m(`${e.prefixCls}-footer-now-wrapper`)
    }, [
      c(l, { onClick: e.onTodayClick }, {
        default: ue(() => [
          Re(Pe(e.datePickerT("datePicker.today")), 1)
        ]),
        _: 1
      }, 8, ["onClick"])
    ], 2)) : te("v-if", !0),
    e.$slots.btn || e.showConfirmBtn ? (v(), b("div", {
      key: 2,
      class: m(`${e.prefixCls}-footer-btn-wrapper`)
    }, [
      _(e.$slots, "btn"),
      e.showConfirmBtn ? (v(), oe(s, {
        key: 0,
        class: m(`${e.prefixCls}-btn-confirm`),
        type: "primary",
        size: "mini",
        disabled: e.confirmBtnDisabled,
        onClick: e.onConfirmBtnClick
      }, {
        default: ue(() => [
          Re(Pe(e.datePickerT("datePicker.ok")), 1)
        ]),
        _: 1
      }, 8, ["class", "disabled", "onClick"])) : te("v-if", !0)
    ], 2)) : te("v-if", !0)
  ], 2);
}
var fh = /* @__PURE__ */ N(JC, [["render", e$]]);
function vh(e) {
  const { mode: t } = ve(e), n = a(
    () => ({ date: 1, week: 1, year: 10 * 12, quarter: 12, month: 12 })[t.value]
  ), o = a(
    () => ["year"].includes(t.value) ? 10 * 12 : 12
  );
  return {
    span: n,
    superSpan: o
  };
}
function pr(e) {
  const { mode: t, value: n, defaultValue: o, selectedValue: i, format: r, onChange: l } = ve(e), s = a(() => (t == null ? void 0 : t.value) || "date"), { span: u, superSpan: f } = vh(
    me({
      mode: s
    })
  ), d = (I, L) => {
    const M = s.value === "date" || s.value === "week" ? "M" : "y";
    return I.isSame(L, M);
  }, p = a(
    () => cn(n == null ? void 0 : n.value, r.value)
  ), h = a(
    () => cn(o == null ? void 0 : o.value, r.value)
  ), k = V(h.value || qt()), y = a(() => p.value || k.value), w = (I) => {
    I && (k.value = I);
  }, g = (I, L = !0) => {
    var M;
    I && (L && !d(y.value, I) && ((M = l == null ? void 0 : l.value) == null || M.call(l, I)), w(I));
  };
  i != null && i.value && w(i.value), ze(
    () => i == null ? void 0 : i.value,
    (I) => {
      g(I);
    }
  );
  function C() {
    return (i == null ? void 0 : i.value) || h.value || qt();
  }
  function P(I = !0) {
    const L = C();
    I ? g(L) : w(L);
  }
  const z = a(() => u.value !== f.value), j = a(() => ({
    onSuperPrev: () => {
      g(Bt.subtract(y.value, f.value, "M"));
    },
    onPrev: z.value ? () => {
      g(Bt.subtract(y.value, u.value, "M"));
    } : void 0,
    onNext: z.value ? () => {
      g(Bt.add(y.value, u.value, "M"));
    } : void 0,
    onSuperNext: () => {
      g(Bt.add(y.value, f.value, "M"));
    }
  }));
  return {
    headerValue: y,
    setHeaderValue: g,
    headerOperations: j,
    resetHeaderValue: P,
    getDefaultLocalValue: C
  };
}
const t$ = S({
  name: "DatePikerPanel",
  components: {
    DatePanel: Uv,
    PanelShortcuts: eh,
    PanelFooter: fh,
    WeekPanel: rh,
    MonthPanel: ah,
    YearPanel: sh,
    QuarterPanel: uh,
    RenderFunction: Xn
  },
  props: {
    mode: {
      type: String
    },
    headerMode: {
      type: String
    },
    prefixCls: {
      type: String,
      required: !0
    },
    value: {
      type: Object
    },
    headerValue: {
      type: Object,
      required: !0
    },
    timePickerValue: {
      type: Object
    },
    showTime: {
      type: Boolean
    },
    showConfirmBtn: {
      type: Boolean
    },
    shortcuts: {
      type: Array,
      default: () => []
    },
    shortcutsPosition: {
      type: String,
      default: "bottom"
    },
    format: {
      type: String,
      required: !0
    },
    dayStartOfWeek: {
      type: Number,
      default: 0
    },
    disabledDate: {
      type: Function
    },
    disabledTime: {
      type: Function
    },
    timePickerProps: {
      type: Object
    },
    extra: {
      type: Function
    },
    dateRender: {
      type: Function
    },
    hideTrigger: {
      type: Boolean
    },
    confirmBtnDisabled: {
      type: Boolean
    },
    showNowBtn: {
      type: Boolean
    },
    headerIcons: {
      type: Object,
      default: () => ({})
    },
    headerOperations: {
      type: Object
    },
    abbreviation: {
      type: Boolean
    }
  },
  emits: [
    "cell-click",
    "time-picker-select",
    "shortcut-click",
    "shortcut-mouse-enter",
    "shortcut-mouse-leave",
    "confirm",
    "today-btn-click",
    "header-label-click",
    "header-select",
    "month-header-click"
  ],
  setup(e, { emit: t }) {
    const {
      prefixCls: n,
      shortcuts: o,
      shortcutsPosition: i,
      format: r,
      value: l,
      disabledDate: s,
      hideTrigger: u,
      showNowBtn: f,
      dateRender: d,
      showConfirmBtn: p,
      headerValue: h,
      headerIcons: k,
      headerOperations: y,
      headerMode: w
    } = ve(e), g = a(
      () => !!(o.value && o.value.length)
    ), C = a(
      () => f.value && p.value && !g.value
    ), P = a(
      () => C.value || g.value
    ), z = a(
      () => P.value && i.value === "left"
    ), j = a(
      () => P.value && i.value === "right"
    ), I = a(
      () => P.value && i.value === "bottom"
    ), L = a(() => [
      `${n.value}-container`,
      {
        [`${n.value}-container-panel-only`]: u.value,
        [`${n.value}-container-shortcuts-placement-left`]: z.value,
        [`${n.value}-container-shortcuts-placement-right`]: j.value
      }
    ]), M = a(() => (l == null ? void 0 : l.value) || qt()), {
      headerValue: E,
      setHeaderValue: K,
      headerOperations: q
    } = pr(
      me({
        mode: w,
        format: r
      })
    );
    ze(h, (ee) => {
      K(ee);
    });
    function T(ee) {
      const { value: Q } = ee;
      return cn(
        Ne(Q) ? Q() : Q,
        ee.format || r.value
      );
    }
    function X(ee) {
      t("shortcut-click", T(ee), ee);
    }
    function Y(ee) {
      t("shortcut-mouse-enter", T(ee));
    }
    function Z(ee) {
      t("shortcut-mouse-leave", T(ee));
    }
    function U(ee) {
      t("cell-click", ee);
    }
    function H(ee) {
      t("time-picker-select", ee);
    }
    function D() {
      t("today-btn-click", qt());
    }
    function R() {
      t("confirm");
    }
    function W(ee) {
      t("header-label-click", ee);
    }
    function O(ee) {
      t("header-select", ee);
    }
    function x() {
      t("month-header-click");
    }
    const G = me({
      prefixCls: n,
      shortcuts: o,
      showNowBtn: C,
      onItemClick: X,
      onItemMouseEnter: Y,
      onItemMouseLeave: Z,
      onNowClick: D
    }), ne = me({
      value: l,
      headerValue: h,
      headerIcons: k,
      headerOperations: y,
      disabledDate: s,
      dateRender: d,
      onSelect: U,
      onHeaderLabelClick: W
    });
    return {
      classNames: L,
      showShortcutsInLeft: z,
      showShortcutsInRight: j,
      showShortcutsInBottom: I,
      shortcutsProps: G,
      commonPanelProps: ne,
      footerValue: M,
      onTodayBtnClick: D,
      onConfirmBtnClick: R,
      onTimePickerSelect: H,
      onHeaderPanelSelect: O,
      headerPanelHeaderValue: E,
      headerPanelHeaderOperations: q,
      onMonthHeaderLabelClick: x
    };
  }
});
function n$(e, t, n, o, i, r) {
  const l = J("PanelShortcuts"), s = J("YearPanel"), u = J("MonthPanel"), f = J("WeekPanel"), d = J("QuarterPanel"), p = J("DatePanel"), h = J("RenderFunction"), k = J("PanelFooter");
  return v(), b("div", {
    class: m(e.classNames)
  }, [
    e.showShortcutsInLeft ? (v(), oe(l, dt(se({ key: 0 }, e.shortcutsProps)), null, 16)) : te("v-if", !0),
    $("div", {
      class: m(`${e.prefixCls}-panel-wrapper`)
    }, [
      e.headerMode ? (v(), b(Ae, { key: 0 }, [
        e.headerMode === "year" ? (v(), oe(s, {
          key: 0,
          "header-value": e.headerPanelHeaderValue,
          "header-icons": e.headerIcons,
          "header-operations": e.headerPanelHeaderOperations,
          onSelect: e.onHeaderPanelSelect
        }, null, 8, ["header-value", "header-icons", "header-operations", "onSelect"])) : e.headerMode === "month" ? (v(), oe(u, {
          key: 1,
          "header-value": e.headerPanelHeaderValue,
          "header-icons": e.headerIcons,
          "header-operations": e.headerPanelHeaderOperations,
          abbreviation: e.abbreviation,
          onSelect: e.onHeaderPanelSelect,
          onHeaderLabelClick: e.onMonthHeaderLabelClick
        }, null, 8, ["header-value", "header-icons", "header-operations", "abbreviation", "onSelect", "onHeaderLabelClick"])) : te("v-if", !0)
      ], 64)) : (v(), b(Ae, { key: 1 }, [
        e.mode === "week" ? (v(), oe(f, se({ key: 0 }, e.commonPanelProps, { "day-start-of-week": e.dayStartOfWeek }), null, 16, ["day-start-of-week"])) : e.mode === "month" ? (v(), oe(u, se({
          key: 1,
          abbreviation: e.abbreviation
        }, e.commonPanelProps), null, 16, ["abbreviation"])) : e.mode === "year" ? (v(), oe(s, dt(se({ key: 2 }, e.commonPanelProps)), null, 16)) : e.mode === "quarter" ? (v(), oe(d, dt(se({ key: 3 }, e.commonPanelProps)), null, 16)) : (v(), oe(p, se({ key: 4 }, e.commonPanelProps, {
          mode: "date",
          "show-time": e.showTime,
          "time-picker-props": e.timePickerProps,
          "day-start-of-week": e.dayStartOfWeek,
          "footer-value": e.footerValue,
          "time-picker-value": e.timePickerValue,
          "disabled-time": e.disabledTime,
          onTimePickerSelect: e.onTimePickerSelect
        }), null, 16, ["show-time", "time-picker-props", "day-start-of-week", "footer-value", "time-picker-value", "disabled-time", "onTimePickerSelect"])),
        c(k, {
          "prefix-cls": e.prefixCls,
          "show-today-btn": e.showNowBtn && !(e.showConfirmBtn || e.showShortcutsInBottom),
          "show-confirm-btn": e.showConfirmBtn,
          "confirm-btn-disabled": e.confirmBtnDisabled,
          onTodayBtnClick: e.onTodayBtnClick,
          onConfirmBtnClick: e.onConfirmBtnClick
        }, kt({ _: 2 }, [
          e.extra ? {
            name: "extra",
            fn: ue(() => [
              e.extra ? (v(), oe(h, {
                key: 0,
                "render-func": e.extra
              }, null, 8, ["render-func"])) : te("v-if", !0)
            ]),
            key: "0"
          } : void 0,
          e.showShortcutsInBottom ? {
            name: "btn",
            fn: ue(() => [
              c(l, dt(Gt(e.shortcutsProps)), null, 16)
            ]),
            key: "1"
          } : void 0
        ]), 1032, ["prefix-cls", "show-today-btn", "show-confirm-btn", "confirm-btn-disabled", "onTodayBtnClick", "onConfirmBtnClick"])
      ], 64))
    ], 2),
    e.showShortcutsInRight ? (v(), oe(l, dt(se({ key: 1 }, e.shortcutsProps)), null, 16)) : te("v-if", !0)
  ], 2);
}
var l$ = /* @__PURE__ */ N(t$, [["render", n$]]);
function o$(e = "date", t = !1) {
  switch (e) {
    case "date":
      return t ? "YYYY-MM-DD HH:mm:ss" : "YYYY-MM-DD";
    case "month":
      return "YYYY-MM";
    case "year":
      return "YYYY";
    case "week":
      return "gggg-wo";
    case "quarter":
      return "YYYY-[Q]Q";
    default:
      return "YYYY-MM-DD";
  }
}
function i$(e = "date", t = !1) {
  switch (e) {
    case "date":
      return t ? "YYYY-MM-DD HH:mm:ss" : "YYYY-MM-DD";
    case "month":
      return "YYYY-MM";
    case "year":
      return "YYYY";
    case "week":
      return "YYYY-MM-DD";
    case "quarter":
      return "YYYY-MM";
    default:
      return "YYYY-MM-DD";
  }
}
function ph(e) {
  const {
    format: t,
    mode: n,
    showTime: o,
    valueFormat: i
  } = ve(e), r = a(
    () => !Ne(t == null ? void 0 : t.value) && (t == null ? void 0 : t.value) || o$(n == null ? void 0 : n.value, o == null ? void 0 : o.value)
  ), l = a(
    () => (i == null ? void 0 : i.value) || i$(n == null ? void 0 : n.value, o == null ? void 0 : o.value)
  ), s = a(
    () => ["timestamp", "Date"].includes(l.value) ? r.value : l.value
  );
  return {
    format: r,
    valueFormat: l,
    parseValueFormat: s
  };
}
function mh(e) {
  const { mode: t, showTime: n, disabledDate: o, disabledTime: i, isRange: r } = ve(e), l = a(
    () => (t == null ? void 0 : t.value) === "date" && (n == null ? void 0 : n.value)
  ), s = a(() => (d, p) => {
    if (!(o != null && o.value))
      return !1;
    const h = rn(d);
    return r != null && r.value ? o.value(h, p) : o.value(h);
  }), u = (d, p) => ((p == null ? void 0 : p()) || []).includes(d), f = a(() => (d, p) => {
    if (!l.value || !(i != null && i.value))
      return !1;
    const h = rn(d), k = r != null && r.value ? i.value(h, p) : i.value(h);
    return u(d.hour(), k.disabledHours) || u(d.minute(), k.disabledMinutes) || u(d.second(), k.disabledSeconds);
  });
  return function(p, h) {
    return p && (s.value(p, h || "start") || f.value(p, h || "start"));
  };
}
const yl = (e, t) => {
  if (!e || !t)
    return;
  t = t.replace(/\[(\w+)\]/g, ".$1");
  const n = t.split(".");
  if (n.length === 0)
    return;
  let o = e;
  for (let i = 0; i < n.length; i++) {
    if (!Qe(o) && !He(o) || !n[i])
      return;
    if (i !== n.length - 1)
      o = o[n[i]];
    else
      return o[n[i]];
  }
}, mr = (e, t, n, { addPath: o } = {}) => {
  if (!e || !t)
    return;
  t = t.replace(/\[(\w+)\]/g, ".$1");
  const i = t.split(".");
  if (i.length === 0)
    return;
  let r = e;
  for (let l = 0; l < i.length; l++) {
    if (!Qe(r) && !He(r) || !i[l])
      return;
    l !== i.length - 1 ? (o && Ve(r[i[l]]) && (r[i[l]] = {}), r = r[i[l]]) : r[i[l]] = n;
  }
};
function hh(e) {
  const { locale: t } = ve(e), { locale: n, t: o } = gt();
  Pt.locale(n.value.toLowerCase());
  const i = (r, ...l) => {
    const s = r.startsWith("datePicker.") ? r.split(".").slice(1).join(".") : r;
    return yl((t == null ? void 0 : t.value) || {}, s) || o(r, ...l);
  };
  return it(Jm, {
    datePickerT: i
  }), i;
}
function av(e) {
  const { timePickerProps: t, selectedValue: n } = ve(e), o = a(() => {
    var p;
    return (p = t == null ? void 0 : t.value) == null ? void 0 : p.format;
  }), i = a(
    () => {
      var p;
      return !!((p = t == null ? void 0 : t.value) != null && p.use12Hours);
    }
  ), { format: r } = Kv(
    me({
      format: o,
      use12Hours: i
    })
  ), l = a(
    () => {
      var p;
      return cn(
        (p = t == null ? void 0 : t.value) == null ? void 0 : p.defaultValue,
        r.value
      );
    }
  ), s = () => (n == null ? void 0 : n.value) || l.value || qt(), u = V(s());
  function f(p) {
    p && (u.value = p);
  }
  function d() {
    u.value = s();
  }
  return ze(n, (p) => {
    f(p);
  }), [u, f, d];
}
function kh(e, t) {
  return t === "timestamp" ? e.toDate().getTime() : t === "Date" ? e.toDate() : e.format(t);
}
function r$(e) {
  const { format: t } = ve(e);
  return (n) => kh(n, t.value);
}
function ds(e, t) {
  return e.map((n) => n ? kh(n, t) : void 0);
}
const a$ = S({
  name: "Picker",
  components: {
    DateInput: _m,
    Trigger: Tt,
    PickerPanel: l$,
    IconCalendar: Rr
  },
  inheritAttrs: !1,
  props: {
    locale: {
      type: Object
    },
    hideTrigger: {
      type: Boolean
    },
    allowClear: {
      type: Boolean,
      default: !0
    },
    readonly: {
      type: Boolean
    },
    error: {
      type: Boolean
    },
    size: {
      type: String
    },
    shortcuts: {
      type: Array,
      default: () => []
    },
    shortcutsPosition: {
      type: String,
      default: "bottom"
    },
    position: {
      type: String,
      default: "bl"
    },
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean,
      default: !1
    },
    triggerProps: {
      type: Object
    },
    unmountOnClose: {
      type: Boolean
    },
    placeholder: {
      type: String
    },
    disabled: {
      type: Boolean
    },
    disabledDate: {
      type: Function
    },
    disabledTime: {
      type: Function
    },
    pickerValue: {
      type: [Object, String, Number]
    },
    defaultPickerValue: {
      type: [Object, String, Number]
    },
    popupContainer: {
      type: [String, Object]
    },
    mode: {
      type: String,
      default: "date"
    },
    format: {
      type: [String, Function]
    },
    valueFormat: {
      type: String
    },
    previewShortcut: {
      type: Boolean,
      default: !0
    },
    showConfirmBtn: {
      type: Boolean
    },
    showTime: {
      type: Boolean
    },
    timePickerProps: {
      type: Object
    },
    showNowBtn: {
      type: Boolean,
      default: !0
    },
    dayStartOfWeek: {
      type: Number,
      default: 0
    },
    modelValue: {
      type: [Object, String, Number]
    },
    defaultValue: {
      type: [Object, String, Number]
    },
    disabledInput: {
      type: Boolean,
      default: !1
    },
    abbreviation: {
      type: Boolean,
      default: !0
    }
  },
  emits: {
    change: (e, t, n) => !0,
    "update:modelValue": (e) => !0,
    select: (e, t, n) => !0,
    "popup-visible-change": (e) => !0,
    "update:popupVisible": (e) => !0,
    ok: (e, t, n) => !0,
    clear: () => !0,
    "select-shortcut": (e) => !0,
    "picker-value-change": (e, t, n) => !0,
    "update:pickerValue": (e) => !0
  },
  setup(e, { emit: t, slots: n }) {
    const {
      mode: o,
      modelValue: i,
      defaultValue: r,
      format: l,
      valueFormat: s,
      placeholder: u,
      popupVisible: f,
      defaultPopupVisible: d,
      disabled: p,
      showTime: h,
      timePickerProps: k,
      disabledDate: y,
      disabledTime: w,
      readonly: g,
      locale: C,
      pickerValue: P,
      defaultPickerValue: z,
      dayStartOfWeek: j,
      previewShortcut: I,
      showConfirmBtn: L
    } = ve(e), { locale: M } = gt();
    Wt(() => {
      zm(M.value, j.value);
    });
    const { mergedDisabled: E, eventHandlers: K } = mt({ disabled: p }), q = hh(
      me({
        locale: C
      })
    ), T = B("picker"), X = V(), Y = a(
      () => (u == null ? void 0 : u.value) || {
        date: q("datePicker.placeholder.date"),
        month: q("datePicker.placeholder.month"),
        year: q("datePicker.placeholder.year"),
        week: q("datePicker.placeholder.week"),
        quarter: q("datePicker.placeholder.quarter")
      }[o.value] || q("datePicker.placeholder.date")
    ), {
      format: Z,
      valueFormat: U,
      parseValueFormat: H
    } = ph(me({ format: l, mode: o, showTime: h, valueFormat: s })), D = a(
      () => l && Ne(l.value) ? (xe) => {
        var ot;
        return (ot = l.value) == null ? void 0 : ot.call(l, rn(xe));
      } : Z.value
    ), R = r$(
      me({
        format: U
      })
    ), W = mh(
      me({
        mode: o,
        disabledDate: y,
        disabledTime: w,
        showTime: h
      })
    ), O = a(() => h.value || L.value), x = a(
      () => O.value && (!be.value || W(be.value))
    ), G = a(() => o.value === "date" && h.value), { value: ne, setValue: ee } = Y3(
      me({
        modelValue: i,
        defaultValue: r,
        format: H
      })
    ), [Q, ae] = Ht(), [ge, Se] = Ht(), be = a(
      () => {
        var xe;
        return (xe = Q.value) != null ? xe : ne.value;
      }
    ), Le = a(
      () => {
        var xe, ot;
        return (ot = (xe = ge.value) != null ? xe : Q.value) != null ? ot : ne.value;
      }
    ), [pe, Me] = Ht(), [ke, le] = Vt(
      d.value,
      me({ value: f })
    ), re = (xe) => {
      ke.value !== xe && (le(xe), t("popup-visible-change", xe), t("update:popupVisible", xe));
    }, { headerValue: fe, setHeaderValue: Oe, headerOperations: Be, resetHeaderValue: $e } = pr(
      me({
        mode: o,
        value: P,
        defaultValue: z,
        selectedValue: Le,
        format: H,
        onChange: (xe) => {
          const ot = R(xe), jt = An(
            xe,
            H.value
          ), Nn = rn(xe);
          t("picker-value-change", ot, Nn, jt), t("update:pickerValue", ot);
        }
      })
    ), [he, , Ue] = av(
      me({
        timePickerProps: k,
        selectedValue: Le
      })
    ), et = a(
      () => !g.value && !Ne(D.value)
    ), tt = V();
    ze(ke, (xe) => {
      ae(void 0), Se(void 0), tt.value = void 0, xe && ($e(), Ue()), xe || Me(void 0);
    });
    function st(xe, ot) {
      var jt, Nn;
      const Hn = xe ? R(xe) : void 0, Qn = An(xe, H.value), fl = rn(xe);
      Wv(xe, ne.value) && (t("update:modelValue", Hn), t("change", Hn, fl, Qn), (Nn = (jt = K.value) == null ? void 0 : jt.onChange) == null || Nn.call(jt)), ot && t("ok", Hn, fl, Qn);
    }
    function $t(xe, ot, jt) {
      W(xe) || (st(xe, jt), ee(xe), ae(void 0), Se(void 0), Me(void 0), tt.value = void 0, Xt(ot) && re(ot));
    }
    function vn(xe, ot) {
      if (ae(xe), Se(void 0), Me(void 0), tt.value = void 0, ot) {
        const jt = xe ? R(xe) : void 0, Nn = An(xe, H.value), Hn = rn(xe);
        t("select", jt, Hn, Nn);
      }
    }
    function ye(xe) {
      X.value && X.value.focus && X.value.focus(xe);
    }
    function ce(xe, ot) {
      return !G.value && !k.value ? xe : th(qt(), xe, ot);
    }
    function Ce(xe) {
      E.value || re(xe);
    }
    function qe(xe) {
      xe.stopPropagation(), $t(void 0), t("clear");
    }
    function Lt() {
      var xe, ot;
      (ot = (xe = K.value) == null ? void 0 : xe.onBlur) == null || ot.call(xe);
    }
    function bt(xe) {
      re(!0);
      const ot = xe.target.value;
      if (Me(ot), !fr(ot, Z.value))
        return;
      const jt = Pt(ot, Z.value);
      W(jt) || (O.value ? vn(jt) : $t(jt, !0));
    }
    function en() {
      $t(Le.value, !1);
    }
    function Ie(xe) {
      O.value ? vn(xe, !0) : $t(xe, !1);
    }
    function Ee(xe) {
      const ot = ce(xe, he.value);
      Ie(ot);
    }
    function Ze(xe) {
      const ot = ce(Le.value || qt(), xe);
      Ie(ot);
    }
    function Xe() {
      $t(Le.value, !1, !0);
    }
    function _e() {
      e.disabledInput && ye();
    }
    let nt;
    Zt(() => {
      clearTimeout(nt);
    });
    function Rt(xe) {
      clearTimeout(nt), Se(xe), Me(void 0);
    }
    function tn() {
      clearTimeout(nt), nt = setTimeout(() => {
        Se(void 0);
      }, 100);
    }
    function no(xe, ot) {
      t("select-shortcut", ot), $t(xe, !1);
    }
    function dl(xe) {
      tt.value = xe;
    }
    function Nl() {
      tt.value = "year";
    }
    function Rn(xe) {
      let ot = fe.value;
      if (ot = ot.set("year", xe.year()), tt.value === "month" && (ot = ot.set("month", xe.month())), Oe(ot), o.value === "quarter" || o.value === "month") {
        tt.value = void 0;
        return;
      }
      tt.value = tt.value === "year" ? "month" : void 0;
    }
    const Mn = a(() => ({
      format: Z.value,
      ...Ft((k == null ? void 0 : k.value) || {}, ["defaultValue"]),
      visible: ke.value
    })), Cn = a(() => ({
      ...Wn(e, [
        "mode",
        "shortcuts",
        "shortcutsPosition",
        "dayStartOfWeek",
        "disabledDate",
        "disabledTime",
        "showTime",
        "hideTrigger",
        "abbreviation"
      ]),
      showNowBtn: e.showNowBtn && o.value === "date",
      prefixCls: T,
      format: H.value,
      value: Le.value,
      visible: ke.value,
      showConfirmBtn: O.value,
      confirmBtnDisabled: x.value,
      timePickerProps: Mn.value,
      extra: n.extra,
      dateRender: n.cell,
      headerValue: fe.value,
      headerIcons: {
        prev: n["icon-prev"],
        prevDouble: n["icon-prev-double"],
        next: n["icon-next"],
        nextDouble: n["icon-next-double"]
      },
      headerOperations: Be.value,
      timePickerValue: he.value,
      headerMode: tt.value,
      onCellClick: Ee,
      onTimePickerSelect: Ze,
      onConfirm: Xe,
      onShortcutClick: no,
      onShortcutMouseEnter: I.value ? Rt : void 0,
      onShortcutMouseLeave: I.value ? tn : void 0,
      onTodayBtnClick: Ie,
      onHeaderLabelClick: dl,
      onHeaderSelect: Rn,
      onMonthHeaderClick: Nl
    }));
    return {
      prefixCls: T,
      refInput: X,
      panelProps: Cn,
      panelValue: Le,
      inputValue: pe,
      selectedValue: ne,
      inputFormat: D,
      computedPlaceholder: Y,
      panelVisible: ke,
      inputEditable: et,
      needConfirm: O,
      mergedDisabled: E,
      onPanelVisibleChange: Ce,
      onInputClear: qe,
      onInputChange: bt,
      onInputPressEnter: en,
      onInputBlur: Lt,
      onPanelClick: _e
    };
  }
});
function s$(e, t, n, o, i, r) {
  const l = J("IconCalendar"), s = J("DateInput"), u = J("PickerPanel"), f = J("Trigger");
  return e.hideTrigger ? (v(), oe(u, dt(se({ key: 1 }, { ...e.$attrs, ...e.panelProps })), null, 16)) : (v(), oe(f, se({
    key: 0,
    trigger: "click",
    "animation-name": "slide-dynamic-origin",
    "auto-fit-transform-origin": "",
    "click-to-close": !1,
    "popup-offset": 4
  }, e.triggerProps, {
    position: e.position,
    disabled: e.mergedDisabled || e.readonly,
    "prevent-focus": !0,
    "popup-visible": e.panelVisible,
    "unmount-on-close": e.unmountOnClose,
    "popup-container": e.popupContainer,
    onPopupVisibleChange: e.onPanelVisibleChange
  }), {
    content: ue(() => [
      c(u, se(e.panelProps, { onClick: e.onPanelClick }), null, 16, ["onClick"])
    ]),
    default: ue(() => [
      _(e.$slots, "default", {}, () => [
        c(s, se(e.$attrs, {
          ref: "refInput",
          size: e.size,
          focused: e.panelVisible,
          visible: e.panelVisible,
          error: e.error,
          disabled: e.mergedDisabled,
          readonly: !e.inputEditable || e.disabledInput,
          "allow-clear": e.allowClear && !e.readonly,
          placeholder: e.computedPlaceholder,
          "input-value": e.inputValue,
          value: e.needConfirm ? e.panelValue : e.selectedValue,
          format: e.inputFormat,
          onClear: e.onInputClear,
          onChange: e.onInputChange,
          onPressEnter: e.onInputPressEnter,
          onBlur: e.onInputBlur
        }), kt({
          "suffix-icon": ue(() => [
            _(e.$slots, "suffix-icon", {}, () => [
              c(l)
            ])
          ]),
          _: 2
        }, [
          e.$slots.prefix ? {
            name: "prefix",
            fn: ue(() => [
              _(e.$slots, "prefix")
            ]),
            key: "0"
          } : void 0
        ]), 1040, ["size", "focused", "visible", "error", "disabled", "readonly", "allow-clear", "placeholder", "input-value", "value", "format", "onClear", "onChange", "onPressEnter", "onBlur"])
      ])
    ]),
    _: 3
  }, 16, ["position", "disabled", "popup-visible", "unmount-on-close", "popup-container", "onPopupVisibleChange"]));
}
var Ao = /* @__PURE__ */ N(a$, [["render", s$]]), fs = S({
  name: "DatePicker",
  props: {
    modelValue: {
      type: [Object, String, Number]
    },
    defaultValue: {
      type: [Object, String, Number]
    },
    format: {
      type: [String, Function]
    },
    dayStartOfWeek: {
      type: Number,
      default: 0
    },
    showTime: {
      type: Boolean
    },
    timePickerProps: {
      type: Object
    },
    disabled: {
      type: Boolean
    },
    disabledDate: {
      type: Function
    },
    disabledTime: {
      type: Function
    },
    showNowBtn: {
      type: Boolean,
      default: !0
    }
  },
  setup(e, {
    attrs: t,
    slots: n
  }) {
    return () => c(Ao, se(e, t, {
      mode: "date"
    }), n);
  }
}), Bi = S({
  name: "WeekPicker",
  props: {
    modelValue: {
      type: [Object, String, Number]
    },
    defaultValue: {
      type: [Object, String, Number]
    },
    format: {
      type: String,
      default: "gggg-wo"
    },
    valueFormat: {
      type: String,
      default: "YYYY-MM-DD"
    },
    dayStartOfWeek: {
      type: Number,
      default: 0
    }
  },
  setup(e, {
    attrs: t,
    slots: n
  }) {
    return () => c(Ao, se(e, t, {
      mode: "week"
    }), n);
  }
}), Mi = S({
  name: "MonthPicker",
  props: {
    modelValue: {
      type: [Object, String, Number]
    },
    defaultValue: {
      type: [Object, String, Number]
    },
    format: {
      type: String,
      default: "YYYY-MM"
    }
  },
  setup(e, {
    attrs: t,
    slots: n
  }) {
    return () => c(Ao, se(e, t, {
      mode: "month"
    }), n);
  }
}), Ni = S({
  name: "YearPicker",
  props: {
    modelValue: {
      type: [Object, String, Number]
    },
    defaultValue: {
      type: [Object, String, Number]
    },
    format: {
      type: String,
      default: "YYYY"
    }
  },
  setup(e, {
    attrs: t,
    slots: n
  }) {
    return () => c(Ao, se(e, t, {
      mode: "year"
    }), n);
  }
}), Oi = S({
  name: "QuarterPicker",
  props: {
    modelValue: {
      type: [Object, String, Number]
    },
    defaultValue: {
      type: [Object, String, Number]
    },
    format: {
      type: String,
      default: "YYYY-[Q]Q"
    },
    valueFormat: {
      type: String,
      default: "YYYY-MM"
    }
  },
  setup(e, {
    attrs: t,
    slots: n
  }) {
    return () => c(Ao, se(e, t, {
      mode: "quarter"
    }), n);
  }
});
function u$(e) {
  const { modelValue: t, defaultValue: n, format: o } = ve(e), i = a(() => cn(ov(t.value), o.value)), r = a(() => cn(ov(n.value), o.value)), [l, s] = Ht(
    Ve(i.value) ? Ve(r.value) ? [] : r.value : i.value
  );
  return ze(i, () => {
    Ve(i.value) && s([]);
  }), {
    value: a(
      () => i.value || l.value
    ),
    setValue: s
  };
}
function c$(e) {
  const {
    startHeaderMode: t,
    endHeaderMode: n,
    mode: o,
    value: i,
    defaultValue: r,
    selectedValue: l,
    format: s,
    onChange: u
  } = ve(e), f = a(() => ["date", "week"].includes(o.value)), d = a(() => f.value ? "M" : "y"), p = (Q, ae) => Q.isSame(ae, d.value), { span: h, superSpan: k } = vh(
    me({
      mode: o
    })
  ), y = a(() => (t == null ? void 0 : t.value) || o.value), w = a(() => (n == null ? void 0 : n.value) || o.value), g = a(() => {
    var Q;
    return (Q = i.value) == null ? void 0 : Q[0];
  }), C = a(() => {
    var Q;
    return (Q = i.value) == null ? void 0 : Q[1];
  }), P = a(() => {
    var Q;
    return (Q = r.value) == null ? void 0 : Q[0];
  }), z = a(() => {
    var Q;
    return (Q = r.value) == null ? void 0 : Q[1];
  }), j = (Q) => {
    u != null && u.value && u.value(Q);
  }, {
    headerValue: I,
    setHeaderValue: L,
    headerOperations: M,
    getDefaultLocalValue: E
  } = pr(
    me({
      mode: y,
      value: g,
      defaultValue: P,
      selectedValue: void 0,
      format: s,
      onChange: (Q) => {
        j([Q, K.value]);
      }
    })
  ), {
    headerValue: K,
    setHeaderValue: q,
    headerOperations: T,
    getDefaultLocalValue: X
  } = pr(
    me({
      mode: w,
      value: C,
      defaultValue: z,
      selectedValue: void 0,
      format: s,
      onChange: (Q) => {
        j([I.value, Q]);
      }
    })
  ), Y = (Q) => {
    const ae = p(I.value, Q[0]), ge = p(K.value, Q[1]);
    L(Q[0], !1), q(Q[1], !1), (!ae || !ge) && u != null && u.value && (u == null || u.value(Q));
  };
  function Z(Q) {
    let [ae, ge] = wo(Q);
    const Se = Bt.add(ae, h.value, "M");
    return ge.isBefore(Se, d.value) && (ge = Se), [ae, ge];
  }
  function U() {
    var Q, ae;
    let ge = (Q = l.value) == null ? void 0 : Q[0], Se = (ae = l.value) == null ? void 0 : ae[1];
    return ge && Se && ([ge, Se] = wo([ge, Se])), [ge, Se];
  }
  const [H, D] = U(), [R, W] = Z([
    H || I.value,
    D || K.value
  ]);
  L(R, !1), q(W, !1);
  const O = () => {
    const Q = E(), ae = X();
    at(() => {
      const [ge, Se] = U(), [be, Le] = Z([
        ge || Q,
        Se || ae
      ]);
      Y([be, Le]);
    });
  }, x = a(
    () => Bt.add(I.value, h.value, "M").isBefore(K.value, d.value)
  ), G = a(
    () => Bt.add(I.value, k.value, "M").isBefore(K.value, d.value)
  ), ne = a(() => {
    const Q = ["onSuperPrev"];
    return f.value && Q.push("onPrev"), x.value && f && Q.push("onNext"), G.value && Q.push("onSuperNext"), Wn(M.value, Q);
  }), ee = a(() => {
    const Q = ["onSuperNext"];
    return f.value && Q.push("onNext"), x.value && f.value && Q.push("onPrev"), G.value && Q.push("onSuperPrev"), Wn(T.value, Q);
  });
  return {
    startHeaderValue: I,
    endHeaderValue: K,
    startHeaderOperations: ne,
    endHeaderOperations: ee,
    setHeaderValue: Y,
    resetHeaderValue: O
  };
}
const d$ = S({
  name: "DateInputRange",
  components: {
    IconHover: pt,
    IconClose: Dt,
    FeedbackIcon: No
  },
  props: {
    size: {
      type: String
    },
    focused: {
      type: Boolean
    },
    focusedIndex: {
      type: Number
    },
    error: {
      type: Boolean
    },
    disabled: {
      type: [Boolean, Array],
      default: !1
    },
    readonly: {
      type: Boolean
    },
    allowClear: {
      type: Boolean
    },
    placeholder: {
      type: Array,
      default: () => []
    },
    inputValue: {
      type: Array
    },
    value: {
      type: Array,
      default: () => []
    },
    format: {
      type: [String, Function],
      required: !0
    }
  },
  emits: [
    "focused-index-change",
    "update:focusedIndex",
    "change",
    "clear",
    "press-enter"
  ],
  setup(e, { emit: t, slots: n }) {
    const {
      error: o,
      focused: i,
      disabled: r,
      size: l,
      value: s,
      format: u,
      focusedIndex: f,
      inputValue: d
    } = ve(e), {
      mergedSize: p,
      mergedDisabled: h,
      mergedError: k,
      feedback: y
    } = mt({ size: l, error: o }), { mergedSize: w } = xt(p), g = V(), C = V(), P = (H) => h.value ? h.value : He(r.value) ? r.value[H] : r.value, z = a(() => P(0)), j = a(() => P(1)), I = B("picker"), L = a(() => [
      I,
      `${I}-range`,
      `${I}-size-${w.value}`,
      {
        [`${I}-focused`]: i.value,
        [`${I}-disabled`]: z.value && j.value,
        [`${I}-error`]: k.value,
        [`${I}-has-prefix`]: n.prefix
      }
    ]);
    function M(H) {
      return [
        `${I}-input`,
        {
          [`${I}-input-active`]: H === (f == null ? void 0 : f.value)
        }
      ];
    }
    function E(H) {
      var D, R;
      if (d != null && d.value)
        return (D = d == null ? void 0 : d.value) == null ? void 0 : D[H];
      const W = (R = s == null ? void 0 : s.value) == null ? void 0 : R[H];
      if (W && gn(W))
        return Ne(u.value) ? u.value(W) : W.format(u.value);
    }
    const K = a(() => E(0)), q = a(() => E(1));
    function T(H) {
      t("focused-index-change", H), t("update:focusedIndex", H);
    }
    function X(H) {
      H.stopPropagation(), t("change", H);
    }
    function Y() {
      t("press-enter");
    }
    function Z(H) {
      H.preventDefault();
    }
    function U(H) {
      t("clear", H);
    }
    return {
      prefixCls: I,
      classNames: L,
      refInput0: g,
      refInput1: C,
      disabled0: z,
      disabled1: j,
      mergedDisabled: h,
      getDisabled: P,
      getInputWrapClassName: M,
      displayValue0: K,
      displayValue1: q,
      changeFocusedInput: T,
      onChange: X,
      onPressEnter: Y,
      onPressTab: Z,
      onClear: U,
      feedback: y
    };
  },
  methods: {
    focus(e) {
      const t = A(e) ? e : this.focusedIndex, n = t === 0 ? this.refInput0 : this.refInput1;
      !Ve(t) && !this.getDisabled(t) && n && n.focus && n.focus();
    },
    blur() {
      const e = this.focusedIndex === 0 ? this.refInput0 : this.refInput1;
      e && e.blur && e.blur();
    }
  }
}), f$ = ["disabled", "placeholder", "value"], v$ = ["disabled", "placeholder", "value"];
function p$(e, t, n, o, i, r) {
  const l = J("IconClose"), s = J("IconHover"), u = J("FeedbackIcon");
  return v(), b("div", {
    class: m(e.classNames)
  }, [
    e.$slots.prefix ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-prefix`)
    }, [
      _(e.$slots, "prefix")
    ], 2)) : te("v-if", !0),
    $("div", {
      class: m(e.getInputWrapClassName(0))
    }, [
      $("input", se({
        ref: "refInput0",
        disabled: e.disabled0,
        placeholder: e.placeholder[0],
        value: e.displayValue0
      }, e.readonly ? { readonly: !0 } : {}, {
        onInput: t[0] || (t[0] = (...f) => e.onChange && e.onChange(...f)),
        onKeydown: [
          t[1] || (t[1] = El((...f) => e.onPressEnter && e.onPressEnter(...f), ["enter"])),
          t[2] || (t[2] = El((...f) => e.onPressTab && e.onPressTab(...f), ["tab"]))
        ],
        onClick: t[3] || (t[3] = () => e.changeFocusedInput(0))
      }), null, 16, f$)
    ], 2),
    $("span", {
      class: m(`${e.prefixCls}-separator`)
    }, [
      _(e.$slots, "separator", {}, () => [
        t[8] || (t[8] = Re(" - "))
      ])
    ], 2),
    $("div", {
      class: m(e.getInputWrapClassName(1))
    }, [
      $("input", se({
        ref: "refInput1",
        disabled: e.disabled1,
        placeholder: e.placeholder[1],
        value: e.displayValue1
      }, e.readonly ? { readonly: !0 } : {}, {
        onInput: t[4] || (t[4] = (...f) => e.onChange && e.onChange(...f)),
        onKeydown: [
          t[5] || (t[5] = El((...f) => e.onPressEnter && e.onPressEnter(...f), ["enter"])),
          t[6] || (t[6] = El((...f) => e.onPressTab && e.onPressTab(...f), ["tab"]))
        ],
        onClick: t[7] || (t[7] = () => e.changeFocusedInput(1))
      }), null, 16, v$)
    ], 2),
    $("div", {
      class: m(`${e.prefixCls}-suffix`)
    }, [
      e.allowClear && !e.mergedDisabled && e.value.length === 2 ? (v(), oe(s, {
        key: 0,
        prefix: e.prefixCls,
        class: m(`${e.prefixCls}-clear-icon`),
        onClick: e.onClear
      }, {
        default: ue(() => [
          c(l)
        ]),
        _: 1
      }, 8, ["prefix", "class", "onClick"])) : te("v-if", !0),
      $("span", {
        class: m(`${e.prefixCls}-suffix-icon`)
      }, [
        _(e.$slots, "suffix-icon")
      ], 2),
      e.feedback ? (v(), oe(u, {
        key: 1,
        type: e.feedback
      }, null, 8, ["type"])) : te("v-if", !0)
    ], 2)
  ], 2);
}
var gh = /* @__PURE__ */ N(d$, [["render", p$]]);
const m$ = S({
  name: "DateRangePikerPanel",
  components: {
    PanelShortcuts: eh,
    PanelFooter: fh,
    RenderFunction: Xn,
    DatePanel: Uv,
    WeekPanel: rh,
    MonthPanel: ah,
    YearPanel: sh,
    QuarterPanel: uh
  },
  props: {
    mode: {
      type: String,
      default: "date"
    },
    value: {
      type: Array,
      default: () => []
    },
    footerValue: {
      type: Array
    },
    timePickerValue: {
      type: Array
    },
    showTime: {
      type: Boolean
    },
    showConfirmBtn: {
      type: Boolean
    },
    prefixCls: {
      type: String,
      required: !0
    },
    shortcuts: {
      type: Array,
      default: () => []
    },
    shortcutsPosition: {
      type: String,
      default: "bottom"
    },
    format: {
      type: String,
      required: !0
    },
    dayStartOfWeek: {
      type: Number,
      default: 0
    },
    disabledDate: {
      type: Function
    },
    disabledTime: {
      type: Function
    },
    timePickerProps: {
      type: Object
    },
    extra: {
      type: Function
    },
    dateRender: {
      type: Function
    },
    hideTrigger: {
      type: Boolean
    },
    startHeaderProps: {
      type: Object,
      default: () => ({})
    },
    endHeaderProps: {
      type: Object,
      default: () => ({})
    },
    confirmBtnDisabled: {
      type: Boolean
    },
    disabled: {
      type: Array,
      default: () => [!1, !1]
    },
    visible: {
      type: Boolean
    },
    startHeaderMode: {
      type: String
    },
    endHeaderMode: {
      type: String
    },
    abbreviation: {
      type: Boolean
    }
  },
  emits: [
    "cell-click",
    "cell-mouse-enter",
    "time-picker-select",
    "shortcut-click",
    "shortcut-mouse-enter",
    "shortcut-mouse-leave",
    "confirm",
    "start-header-label-click",
    "end-header-label-click",
    "start-header-select",
    "end-header-select"
  ],
  setup(e, { emit: t }) {
    const {
      prefixCls: n,
      shortcuts: o,
      shortcutsPosition: i,
      format: r,
      hideTrigger: l,
      value: s,
      disabledDate: u,
      disabledTime: f,
      startHeaderProps: d,
      endHeaderProps: p,
      dateRender: h,
      visible: k,
      startHeaderMode: y,
      endHeaderMode: w
    } = ve(e), g = a(
      () => He(o.value) && o.value.length
    ), C = a(() => [
      `${n.value}-range-container`,
      {
        [`${n.value}-range-container-panel-only`]: l.value,
        [`${n.value}-range-container-shortcuts-placement-left`]: g.value && i.value === "left",
        [`${n.value}-range-container-shortcuts-placement-right`]: g.value && i.value === "right"
      }
    ]), P = V("date");
    ze(k, (G, ne) => {
      G && !ne && (P.value = "date");
    });
    function z(G) {
      return cn(
        ov(
          Ne(G.value) ? G.value() : G.value
        ),
        G.format || r.value
      );
    }
    function j(G) {
      t("shortcut-click", z(G), G);
    }
    function I(G) {
      t("shortcut-mouse-enter", z(G));
    }
    function L(G) {
      t("shortcut-mouse-leave", z(G));
    }
    function M(G) {
      t("cell-click", G);
    }
    function E(G) {
      t("cell-mouse-enter", G);
    }
    function K() {
      t("confirm");
    }
    function q(G) {
      t("time-picker-select", G, "start");
    }
    function T(G) {
      t("time-picker-select", G, "end");
    }
    function X(G) {
      t("start-header-label-click", G);
    }
    function Y(G) {
      t("end-header-label-click", G);
    }
    function Z(G) {
      t("start-header-select", G);
    }
    function U(G) {
      t("end-header-select", G);
    }
    function H(G) {
      return Ne(u == null ? void 0 : u.value) ? (ne) => {
        var ee;
        return ((ee = u == null ? void 0 : u.value) == null ? void 0 : ee.call(u, ne, G === 0 ? "start" : "end")) || !1;
      } : void 0;
    }
    function D(G) {
      return Ne(f == null ? void 0 : f.value) ? (ne) => {
        var ee;
        return ((ee = f == null ? void 0 : f.value) == null ? void 0 : ee.call(f, ne, G === 0 ? "start" : "end")) || !1;
      } : void 0;
    }
    function R(G) {
      return Ne(h == null ? void 0 : h.value) ? (ne) => {
        var ee;
        const Q = {
          ...ne,
          type: G === 0 ? "start" : "end"
        };
        return (ee = h == null ? void 0 : h.value) == null ? void 0 : ee.call(h, Q);
      } : void 0;
    }
    const W = me({
      prefixCls: n,
      shortcuts: o,
      onItemClick: j,
      onItemMouseEnter: I,
      onItemMouseLeave: L
    }), O = a(() => ({
      ...d.value,
      rangeValues: s.value,
      disabledDate: H(0),
      dateRender: R(0),
      onSelect: y.value ? Z : M,
      onCellMouseEnter: E,
      onHeaderLabelClick: X
    })), x = a(() => ({
      ...p.value,
      rangeValues: s.value,
      disabledDate: H(1),
      dateRender: R(1),
      onSelect: w.value ? U : M,
      onCellMouseEnter: E,
      onHeaderLabelClick: Y
    }));
    return {
      pick: Wn,
      classNames: C,
      showShortcuts: g,
      shortcutsProps: W,
      startPanelProps: O,
      endPanelProps: x,
      getDisabledTimeFunc: D,
      onConfirmBtnClick: K,
      currentDateView: P,
      onStartTimePickerSelect: q,
      onEndTimePickerSelect: T,
      onStartHeaderPanelSelect: Z,
      onEndHeaderPanelSelect: U
    };
  }
});
function h$(e, t, n, o, i, r) {
  const l = J("PanelShortcuts"), s = J("YearPanel"), u = J("MonthPanel"), f = J("WeekPanel"), d = J("QuarterPanel"), p = J("DatePanel"), h = J("RenderFunction"), k = J("PanelFooter");
  return v(), b("div", {
    class: m(e.classNames)
  }, [
    e.showShortcuts && e.shortcutsPosition === "left" ? (v(), oe(l, dt(se({ key: 0 }, e.shortcutsProps)), null, 16)) : te("v-if", !0),
    $("div", {
      class: m(`${e.prefixCls}-range-panel-wrapper`)
    }, [
      te(" panel "),
      $("div", {
        class: m(`${e.prefixCls}-range`)
      }, [
        $("div", {
          class: m(`${e.prefixCls}-range-wrapper`)
        }, [
          e.startHeaderMode || e.endHeaderMode ? (v(), b(Ae, { key: 0 }, [
            e.startHeaderMode === "year" ? (v(), oe(s, dt(se({ key: 0 }, e.startPanelProps)), null, 16)) : te("v-if", !0),
            e.endHeaderMode === "year" ? (v(), oe(s, dt(se({ key: 1 }, e.endPanelProps)), null, 16)) : e.startHeaderMode === "month" ? (v(), oe(u, se({ key: 2 }, e.startPanelProps, { abbreviation: e.abbreviation }), null, 16, ["abbreviation"])) : e.endHeaderMode === "month" ? (v(), oe(u, se({ key: 3 }, e.endPanelProps, { abbreviation: e.abbreviation }), null, 16, ["abbreviation"])) : te("v-if", !0)
          ], 64)) : (v(), b(Ae, { key: 1 }, [
            te(" week "),
            e.mode === "week" ? (v(), b(Ae, { key: 0 }, [
              c(f, se(e.startPanelProps, { "day-start-of-week": e.dayStartOfWeek }), null, 16, ["day-start-of-week"]),
              c(f, se(e.endPanelProps, { "day-start-of-week": e.dayStartOfWeek }), null, 16, ["day-start-of-week"])
            ], 64)) : e.mode === "month" ? (v(), b(Ae, { key: 1 }, [
              te(" month "),
              c(u, se(e.startPanelProps, { abbreviation: e.abbreviation }), null, 16, ["abbreviation"]),
              c(u, se(e.endPanelProps, { abbreviation: e.abbreviation }), null, 16, ["abbreviation"])
            ], 64)) : e.mode === "year" ? (v(), b(Ae, { key: 2 }, [
              te(" year "),
              c(s, dt(Gt(e.startPanelProps)), null, 16),
              c(s, dt(Gt(e.endPanelProps)), null, 16)
            ], 64)) : e.mode === "quarter" ? (v(), b(Ae, { key: 3 }, [
              te(" quarter "),
              c(d, dt(Gt(e.startPanelProps)), null, 16),
              c(d, dt(Gt(e.endPanelProps)), null, 16)
            ], 64)) : (v(), b(Ae, { key: 4 }, [
              te(" date "),
              c(p, se({
                currentView: e.currentDateView,
                "onUpdate:currentView": t[0] || (t[0] = (y) => e.currentDateView = y)
              }, e.startPanelProps, {
                "is-range": "",
                value: e.value && e.value[0],
                "footer-value": e.footerValue && e.footerValue[0],
                "time-picker-value": e.timePickerValue && e.timePickerValue[0],
                "day-start-of-week": e.dayStartOfWeek,
                "show-time": e.showTime,
                "time-picker-props": e.timePickerProps,
                "disabled-time": e.getDisabledTimeFunc(0),
                disabled: e.disabled[0],
                onTimePickerSelect: e.onStartTimePickerSelect
              }), null, 16, ["currentView", "value", "footer-value", "time-picker-value", "day-start-of-week", "show-time", "time-picker-props", "disabled-time", "disabled", "onTimePickerSelect"]),
              c(p, se({
                currentView: e.currentDateView,
                "onUpdate:currentView": t[1] || (t[1] = (y) => e.currentDateView = y)
              }, e.endPanelProps, {
                "is-range": "",
                value: e.value && e.value[1],
                "footer-value": e.footerValue && e.footerValue[1],
                "time-picker-value": e.timePickerValue && e.timePickerValue[1],
                "day-start-of-week": e.dayStartOfWeek,
                "show-time": e.showTime,
                "time-picker-props": e.timePickerProps,
                "disabled-time": e.getDisabledTimeFunc(1),
                disabled: e.disabled[1],
                onTimePickerSelect: e.onEndTimePickerSelect
              }), null, 16, ["currentView", "value", "footer-value", "time-picker-value", "day-start-of-week", "show-time", "time-picker-props", "disabled-time", "disabled", "onTimePickerSelect"])
            ], 64))
          ], 64))
        ], 2)
      ], 2),
      te(" footer "),
      c(k, {
        "prefix-cls": e.prefixCls,
        "show-today-btn": !1,
        "show-confirm-btn": e.showConfirmBtn,
        "confirm-btn-disabled": e.confirmBtnDisabled,
        onConfirmBtnClick: e.onConfirmBtnClick
      }, kt({ _: 2 }, [
        e.extra || e.$slots.extra ? {
          name: "extra",
          fn: ue(() => [
            e.$slots.extra ? _(e.$slots, "extra", { key: 0 }) : (v(), oe(h, {
              key: 1,
              "render-func": e.extra
            }, null, 8, ["render-func"]))
          ]),
          key: "0"
        } : void 0,
        e.showShortcuts && e.shortcutsPosition === "bottom" ? {
          name: "btn",
          fn: ue(() => [
            c(l, dt(Gt(e.shortcutsProps)), null, 16)
          ]),
          key: "1"
        } : void 0
      ]), 1032, ["prefix-cls", "show-confirm-btn", "confirm-btn-disabled", "onConfirmBtnClick"])
    ], 2),
    e.showShortcuts && e.shortcutsPosition === "right" ? (v(), oe(l, dt(se({ key: 1 }, e.shortcutsProps)), null, 16)) : te("v-if", !0)
  ], 2);
}
var k$ = /* @__PURE__ */ N(m$, [["render", h$]]);
function g$(e) {
  const { timePickerProps: t, selectedValue: n } = ve(e), o = a(() => {
    var C;
    return (C = n == null ? void 0 : n.value) == null ? void 0 : C[0];
  }), i = a(() => {
    var C;
    return (C = n == null ? void 0 : n.value) == null ? void 0 : C[1];
  }), r = a(
    () => {
      var C;
      return (C = t == null ? void 0 : t.value) == null ? void 0 : C.defaultValue;
    }
  ), l = a(
    () => He(r.value) ? {
      ...t == null ? void 0 : t.value,
      defaultValue: r.value[0]
    } : t == null ? void 0 : t.value
  ), s = a(
    () => He(r.value) ? {
      ...t == null ? void 0 : t.value,
      defaultValue: r.value[1]
    } : t == null ? void 0 : t.value
  ), [u, f, d] = av(
    me({
      timePickerProps: l,
      selectedValue: o
    })
  ), [p, h, k] = av(
    me({
      timePickerProps: s,
      selectedValue: i
    })
  ), y = a(() => [
    u.value,
    p.value
  ]);
  function w(C) {
    C && (f(C[0]), h(C[1]));
  }
  function g() {
    d(), k();
  }
  return [y, w, g];
}
const y$ = S({
  name: "RangePicker",
  components: {
    RangePickerPanel: k$,
    DateRangeInput: gh,
    Trigger: Tt,
    IconCalendar: Rr
  },
  inheritAttrs: !1,
  props: {
    mode: {
      type: String,
      default: "date"
    },
    modelValue: {
      type: Array
    },
    defaultValue: {
      type: Array
    },
    pickerValue: {
      type: Array
    },
    defaultPickerValue: {
      type: Array
    },
    disabled: {
      type: [Boolean, Array],
      default: !1
    },
    dayStartOfWeek: {
      type: Number,
      default: 0
    },
    format: {
      type: String
    },
    valueFormat: {
      type: String
    },
    showTime: {
      type: Boolean
    },
    timePickerProps: {
      type: Object
    },
    placeholder: {
      type: Array
    },
    disabledDate: {
      type: Function
    },
    disabledTime: {
      type: Function
    },
    separator: {
      type: String
    },
    exchangeTime: {
      type: Boolean,
      default: !0
    },
    popupContainer: {
      type: [String, Object]
    },
    locale: {
      type: Object
    },
    hideTrigger: {
      type: Boolean
    },
    allowClear: {
      type: Boolean,
      default: !0
    },
    readonly: {
      type: Boolean
    },
    error: {
      type: Boolean
    },
    size: {
      type: String
    },
    shortcuts: {
      type: Array,
      default: () => []
    },
    shortcutsPosition: {
      type: String,
      default: "bottom"
    },
    position: {
      type: String,
      default: "bl"
    },
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean
    },
    triggerProps: {
      type: Object
    },
    unmountOnClose: {
      type: Boolean
    },
    previewShortcut: {
      type: Boolean,
      default: !0
    },
    showConfirmBtn: {
      type: Boolean
    },
    disabledInput: {
      type: Boolean,
      default: !1
    },
    abbreviation: {
      type: Boolean,
      default: !0
    }
  },
  emits: {
    change: (e, t, n) => !0,
    "update:modelValue": (e) => !0,
    select: (e, t, n) => !0,
    "popup-visible-change": (e) => !0,
    "update:popupVisible": (e) => !0,
    ok: (e, t, n) => !0,
    clear: () => !0,
    "select-shortcut": (e) => !0,
    "picker-value-change": (e, t, n) => !0,
    "update:pickerValue": (e) => !0
  },
  setup(e, { emit: t, slots: n }) {
    const {
      mode: o,
      showTime: i,
      format: r,
      modelValue: l,
      defaultValue: s,
      popupVisible: u,
      defaultPopupVisible: f,
      placeholder: d,
      timePickerProps: p,
      disabled: h,
      disabledDate: k,
      disabledTime: y,
      locale: w,
      pickerValue: g,
      defaultPickerValue: C,
      valueFormat: P,
      size: z,
      error: j,
      dayStartOfWeek: I,
      exchangeTime: L,
      previewShortcut: M,
      showConfirmBtn: E
    } = ve(e), { locale: K } = gt(), q = Ge(Kt, void 0);
    Wt(() => {
      zm(K.value, I.value);
    });
    const T = a(() => {
      var je;
      return !(!L.value || !((je = q == null ? void 0 : q.exchangeTime) == null || je));
    }), {
      mergedSize: X,
      mergedDisabled: Y,
      mergedError: Z,
      eventHandlers: U
    } = mt({
      size: z,
      error: j
    }), H = hh(
      me({
        locale: w
      })
    ), D = B("picker"), R = a(
      () => (d == null ? void 0 : d.value) || {
        date: H("datePicker.rangePlaceholder.date"),
        month: H("datePicker.rangePlaceholder.month"),
        year: H("datePicker.rangePlaceholder.year"),
        week: H("datePicker.rangePlaceholder.week"),
        quarter: H("datePicker.rangePlaceholder.quarter")
      }[o.value] || H("datePicker.rangePlaceholder.date")
    ), {
      format: W,
      valueFormat: O,
      parseValueFormat: x
    } = ph(
      me({
        mode: o,
        format: r,
        showTime: i,
        valueFormat: P
      })
    ), G = a(() => {
      const je = h.value === !0 || Y.value || He(h.value) && h.value[0] === !0, Ke = h.value === !0 || Y.value || He(h.value) && h.value[1] === !0;
      return [je, Ke];
    }), ne = a(
      () => G.value[0] && G.value[1]
    );
    function ee(je = 0) {
      return G.value[je] ? je ^ 1 : je;
    }
    const Q = V(), ae = V(ee()), ge = a(() => {
      const je = ae.value, Ke = je ^ 1;
      return G.value[Ke] ? je : Ke;
    }), Se = a(
      () => G.value[ae.value ^ 1]
    ), { value: be, setValue: Le } = u$(
      me({
        modelValue: l,
        defaultValue: s,
        format: x
      })
    ), [pe, Me] = Ht(), [ke, le] = Ht(), re = a(
      () => {
        var je;
        return (je = pe.value) != null ? je : be.value;
      }
    ), fe = a(
      () => {
        var je, Ke;
        return (Ke = (je = ke.value) != null ? je : pe.value) != null ? Ke : be.value;
      }
    ), [Oe, Be] = Ht(), $e = V(), he = V(), [Ue, et] = Vt(
      f.value,
      me({ value: u })
    ), tt = (je) => {
      Ue.value !== je && (et(je), t("popup-visible-change", je), t("update:popupVisible", je));
    }, {
      startHeaderValue: st,
      endHeaderValue: $t,
      startHeaderOperations: vn,
      endHeaderOperations: ye,
      resetHeaderValue: ce,
      setHeaderValue: Ce
    } = c$(
      me({
        mode: o,
        startHeaderMode: $e,
        endHeaderMode: he,
        value: g,
        defaultValue: C,
        selectedValue: fe,
        format: x,
        onChange: (je) => {
          const Ke = ds(
            je,
            O.value
          ), ht = An(
            je,
            x.value
          ), wt = rn(je);
          t("picker-value-change", Ke, wt, ht), t("update:pickerValue", Ke);
        }
      })
    );
    function qe(je) {
      $e.value = je;
    }
    function Lt(je) {
      he.value = je;
    }
    function bt(je) {
      let Ke = st.value;
      Ke = Ke.set("year", je.year()), $e.value === "month" && (Ke = Ke.set("month", je.month())), Ce([Ke, $t.value]), $e.value = void 0;
    }
    function en(je) {
      let Ke = $t.value;
      Ke = Ke.set("year", je.year()), he.value === "month" && (Ke = Ke.set("month", je.month())), Ce([st.value, Ke]), he.value = void 0;
    }
    const Ie = V([
      fe.value[0] || qt(),
      fe.value[1] || qt()
    ]);
    ze(fe, () => {
      const [je, Ke] = fe.value;
      Ie.value[0] = je || Ie.value[0], Ie.value[1] = Ke || Ie.value[1];
    });
    const [Ee, Ze, Xe] = g$(
      me({
        timePickerProps: p,
        selectedValue: fe
      })
    ), _e = a(() => o.value === "date" && i.value), nt = a(() => _e.value || p.value), Rt = mh(
      me({
        mode: o,
        isRange: !0,
        showTime: i,
        disabledDate: k,
        disabledTime: y
      })
    ), tn = a(
      () => _e.value || E.value
    ), no = a(
      () => tn.value && (!tl(re.value) || Rt(re.value[0], "start") || Rt(re.value[1], "end"))
    );
    ze(Ue, (je) => {
      $e.value = void 0, he.value = void 0, Me(void 0), le(void 0), je && (ce(), Xe(), ae.value = ee(ae.value), at(() => ot(ae.value))), je || Be(void 0);
    }), ze(ae, () => {
      e.disabledInput && (ot(ae.value), Be(void 0));
    });
    function dl(je, Ke) {
      var ht, wt;
      const At = je ? ds(je, O.value) : void 0, pn = An(je, x.value), xo = rn(je);
      Wv(je, be.value) && (t("update:modelValue", At), t("change", At, xo, pn), (wt = (ht = U.value) == null ? void 0 : ht.onChange) == null || wt.call(ht)), Ke && t("ok", At, xo, pn);
    }
    function Nl(je) {
      let Ke = wo(je);
      return nt.value && !T.value && (Ke = [
        jt(Ke[0], je[0]),
        jt(Ke[1], je[1])
      ]), Ke;
    }
    function Rn(je, Ke, ht) {
      if (Rt(je == null ? void 0 : je[0], "start") || Rt(je == null ? void 0 : je[1], "end"))
        return;
      let wt = je ? [...je] : void 0;
      tl(wt) && (wt = Nl(wt)), dl(wt, ht), Le(wt || []), Me(void 0), le(void 0), Be(void 0), $e.value = void 0, he.value = void 0, Xt(Ke) && tt(Ke);
    }
    function Mn(je) {
      const Ke = ds(je, O.value), ht = An(je, x.value), wt = rn(je);
      t("select", Ke, wt, ht);
    }
    function Cn(je, Ke) {
      const { emitSelect: ht = !1, updateHeader: wt = !1 } = Ke || {};
      let At = [...je];
      tl(At) && (At = Nl(At)), Me(At), le(void 0), Be(void 0), $e.value = void 0, he.value = void 0, ht && Mn(At), wt && ce();
    }
    function xe(je, Ke) {
      const { updateHeader: ht = !1 } = Ke || {};
      le(je), Be(void 0), ht && ce();
    }
    function ot(je) {
      Q.value && Q.value.focus && Q.value.focus(je);
    }
    function jt(je, Ke) {
      return nt.value ? th(qt(), je, Ke) : je;
    }
    function Nn(je) {
      tt(je);
    }
    function Hn(je) {
      if (pe.value && fe.value[ge.value] && (!tn.value || !tl(pe.value))) {
        const Ke = [...fe.value], ht = jt(
          je,
          Ee.value[ae.value]
        );
        Ke[ae.value] = ht, xe(Ke);
      }
    }
    function Qn(je = !1) {
      return Se.value ? [...be.value] : pe.value ? je || !tl(pe.value) ? [...pe.value] : [] : je ? [...be.value] : [];
    }
    function fl(je) {
      const Ke = Qn(), ht = jt(
        je,
        Ee.value[ae.value]
      );
      Ke[ae.value] = ht, Mn(Ke), !tn.value && tl(Ke) ? Rn(Ke, !1) : (Cn(Ke), tl(Ke) ? ae.value = 0 : ae.value = ge.value);
    }
    function _n(je, Ke) {
      const ht = Ke === "start" ? 0 : 1, wt = jt(
        Ee.value[ht],
        je
      ), At = [...Ee.value];
      At[ht] = wt, Ze(At);
      const pn = Qn(!0);
      pn[ht] && (pn[ht] = wt, Cn(pn, { emitSelect: !0 }));
    }
    let On;
    Zt(() => {
      clearTimeout(On);
    });
    function vl(je) {
      clearTimeout(On), xe(je, { updateHeader: !0 });
    }
    function Jr() {
      clearTimeout(On), On = setTimeout(() => {
        le(void 0), Be(void 0), ce();
      }, 100);
    }
    function ea(je, Ke) {
      t("select-shortcut", Ke), Rn(je, !1);
    }
    function ta() {
      Rn(fe.value, !1, !0);
    }
    function Mt(je) {
      je.stopPropagation(), Rn(void 0), t("clear");
    }
    function Fo(je) {
      tt(!0);
      const Ke = je.target.value;
      if (!Ke) {
        Be(void 0);
        return;
      }
      const ht = An(
        fe.value,
        W.value
      ), wt = He(Oe.value) ? [...Oe.value] : ht || [];
      if (wt[ae.value] = Ke, Be(wt), !fr(Ke, W.value))
        return;
      const At = Pt(Ke, W.value);
      if (Rt(
        At,
        ae.value === 0 ? "start" : "end"
      ))
        return;
      const pn = He(fe.value) ? [...fe.value] : [];
      pn[ae.value] = At, Cn(pn, { updateHeader: !0 });
    }
    function na() {
      tC(fe.value) ? Rn(fe.value, !1) : ae.value = ge.value;
    }
    const Do = a(() => ({
      format: W.value,
      ...Ft((p == null ? void 0 : p.value) || {}, ["defaultValue"]),
      visible: Ue.value
    })), $n = a(() => ({
      prev: n["icon-prev"],
      prevDouble: n["icon-prev-double"],
      next: n["icon-next"],
      nextDouble: n["icon-next-double"]
    })), Ol = me({
      headerValue: st,
      headerOperations: vn,
      headerIcons: $n
    }), Vl = me({
      headerValue: $t,
      headerOperations: ye,
      headerIcons: $n
    }), Tl = a(() => ({
      ...Wn(e, [
        "mode",
        "showTime",
        "shortcuts",
        "shortcutsPosition",
        "dayStartOfWeek",
        "disabledDate",
        "disabledTime",
        "hideTrigger",
        "abbreviation"
      ]),
      prefixCls: D,
      format: x.value,
      value: fe.value,
      showConfirmBtn: tn.value,
      confirmBtnDisabled: no.value,
      timePickerValue: Ee.value,
      timePickerProps: Do.value,
      extra: n.extra,
      dateRender: n.cell,
      startHeaderProps: Ol,
      endHeaderProps: Vl,
      footerValue: Ie.value,
      disabled: G.value,
      visible: Ue.value,
      onCellClick: fl,
      onCellMouseEnter: Hn,
      onShortcutClick: ea,
      onShortcutMouseEnter: M.value ? vl : void 0,
      onShortcutMouseLeave: M.value ? Jr : void 0,
      onConfirm: ta,
      onTimePickerSelect: _n,
      startHeaderMode: $e.value,
      endHeaderMode: he.value,
      onStartHeaderLabelClick: qe,
      onEndHeaderLabelClick: Lt,
      onStartHeaderSelect: bt,
      onEndHeaderSelect: en
    }));
    return {
      prefixCls: D,
      refInput: Q,
      computedFormat: W,
      computedPlaceholder: R,
      panelVisible: Ue,
      panelValue: fe,
      inputValue: Oe,
      focusedIndex: ae,
      triggerDisabled: ne,
      mergedSize: X,
      mergedError: Z,
      onPanelVisibleChange: Nn,
      onInputClear: Mt,
      onInputChange: Fo,
      onInputPressEnter: na,
      rangePanelProps: Tl
    };
  }
});
function b$(e, t, n, o, i, r) {
  const l = J("IconCalendar"), s = J("DateRangeInput"), u = J("RangePickerPanel"), f = J("Trigger");
  return e.hideTrigger ? (v(), oe(u, dt(se({ key: 1 }, { ...e.$attrs, ...e.rangePanelProps })), null, 16)) : (v(), oe(f, se({
    key: 0,
    trigger: "click",
    "animation-name": "slide-dynamic-origin",
    "auto-fit-transform-origin": "",
    "click-to-close": !1,
    "popup-offset": 4
  }, e.triggerProps, {
    "unmount-on-close": e.unmountOnClose,
    position: e.position,
    disabled: e.triggerDisabled || e.readonly,
    "popup-visible": e.panelVisible,
    "popup-container": e.popupContainer,
    onPopupVisibleChange: e.onPanelVisibleChange
  }), {
    content: ue(() => [
      c(u, dt(Gt(e.rangePanelProps)), null, 16)
    ]),
    default: ue(() => [
      _(e.$slots, "default", {}, () => [
        c(s, se({ ref: "refInput" }, e.$attrs, {
          focusedIndex: e.focusedIndex,
          "onUpdate:focusedIndex": t[0] || (t[0] = (d) => e.focusedIndex = d),
          size: e.size,
          focused: e.panelVisible,
          visible: e.panelVisible,
          error: e.error,
          disabled: e.disabled,
          readonly: e.readonly || e.disabledInput,
          "allow-clear": e.allowClear && !e.readonly,
          placeholder: e.computedPlaceholder,
          "input-value": e.inputValue,
          value: e.panelValue,
          format: e.computedFormat,
          onClear: e.onInputClear,
          onChange: e.onInputChange,
          onPressEnter: e.onInputPressEnter
        }), kt({
          "suffix-icon": ue(() => [
            _(e.$slots, "suffix-icon", {}, () => [
              c(l)
            ])
          ]),
          separator: ue(() => [
            _(e.$slots, "separator", {}, () => [
              Re(Pe(e.separator || "-"), 1)
            ])
          ]),
          _: 2
        }, [
          e.$slots.prefix ? {
            name: "prefix",
            fn: ue(() => [
              _(e.$slots, "prefix")
            ]),
            key: "0"
          } : void 0
        ]), 1040, ["focusedIndex", "size", "focused", "visible", "error", "disabled", "readonly", "allow-clear", "placeholder", "input-value", "value", "format", "onClear", "onChange", "onPressEnter"])
      ])
    ]),
    _: 3
  }, 16, ["unmount-on-close", "position", "disabled", "popup-visible", "popup-container", "onPopupVisibleChange"]));
}
var Vi = /* @__PURE__ */ N(y$, [["render", b$]]);
const C$ = Object.assign(fs, {
  WeekPicker: Bi,
  MonthPicker: Mi,
  YearPicker: Ni,
  QuarterPicker: Oi,
  RangePicker: Vi,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + fs.name, fs), e.component(n + Ni.name, Ni), e.component(n + Oi.name, Oi), e.component(n + Mi.name, Mi), e.component(n + Bi.name, Bi), e.component(n + Vi.name, Vi);
  }
}), hr = [
  "xxl",
  "xl",
  "lg",
  "md",
  "sm",
  "xs"
], Xo = {
  xs: "(max-width: 575px)",
  sm: "(min-width: 576px)",
  md: "(min-width: 768px)",
  lg: "(min-width: 992px)",
  xl: "(min-width: 1200px)",
  xxl: "(min-width: 1600px)"
};
let pl = [], $$ = -1, Qo = {};
const kr = {
  matchHandlers: {},
  dispatch(e, t) {
    return Qo = e, pl.length < 1 ? !1 : (pl.forEach((n) => {
      n.func(Qo, t);
    }), !0);
  },
  subscribe(e) {
    pl.length === 0 && this.register();
    const t = (++$$).toString();
    return pl.push({
      token: t,
      func: e
    }), e(Qo, null), t;
  },
  unsubscribe(e) {
    pl = pl.filter((t) => t.token !== e), pl.length === 0 && this.unregister();
  },
  unregister() {
    Object.keys(Xo).forEach(
      (e) => {
        const t = Xo[e];
        if (!t)
          return;
        const n = this.matchHandlers[t];
        n && n.mql && n.listener && (n.mql.removeEventListener ? n.mql.removeEventListener("change", n.listener) : n.mql.removeListener(n.listener));
      }
    );
  },
  register() {
    Object.keys(Xo).forEach(
      (e) => {
        const t = Xo[e];
        if (!t)
          return;
        const n = ({ matches: i }) => {
          this.dispatch(
            {
              ...Qo,
              [e]: i
            },
            e
          );
        }, o = window.matchMedia(t);
        o.addEventListener ? o.addEventListener("change", n) : o.addListener(n), this.matchHandlers[t] = {
          mql: o,
          listener: n
        }, n(o);
      }
    );
  }
};
function cp(e) {
  return Qe(e);
}
function Yn(e, t, n = !1) {
  const o = V({
    xs: !0,
    sm: !0,
    md: !0,
    lg: !0,
    xl: !0,
    xxl: !0
  }), i = a(() => {
    let l = t;
    if (cp(e.value))
      for (let s = 0; s < hr.length; s++) {
        const u = hr[s];
        if ((o.value[u] || u === "xs" && n) && e.value[u] !== void 0) {
          l = e.value[u];
          break;
        }
      }
    else
      l = e.value;
    return l;
  });
  let r = "";
  return Je(() => {
    r = kr.subscribe((l) => {
      cp(e.value) && (o.value = l);
    });
  }), Zt(() => {
    r && kr.unsubscribe(r);
  }), i;
}
var vs = S({
  name: "Descriptions",
  props: {
    data: {
      type: Array,
      default: () => []
    },
    column: {
      type: [Number, Object],
      default: 3
    },
    title: String,
    layout: {
      type: String,
      default: "horizontal"
    },
    align: {
      type: [String, Object],
      default: "left"
    },
    size: {
      type: String
    },
    bordered: {
      type: Boolean,
      default: !1
    },
    labelStyle: {
      type: Object
    },
    valueStyle: {
      type: Object
    },
    tableLayout: {
      type: String,
      default: "auto"
    }
  },
  setup(e, {
    slots: t
  }) {
    const {
      column: n,
      size: o
    } = ve(e), i = B("descriptions"), {
      mergedSize: r
    } = xt(o), l = Yn(n, 3, !0), s = a(() => {
      var I;
      return (I = Qe(e.align) ? e.align.label : e.align) != null ? I : "left";
    }), u = a(() => {
      var I;
      return (I = Qe(e.align) ? e.align.value : e.align) != null ? I : "left";
    }), f = a(() => ({
      textAlign: s.value,
      ...e.labelStyle
    })), d = a(() => ({
      textAlign: u.value,
      ...e.valueStyle
    })), p = (I) => {
      const L = [];
      let M = [], E = 0;
      const K = () => {
        if (M.length) {
          const q = l.value - E;
          M[M.length - 1].span += q, L.push(M);
        }
      };
      return I.forEach((q) => {
        var T, X;
        const Y = Math.min((X = Ct(q) ? (T = q.props) == null ? void 0 : T.span : q.span) != null ? X : 1, l.value);
        E + Y > l.value && (K(), M = [], E = 0), M.push({
          data: q,
          span: Y
        }), E += Y;
      }), K(), L;
    }, h = a(() => {
      var I;
      return p((I = e.data) != null ? I : []);
    }), k = (I, L) => {
      var M, E, K, q, T;
      return Ct(I) ? Lr(I, I.children) && ((E = (M = I.children).label) == null ? void 0 : E.call(M)) || ((K = I.props) == null ? void 0 : K.label) : (T = (q = t.label) == null ? void 0 : q.call(t, {
        label: I.label,
        index: L,
        data: I
      })) != null ? T : Ne(I.label) ? I.label() : I.label;
    }, y = (I, L) => {
      var M, E;
      return Ct(I) ? I : (E = (M = t.value) == null ? void 0 : M.call(t, {
        value: I.value,
        index: L,
        data: I
      })) != null ? E : Ne(I.value) ? I.value() : I.value;
    }, w = (I) => c(Ae, null, [c("tr", {
      class: `${i}-row`
    }, [I.map((L, M) => c("td", {
      key: `label-${M}`,
      class: [`${i}-item-label`, `${i}-item-label-block`],
      style: f.value,
      colspan: L.span
    }, [k(L.data, M)]))]), c("tr", {
      class: `${i}-row`
    }, [I.map((L, M) => c("td", {
      key: `value-${M}`,
      class: [`${i}-item-value`, `${i}-item-value-block`],
      style: d.value,
      colspan: L.span
    }, [y(L.data, M)]))])]), g = (I, L) => c("tr", {
      class: `${i}-row`,
      key: `tr-${L}`
    }, [I.map((M) => c(Ae, null, [c("td", {
      class: [`${i}-item-label`, `${i}-item-label-block`],
      style: f.value
    }, [k(M.data, L)]), c("td", {
      class: [`${i}-item-value`, `${i}-item-value-block`],
      style: d.value,
      colspan: M.span * 2 - 1
    }, [y(M.data, L)])]))]), C = (I, L) => c("tr", {
      class: `${i}-row`,
      key: `inline-${L}`
    }, [I.map((M, E) => c("td", {
      key: `item-${E}`,
      class: `${i}-item`,
      colspan: M.span
    }, [c("div", {
      class: [`${i}-item-label`, `${i}-item-label-inline`],
      style: f.value
    }, [k(M.data, E)]), c("div", {
      class: [`${i}-item-value`, `${i}-item-value-inline`],
      style: d.value
    }, [y(M.data, E)])]))]), P = (I, L) => ["inline-horizontal", "inline-vertical"].includes(e.layout) ? C(I, L) : e.layout === "vertical" ? w(I) : g(I, L), z = a(() => [i, `${i}-layout-${e.layout}`, `${i}-size-${r.value}`, {
      [`${i}-border`]: e.bordered
    }, {
      [`${i}-table-layout-fixed`]: e.tableLayout === "fixed"
    }]), j = () => {
      var I, L;
      const M = (L = (I = t.title) == null ? void 0 : I.call(t)) != null ? L : e.title;
      return M ? c("div", {
        class: `${i}-title`
      }, [M]) : null;
    };
    return () => {
      const I = t.default ? p(En(t.default())) : h.value;
      return c("div", {
        class: z.value
      }, [j(), c("div", {
        class: `${i}-body`
      }, [c("table", {
        class: `${i}-table`
      }, [c("tbody", null, [I.map((L, M) => P(L, M))])])])]);
    };
  }
});
const w$ = S({
  name: "DescriptionsItem",
  props: {
    span: {
      type: Number,
      default: 1
    },
    label: String
  },
  setup() {
    return {
      prefixCls: B("descriptions")
    };
  }
});
function S$(e, t, n, o, i, r) {
  return _(e.$slots, "default");
}
var Ti = /* @__PURE__ */ N(w$, [["render", S$]]);
const z$ = Object.assign(vs, {
  DescriptionsItem: Ti,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + vs.name, vs), e.component(n + Ti.name, Ti);
  }
});
var ps = S({
  name: "Divider",
  props: {
    direction: {
      type: String,
      default: "horizontal"
    },
    orientation: {
      type: String,
      default: "center"
    },
    type: {
      type: String
    },
    size: {
      type: Number
    },
    margin: {
      type: [Number, String]
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("divider"), o = a(() => e.direction === "horizontal"), i = a(() => {
      const r = {};
      if (e.size && (r[o.value ? "border-bottom-width" : "border-left-width"] = A(e.size) ? `${e.size}px` : e.size), e.type && (r[o.value ? "border-bottom-style" : "border-left-style"] = e.type), !Ve(e.margin)) {
        const l = A(e.margin) ? `${e.margin}px` : e.margin;
        r.margin = o.value ? `${l} 0` : `0 ${l}`;
      }
      return r;
    });
    return () => {
      var r;
      const l = (r = t.default) == null ? void 0 : r.call(t), s = [n, `${n}-${e.direction}`, {
        [`${n}-with-text`]: l
      }];
      return c("div", {
        role: "separator",
        class: s,
        style: i.value
      }, [l && e.direction === "horizontal" && c("span", {
        class: [`${n}-text`, `${n}-text-${e.orientation}`]
      }, [l])]);
    };
  }
});
const L$ = Object.assign(ps, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ps.name, ps);
  }
}), yh = (e) => {
  const t = V(!1), n = {
    overflow: "",
    width: "",
    boxSizing: ""
  };
  return {
    setOverflowHidden: () => {
      if (e.value) {
        const r = e.value;
        if (!t.value && r.style.overflow !== "hidden") {
          const l = Ak(r);
          (l > 0 || Tk(r)) && (n.overflow = r.style.overflow, n.width = r.style.width, n.boxSizing = r.style.boxSizing, r.style.overflow = "hidden", r.style.width = `${r.offsetWidth - l}px`, r.style.boxSizing = "border-box", t.value = !0);
        }
      }
    },
    resetOverflow: () => {
      if (e.value && t.value) {
        const r = e.value;
        r.style.overflow = n.overflow, r.style.width = n.width, r.style.boxSizing = n.boxSizing, t.value = !1;
      }
    }
  };
}, j$ = ["top", "right", "bottom", "left"], P$ = S({
  name: "Drawer",
  components: {
    ClientOnly: Mv,
    ArcoButton: Qt,
    IconHover: pt,
    IconClose: Dt
  },
  inheritAttrs: !1,
  props: {
    visible: {
      type: Boolean,
      default: !1
    },
    defaultVisible: {
      type: Boolean,
      default: !1
    },
    placement: {
      type: String,
      default: "right",
      validator: (e) => j$.includes(e)
    },
    title: String,
    mask: {
      type: Boolean,
      default: !0
    },
    maskClosable: {
      type: Boolean,
      default: !0
    },
    closable: {
      type: Boolean,
      default: !0
    },
    okText: String,
    cancelText: String,
    okLoading: {
      type: Boolean,
      default: !1
    },
    okButtonProps: {
      type: Object
    },
    cancelButtonProps: {
      type: Object
    },
    unmountOnClose: Boolean,
    width: {
      type: [Number, String],
      default: 250
    },
    height: {
      type: [Number, String],
      default: 250
    },
    popupContainer: {
      type: [String, Object],
      default: "body"
    },
    drawerStyle: {
      type: Object
    },
    bodyClass: {
      type: [String, Array]
    },
    bodyStyle: {
      type: [String, Object, Array]
    },
    onBeforeOk: {
      type: Function
    },
    onBeforeCancel: {
      type: Function
    },
    escToClose: {
      type: Boolean,
      default: !0
    },
    renderToBody: {
      type: Boolean,
      default: !0
    },
    header: {
      type: Boolean,
      default: !0
    },
    footer: {
      type: Boolean,
      default: !0
    },
    hideCancel: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:visible": (e) => !0,
    ok: (e) => !0,
    cancel: (e) => !0,
    open: () => !0,
    close: () => !0,
    beforeOpen: () => !0,
    beforeClose: () => !0
  },
  setup(e, { emit: t }) {
    const { popupContainer: n } = ve(e), o = B("drawer"), { t: i } = gt(), r = V(e.defaultVisible), l = a(() => {
      var Y;
      return (Y = e.visible) != null ? Y : r.value;
    }), s = V(!1), u = a(() => e.okLoading || s.value), { teleportContainer: f, containerRef: d } = Nv({
      popupContainer: n,
      visible: l
    }), p = V(l.value);
    let h = !1;
    const k = (Y) => {
      e.escToClose && Y.key === yt.ESC && C() && L(Y);
    }, y = () => {
      e.escToClose && !h && (h = !0, rt(document.documentElement, "keydown", k));
    }, w = () => {
      h && (h = !1, ct(document.documentElement, "keydown", k));
    }, { zIndex: g, isLastDialog: C } = Ql("dialog", {
      visible: l
    }), P = a(() => (d == null ? void 0 : d.value) === document.body);
    let z = 0;
    const j = () => {
      z++, s.value && (s.value = !1), r.value = !1, t("update:visible", !1);
    }, I = async (Y) => {
      const Z = z, U = await new Promise(
        async (H) => {
          var D;
          if (Ne(e.onBeforeOk)) {
            let R = e.onBeforeOk((W = !0) => H(W));
            if (($l(R) || !Xt(R)) && (s.value = !0), $l(R))
              try {
                R = (D = await R) != null ? D : !0;
              } catch (W) {
                throw R = !1, W;
              }
            Xt(R) && H(R);
          } else
            H(!0);
        }
      );
      Z === z && (U ? (t("ok", Y), j()) : s.value && (s.value = !1));
    }, L = (Y) => {
      var Z;
      let U = !0;
      Ne(e.onBeforeCancel) && (U = (Z = e.onBeforeCancel()) != null ? Z : !1), U && (t("cancel", Y), j());
    }, M = (Y) => {
      e.maskClosable && L(Y);
    }, E = () => {
      l.value && t("open");
    }, K = () => {
      l.value || (p.value = !1, T(), t("close"));
    }, { setOverflowHidden: q, resetOverflow: T } = yh(d);
    Je(() => {
      l.value && (p.value = !0, q(), y());
    }), _t(() => {
      T(), w();
    }), ze(l, (Y) => {
      r.value !== Y && (r.value = Y), Y ? (t("beforeOpen"), p.value = !0, q(), y()) : (t("beforeClose"), w());
    });
    const X = a(() => {
      var Y;
      const Z = {
        [e.placement]: 0,
        ...(Y = e.drawerStyle) != null ? Y : {}
      };
      return ["right", "left"].includes(e.placement) ? Z.width = A(e.width) ? `${e.width}px` : e.width : Z.height = A(e.height) ? `${e.height}px` : e.height, Z;
    });
    return {
      prefixCls: o,
      style: X,
      t: i,
      mounted: p,
      computedVisible: l,
      mergedOkLoading: u,
      zIndex: g,
      handleOk: I,
      handleCancel: L,
      handleOpen: E,
      handleClose: K,
      handleMask: M,
      isFixed: P,
      teleportContainer: f
    };
  }
});
function I$(e, t, n, o, i, r) {
  const l = J("icon-close"), s = J("icon-hover"), u = J("arco-button"), f = J("client-only");
  return v(), oe(f, null, {
    default: ue(() => [
      (v(), oe(br, {
        to: e.teleportContainer,
        disabled: !e.renderToBody
      }, [
        !e.unmountOnClose || e.computedVisible || e.mounted ? hn((v(), b("div", se({
          key: 0,
          class: `${e.prefixCls}-container`,
          style: e.isFixed ? { zIndex: e.zIndex } : { zIndex: "inherit", position: "absolute" }
        }, e.$attrs), [
          c(on, {
            name: "fade-drawer",
            appear: ""
          }, {
            default: ue(() => [
              e.mask ? hn((v(), b("div", {
                key: 0,
                class: m(`${e.prefixCls}-mask`),
                onClick: t[0] || (t[0] = (...d) => e.handleMask && e.handleMask(...d))
              }, null, 2)), [
                [kn, e.computedVisible]
              ]) : te("v-if", !0)
            ]),
            _: 1
          }),
          c(on, {
            name: `slide-${e.placement}-drawer`,
            appear: "",
            onAfterEnter: e.handleOpen,
            onAfterLeave: e.handleClose,
            persisted: ""
          }, {
            default: ue(() => [
              hn($("div", {
                class: m(e.prefixCls),
                style: F(e.style)
              }, [
                e.header ? (v(), b("div", {
                  key: 0,
                  class: m(`${e.prefixCls}-header`)
                }, [
                  _(e.$slots, "header", {}, () => [
                    e.$slots.title || e.title ? (v(), b("div", {
                      key: 0,
                      class: m(`${e.prefixCls}-title`)
                    }, [
                      _(e.$slots, "title", {}, () => [
                        Re(Pe(e.title), 1)
                      ])
                    ], 2)) : te("v-if", !0),
                    e.closable ? (v(), b("div", {
                      key: 1,
                      tabindex: "-1",
                      role: "button",
                      "aria-label": "Close",
                      class: m(`${e.prefixCls}-close-btn`),
                      onClick: t[1] || (t[1] = (...d) => e.handleCancel && e.handleCancel(...d))
                    }, [
                      c(s, null, {
                        default: ue(() => [
                          c(l)
                        ]),
                        _: 1
                      })
                    ], 2)) : te("v-if", !0)
                  ])
                ], 2)) : te("v-if", !0),
                $("div", {
                  class: m([`${e.prefixCls}-body`, e.bodyClass]),
                  style: F(e.bodyStyle)
                }, [
                  _(e.$slots, "default")
                ], 6),
                e.footer ? (v(), b("div", {
                  key: 1,
                  class: m(`${e.prefixCls}-footer`)
                }, [
                  _(e.$slots, "footer", {}, () => [
                    e.hideCancel ? te("v-if", !0) : (v(), oe(u, se({ key: 0 }, e.cancelButtonProps, { onClick: e.handleCancel }), {
                      default: ue(() => [
                        Re(Pe(e.cancelText || e.t("drawer.cancelText")), 1)
                      ]),
                      _: 1
                    }, 16, ["onClick"])),
                    c(u, se({
                      type: "primary",
                      loading: e.mergedOkLoading
                    }, e.okButtonProps, { onClick: e.handleOk }), {
                      default: ue(() => [
                        Re(Pe(e.okText || e.t("drawer.okText")), 1)
                      ]),
                      _: 1
                    }, 16, ["loading", "onClick"])
                  ])
                ], 2)) : te("v-if", !0)
              ], 6), [
                [kn, e.computedVisible]
              ])
            ]),
            _: 3
          }, 8, ["name", "onAfterEnter", "onAfterLeave"])
        ], 16)), [
          [kn, e.computedVisible || e.mounted]
        ]) : te("v-if", !0)
      ], 8, ["to", "disabled"]))
    ]),
    _: 3
  });
}
var Ai = /* @__PURE__ */ N(P$, [["render", I$]]);
const dp = (e, t) => {
  let n = jr("drawer");
  const o = () => {
    f.component && (f.component.props.visible = !1), Ne(e.onOk) && e.onOk();
  }, i = () => {
    f.component && (f.component.props.visible = !1), Ne(e.onCancel) && e.onCancel();
  }, r = async () => {
    await at(), n && (il(null, n), document.body.removeChild(n)), n = null, Ne(e.onClose) && e.onClose();
  }, l = () => {
    f.component && (f.component.props.visible = !1);
  }, s = (d) => {
    f.component && Object.entries(d).forEach(([p, h]) => {
      f.component.props[p] = h;
    });
  }, f = c(
    Ai,
    {
      ...{
        visible: !0,
        renderToBody: !1,
        unmountOnClose: !0,
        onOk: o,
        onCancel: i,
        onClose: r
      },
      ...Ft(e, [
        "content",
        "title",
        "footer",
        "visible",
        "unmountOnClose",
        "onOk",
        "onCancel",
        "onClose"
      ]),
      header: typeof e.header == "boolean" ? e.header : void 0,
      footer: typeof e.footer == "boolean" ? e.footer : void 0
    },
    {
      default: nn(e.content),
      header: typeof e.header != "boolean" ? nn(e.header) : void 0,
      title: nn(e.title),
      footer: typeof e.footer != "boolean" ? nn(e.footer) : void 0
    }
  );
  return (t ?? sv._context) && (f.appContext = t ?? sv._context), il(f, n), document.body.appendChild(n), {
    close: l,
    update: s
  };
}, sv = Object.assign(Ai, {
  open: dp,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ai.name, Ai);
    const o = {
      open: (i, r = e._context) => dp(i, r)
    };
    e.config.globalProperties.$drawer = o;
  },
  _context: null
});
function bh(e) {
  return e === Object(e) && Object.keys(e).length !== 0;
}
function B$(e, t) {
  t === void 0 && (t = "auto");
  var n = "scrollBehavior" in document.body.style;
  e.forEach(function(o) {
    var i = o.el, r = o.top, l = o.left;
    i.scroll && n ? i.scroll({
      top: r,
      left: l,
      behavior: t
    }) : (i.scrollTop = r, i.scrollLeft = l);
  });
}
function M$(e) {
  return e === !1 ? {
    block: "end",
    inline: "nearest"
  } : bh(e) ? e : {
    block: "start",
    inline: "nearest"
  };
}
function Ch(e, t) {
  var n = e.isConnected || e.ownerDocument.documentElement.contains(e);
  if (bh(t) && typeof t.behavior == "function")
    return t.behavior(n ? _1(e, t) : []);
  if (n) {
    var o = M$(t);
    return B$(_1(e, o), o.behavior);
  }
}
const fp = [
  "success",
  "warning",
  "error",
  "validating"
], N$ = (e) => {
  let t = "";
  for (const n of Object.keys(e)) {
    const o = e[n];
    o && (!t || fp.indexOf(o) > fp.indexOf(t)) && (t = e[n]);
  }
  return t;
}, O$ = (e) => {
  const t = [];
  for (const n of Object.keys(e)) {
    const o = e[n];
    o && t.push(o);
  }
  return t;
}, $h = (e, t) => {
  const n = t.replace(/[[.]/g, "_").replace(/\]/g, "");
  return e ? `${e}-${n}` : `${n}`;
}, V$ = S({
  name: "Form",
  props: {
    model: {
      type: Object,
      required: !0
    },
    layout: {
      type: String,
      default: "horizontal"
    },
    size: {
      type: String
    },
    labelColProps: {
      type: Object,
      default: () => ({ span: 5, offset: 0 })
    },
    wrapperColProps: {
      type: Object,
      default: () => ({ span: 19, offset: 0 })
    },
    labelColStyle: Object,
    wrapperColStyle: Object,
    labelAlign: {
      type: String,
      default: "right"
    },
    disabled: {
      type: Boolean,
      default: void 0
    },
    rules: {
      type: Object
    },
    autoLabelWidth: {
      type: Boolean,
      default: !1
    },
    id: {
      type: String
    },
    scrollToFirstError: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    submit: (e, t) => !0,
    submitSuccess: (e, t) => !0,
    submitFailed: (e, t) => !0
  },
  setup(e, { emit: t }) {
    const n = B("form"), o = V(), {
      id: i,
      model: r,
      layout: l,
      disabled: s,
      labelAlign: u,
      labelColProps: f,
      wrapperColProps: d,
      labelColStyle: p,
      wrapperColStyle: h,
      size: k,
      rules: y
    } = ve(e), { mergedSize: w } = xt(k), g = a(
      () => e.layout === "horizontal" && e.autoLabelWidth
    ), C = [], P = [], z = me({}), j = a(
      () => Math.max(...Object.values(z))
    ), I = (R) => {
      R && R.field && C.push(R);
    }, L = (R) => {
      R && R.field && C.splice(C.indexOf(R), 1);
    }, M = (R) => {
      C.forEach((W) => {
        R[W.field] && W.setField(R[W.field]);
      });
    }, E = (R, W) => {
      W && z[W] !== R && (z[W] = R);
    }, K = (R) => {
      R && delete z[R];
    }, q = (R) => {
      const W = R ? [].concat(R) : [];
      C.forEach((O) => {
        (W.length === 0 || W.includes(O.field)) && O.resetField();
      });
    }, T = (R) => {
      const W = R ? [].concat(R) : [];
      C.forEach((O) => {
        (W.length === 0 || W.includes(O.field)) && O.clearValidate();
      });
    }, X = (R, W) => {
      const x = (o.value || document.body).querySelector(
        `#${$h(e.id, R)}`
      );
      x && Ch(x, {
        behavior: "smooth",
        block: "nearest",
        scrollMode: "if-needed",
        ...W
      });
    }, Y = (R) => {
      const W = Xt(e.scrollToFirstError) ? void 0 : e.scrollToFirstError;
      X(R, W);
    }, Z = (R) => {
      const W = [];
      return C.forEach((O) => {
        W.push(O.validate());
      }), Promise.all(W).then((O) => {
        const x = {};
        let G = !1;
        return O.forEach((ne) => {
          ne && (G = !0, x[ne.field] = ne);
        }), G && e.scrollToFirstError && Y(Object.keys(x)[0]), Ne(R) && R(G ? x : void 0), G ? x : void 0;
      });
    }, U = (R, W) => {
      const O = [];
      for (const x of C)
        (He(R) && R.includes(x.field) || R === x.field) && O.push(x.validate());
      return Promise.all(O).then((x) => {
        const G = {};
        let ne = !1;
        return x.forEach((ee) => {
          ee && (ne = !0, G[ee.field] = ee);
        }), ne && e.scrollToFirstError && Y(Object.keys(G)[0]), Ne(W) && W(ne ? G : void 0), ne ? G : void 0;
      });
    }, H = (R) => {
      const W = [];
      C.forEach((O) => {
        W.push(O.validate());
      }), Promise.all(W).then((O) => {
        const x = {};
        let G = !1;
        O.forEach((ne) => {
          ne && (G = !0, x[ne.field] = ne);
        }), G ? (e.scrollToFirstError && Y(Object.keys(x)[0]), t("submitFailed", { values: r.value, errors: x }, R)) : t("submitSuccess", r.value, R), t(
          "submit",
          { values: r.value, errors: G ? x : void 0 },
          R
        );
      });
    };
    return it(
      Iv,
      me({
        id: i,
        layout: l,
        disabled: s,
        labelAlign: u,
        labelColProps: f,
        wrapperColProps: d,
        labelColStyle: p,
        wrapperColStyle: h,
        model: r,
        size: w,
        rules: y,
        fields: C,
        touchedFields: P,
        addField: I,
        removeField: L,
        validateField: U,
        setLabelWidth: E,
        removeLabelWidth: K,
        maxLabelWidth: j,
        autoLabelWidth: g
      })
    ), {
      cls: a(() => [
        n,
        `${n}-layout-${e.layout}`,
        `${n}-size-${w.value}`,
        {
          [`${n}-auto-label-width`]: e.autoLabelWidth
        }
      ]),
      formRef: o,
      handleSubmit: H,
      innerValidate: Z,
      innerValidateField: U,
      innerResetFields: q,
      innerClearValidate: T,
      innerSetFields: M,
      innerScrollToField: X
    };
  },
  methods: {
    validate(e) {
      return this.innerValidate(e);
    },
    validateField(e, t) {
      return this.innerValidateField(e, t);
    },
    resetFields(e) {
      return this.innerResetFields(e);
    },
    clearValidate(e) {
      return this.innerClearValidate(e);
    },
    setFields(e) {
      return this.innerSetFields(e);
    },
    scrollToField(e) {
      return this.innerScrollToField(e);
    }
  }
}), T$ = ["id"];
function A$(e, t, n, o, i, r) {
  return v(), b("form", {
    id: e.id,
    ref: "formRef",
    class: m(e.cls),
    onSubmit: t[0] || (t[0] = an((...l) => e.handleSubmit && e.handleSubmit(...l), ["prevent"]))
  }, [
    _(e.$slots, "default")
  ], 42, T$);
}
var ms = /* @__PURE__ */ N(V$, [["render", A$]]), eo = Object.prototype.toString;
function Hr(e) {
  return eo.call(e) === "[object Array]";
}
function Un(e) {
  return eo.call(e) === "[object Object]";
}
function uv(e) {
  return eo.call(e) === "[object String]";
}
function E$(e) {
  return eo.call(e) === "[object Number]" && e === e;
}
function W$(e) {
  return eo.call(e) === "[object Boolean]";
}
function cv(e) {
  return eo.call(e) === "[object Function]";
}
function F$(e) {
  return Un(e) && Object.keys(e).length === 0;
}
function ml(e) {
  return e == null || e === "";
}
function wh(e) {
  return Hr(e) && !e.length;
}
var Gv = function(e, t) {
  if (typeof e != "object" || typeof t != "object")
    return e === t;
  if (cv(e) && cv(t))
    return e === t || e.toString() === t.toString();
  if (Object.keys(e).length !== Object.keys(t).length)
    return !1;
  for (var n in e) {
    var o = Gv(e[n], t[n]);
    if (!o)
      return !1;
  }
  return !0;
}, Xv = function(e, t) {
  var n = Object.assign({}, e);
  return Object.keys(t || {}).forEach(function(o) {
    var i = n[o], r = t == null ? void 0 : t[o];
    n[o] = Un(i) ? Object.assign(Object.assign({}, i), r) : r || i;
  }), n;
}, D$ = function(e, t) {
  for (var n = t.split("."), o = e, i = 0; i < n.length; i++)
    if (o = o && o[n[i]], o === void 0)
      return o;
  return o;
}, el = "#{field} is not a #{type} type", x$ = {
  required: "#{field} is required",
  type: {
    ip: el,
    email: el,
    url: el,
    string: el,
    number: el,
    array: el,
    object: el,
    boolean: el
  },
  number: {
    min: "`#{value}` is not greater than `#{min}`",
    max: "`#{value}` is not less than `#{max}`",
    equal: "`#{value}` is not equal to `#{equal}`",
    range: "`#{value}` is not in range `#{min} ~ #{max}`",
    positive: "`#{value}` is not a positive number",
    negative: "`#{value}` is not a negative number"
  },
  string: {
    maxLength: "#{field} cannot be longer than #{maxLength} characters",
    minLength: "#{field} must be at least #{minLength} characters",
    length: "#{field} must be exactly #{length} characters",
    match: "`#{value}` does not match pattern #{pattern}",
    uppercase: "`#{value}` must be all uppercase",
    lowercase: "`#{value}` must be all lowercased"
  },
  array: {
    length: "#{field} must be exactly #{length} in length",
    minLength: "#{field} cannot be less than #{minLength} in length",
    maxLength: "#{field} cannot be greater than #{maxLength} in length",
    includes: "#{field} is not includes #{includes}",
    deepEqual: "#{field} is not deep equal with #{deepEqual}",
    empty: "#{field} is not an empty array"
  },
  object: {
    deepEqual: "#{field} is not deep equal to expected value",
    hasKeys: "#{field} does not contain required fields",
    empty: "#{field} is not an empty object"
  },
  boolean: {
    true: "Expect true but got `#{value}`",
    false: "Expect false but got `#{value}`"
  }
}, Bn = function(t, n) {
  var o = this;
  this.getValidateMsg = function(i, r) {
    r === void 0 && (r = {});
    var l = Object.assign(Object.assign({}, r), { value: o.obj, field: o.field, type: o.type }), s = D$(o.validateMessages, i);
    return cv(s) ? s(l) : uv(s) ? s.replace(/\#\{.+?\}/g, function(u) {
      var f = u.slice(2, -1);
      if (f in l) {
        if (Un(l[f]) || Hr(l[f]))
          try {
            return JSON.stringify(l[f]);
          } catch {
            return l[f];
          }
        return String(l[f]);
      }
      return u;
    }) : s;
  }, Un(n) && uv(t) && n.trim ? this.obj = t.trim() : Un(n) && n.ignoreEmptyString && t === "" ? this.obj = void 0 : this.obj = t, this.message = n.message, this.type = n.type, this.error = null, this.field = n.field || n.type, this.validateMessages = Xv(x$, n.validateMessages);
}, qr = { not: { configurable: !0 }, isRequired: { configurable: !0 }, end: { configurable: !0 } };
qr.not.get = function() {
  return this._not = !this._not, this;
};
qr.isRequired.get = function() {
  if (ml(this.obj) || wh(this.obj)) {
    var e = this.getValidateMsg("required");
    this.error = {
      value: this.obj,
      type: this.type,
      requiredError: !0,
      message: this.message || (Un(e) ? e : (this._not ? "[NOT MODE]:" : "") + e)
    };
  }
  return this;
};
qr.end.get = function() {
  return this.error;
};
Bn.prototype.addError = function(t) {
  !this.error && t && (this.error = {
    value: this.obj,
    type: this.type,
    message: this.message || (Un(t) ? t : (this._not ? "[NOT MODE]:" : "") + t)
  });
};
Bn.prototype.validate = function(t, n) {
  var o = this._not ? t : !t;
  return o && this.addError(n), this;
};
Bn.prototype.collect = function(t) {
  t && t(this.error);
};
Object.defineProperties(Bn.prototype, qr);
var R$ = /* @__PURE__ */ function(e) {
  function t(o, i) {
    e.call(this, o, Object.assign(Object.assign({}, i), { type: "string" })), this.validate(i && i.strict ? uv(this.obj) : !0, this.getValidateMsg("type.string"));
  }
  e && (t.__proto__ = e), t.prototype = Object.create(e && e.prototype), t.prototype.constructor = t;
  var n = { uppercase: { configurable: !0 }, lowercase: { configurable: !0 } };
  return t.prototype.maxLength = function(i) {
    return this.obj ? this.validate(this.obj.length <= i, this.getValidateMsg("string.maxLength", { maxLength: i })) : this;
  }, t.prototype.minLength = function(i) {
    return this.obj ? this.validate(this.obj.length >= i, this.getValidateMsg("string.minLength", { minLength: i })) : this;
  }, t.prototype.length = function(i) {
    return this.obj ? this.validate(this.obj.length === i, this.getValidateMsg("string.length", { length: i })) : this;
  }, t.prototype.match = function(i) {
    var r = i instanceof RegExp;
    return r && (i.lastIndex = 0), this.validate(this.obj === void 0 || r && i.test(this.obj), this.getValidateMsg("string.match", { pattern: i }));
  }, n.uppercase.get = function() {
    return this.obj ? this.validate(this.obj.toUpperCase() === this.obj, this.getValidateMsg("string.uppercase")) : this;
  }, n.lowercase.get = function() {
    return this.obj ? this.validate(this.obj.toLowerCase() === this.obj, this.getValidateMsg("string.lowercase")) : this;
  }, Object.defineProperties(t.prototype, n), t;
}(Bn), H$ = /* @__PURE__ */ function(e) {
  function t(o, i) {
    e.call(this, o, Object.assign(Object.assign({}, i), { type: "number" })), this.validate(i && i.strict ? E$(this.obj) : !0, this.getValidateMsg("type.number"));
  }
  e && (t.__proto__ = e), t.prototype = Object.create(e && e.prototype), t.prototype.constructor = t;
  var n = { positive: { configurable: !0 }, negative: { configurable: !0 } };
  return t.prototype.min = function(i) {
    return ml(this.obj) ? this : this.validate(this.obj >= i, this.getValidateMsg("number.min", { min: i }));
  }, t.prototype.max = function(i) {
    return ml(this.obj) ? this : this.validate(this.obj <= i, this.getValidateMsg("number.max", { max: i }));
  }, t.prototype.equal = function(i) {
    return ml(this.obj) ? this : this.validate(this.obj === i, this.getValidateMsg("number.equal", { equal: i }));
  }, t.prototype.range = function(i, r) {
    return ml(this.obj) ? this : this.validate(this.obj >= i && this.obj <= r, this.getValidateMsg("number.range", { min: i, max: r }));
  }, n.positive.get = function() {
    return ml(this.obj) ? this : this.validate(this.obj > 0, this.getValidateMsg("number.positive"));
  }, n.negative.get = function() {
    return ml(this.obj) ? this : this.validate(this.obj < 0, this.getValidateMsg("number.negative"));
  }, Object.defineProperties(t.prototype, n), t;
}(Bn), q$ = /* @__PURE__ */ function(e) {
  function t(o, i) {
    e.call(this, o, Object.assign(Object.assign({}, i), { type: "array" })), this.validate(i && i.strict ? Hr(this.obj) : !0, this.getValidateMsg("type.array", { value: this.obj, type: this.type }));
  }
  e && (t.__proto__ = e), t.prototype = Object.create(e && e.prototype), t.prototype.constructor = t;
  var n = { empty: { configurable: !0 } };
  return t.prototype.length = function(i) {
    return this.obj ? this.validate(this.obj.length === i, this.getValidateMsg("array.length", { value: this.obj, length: i })) : this;
  }, t.prototype.minLength = function(i) {
    return this.obj ? this.validate(this.obj.length >= i, this.getValidateMsg("array.minLength", { value: this.obj, minLength: i })) : this;
  }, t.prototype.maxLength = function(i) {
    return this.obj ? this.validate(this.obj.length <= i, this.getValidateMsg("array.maxLength", { value: this.obj, maxLength: i })) : this;
  }, t.prototype.includes = function(i) {
    var r = this;
    return this.obj ? this.validate(i.every(function(l) {
      return r.obj.indexOf(l) !== -1;
    }), this.getValidateMsg("array.includes", {
      value: this.obj,
      includes: i
    })) : this;
  }, t.prototype.deepEqual = function(i) {
    return this.obj ? this.validate(Gv(this.obj, i), this.getValidateMsg("array.deepEqual", { value: this.obj, deepEqual: i })) : this;
  }, n.empty.get = function() {
    return this.validate(wh(this.obj), this.getValidateMsg("array.empty", { value: this.obj }));
  }, Object.defineProperties(t.prototype, n), t;
}(Bn), Z$ = /* @__PURE__ */ function(e) {
  function t(o, i) {
    e.call(this, o, Object.assign(Object.assign({}, i), { type: "object" })), this.validate(i && i.strict ? Un(this.obj) : !0, this.getValidateMsg("type.object"));
  }
  e && (t.__proto__ = e), t.prototype = Object.create(e && e.prototype), t.prototype.constructor = t;
  var n = { empty: { configurable: !0 } };
  return t.prototype.deepEqual = function(i) {
    return this.obj ? this.validate(Gv(this.obj, i), this.getValidateMsg("object.deepEqual", { deepEqual: i })) : this;
  }, t.prototype.hasKeys = function(i) {
    var r = this;
    return this.obj ? this.validate(i.every(function(l) {
      return r.obj[l];
    }), this.getValidateMsg("object.hasKeys", { keys: i })) : this;
  }, n.empty.get = function() {
    return this.validate(F$(this.obj), this.getValidateMsg("object.empty"));
  }, Object.defineProperties(t.prototype, n), t;
}(Bn), K$ = /* @__PURE__ */ function(e) {
  function t(o, i) {
    e.call(this, o, Object.assign(Object.assign({}, i), { type: "boolean" })), this.validate(i && i.strict ? W$(this.obj) : !0, this.getValidateMsg("type.boolean"));
  }
  e && (t.__proto__ = e), t.prototype = Object.create(e && e.prototype), t.prototype.constructor = t;
  var n = { true: { configurable: !0 }, false: { configurable: !0 } };
  return n.true.get = function() {
    return this.validate(this.obj === !0, this.getValidateMsg("boolean.true"));
  }, n.false.get = function() {
    return this.validate(this.obj === !1, this.getValidateMsg("boolean.false"));
  }, Object.defineProperties(t.prototype, n), t;
}(Bn), Y$ = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/, U$ = new RegExp("^(?!mailto:)(?:(?:http|https|ftp)://)(?:\\S+(?::\\S*)?@)?(?:(?:(?:[1-9]\\d?|1\\d\\d|2[01]\\d|22[0-3])(?:\\.(?:1?\\d{1,2}|2[0-4]\\d|25[0-5])){2}(?:\\.(?:[0-9]\\d?|1\\d\\d|2[0-4]\\d|25[0-4]))|(?:(?:[a-z\\u00a1-\\uffff0-9]+-?)*[a-z\\u00a1-\\uffff0-9]+)(?:\\.(?:[a-z\\u00a1-\\uffff0-9]+-?)*[a-z\\u00a1-\\uffff0-9]+)*(?:\\.(?:[a-z\\u00a1-\\uffff]{2,})))|localhost)(?::\\d{2,5})?(?:(/|\\?|#)[^\\s]*)?$", "i"), G$ = /^(2(5[0-5]{1}|[0-4]\d{1})|[0-1]?\d{1,2})(\.(2(5[0-5]{1}|[0-4]\d{1})|[0-1]?\d{1,2})){3}$/, X$ = /* @__PURE__ */ function(e) {
  function t(o, i) {
    e.call(this, o, Object.assign(Object.assign({}, i), { type: "type" }));
  }
  e && (t.__proto__ = e), t.prototype = Object.create(e && e.prototype), t.prototype.constructor = t;
  var n = { email: { configurable: !0 }, url: { configurable: !0 }, ip: { configurable: !0 } };
  return n.email.get = function() {
    return this.type = "email", this.validate(this.obj === void 0 || Y$.test(this.obj), this.getValidateMsg("type.email"));
  }, n.url.get = function() {
    return this.type = "url", this.validate(this.obj === void 0 || U$.test(this.obj), this.getValidateMsg("type.url"));
  }, n.ip.get = function() {
    return this.type = "ip", this.validate(this.obj === void 0 || G$.test(this.obj), this.getValidateMsg("type.ip"));
  }, Object.defineProperties(t.prototype, n), t;
}(Bn), Q$ = /* @__PURE__ */ function(e) {
  function t(o, i) {
    e.call(this, o, Object.assign(Object.assign({}, i), { type: "custom" }));
  }
  e && (t.__proto__ = e), t.prototype = Object.create(e && e.prototype), t.prototype.constructor = t;
  var n = { validate: { configurable: !0 } };
  return n.validate.get = function() {
    var o = this;
    return function(i, r) {
      var l;
      if (i)
        return l = i(o.obj, o.addError.bind(o)), l && l.then ? (r && l.then(function() {
          r && r(o.error);
        }, function(s) {
          console.error(s);
        }), [l, o]) : (r && r(o.error), o.error);
    };
  }, Object.defineProperties(t.prototype, n), t;
}(Bn), gr = function(e, t) {
  return new Sh(e, Object.assign({ field: "value" }, t));
};
gr.globalConfig = {};
gr.setGlobalConfig = function(e) {
  gr.globalConfig = e || {};
};
var Sh = function(t, n) {
  var o = gr.globalConfig, i = Object.assign(Object.assign(Object.assign({}, o), n), { validateMessages: Xv(o.validateMessages, n.validateMessages) });
  this.string = new R$(t, i), this.number = new H$(t, i), this.array = new q$(t, i), this.object = new Z$(t, i), this.boolean = new K$(t, i), this.type = new X$(t, i), this.custom = new Q$(t, i);
}, Qv = function(t, n) {
  n === void 0 && (n = {}), this.schema = t, this.options = n;
};
Qv.prototype.messages = function(t) {
  this.options = Object.assign(Object.assign({}, this.options), { validateMessages: Xv(this.options.validateMessages, t) });
};
Qv.prototype.validate = function(t, n) {
  var o = this;
  if (!Un(t))
    return;
  var i = [], r = null;
  function l(s, u) {
    r || (r = {}), (!r[s] || u.requiredError) && (r[s] = u);
  }
  this.schema && Object.keys(this.schema).forEach(function(s) {
    if (Hr(o.schema[s]))
      for (var u = function(p) {
        var h = o.schema[s][p], k = h.type, y = h.message;
        if (!k && !h.validator)
          throw "You must specify a type to field " + s + "!";
        var w = Object.assign(Object.assign({}, o.options), { message: y, field: s });
        "ignoreEmptyString" in h && (w.ignoreEmptyString = h.ignoreEmptyString), "strict" in h && (w.strict = h.strict);
        var g = new Sh(t[s], w), C = g.type[k] || null;
        if (!C)
          if (h.validator) {
            C = g.custom.validate(h.validator), Object.prototype.toString.call(C) === "[object Array]" && C[0].then ? i.push({
              function: C[0],
              _this: C[1],
              key: s
            }) : C && l(s, C);
            return;
          } else
            C = g[k];
        if (Object.keys(h).forEach(function(P) {
          h.required && (C = C.isRequired), P !== "message" && C[P] && h[P] && typeof C[P] == "object" && (C = C[P]), C[P] && h[P] !== void 0 && typeof C[P] == "function" && (C = C[P](h[P]));
        }), C.collect(function(P) {
          P && l(s, P);
        }), r)
          return "break";
      }, f = 0; f < o.schema[s].length; f++) {
        var d = u(f);
        if (d === "break") break;
      }
  }), i.length > 0 ? Promise.all(i.map(function(s) {
    return s.function;
  })).then(function() {
    i.forEach(function(s) {
      s._this.error && l(s.key, s._this.error);
    }), n && n(r);
  }) : n && n(r);
};
const zh = Symbol(
  "RowContextInjectionKey"
), Lh = Symbol(
  "GridContextInjectionKey"
), jh = Symbol("GridDataCollectorInjectionKey"), _$ = S({
  name: "Row",
  props: {
    gutter: {
      type: [Number, Object, Array],
      default: 0
    },
    justify: {
      type: String,
      default: "start"
    },
    align: {
      type: String,
      default: "start"
    },
    div: {
      type: Boolean
    },
    wrap: {
      type: Boolean,
      default: !0
    }
  },
  setup(e) {
    const { gutter: t, align: n, justify: o, div: i, wrap: r } = ve(e), l = B("row"), s = a(() => ({
      [`${l}`]: !i.value,
      [`${l}-nowrap`]: !r.value,
      [`${l}-align-${n.value}`]: n.value,
      [`${l}-justify-${o.value}`]: o.value
    })), u = a(
      () => Array.isArray(t.value) ? t.value[0] : t.value
    ), f = a(
      () => Array.isArray(t.value) ? t.value[1] : 0
    ), d = Yn(u, 0), p = Yn(f, 0), h = a(() => {
      const y = {};
      if ((d.value || p.value) && !i.value) {
        const w = -d.value / 2, g = -p.value / 2;
        w && (y.marginLeft = `${w}px`, y.marginRight = `${w}px`), g && (y.marginTop = `${g}px`, y.marginBottom = `${g}px`);
      }
      return y;
    }), k = a(() => [
      d.value,
      p.value
    ]);
    return it(
      zh,
      me({
        gutter: k,
        div: i
      })
    ), {
      classNames: s,
      styles: h
    };
  }
});
function J$(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.classNames),
    style: F(e.styles)
  }, [
    _(e.$slots, "default")
  ], 6);
}
var mo = /* @__PURE__ */ N(_$, [["render", J$]]);
function e5(e) {
  return a(() => {
    const { val: n, key: o, xs: i, sm: r, md: l, lg: s, xl: u, xxl: f } = e.value;
    if (!i && !r && !l && !s && !u && !f)
      return n;
    const d = {};
    return hr.forEach((p) => {
      const h = e.value[p];
      A(h) ? d[p] = h : Qe(h) && A(h[o]) && (d[p] = h[o]);
    }), d;
  });
}
function t5(e) {
  if (zt(e) && (["initial", "auto", "none"].includes(e) || /^\d+$/.test(e)) || A(e))
    return e;
  if (zt(e) && /^\d+(px|em|rem|%)$/.test(e))
    return `0 0 ${e}`;
}
const n5 = S({
  name: "Col",
  props: {
    span: {
      type: Number,
      default: 24
    },
    offset: {
      type: Number
    },
    order: {
      type: Number
    },
    xs: {
      type: [Number, Object]
    },
    sm: {
      type: [Number, Object]
    },
    md: {
      type: [Number, Object]
    },
    lg: {
      type: [Number, Object]
    },
    xl: {
      type: [Number, Object]
    },
    xxl: {
      type: [Number, Object]
    },
    flex: {
      type: [Number, String]
    }
  },
  setup(e) {
    const t = B("col"), n = Ge(zh, {}), o = a(() => t5(e.flex)), i = a(() => {
      const { div: p } = n, { span: h, offset: k, order: y, xs: w, sm: g, md: C, lg: P, xl: z, xxl: j } = e, I = {
        [`${t}`]: !p,
        [`${t}-order-${y}`]: y,
        [`${t}-${h}`]: !p && !w && !g && !C && !P && !z && !j,
        [`${t}-offset-${k}`]: k && k > 0
      }, L = { xs: w, sm: g, md: C, lg: P, xl: z, xxl: j };
      return Object.keys(L).forEach((M) => {
        const E = L[M];
        E && A(E) ? I[`${t}-${M}-${E}`] = !0 : E && Qe(E) && (I[`${t}-${M}-${E.span}`] = E.span, I[`${t}-${M}-offset-${E.offset}`] = E.offset, I[`${t}-${M}-order-${E.order}`] = E.order);
      }), I;
    }), r = a(() => o.value ? t : i.value), l = a(() => {
      const { gutter: p, div: h } = n, k = {};
      if (Array.isArray(p) && !h) {
        const y = p[0] && p[0] / 2 || 0, w = p[1] && p[1] / 2 || 0;
        y && (k.paddingLeft = `${y}px`, k.paddingRight = `${y}px`), w && (k.paddingTop = `${w}px`, k.paddingBottom = `${w}px`);
      }
      return k;
    }), s = a(
      () => o.value ? { flex: o.value } : {}
    ), u = a(() => Wn(e, hr)), f = e5(
      a(() => ({
        val: e.span,
        key: "span",
        ...u.value
      }))
    ), d = Yn(f, 24, !0);
    return {
      visible: a(() => !!d.value),
      classNames: r,
      styles: a(() => ({ ...l.value, ...s.value }))
    };
  }
});
function l5(e, t, n, o, i, r) {
  return e.visible ? (v(), b("div", {
    key: 0,
    class: m(e.classNames),
    style: F(e.styles)
  }, [
    _(e.$slots, "default")
  ], 6)) : te("v-if", !0);
}
var ho = /* @__PURE__ */ N(n5, [["render", l5]]);
function o5(e, t) {
  var n, o;
  const i = (n = t.span) != null ? n : 1, r = (o = t.offset) != null ? o : 0, l = Math.min(r, e);
  return {
    span: Math.min(
      l > 0 ? i + r : i,
      e
    ),
    offset: l,
    suffix: "suffix" in t ? t.suffix !== !1 : !1
  };
}
function i5({
  cols: e,
  collapsed: t,
  collapsedRows: n,
  itemDataList: o
}) {
  let i = !1, r = [];
  function l(s) {
    return Math.ceil(s / e) > n;
  }
  if (t) {
    let s = 0;
    for (let u = 0; u < o.length; u++)
      o[u].suffix && (s += o[u].span, r.push(u));
    if (!l(s)) {
      let u = 0;
      for (; u < o.length; ) {
        const f = o[u];
        if (!f.suffix) {
          if (s += f.span, l(s))
            break;
          r.push(u);
        }
        u++;
      }
    }
    i = o.some(
      (u, f) => !u.suffix && !r.includes(f)
    );
  } else
    r = o.map((s, u) => u);
  return {
    overflow: i,
    displayIndexList: r
  };
}
const r5 = S({
  name: "Grid",
  props: {
    cols: {
      type: [Number, Object],
      default: 24
    },
    rowGap: {
      type: [Number, Object],
      default: 0
    },
    colGap: {
      type: [Number, Object],
      default: 0
    },
    collapsed: {
      type: Boolean,
      default: !1
    },
    collapsedRows: {
      type: Number,
      default: 1
    }
  },
  setup(e) {
    const {
      cols: t,
      rowGap: n,
      colGap: o,
      collapsedRows: i,
      collapsed: r
    } = ve(e), l = Yn(t, 24), s = Yn(o, 0), u = Yn(n, 0), f = B("grid"), d = a(() => [f]), p = a(() => [
      {
        gap: `${u.value}px ${s.value}px`,
        "grid-template-columns": `repeat(${l.value}, minmax(0px, 1fr))`
      }
    ]), h = me(/* @__PURE__ */ new Map()), k = a(() => {
      const w = [];
      for (const [g, C] of h.entries())
        w[g] = C;
      return w;
    }), y = me({
      overflow: !1,
      displayIndexList: [],
      cols: l.value,
      colGap: s.value
    });
    return Wt(() => {
      y.cols = l.value, y.colGap = s.value;
    }), Wt(() => {
      const w = i5({
        cols: l.value,
        collapsed: r.value,
        collapsedRows: i.value,
        itemDataList: k.value
      });
      y.overflow = w.overflow, y.displayIndexList = w.displayIndexList;
    }), it(Lh, y), it(jh, {
      collectItemData(w, g) {
        h.set(w, g);
      },
      removeItemData(w) {
        h.delete(w);
      }
    }), {
      classNames: d,
      style: p
    };
  }
});
function a5(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.classNames),
    style: F(e.style)
  }, [
    _(e.$slots, "default")
  ], 6);
}
var hs = /* @__PURE__ */ N(r5, [["render", a5]]);
const s5 = S({
  name: "GridItem",
  props: {
    span: {
      type: [Number, Object],
      default: 1
    },
    offset: {
      type: [Number, Object],
      default: 0
    },
    suffix: {
      type: Boolean,
      default: !1
    }
  },
  setup(e) {
    const t = B("grid-item"), n = V(), { computedIndex: o } = Tv({
      itemRef: n,
      selector: `.${t}`
    }), i = Ge(Lh, {
      overflow: !1,
      displayIndexList: [],
      cols: 24,
      colGap: 0
    }), r = Ge(jh), l = a(
      () => {
        var g;
        return (g = i == null ? void 0 : i.displayIndexList) == null ? void 0 : g.includes(o.value);
      }
    ), { span: s, offset: u } = ve(e), f = Yn(s, 1), d = Yn(u, 0), p = a(
      () => o5(i.cols, {
        ...e,
        span: f.value,
        offset: d.value
      })
    ), h = a(() => [t]), k = a(() => {
      const { offset: g, span: C } = p.value, { colGap: P } = i;
      return g > 0 ? {
        "margin-left": `calc((${`(100% - ${P * (C - 1)}px) / ${C}`} * ${g}) + ${P * g}px)`
      } : {};
    }), y = a(() => {
      const { suffix: g, span: C } = p.value, { cols: P } = i;
      return g ? `${P - C + 1}` : `span ${C}`;
    }), w = a(() => {
      const { span: g } = p.value;
      return n.value ? [
        {
          "grid-column": `${y.value} / span ${g}`
        },
        k.value,
        !l.value || g === 0 ? { display: "none" } : {}
      ] : [];
    });
    return Wt(() => {
      o.value !== -1 && (r == null || r.collectItemData(o.value, p.value));
    }), Zt(() => {
      o.value !== -1 && (r == null || r.removeItemData(o.value));
    }), {
      classNames: h,
      style: w,
      domRef: n,
      overflow: a(() => i.overflow)
    };
  }
});
function u5(e, t, n, o, i, r) {
  return v(), b("div", {
    ref: "domRef",
    class: m(e.classNames),
    style: F(e.style)
  }, [
    _(e.$slots, "default", { overflow: e.overflow })
  ], 6);
}
var Ei = /* @__PURE__ */ N(s5, [["render", u5]]);
const uo = Object.assign(hs, {
  Row: mo,
  Col: ho,
  Item: Ei,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + mo.name, mo), e.component(n + ho.name, ho), e.component(n + hs.name, hs), e.component(n + Ei.name, Ei);
  }
}), c5 = S({
  name: "Tooltip",
  components: {
    Trigger: Tt
  },
  props: {
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean,
      default: !1
    },
    content: String,
    position: {
      type: String,
      default: "top"
    },
    mini: {
      type: Boolean,
      default: !1
    },
    backgroundColor: {
      type: String
    },
    contentClass: {
      type: [String, Array, Object]
    },
    contentStyle: {
      type: Object
    },
    arrowClass: {
      type: [String, Array, Object]
    },
    arrowStyle: {
      type: Object
    },
    popupContainer: {
      type: [String, Object]
    }
  },
  emits: {
    "update:popupVisible": (e) => !0,
    popupVisibleChange: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("tooltip"), o = V(e.defaultPopupVisible), i = a(
      () => {
        var d;
        return (d = e.popupVisible) != null ? d : o.value;
      }
    ), r = (d) => {
      o.value = d, t("update:popupVisible", d), t("popupVisibleChange", d);
    }, l = a(() => [
      `${n}-content`,
      e.contentClass,
      { [`${n}-mini`]: e.mini }
    ]), s = a(() => {
      if (e.backgroundColor || e.contentStyle)
        return {
          backgroundColor: e.backgroundColor,
          ...e.contentStyle
        };
    }), u = a(() => [
      `${n}-popup-arrow`,
      e.arrowClass
    ]), f = a(() => {
      if (e.backgroundColor || e.arrowStyle)
        return {
          backgroundColor: e.backgroundColor,
          ...e.arrowStyle
        };
    });
    return {
      prefixCls: n,
      computedPopupVisible: i,
      contentCls: l,
      computedContentStyle: s,
      arrowCls: u,
      computedArrowStyle: f,
      handlePopupVisibleChange: r
    };
  }
});
function d5(e, t, n, o, i, r) {
  const l = J("Trigger");
  return v(), oe(l, {
    class: m(e.prefixCls),
    trigger: "hover",
    position: e.position,
    "popup-visible": e.computedPopupVisible,
    "popup-offset": 10,
    "show-arrow": "",
    "content-class": e.contentCls,
    "content-style": e.computedContentStyle,
    "arrow-class": e.arrowCls,
    "arrow-style": e.computedArrowStyle,
    "popup-container": e.popupContainer,
    "animation-name": "zoom-in-fade-out",
    "auto-fit-transform-origin": "",
    role: "tooltip",
    onPopupVisibleChange: e.handlePopupVisibleChange
  }, {
    content: ue(() => [
      _(e.$slots, "content", {}, () => [
        Re(Pe(e.content), 1)
      ])
    ]),
    default: ue(() => [
      _(e.$slots, "default")
    ]),
    _: 3
  }, 8, ["class", "position", "popup-visible", "content-class", "content-style", "arrow-class", "arrow-style", "popup-container", "onPopupVisibleChange"]);
}
var ks = /* @__PURE__ */ N(c5, [["render", d5]]);
const yn = Object.assign(ks, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ks.name, ks);
  }
}), f5 = S({
  name: "IconQuestionCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-question-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), v5 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function p5(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M42 24c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6s18 8.059 18 18Z" }, null, -1),
    $("path", { d: "M24.006 31v4.008m0-6.008L24 28c0-3 3-4 4.78-6.402C30.558 19.195 28.288 15 23.987 15c-4.014 0-5.382 2.548-5.388 4.514v.465" }, null, -1)
  ]), 14, v5);
}
var gs = /* @__PURE__ */ N(f5, [["render", p5]]);
const Ph = Object.assign(gs, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + gs.name, gs);
  }
}), m5 = S({
  name: "FormItemLabel",
  components: {
    ResizeObserver: al,
    Tooltip: yn,
    IconQuestionCircle: Ph
  },
  props: {
    required: {
      type: Boolean,
      default: !1
    },
    showColon: {
      type: Boolean,
      default: !1
    },
    component: {
      type: String,
      default: "label"
    },
    asteriskPosition: {
      type: String,
      default: "start"
    },
    tooltip: {
      type: String
    },
    attrs: Object
  },
  setup() {
    const e = B("form-item-label"), t = Ge(Iv, void 0), n = dn(), o = V(), i = () => {
      o.value && A(o.value.offsetWidth) && (t == null || t.setLabelWidth(o.value.offsetWidth, n == null ? void 0 : n.uid));
    };
    return Je(() => {
      o.value && A(o.value.offsetWidth) && (t == null || t.setLabelWidth(o.value.offsetWidth, n == null ? void 0 : n.uid));
    }), _t(() => {
      t == null || t.removeLabelWidth(n == null ? void 0 : n.uid);
    }), {
      prefixCls: e,
      labelRef: o,
      handleResize: i
    };
  }
});
function h5(e, t, n, o, i, r) {
  const l = J("icon-question-circle"), s = J("Tooltip"), u = J("ResizeObserver");
  return v(), oe(u, { onResize: e.handleResize }, {
    default: ue(() => [
      (v(), oe(sn(e.component), se({
        ref: "labelRef",
        class: e.prefixCls
      }, e.attrs), {
        default: ue(() => [
          e.required && e.asteriskPosition === "start" ? (v(), b("strong", {
            key: 0,
            class: m(`${e.prefixCls}-required-symbol`)
          }, t[0] || (t[0] = [
            $("svg", {
              fill: "currentColor",
              viewBox: "0 0 1024 1024",
              width: "1em",
              height: "1em"
            }, [
              $("path", { d: "M583.338667 17.066667c18.773333 0 34.133333 15.36 34.133333 34.133333v349.013333l313.344-101.888a34.133333 34.133333 0 0 1 43.008 22.016l42.154667 129.706667a34.133333 34.133333 0 0 1-21.845334 43.178667l-315.733333 102.4 208.896 287.744a34.133333 34.133333 0 0 1-7.509333 47.786666l-110.421334 80.213334a34.133333 34.133333 0 0 1-47.786666-7.509334L505.685333 706.218667 288.426667 1005.226667a34.133333 34.133333 0 0 1-47.786667 7.509333l-110.421333-80.213333a34.133333 34.133333 0 0 1-7.509334-47.786667l214.186667-295.253333L29.013333 489.813333a34.133333 34.133333 0 0 1-22.016-43.008l42.154667-129.877333a34.133333 34.133333 0 0 1 43.008-22.016l320.512 104.106667L412.672 51.2c0-18.773333 15.36-34.133333 34.133333-34.133333h136.533334z" })
            ], -1)
          ]), 2)) : te("v-if", !0),
          _(e.$slots, "default"),
          e.tooltip ? (v(), oe(s, {
            key: 1,
            content: e.tooltip
          }, {
            default: ue(() => [
              c(l, {
                class: m(`${e.prefixCls}-tooltip`)
              }, null, 8, ["class"])
            ]),
            _: 1
          }, 8, ["content"])) : te("v-if", !0),
          e.required && e.asteriskPosition === "end" ? (v(), b("strong", {
            key: 2,
            class: m(`${e.prefixCls}-required-symbol`)
          }, t[1] || (t[1] = [
            $("svg", {
              fill: "currentColor",
              viewBox: "0 0 1024 1024",
              width: "1em",
              height: "1em"
            }, [
              $("path", { d: "M583.338667 17.066667c18.773333 0 34.133333 15.36 34.133333 34.133333v349.013333l313.344-101.888a34.133333 34.133333 0 0 1 43.008 22.016l42.154667 129.706667a34.133333 34.133333 0 0 1-21.845334 43.178667l-315.733333 102.4 208.896 287.744a34.133333 34.133333 0 0 1-7.509333 47.786666l-110.421334 80.213334a34.133333 34.133333 0 0 1-47.786666-7.509334L505.685333 706.218667 288.426667 1005.226667a34.133333 34.133333 0 0 1-47.786667 7.509333l-110.421333-80.213333a34.133333 34.133333 0 0 1-7.509334-47.786667l214.186667-295.253333L29.013333 489.813333a34.133333 34.133333 0 0 1-22.016-43.008l42.154667-129.877333a34.133333 34.133333 0 0 1 43.008-22.016l320.512 104.106667L412.672 51.2c0-18.773333 15.36-34.133333 34.133333-34.133333h136.533334z" })
            ], -1)
          ]), 2)) : te("v-if", !0),
          Re(" " + Pe(e.showColon ? ":" : ""), 1)
        ]),
        _: 3
      }, 16, ["class"]))
    ]),
    _: 3
  }, 8, ["onResize"]);
}
var k5 = /* @__PURE__ */ N(m5, [["render", h5]]);
const g5 = S({
  name: "FormItemMessage",
  props: {
    error: {
      type: Array,
      default: () => []
    },
    help: String
  },
  setup() {
    return {
      prefixCls: B("form-item-message")
    };
  }
});
function y5(e, t, n, o, i, r) {
  return e.error.length > 0 ? (v(!0), b(Ae, { key: 0 }, St(e.error, (l) => (v(), oe(on, {
    key: l,
    name: "form-blink",
    appear: ""
  }, {
    default: ue(() => [
      $("div", {
        role: "alert",
        class: m([e.prefixCls])
      }, Pe(l), 3)
    ]),
    _: 2
  }, 1024))), 128)) : e.help || e.$slots.help ? (v(), oe(on, {
    key: 1,
    name: "form-blink",
    appear: ""
  }, {
    default: ue(() => [
      $("div", {
        class: m([e.prefixCls, `${e.prefixCls}-help`])
      }, [
        _(e.$slots, "help", {}, () => [
          Re(Pe(e.help), 1)
        ])
      ], 2)
    ]),
    _: 3
  })) : te("v-if", !0);
}
var b5 = /* @__PURE__ */ N(g5, [["render", y5]]);
const C5 = S({
  name: "FormItem",
  components: {
    ArcoRow: mo,
    ArcoCol: ho,
    FormItemLabel: k5,
    FormItemMessage: b5
  },
  props: {
    field: {
      type: String,
      default: ""
    },
    label: String,
    tooltip: {
      type: String
    },
    showColon: {
      type: Boolean,
      default: !1
    },
    noStyle: {
      type: Boolean,
      default: !1
    },
    disabled: {
      type: Boolean,
      default: void 0
    },
    help: String,
    extra: String,
    required: {
      type: Boolean,
      default: !1
    },
    asteriskPosition: {
      type: String,
      default: "start"
    },
    rules: {
      type: [Object, Array]
    },
    validateStatus: {
      type: String
    },
    validateTrigger: {
      type: [String, Array],
      default: "change"
    },
    labelColProps: Object,
    wrapperColProps: Object,
    hideLabel: {
      type: Boolean,
      default: !1
    },
    hideAsterisk: {
      type: Boolean,
      default: !1
    },
    labelColStyle: Object,
    wrapperColStyle: Object,
    rowProps: Object,
    rowClass: [String, Array, Object],
    contentClass: [String, Array, Object],
    contentFlex: {
      type: Boolean,
      default: !0
    },
    mergeProps: {
      type: [Boolean, Function],
      default: !0
    },
    labelColFlex: {
      type: [Number, String]
    },
    feedback: {
      type: Boolean,
      default: !1
    },
    labelComponent: {
      type: String,
      default: "label"
    },
    labelAttrs: Object
  },
  setup(e) {
    const t = B("form-item"), { field: n } = ve(e), o = Ge(Iv, {}), { autoLabelWidth: i, layout: r } = ve(o), { i18nMessage: l } = gt(), s = a(() => {
      var O;
      const x = { ...(O = e.labelColProps) != null ? O : o.labelColProps };
      return e.labelColFlex ? x.flex = e.labelColFlex : o.autoLabelWidth && (x.flex = `${o.maxLabelWidth}px`), x;
    }), u = a(() => {
      var O;
      const x = {
        ...(O = e.wrapperColProps) != null ? O : o.wrapperColProps
      };
      return n.value && (x.id = $h(o.id, n.value)), (e.labelColFlex || o.autoLabelWidth) && (x.flex = "auto"), x;
    }), f = a(
      () => {
        var O;
        return (O = e.labelColStyle) != null ? O : o.labelColStyle;
      }
    ), d = a(
      () => {
        var O;
        return (O = e.wrapperColStyle) != null ? O : o.wrapperColStyle;
      }
    ), p = yl(o.model, e.field), h = me({}), k = me({}), y = a(() => N$(h)), w = a(
      () => O$(k)
    ), g = V(!1), C = a(
      () => yl(o.model, e.field)
    ), P = a(
      () => {
        var O;
        return !!((O = e.disabled) != null ? O : o != null && o.disabled);
      }
    ), z = a(
      () => {
        var O;
        return (O = e.validateStatus) != null ? O : y.value;
      }
    ), j = a(() => z.value === "error"), I = a(() => {
      var O, x, G;
      const ne = [].concat(
        (G = (x = e.rules) != null ? x : (O = o == null ? void 0 : o.rules) == null ? void 0 : O[e.field]) != null ? G : []
      ), ee = ne.some((Q) => Q.required);
      return e.required && !ee ? [{ required: !0 }].concat(ne) : ne;
    }), L = a(
      () => I.value.some((O) => O.required)
    ), M = e.noStyle ? Ge(J1, void 0) : void 0, E = (O, { status: x, message: G }) => {
      h[O] = x, k[O] = G, e.noStyle && (M == null || M.updateValidateState(O, { status: x, message: G }));
    }, K = a(
      () => e.feedback && z.value ? z.value : void 0
    ), q = () => {
      var O;
      if (g.value)
        return Promise.resolve();
      const x = I.value;
      if (!n.value || x.length === 0)
        return y.value && Y(), Promise.resolve();
      const G = n.value, ne = C.value;
      E(G, {
        status: "",
        message: ""
      });
      const ee = new Qv(
        {
          [G]: x.map(({ ...Q }) => (!Q.type && !Q.validator && (Q.type = "string"), Q))
        },
        {
          ignoreEmptyString: !0,
          validateMessages: (O = l.value.form) == null ? void 0 : O.validateMessages
        }
      );
      return new Promise((Q) => {
        ee.validate({ [G]: ne }, (ae) => {
          var ge;
          const Se = !!(ae != null && ae[G]);
          E(G, {
            status: Se ? "error" : "",
            message: (ge = ae == null ? void 0 : ae[G].message) != null ? ge : ""
          });
          const be = Se ? {
            label: e.label,
            field: n.value,
            value: ae[G].value,
            type: ae[G].type,
            isRequiredError: !!ae[G].requiredError,
            message: ae[G].message
          } : void 0;
          Q(be);
        });
      });
    }, T = a(
      () => [].concat(e.validateTrigger)
    ), X = a(
      () => T.value.reduce((O, x) => {
        switch (x) {
          case "change":
            return O.onChange = () => {
              q();
            }, O;
          case "input":
            return O.onInput = () => {
              at(() => {
                q();
              });
            }, O;
          case "focus":
            return O.onFocus = () => {
              q();
            }, O;
          case "blur":
            return O.onBlur = () => {
              q();
            }, O;
          default:
            return O;
        }
      }, {})
    );
    it(
      J1,
      me({
        eventHandlers: X,
        size: o && un(o, "size"),
        disabled: P,
        error: j,
        feedback: K,
        updateValidateState: E
      })
    );
    const Y = () => {
      n.value && E(n.value, {
        status: "",
        message: ""
      });
    }, H = me({
      field: n,
      disabled: P,
      error: j,
      validate: q,
      clearValidate: Y,
      resetField: () => {
        Y(), g.value = !0, o != null && o.model && n.value && mr(o.model, n.value, p), at(() => {
          g.value = !1;
        });
      },
      setField: (O) => {
        var x, G;
        n.value && (g.value = !0, "value" in O && (o != null && o.model) && n.value && mr(o.model, n.value, O.value), (O.status || O.message) && E(n.value, {
          status: (x = O.status) != null ? x : "",
          message: (G = O.message) != null ? G : ""
        }), at(() => {
          g.value = !1;
        }));
      }
    });
    Je(() => {
      var O;
      H.field && ((O = o.addField) == null || O.call(o, H));
    }), _t(() => {
      var O;
      H.field && ((O = o.removeField) == null || O.call(o, H));
    });
    const D = a(() => [
      t,
      `${t}-layout-${o.layout}`,
      {
        [`${t}-error`]: j.value,
        [`${t}-status-${z.value}`]: !!z.value
      },
      e.rowClass
    ]), R = a(() => [
      `${t}-label-col`,
      {
        [`${t}-label-col-left`]: o.labelAlign === "left",
        [`${t}-label-col-flex`]: o.autoLabelWidth || e.labelColFlex
      }
    ]), W = a(() => [
      `${t}-wrapper-col`,
      {
        [`${t}-wrapper-col-flex`]: !u.value
      }
    ]);
    return {
      prefixCls: t,
      cls: D,
      isRequired: L,
      isError: j,
      finalMessage: w,
      mergedLabelCol: s,
      mergedWrapperCol: u,
      labelColCls: R,
      autoLabelWidth: i,
      layout: r,
      mergedLabelStyle: f,
      wrapperColCls: W,
      mergedWrapperStyle: d
    };
  }
});
function $5(e, t, n, o, i, r) {
  var l;
  const s = J("FormItemLabel"), u = J("ArcoCol"), f = J("FormItemMessage"), d = J("ArcoRow");
  return e.noStyle ? _(e.$slots, "default", { key: 0 }) : (v(), oe(d, se({
    key: 1,
    class: [
      e.cls,
      {
        [`${e.prefixCls}-has-help`]: !!((l = e.$slots.help) != null ? l : e.help)
      }
    ],
    wrap: !(e.labelColFlex || e.autoLabelWidth),
    div: e.layout !== "horizontal" || e.hideLabel
  }, e.rowProps), {
    default: ue(() => [
      e.hideLabel ? te("v-if", !0) : (v(), oe(u, se({
        key: 0,
        class: e.labelColCls,
        style: e.mergedLabelStyle
      }, e.mergedLabelCol), {
        default: ue(() => [
          c(s, {
            required: e.hideAsterisk ? !1 : e.isRequired,
            "show-colon": e.showColon,
            "asterisk-position": e.asteriskPosition,
            component: e.labelComponent,
            attrs: e.labelAttrs,
            tooltip: e.tooltip
          }, {
            default: ue(() => [
              e.$slots.label || e.label ? _(e.$slots, "label", { key: 0 }, () => [
                Re(Pe(e.label), 1)
              ]) : te("v-if", !0)
            ]),
            _: 3
          }, 8, ["required", "show-colon", "asterisk-position", "component", "attrs", "tooltip"])
        ]),
        _: 3
      }, 16, ["class", "style"])),
      c(u, se({
        class: e.wrapperColCls,
        style: e.mergedWrapperStyle
      }, e.mergedWrapperCol), {
        default: ue(() => [
          $("div", {
            class: m(`${e.prefixCls}-content-wrapper`)
          }, [
            $("div", {
              class: m([
                `${e.prefixCls}-content`,
                {
                  [`${e.prefixCls}-content-flex`]: e.contentFlex
                },
                e.contentClass
              ])
            }, [
              _(e.$slots, "default")
            ], 2)
          ], 2),
          e.isError || e.$slots.help || e.help ? (v(), oe(f, {
            key: 0,
            error: e.finalMessage,
            help: e.help
          }, kt({ _: 2 }, [
            e.$slots.help ? {
              name: "help",
              fn: ue(() => [
                _(e.$slots, "help")
              ]),
              key: "0"
            } : void 0
          ]), 1032, ["error", "help"])) : te("v-if", !0),
          e.$slots.extra || e.extra ? (v(), b("div", {
            key: 1,
            class: m(`${e.prefixCls}-extra`)
          }, [
            _(e.$slots, "extra", {}, () => [
              Re(Pe(e.extra), 1)
            ])
          ], 2)) : te("v-if", !0)
        ]),
        _: 3
      }, 16, ["class", "style"])
    ]),
    _: 3
  }, 16, ["class", "wrap", "div"]));
}
var Wi = /* @__PURE__ */ N(C5, [["render", $5]]);
const w5 = Object.assign(ms, {
  Item: Wi,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ms.name, ms), e.component(n + Wi.name, Wi);
  }
}), S5 = S({
  name: "Icon",
  props: {
    type: String,
    size: [Number, String],
    rotate: Number,
    spin: Boolean
  },
  setup(e) {
    const t = B("icon"), n = a(() => {
      const i = {};
      return e.size && (i.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (i.transform = `rotate(${e.rotate}deg)`), i;
    });
    return {
      cls: a(() => [
        t,
        {
          [`${t}-loading`]: e.spin
        },
        e.type
      ]),
      innerStyle: n
    };
  }
});
function z5(e, t, n, o, i, r) {
  return v(), b("svg", {
    class: m(e.cls),
    style: F(e.innerStyle),
    fill: "currentColor"
  }, [
    _(e.$slots, "default")
  ], 6);
}
var Fi = /* @__PURE__ */ N(S5, [["render", z5]]);
function L5(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
const vp = [], j5 = (e) => {
  const {
    src: t,
    extraProps: n = {}
  } = e;
  if (!Io && (t != null && t.length) && !vp.includes(t)) {
    const o = document.createElement("script");
    o.setAttribute("src", t), o.setAttribute("data-namespace", t), vp.push(t), document.body.appendChild(o);
  }
  return S({
    name: "IconFont",
    props: {
      type: String,
      size: [Number, String],
      rotate: Number,
      spin: Boolean
    },
    setup(o, {
      slots: i
    }) {
      return () => {
        var r;
        const l = o.type ? c("use", {
          "xlink:href": `#${o.type}`
        }, null) : (r = i.default) == null ? void 0 : r.call(i);
        return c(Fi, se(o, n), L5(l) ? l : {
          default: () => [l]
        });
      };
    }
  });
}, P5 = Object.assign(Fi, {
  addFromIconFontCn: j5,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Fi.name, Fi);
  }
}), I5 = S({
  name: "ImageFooter",
  props: {
    title: {
      type: String
    },
    description: {
      type: String
    }
  },
  setup() {
    return {
      prefixCls: B("image-footer")
    };
  }
}), B5 = ["title"], M5 = ["title"];
function N5(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    e.title || e.description ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-caption`)
    }, [
      e.title ? (v(), b("div", {
        key: 0,
        class: m(`${e.prefixCls}-caption-title`),
        title: e.title
      }, Pe(e.title), 11, B5)) : te("v-if", !0),
      e.description ? (v(), b("div", {
        key: 1,
        class: m(`${e.prefixCls}-caption-description`),
        title: e.description
      }, Pe(e.description), 11, M5)) : te("v-if", !0)
    ], 2)) : te("v-if", !0),
    e.$slots.extra ? (v(), b("div", {
      key: 1,
      class: m(`${e.prefixCls}-extra`)
    }, [
      _(e.$slots, "extra")
    ], 2)) : te("v-if", !0)
  ], 2);
}
var O5 = /* @__PURE__ */ N(I5, [["render", N5]]);
const V5 = S({
  name: "ImagePreviewArrow",
  components: {
    IconLeft: xn,
    IconRight: bn
  },
  props: {
    onPrev: {
      type: Function
    },
    onNext: {
      type: Function
    }
  },
  setup() {
    return {
      prefixCls: B("image-preview-arrow")
    };
  }
});
function T5(e, t, n, o, i, r) {
  const l = J("icon-left"), s = J("icon-right");
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    $("div", {
      class: m([
        `${e.prefixCls}-left`,
        {
          [`${e.prefixCls}-disabled`]: !e.onPrev
        }
      ]),
      onClick: t[0] || (t[0] = (u) => {
        u.preventDefault(), e.onPrev && e.onPrev();
      })
    }, [
      c(l)
    ], 2),
    $("div", {
      class: m([
        `${e.prefixCls}-right`,
        {
          [`${e.prefixCls}-disabled`]: !e.onNext
        }
      ]),
      onClick: t[1] || (t[1] = (u) => {
        u.preventDefault(), e.onNext && e.onNext();
      })
    }, [
      c(s)
    ], 2)
  ], 2);
}
var A5 = /* @__PURE__ */ N(V5, [["render", T5]]);
function E5(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var yr = S({
  name: "ImagePreviewAction",
  components: {
    Tooltip: yn
  },
  inheritAttrs: !1,
  props: {
    name: {
      type: String
    },
    disabled: {
      type: Boolean
    }
  },
  setup(e, {
    slots: t,
    attrs: n
  }) {
    const o = B("image-preview-toolbar-action");
    return () => {
      var i;
      const {
        name: r,
        disabled: l
      } = e, s = (i = t.default) == null ? void 0 : i.call(t);
      if (!s || !s.length)
        return null;
      const u = c("div", se({
        class: [`${o}`, {
          [`${o}-disabled`]: l
        }],
        onMousedown: (f) => {
          f.preventDefault();
        }
      }, n), [c("span", {
        class: `${o}-content`
      }, [s])]);
      return r ? c(yn, {
        class: `${o}-tooltip`,
        content: r
      }, E5(u) ? u : {
        default: () => [u]
      }) : u;
    };
  }
}), W5 = S({
  name: "ImagePreviewToolbar",
  components: {
    RenderFunction: Xn,
    PreviewAction: yr
  },
  props: {
    actions: {
      type: Array,
      default: () => []
    },
    actionsLayout: {
      type: Array,
      default: () => []
    }
  },
  setup(e) {
    const {
      actions: t,
      actionsLayout: n
    } = ve(e), o = B("image-preview-toolbar"), i = a(() => {
      const r = new Set(n.value), l = (u) => r.has(u.key);
      return t.value.filter(l).sort((u, f) => {
        const d = n.value.indexOf(u.key), p = n.value.indexOf(f.key);
        return d > p ? 1 : -1;
      });
    });
    return {
      prefixCls: o,
      resultActions: i
    };
  }
});
function F5(e, t, n, o, i, r) {
  const l = J("RenderFunction"), s = J("PreviewAction");
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    (v(!0), b(Ae, null, St(e.resultActions, (u) => (v(), oe(s, {
      key: u.key,
      name: u.name,
      disabled: u.disabled,
      onClick: u.onClick
    }, {
      default: ue(() => [
        c(l, {
          "render-func": u.content
        }, null, 8, ["render-func"])
      ]),
      _: 2
    }, 1032, ["name", "disabled", "onClick"]))), 128)),
    _(e.$slots, "default")
  ], 2);
}
var D5 = /* @__PURE__ */ N(W5, [["render", F5]]);
function Ih(e) {
  const t = V("beforeLoad"), n = a(() => t.value === "beforeLoad"), o = a(() => t.value === "loading"), i = a(() => t.value === "error"), r = a(() => t.value === "loaded");
  return {
    status: t,
    isBeforeLoad: n,
    isLoading: o,
    isError: i,
    isLoaded: r,
    setLoadStatus: (l) => {
      t.value = l;
    }
  };
}
function x5(e, t, n, o, i) {
  let r = n, l = o;
  return n && (e.width > t.width ? r = 0 : (t.left > e.left && (r -= Math.abs(e.left - t.left) / i), t.right < e.right && (r += Math.abs(e.right - t.right) / i))), o && (e.height > t.height ? l = 0 : (t.top > e.top && (l -= Math.abs(e.top - t.top) / i), t.bottom < e.bottom && (l += Math.abs(e.bottom - t.bottom) / i))), [r, l];
}
function R5(e) {
  const { wrapperEl: t, imageEl: n, scale: o } = ve(e), i = V([0, 0]), r = V(!1);
  let l = 0, s = 0, u = [0, 0];
  const f = () => {
    if (!t.value || !n.value)
      return;
    const y = t.value.getBoundingClientRect(), w = n.value.getBoundingClientRect(), [g, C] = x5(
      y,
      w,
      i.value[0],
      i.value[1],
      o.value
    );
    (g !== i.value[0] || C !== i.value[1]) && (i.value = [g, C]);
  }, d = (y) => {
    y.preventDefault && y.preventDefault();
    const w = u[0] + (y.pageX - l) / o.value, g = u[1] + (y.pageY - s) / o.value;
    i.value = [w, g];
  }, p = (y) => {
    y.preventDefault && y.preventDefault(), r.value = !1, f(), k();
  }, h = (y) => {
    y.target === y.currentTarget && (y.preventDefault && y.preventDefault(), r.value = !0, l = y.pageX, s = y.pageY, u = [...i.value], rt(window, "mousemove", d, !1), rt(window, "mouseup", p, !1));
  };
  function k() {
    ct(window, "mousemove", d, !1), ct(window, "mouseup", p, !1);
  }
  return Wt((y) => {
    n.value && rt(n.value, "mousedown", h), y(() => {
      n.value && ct(n.value, "mousedown", h), k();
    });
  }), ze([o], () => {
    at(() => f());
  }), {
    translate: i,
    moving: r,
    resetTranslate() {
      i.value = [0, 0];
    }
  };
}
const H5 = S({
  name: "IconZoomOut",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-zoom-out`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), q5 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Z5(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M32.607 32.607A14.953 14.953 0 0 0 37 22c0-8.284-6.716-15-15-15-8.284 0-15 6.716-15 15 0 8.284 6.716 15 15 15 4.142 0 7.892-1.679 10.607-4.393Zm0 0L41.5 41.5M29 22H15" }, null, -1)
  ]), 14, q5);
}
var ys = /* @__PURE__ */ N(H5, [["render", Z5]]);
const Bh = Object.assign(ys, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ys.name, ys);
  }
}), K5 = S({
  name: "IconZoomIn",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-zoom-in`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Y5 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function U5(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M32.607 32.607A14.953 14.953 0 0 0 37 22c0-8.284-6.716-15-15-15-8.284 0-15 6.716-15 15 0 8.284 6.716 15 15 15 4.142 0 7.892-1.679 10.607-4.393Zm0 0L41.5 41.5M29 22H15m7 7V15" }, null, -1)
  ]), 14, Y5);
}
var bs = /* @__PURE__ */ N(K5, [["render", U5]]);
const Mh = Object.assign(bs, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + bs.name, bs);
  }
}), G5 = S({
  name: "IconFullscreen",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-fullscreen`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), X5 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Q5(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M42 17V9a1 1 0 0 0-1-1h-8M6 17V9a1 1 0 0 1 1-1h8m27 23v8a1 1 0 0 1-1 1h-8M6 31v8a1 1 0 0 0 1 1h8" }, null, -1)
  ]), 14, X5);
}
var Cs = /* @__PURE__ */ N(G5, [["render", Q5]]);
const Nh = Object.assign(Cs, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Cs.name, Cs);
  }
}), _5 = S({
  name: "IconRotateLeft",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-rotate-left`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), J5 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function e6(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M10 22a1 1 0 0 1 1-1h20a1 1 0 0 1 1 1v16a1 1 0 0 1-1 1H11a1 1 0 0 1-1-1V22ZM23 11h11a6 6 0 0 1 6 6v6M22.5 12.893 19.587 11 22.5 9.107v3.786Z" }, null, -1)
  ]), 14, J5);
}
var $s = /* @__PURE__ */ N(_5, [["render", e6]]);
const Oh = Object.assign($s, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + $s.name, $s);
  }
}), t6 = S({
  name: "IconRotateRight",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-rotate-right`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), n6 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function l6(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M38 22a1 1 0 0 0-1-1H17a1 1 0 0 0-1 1v16a1 1 0 0 0 1 1h20a1 1 0 0 0 1-1V22ZM25 11H14a6 6 0 0 0-6 6v6M25.5 12.893 28.413 11 25.5 9.107v3.786Z" }, null, -1)
  ]), 14, n6);
}
var ws = /* @__PURE__ */ N(t6, [["render", l6]]);
const Vh = Object.assign(ws, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ws.name, ws);
  }
}), o6 = S({
  name: "IconOriginalSize",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-original-size`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), i6 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function r6(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m5.5 11.5 5-2.5h1v32M34 11.5 39 9h1v32" }, null, -1),
    $("path", {
      d: "M24 17h1v1h-1v-1ZM24 30h1v1h-1v-1Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M24 17h1v1h-1v-1ZM24 30h1v1h-1v-1Z" }, null, -1)
  ]), 14, i6);
}
var Ss = /* @__PURE__ */ N(o6, [["render", r6]]);
const Th = Object.assign(Ss, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ss.name, Ss);
  }
});
function a6(e) {
  const { container: t, hidden: n } = ve(e);
  let o = !1, i = {};
  const r = (u) => u.tagName === "BODY" ? window.innerWidth - (document.body.clientWidth || document.documentElement.clientWidth) : u.offsetWidth - u.clientWidth, l = () => {
    if (t.value && t.value.style.overflow !== "hidden") {
      const u = t.value.style;
      o = !0;
      const f = r(t.value);
      f && (i.width = u.width, t.value.style.width = `calc(${t.value.style.width || "100%"} - ${f}px)`), i.overflow = u.overflow, t.value.style.overflow = "hidden";
    }
  }, s = () => {
    if (t.value && o) {
      const u = i;
      Object.keys(u).forEach((f) => {
        t.value.style[f] = u[f];
      });
    }
    o = !1, i = {};
  };
  return Wt((u) => {
    n.value ? l() : s(), u(() => {
      s();
    });
  }), [s, l];
}
function s6(e, t) {
  const { popupContainer: n } = ve(t);
  return a(
    () => (zt(n.value) ? im(n.value) : n.value) || e
  );
}
const zn = [
  25,
  33,
  50,
  67,
  75,
  80,
  90,
  100,
  110,
  125,
  150,
  175,
  200,
  250,
  300,
  400,
  500
].map((e) => +(e / 100).toFixed(2)), Ah = zn[0], Eh = zn[zn.length - 1];
function u6(e = 1, t = "zoomIn") {
  let n = zn.indexOf(e);
  return n === -1 && (n = d6(e)), t === "zoomIn" ? n === zn.length - 1 ? e : zn[n + 1] : n === 0 ? e : zn[n - 1];
}
function c6(e, t = 1.1, n = "zoomIn") {
  const o = n === "zoomIn" ? t : 1 / t, i = Number.parseFloat((e * o).toFixed(3));
  return Math.min(Eh, Math.max(Ah, i));
}
function d6(e) {
  let t = zn.length - 1;
  for (let n = 0; n < zn.length; n++) {
    const o = zn[n];
    if (e === o) {
      t = n;
      break;
    }
    if (e < o) {
      const i = zn[n - 1];
      t = i === void 0 || Math.abs(i - e) <= Math.abs(o - e) ? n - 1 : n;
      break;
    }
  }
  return t;
}
const zs = 90;
var f6 = S({
  name: "ImagePreview",
  components: {
    PreviewArrow: A5,
    PreviewToolbar: D5,
    IconLoading: Yt,
    IconClose: Dt
  },
  props: {
    renderToBody: {
      type: Boolean,
      default: !0
    },
    src: {
      type: String
    },
    visible: {
      type: Boolean,
      default: void 0
    },
    defaultVisible: {
      type: Boolean,
      default: !1
    },
    maskClosable: {
      type: Boolean,
      default: !0
    },
    closable: {
      type: Boolean,
      default: !0
    },
    actionsLayout: {
      type: Array,
      default: () => ["fullScreen", "rotateRight", "rotateLeft", "zoomIn", "zoomOut", "originalSize"]
    },
    popupContainer: {
      type: [Object, String]
    },
    inGroup: {
      type: Boolean,
      default: !1
    },
    groupArrowProps: {
      type: Object,
      default: () => ({})
    },
    escToClose: {
      type: Boolean,
      default: !0
    },
    wheelZoom: {
      type: Boolean,
      default: !0
    },
    keyboard: {
      type: Boolean,
      default: !0
    },
    defaultScale: {
      type: Number,
      default: 1
    },
    zoomRate: {
      type: Number,
      default: 1.1
    }
  },
  emits: [
    "close",
    "update:visible"
  ],
  setup(e, {
    emit: t
  }) {
    const {
      t: n
    } = gt(), {
      src: o,
      popupContainer: i,
      visible: r,
      defaultVisible: l,
      maskClosable: s,
      actionsLayout: u,
      defaultScale: f,
      zoomRate: d
    } = ve(e), p = V(), h = V(), k = B("image-preview"), [y, w] = Vt(l.value, me({
      value: r
    })), g = a(() => [k, {
      [`${k}-hide`]: !y.value
    }]), C = s6(document.body, me({
      popupContainer: i
    })), P = a(() => C.value === document.body), {
      zIndex: z
    } = Ql("dialog", {
      visible: y
    }), j = a(() => ({
      ...P.value ? {
        zIndex: z.value,
        position: "fixed"
      } : {
        zIndex: "inherit",
        position: "absolute"
      }
    })), {
      isLoading: I,
      isLoaded: L,
      setLoadStatus: M
    } = Ih(), E = V(0), K = V(f.value), {
      translate: q,
      moving: T,
      resetTranslate: X
    } = R5(me({
      wrapperEl: p,
      imageEl: h,
      visible: y,
      scale: K
    })), Y = V(!1);
    let Z = null;
    const U = () => {
      !Y.value && (Y.value = !0), Z && clearTimeout(Z), Z = setTimeout(() => {
        Y.value = !1;
      }, 1e3);
    };
    a6(me({
      container: C,
      hidden: y
    }));
    function H() {
      E.value = 0, K.value = f.value, X();
    }
    const D = (be) => u.value.includes(be), R = (be) => {
      switch (be.stopPropagation(), be.preventDefault(), be.key) {
        case yt.ESC:
          e.escToClose && ne();
          break;
        case yt.ARROW_LEFT:
          e.groupArrowProps.onPrev && e.groupArrowProps.onPrev();
          break;
        case yt.ARROW_RIGHT:
          e.groupArrowProps.onNext && e.groupArrowProps.onNext();
          break;
        case yt.ARROW_UP:
          D("zoomIn") && Se("zoomIn");
          break;
        case yt.ARROW_DOWN:
          D("zoomOut") && Se("zoomOut");
          break;
        case yt.SPACE:
          D("originalSize") && Q(1);
          break;
      }
    }, W = wl((be) => {
      if (be.preventDefault(), be.stopPropagation(), !e.wheelZoom)
        return;
      const pe = (be.deltaY || be.deltaX) > 0 ? "zoomOut" : "zoomIn", Me = c6(K.value, d.value, pe);
      Q(Me);
    });
    let O = !1;
    const x = () => {
      at(() => {
        var be;
        (be = p == null ? void 0 : p.value) == null || be.focus();
      }), e.keyboard && !O && (O = !0, rt(C.value, "keydown", R));
    }, G = () => {
      O && (O = !1, ct(C.value, "keydown", R));
    };
    ze([o, y], () => {
      y.value ? (H(), M("loading"), x()) : G();
    });
    function ne() {
      y.value && (t("close"), t("update:visible", !1), w(!1));
    }
    function ee(be) {
      var Le;
      (Le = p == null ? void 0 : p.value) == null || Le.focus(), s.value && be.target === be.currentTarget && ne();
    }
    function Q(be) {
      K.value !== be && (K.value = be, U());
    }
    function ae() {
      const be = p.value.getBoundingClientRect(), Le = h.value.getBoundingClientRect(), pe = be.height / (Le.height / K.value), Me = be.width / (Le.width / K.value), ke = Math.max(pe, Me);
      Q(ke);
    }
    function ge(be) {
      const pe = be === "clockwise" ? (E.value + zs) % 360 : E.value === 0 ? 360 - zs : E.value - zs;
      E.value = pe;
    }
    function Se(be) {
      const Le = u6(K.value, be);
      Q(Le);
    }
    return _t(() => {
      G();
    }), {
      prefixCls: k,
      classNames: g,
      container: C,
      wrapperStyles: j,
      scale: K,
      translate: q,
      rotate: E,
      moving: T,
      mergedVisible: y,
      isLoading: I,
      isLoaded: L,
      scaleValueVisible: Y,
      refWrapper: p,
      refImage: h,
      onWheel: W,
      onMaskClick: ee,
      onCloseClick: ne,
      onImgLoad() {
        M("loaded");
      },
      onImgError() {
        M("error");
      },
      actions: a(() => [
        {
          key: "fullScreen",
          name: n("imagePreview.fullScreen"),
          content: () => mn(Nh),
          onClick: () => ae()
        },
        {
          key: "rotateRight",
          name: n("imagePreview.rotateRight"),
          content: () => mn(Vh),
          onClick: () => ge("clockwise")
        },
        {
          key: "rotateLeft",
          name: n("imagePreview.rotateLeft"),
          content: () => mn(Oh),
          onClick: () => ge("counterclockwise")
        },
        {
          key: "zoomIn",
          name: n("imagePreview.zoomIn"),
          content: () => mn(Mh),
          onClick: () => Se("zoomIn"),
          disabled: K.value === Eh
        },
        {
          key: "zoomOut",
          name: n("imagePreview.zoomOut"),
          content: () => mn(Bh),
          onClick: () => Se("zoomOut"),
          disabled: K.value === Ah
        },
        {
          key: "originalSize",
          name: n("imagePreview.originalSize"),
          content: () => mn(Th),
          onClick: () => Q(1)
        }
      ])
    };
  }
});
const v6 = ["src"];
function p6(e, t, n, o, i, r) {
  const l = J("IconLoading"), s = J("PreviewToolbar"), u = J("IconClose"), f = J("PreviewArrow");
  return v(), oe(br, {
    to: e.container,
    disabled: !e.renderToBody
  }, [
    $("div", {
      class: m(e.classNames),
      style: F(e.wrapperStyles)
    }, [
      c(on, {
        name: "image-fade",
        onBeforeEnter: t[0] || (t[0] = (d) => d.parentElement && (d.parentElement.style.display = "block")),
        onAfterLeave: t[1] || (t[1] = (d) => d.parentElement && (d.parentElement.style.display = "")),
        persisted: ""
      }, {
        default: ue(() => [
          hn($("div", {
            class: m(`${e.prefixCls}-mask`)
          }, null, 2), [
            [kn, e.mergedVisible]
          ])
        ]),
        _: 1
      }),
      e.mergedVisible ? (v(), b("div", {
        key: 0,
        ref: "refWrapper",
        tabindex: "0",
        class: m(`${e.prefixCls}-wrapper`),
        onClick: t[6] || (t[6] = (...d) => e.onMaskClick && e.onMaskClick(...d)),
        onWheel: t[7] || (t[7] = an((...d) => e.onWheel && e.onWheel(...d), ["prevent", "stop"]))
      }, [
        te(" img "),
        $("div", {
          class: m(`${e.prefixCls}-img-container`),
          style: F({ transform: `scale(${e.scale}, ${e.scale})` }),
          onClick: t[4] || (t[4] = (...d) => e.onMaskClick && e.onMaskClick(...d))
        }, [
          (v(), b("img", {
            ref: "refImage",
            key: e.src,
            src: e.src,
            class: m([
              `${e.prefixCls}-img`,
              {
                [`${e.prefixCls}-img-moving`]: e.moving
              }
            ]),
            style: F({
              transform: `translate(${e.translate[0]}px, ${e.translate[1]}px) rotate(${e.rotate}deg)`
            }),
            onLoad: t[2] || (t[2] = (...d) => e.onImgLoad && e.onImgLoad(...d)),
            onError: t[3] || (t[3] = (...d) => e.onImgError && e.onImgError(...d))
          }, null, 46, v6))
        ], 6),
        te(" loading "),
        e.isLoading ? (v(), b("div", {
          key: 0,
          class: m(`${e.prefixCls}-loading`)
        }, [
          c(l)
        ], 2)) : te("v-if", !0),
        te(" scale value "),
        c(on, { name: "image-fade" }, {
          default: ue(() => [
            e.scaleValueVisible ? (v(), b("div", {
              key: 0,
              class: m(`${e.prefixCls}-scale-value`)
            }, Pe((e.scale * 100).toFixed(0)) + "% ", 3)) : te("v-if", !0)
          ]),
          _: 1
        }),
        te(" toolbar "),
        e.isLoaded && e.actionsLayout.length ? (v(), oe(s, {
          key: 1,
          actions: e.actions,
          "actions-layout": e.actionsLayout
        }, {
          default: ue(() => [
            _(e.$slots, "actions")
          ]),
          _: 3
        }, 8, ["actions", "actions-layout"])) : te("v-if", !0),
        te(" close btn "),
        e.closable ? (v(), b("div", {
          key: 2,
          class: m(`${e.prefixCls}-close-btn`),
          onClick: t[5] || (t[5] = (...d) => e.onCloseClick && e.onCloseClick(...d))
        }, [
          c(u)
        ], 2)) : te("v-if", !0),
        te(" group arrow "),
        e.inGroup ? (v(), oe(f, dt(se({ key: 3 }, e.groupArrowProps)), null, 16)) : te("v-if", !0)
      ], 34)) : te("v-if", !0)
    ], 6)
  ], 8, ["to", "disabled"]);
}
var Hl = /* @__PURE__ */ N(f6, [["render", p6]]);
function pp(e) {
  if (Ve(e))
    return;
  if (!A(e) && /^\d+(%)$/.test(e))
    return e;
  const t = parseInt(e, 10);
  return A(t) ? `${t}px` : void 0;
}
const Wh = Symbol("PreviewGroupInjectionKey");
let m6 = 0;
const h6 = S({
  name: "Image",
  components: {
    IconImageClose: Or,
    IconLoading: Yt,
    ImageFooter: O5,
    ImagePreview: Hl
  },
  inheritAttrs: !1,
  props: {
    renderToBody: {
      type: Boolean,
      default: !0
    },
    src: {
      type: String
    },
    width: {
      type: [String, Number]
    },
    height: {
      type: [String, Number]
    },
    title: {
      type: String
    },
    description: {
      type: String
    },
    fit: {
      type: String
    },
    alt: {
      type: String
    },
    hideFooter: {
      type: [Boolean, String],
      default: !1
    },
    footerPosition: {
      type: String,
      default: "inner"
    },
    showLoader: {
      type: Boolean,
      default: !1
    },
    preview: {
      type: Boolean,
      default: !0
    },
    previewVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPreviewVisible: {
      type: Boolean,
      default: !1
    },
    previewProps: {
      type: Object
    },
    footerClass: {
      type: [String, Array, Object]
    }
  },
  emits: [
    "preview-visible-change",
    "update:previewVisible"
  ],
  setup(e, { attrs: t, slots: n, emit: o }) {
    const { t: i } = gt(), {
      height: r,
      width: l,
      hideFooter: s,
      title: u,
      description: f,
      src: d,
      footerPosition: p,
      defaultPreviewVisible: h,
      previewVisible: k,
      preview: y,
      previewProps: w
    } = ve(e), g = Ge(Wh, void 0), C = B("image"), P = V(), { isLoaded: z, isError: j, isLoading: I, setLoadStatus: L } = Ih(), M = a(() => ({
      width: pp(l == null ? void 0 : l.value),
      height: pp(r == null ? void 0 : r.value)
    })), E = a(() => e.fit ? { objectFit: e.fit } : {}), K = a(() => [
      `${C}`,
      {
        [`${C}-loading`]: I.value,
        [`${C}-loading-error`]: j.value,
        [`${C}-with-footer-inner`]: z && T && p.value === "inner",
        [`${C}-with-footer-outer`]: z && T && p.value === "outer"
      },
      t.class
    ]), q = a(() => [
      M.value,
      t.style
    ]), T = a(() => u != null && u.value || f != null && f.value || n.extra ? Xt(s.value) ? !s.value && z.value : s.value === "never" : !1), X = a(() => Ft(t, ["class", "style"])), [Y, Z] = Vt(
      h.value,
      me({
        value: k
      })
    ), U = a(
      () => !(g != null && g.preview) && y.value
    );
    Wt(() => {
      Io || !P.value || (P.value.src = d == null ? void 0 : d.value, L("loading"));
    });
    const H = m6++;
    Wt((x) => {
      var G, ne, ee;
      const Q = (ee = g == null ? void 0 : g.registerImageUrl) == null ? void 0 : ee.call(
        g,
        H,
        ((ne = (G = w == null ? void 0 : w.value) == null ? void 0 : G.src) != null ? ne : d == null ? void 0 : d.value) || "",
        y.value
      );
      x(() => {
        Q == null || Q();
      });
    });
    function D() {
      L("loaded");
    }
    function R() {
      L("error");
    }
    function W() {
      y.value && (g != null && g.preview ? g.preview(H) : (o("preview-visible-change", !0), Z(!0)));
    }
    function O() {
      o("preview-visible-change", !1), Z(!1);
    }
    return {
      t: i,
      refImg: P,
      prefixCls: C,
      wrapperClassNames: K,
      wrapperStyles: q,
      showFooter: T,
      imgProps: X,
      imgStyle: M,
      isLoaded: z,
      isError: j,
      isLoading: I,
      mergedPreviewVisible: Y,
      mergePreview: U,
      onImgLoaded: D,
      onImgLoadError: R,
      onImgClick: W,
      onPreviewClose: O,
      fitStyle: E
    };
  }
}), k6 = ["title", "alt"];
function g6(e, t, n, o, i, r) {
  const l = J("IconImageClose"), s = J("IconLoading"), u = J("ImageFooter"), f = J("ImagePreview");
  return v(), b("div", {
    class: m(e.wrapperClassNames),
    style: F(e.wrapperStyles)
  }, [
    $("img", se({
      ref: "refImg",
      class: `${e.prefixCls}-img`
    }, e.imgProps, {
      style: { ...e.imgStyle, ...e.fitStyle },
      title: e.title,
      alt: e.alt,
      onLoad: t[0] || (t[0] = (...d) => e.onImgLoaded && e.onImgLoaded(...d)),
      onError: t[1] || (t[1] = (...d) => e.onImgLoadError && e.onImgLoadError(...d)),
      onClick: t[2] || (t[2] = (...d) => e.onImgClick && e.onImgClick(...d))
    }), null, 16, k6),
    e.isLoaded ? te("v-if", !0) : (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-overlay`)
    }, [
      e.isError ? _(e.$slots, "error", { key: 0 }, () => [
        $("div", {
          class: m(`${e.prefixCls}-error`)
        }, [
          $("div", {
            class: m(`${e.prefixCls}-error-icon`)
          }, [
            _(e.$slots, "error-icon", {}, () => [
              c(l)
            ])
          ], 2),
          e.alt || e.description ? (v(), b("div", {
            key: 0,
            class: m(`${e.prefixCls}-error-alt`)
          }, Pe(e.alt || e.description), 3)) : te("v-if", !0)
        ], 2)
      ]) : te("v-if", !0),
      e.isLoading && (e.showLoader || e.$slots.loader) ? _(e.$slots, "loader", { key: 1 }, () => [
        $("div", {
          class: m([`${e.prefixCls}-loader`])
        }, [
          $("div", {
            class: m(`${e.prefixCls}-loader-spin`)
          }, [
            c(s),
            $("div", {
              class: m(`${e.prefixCls}-loader-spin-text`)
            }, Pe(e.t("image.loading")), 3)
          ], 2)
        ], 2)
      ]) : te("v-if", !0)
    ], 2)),
    e.showFooter ? (v(), oe(u, {
      key: 1,
      class: m(e.footerClass),
      "prefix-cls": e.prefixCls,
      title: e.title,
      description: e.description
    }, kt({ _: 2 }, [
      e.$slots.extra ? {
        name: "extra",
        fn: ue(() => [
          _(e.$slots, "extra")
        ]),
        key: "0"
      } : void 0
    ]), 1032, ["class", "prefix-cls", "title", "description"])) : te("v-if", !0),
    e.isLoaded && e.mergePreview ? (v(), oe(f, se({
      key: 2,
      src: e.src
    }, e.previewProps, {
      visible: e.mergedPreviewVisible,
      "render-to-body": e.renderToBody,
      onClose: e.onPreviewClose
    }), {
      actions: ue(() => [
        _(e.$slots, "preview-actions")
      ]),
      _: 3
    }, 16, ["src", "visible", "render-to-body", "onClose"])) : te("v-if", !0)
  ], 6);
}
var Ls = /* @__PURE__ */ N(h6, [["render", g6]]), y6 = S({
  name: "ImagePreviewGroup",
  components: {
    ImagePreview: Hl
  },
  inheritAttrs: !1,
  props: {
    renderToBody: {
      type: Boolean,
      default: !0
    },
    srcList: {
      type: Array
    },
    current: {
      type: Number
    },
    defaultCurrent: {
      type: Number,
      default: 0
    },
    infinite: {
      type: Boolean,
      default: !1
    },
    visible: {
      type: Boolean,
      default: void 0
    },
    defaultVisible: {
      type: Boolean,
      default: !1
    },
    maskClosable: {
      type: Boolean,
      default: !0
    },
    closable: {
      type: Boolean,
      default: !0
    },
    actionsLayout: {
      type: Array,
      default: () => ["fullScreen", "rotateRight", "rotateLeft", "zoomIn", "zoomOut", "originalSize"]
    },
    popupContainer: {
      type: [String, Object]
    }
  },
  emits: [
    "change",
    "update:current",
    "visible-change",
    "update:visible"
  ],
  setup(e, {
    emit: t
  }) {
    const {
      srcList: n,
      visible: o,
      defaultVisible: i,
      current: r,
      defaultCurrent: l,
      infinite: s
    } = ve(e), [u, f] = Vt(i.value, me({
      value: o
    })), d = (q) => {
      q !== u.value && (t("visible-change", q), t("update:visible", q), f(q));
    }, p = a(() => new Map(He(n == null ? void 0 : n.value) ? n == null ? void 0 : n.value.map((q, T) => [T, {
      url: q,
      canPreview: !0
    }]) : [])), h = V(new Map(p.value || [])), k = a(() => Array.from(h.value.keys())), y = a(() => k.value.length);
    function w(q, T, X) {
      return p.value.has(q) || h.value.set(q, {
        url: T,
        canPreview: X
      }), function() {
        p.value.has(q) || h.value.delete(q);
      };
    }
    ze(p, () => {
      h.value = new Map(p.value || []);
    });
    const [g, C] = Vt(l.value, me({
      value: r
    })), P = (q) => {
      q !== g.value && (t("change", q), t("update:current", q), C(q));
    }, z = a(() => k.value[g.value]), j = (q) => {
      const T = k.value.indexOf(q);
      T !== g.value && P(T);
    }, I = a(() => {
      var q;
      return (q = h.value.get(z.value)) == null ? void 0 : q.url;
    });
    it(Wh, me({
      registerImageUrl: w,
      preview: (q) => {
        d(!0), j(q);
      }
    }));
    const L = a(() => {
      const q = (X, Y) => {
        var Z;
        for (let U = X; U <= Y; U++) {
          const H = k.value[U];
          if ((Z = h.value.get(H)) != null && Z.canPreview)
            return U;
        }
      }, T = q(g.value + 1, y.value - 1);
      return Ve(T) && s.value ? q(0, g.value - 1) : T;
    }), M = a(() => {
      const q = (X, Y) => {
        var Z;
        for (let U = X; U >= Y; U--) {
          const H = k.value[U];
          if ((Z = h.value.get(H)) != null && Z.canPreview)
            return U;
        }
      }, T = q(g.value - 1, 0);
      return Ve(T) && s.value ? q(y.value - 1, g.value + 1) : T;
    }), E = a(() => Ve(M.value) ? void 0 : () => {
      !Ve(M.value) && P(M.value);
    }), K = a(() => Ve(L.value) ? void 0 : () => {
      !Ve(L.value) && P(L.value);
    });
    return {
      mergedVisible: u,
      currentUrl: I,
      prevIndex: M,
      nextIndex: L,
      onClose() {
        d(!1);
      },
      groupArrowProps: me({
        onPrev: E,
        onNext: K
      })
    };
  }
});
function b6(e, t, n, o, i, r) {
  const l = J("ImagePreview");
  return v(), b(Ae, null, [
    _(e.$slots, "default"),
    c(l, se({ ...e.$attrs, groupArrowProps: e.groupArrowProps }, {
      "in-group": "",
      src: e.currentUrl,
      visible: e.mergedVisible,
      "mask-closable": e.maskClosable,
      closable: e.closable,
      "actions-layout": e.actionsLayout,
      "popup-container": e.popupContainer,
      "render-to-body": e.renderToBody,
      onClose: e.onClose
    }), kt({ _: 2 }, [
      e.$slots.actions ? {
        name: "actions",
        fn: ue(() => [
          _(e.$slots, "actions", { url: e.currentUrl })
        ]),
        key: "0"
      } : void 0
    ]), 1040, ["src", "visible", "mask-closable", "closable", "actions-layout", "popup-container", "render-to-body", "onClose"])
  ], 64);
}
var ko = /* @__PURE__ */ N(y6, [["render", b6]]);
const C6 = Object.assign(Ls, {
  Preview: Hl,
  PreviewGroup: ko,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ls.name, Ls), e.component(n + Hl.name, Hl), e.component(
      n + ko.name,
      ko
    ), e.component(
      n + yr.name,
      yr
    );
  }
}), Fh = Symbol(
  "LayoutSiderInjectionKey"
), Dh = Symbol("SiderInjectionKey");
var $6 = S({
  name: "Layout",
  props: {
    hasSider: {
      type: Boolean
    }
  },
  setup(e) {
    const t = V([]), n = B("layout"), o = a(() => [n, {
      [`${n}-has-sider`]: e.hasSider || t.value.length
    }]);
    return it(Fh, {
      onSiderMount: (i) => t.value.push(i),
      onSiderUnMount: (i) => {
        t.value = t.value.filter((r) => r !== i);
      }
    }), {
      classNames: o
    };
  }
});
function w6(e, t, n, o, i, r) {
  return v(), b("section", {
    class: m(e.classNames)
  }, [
    _(e.$slots, "default")
  ], 2);
}
var js = /* @__PURE__ */ N($6, [["render", w6]]);
const S6 = S({
  name: "LayoutHeader",
  setup() {
    return {
      classNames: [B("layout-header")]
    };
  }
});
function z6(e, t, n, o, i, r) {
  return v(), b("header", {
    class: m(e.classNames)
  }, [
    _(e.$slots, "default")
  ], 2);
}
var Di = /* @__PURE__ */ N(S6, [["render", z6]]);
const L6 = S({
  name: "LayoutContent",
  setup() {
    return {
      classNames: [B("layout-content")]
    };
  }
});
function j6(e, t, n, o, i, r) {
  return v(), b("main", {
    class: m(e.classNames)
  }, [
    _(e.$slots, "default")
  ], 2);
}
var xi = /* @__PURE__ */ N(L6, [["render", j6]]);
const P6 = S({
  name: "LayoutFooter",
  setup() {
    return {
      classNames: [B("layout-footer")]
    };
  }
});
function I6(e, t, n, o, i, r) {
  return v(), b("footer", {
    class: m(e.classNames)
  }, [
    _(e.$slots, "default")
  ], 2);
}
var Ri = /* @__PURE__ */ N(P6, [["render", I6]]);
const B6 = S({
  name: "IconDragDot",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-drag-dot`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), M6 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function N6(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M40 17v2h-2v-2h2ZM25 17v2h-2v-2h2ZM10 17v2H8v-2h2ZM40 29v2h-2v-2h2ZM25 29v2h-2v-2h2ZM10 29v2H8v-2h2Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M40 17v2h-2v-2h2ZM25 17v2h-2v-2h2ZM10 17v2H8v-2h2ZM40 29v2h-2v-2h2ZM25 29v2h-2v-2h2ZM10 29v2H8v-2h2Z" }, null, -1)
  ]), 14, M6);
}
var Ps = /* @__PURE__ */ N(B6, [["render", N6]]);
const xh = Object.assign(Ps, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ps.name, Ps);
  }
}), O6 = S({
  name: "IconDragDotVertical",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-drag-dot-vertical`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), V6 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function T6(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M17 8h2v2h-2V8ZM17 23h2v2h-2v-2ZM17 38h2v2h-2v-2ZM29 8h2v2h-2V8ZM29 23h2v2h-2v-2ZM29 38h2v2h-2v-2Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M17 8h2v2h-2V8ZM17 23h2v2h-2v-2ZM17 38h2v2h-2v-2ZM29 8h2v2h-2V8ZM29 23h2v2h-2v-2ZM29 38h2v2h-2v-2Z" }, null, -1)
  ]), 14, V6);
}
var Is = /* @__PURE__ */ N(O6, [["render", T6]]);
const Zr = Object.assign(Is, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Is.name, Is);
  }
});
var A6 = S({
  name: "ResizeTrigger",
  components: {
    ResizeObserver: jn,
    IconDragDot: xh,
    IconDragDotVertical: Zr
  },
  props: {
    prefixCls: {
      type: String,
      required: !0
    },
    direction: {
      type: String,
      default: "horizontal"
    }
  },
  emits: ["resize"],
  setup(e, {
    emit: t
  }) {
    const {
      direction: n,
      prefixCls: o
    } = ve(e), i = a(() => (n == null ? void 0 : n.value) === "horizontal");
    return {
      classNames: a(() => [o.value, {
        [`${o.value}-horizontal`]: i.value,
        [`${o.value}-vertical`]: !i.value
      }]),
      onResize: (s) => {
        t("resize", s);
      },
      isHorizontal: i
    };
  }
});
function E6(e, t, n, o, i, r) {
  const l = J("IconDragDot"), s = J("IconDragDotVertical"), u = J("ResizeObserver");
  return v(), oe(u, { onResize: e.onResize }, {
    default: ue(() => [
      $("div", {
        class: m(e.classNames)
      }, [
        te(" @slot 自定义内容 "),
        _(e.$slots, "default", {}, () => [
          $("div", {
            class: m(`${e.prefixCls}-icon-wrapper`)
          }, [
            te(" @slot 自定义 icon "),
            _(e.$slots, "icon", {}, () => [
              e.isHorizontal ? (v(), oe(l, {
                key: 0,
                class: m(`${e.prefixCls}-icon`)
              }, null, 8, ["class"])) : (v(), oe(s, {
                key: 1,
                class: m(`${e.prefixCls}-icon`)
              }, null, 8, ["class"]))
            ])
          ], 2)
        ])
      ], 2)
    ]),
    _: 3
  }, 8, ["onResize"]);
}
var Rh = /* @__PURE__ */ N(A6, [["render", E6]]);
const Hh = "left", qh = "right", _v = "top", Jv = "bottom", W6 = [
  Hh,
  qh,
  _v,
  Jv
];
function mp(e, t) {
  if (e === 0)
    return 0;
  const n = e - t;
  return n <= 0 ? 0 : n;
}
function Bs(e) {
  return [_v, Jv].indexOf(e) > -1;
}
const F6 = S({
  name: "ResizeBox",
  components: {
    ResizeTrigger: Rh
  },
  inheritAttrs: !1,
  props: {
    width: {
      type: Number
    },
    height: {
      type: Number
    },
    component: {
      type: String,
      default: "div"
    },
    directions: {
      type: Array,
      default: () => ["right"]
    }
  },
  emits: {
    "update:width": (e) => !0,
    "update:height": (e) => !0,
    movingStart: (e) => !0,
    moving: (e, t) => !0,
    movingEnd: (e) => !0
  },
  setup(e, { emit: t }) {
    const { height: n, width: o, directions: i } = ve(e), [r, l] = Vt(
      null,
      me({
        value: o
      })
    ), [s, u] = Vt(
      null,
      me({
        value: n
      })
    ), f = V(), d = me({}), p = B("resizebox"), h = a(() => [p]), k = a(() => ({
      ...A(r.value) ? { width: `${r.value}px` } : {},
      ...A(s.value) ? { height: `${s.value}px` } : {},
      ...d
    })), y = a(
      () => i.value.filter((j) => W6.includes(j))
    ), w = {
      direction: "",
      startPageX: 0,
      startPageY: 0,
      startWidth: 0,
      startHeight: 0,
      moving: !1,
      padding: {
        left: 0,
        right: 0,
        top: 0,
        bottom: 0
      }
    };
    function g(j) {
      if (!w.moving)
        return;
      const { startPageX: I, startPageY: L, startWidth: M, startHeight: E, direction: K } = w;
      let q = M, T = E;
      const X = j.pageX - I, Y = j.pageY - L;
      switch (K) {
        case Hh:
          q = M - X, l(q), t("update:width", q);
          break;
        case qh:
          q = M + X, l(q), t("update:width", q);
          break;
        case _v:
          T = E - Y, u(T), t("update:height", T);
          break;
        case Jv:
          T = E + Y, u(T), t("update:height", T);
          break;
      }
      t(
        "moving",
        {
          width: q,
          height: T
        },
        j
      );
    }
    function C(j) {
      w.moving = !1, ct(window, "mousemove", g), ct(window, "mouseup", C), ct(window, "contextmenu", C), document.body.style.cursor = "default", t("movingEnd", j);
    }
    function P(j, I) {
      var L, M;
      t("movingStart", I), w.moving = !0, w.startPageX = I.pageX, w.startPageY = I.pageY, w.direction = j;
      const { top: E, left: K, right: q, bottom: T } = w.padding;
      w.startWidth = mp(
        ((L = f.value) == null ? void 0 : L.clientWidth) || 0,
        K + q
      ), w.startHeight = mp(
        ((M = f.value) == null ? void 0 : M.clientHeight) || 0,
        E + T
      ), rt(window, "mousemove", g), rt(window, "mouseup", C), rt(window, "contextmenu", C), document.body.style.cursor = Bs(j) ? "row-resize" : "col-resize";
    }
    function z(j, I) {
      const { width: L, height: M } = I.contentRect, E = Bs(j) ? M : L;
      w.padding[j] = E, d[`padding-${j}`] = `${E}px`;
    }
    return {
      prefixCls: p,
      classNames: h,
      styles: k,
      wrapperRef: f,
      onMoveStart: P,
      isHorizontal: Bs,
      allowDirections: y,
      onTiggerResize: z
    };
  }
});
function D6(e, t, n, o, i, r) {
  const l = J("ResizeTrigger");
  return v(), oe(sn(e.component), se({
    ref: "wrapperRef",
    class: e.classNames
  }, e.$attrs, { style: e.styles }), {
    default: ue(() => [
      _(e.$slots, "default"),
      (v(!0), b(Ae, null, St(e.allowDirections, (s) => (v(), oe(l, {
        key: s,
        "prefix-cls": `${e.prefixCls}-trigger`,
        class: m(`${e.prefixCls}-direction-${s}`),
        direction: e.isHorizontal(s) ? "horizontal" : "vertical",
        onMousedown: (u) => {
          e.onMoveStart(s, u);
        },
        onResize: (u) => {
          e.onTiggerResize(s, u);
        }
      }, kt({
        default: ue(() => [
          e.$slots["resize-trigger"] ? _(e.$slots, "resize-trigger", {
            key: 0,
            direction: s
          }) : te("v-if", !0)
        ]),
        _: 2
      }, [
        e.$slots["resize-trigger-icon"] ? {
          name: "icon",
          fn: ue(() => [
            _(e.$slots, "resize-trigger-icon", { direction: s })
          ]),
          key: "0"
        } : void 0
      ]), 1032, ["prefix-cls", "class", "direction", "onMousedown", "onResize"]))), 128))
    ]),
    _: 3
  }, 16, ["class", "style"]);
}
var Ms = /* @__PURE__ */ N(F6, [["render", D6]]);
const Zh = Object.assign(Ms, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ms.name, Ms);
  }
});
function Kh(e, t) {
  const n = a(
    () => Hp(e) ? e.value : e
  );
  let o = "";
  Je(() => {
    o = kr.subscribe(
      (i, r) => {
        n.value && (!r || r === n.value) && t(!!i[n.value]);
      }
    );
  }), Zt(() => {
    o && kr.unsubscribe(o);
  });
}
const x6 = /* @__PURE__ */ (() => {
  let e = 0;
  return (t = "") => (e += 1, `${t}${e}`);
})();
var R6 = S({
  name: "LayoutSider",
  components: {
    IconLeft: xn,
    IconRight: bn,
    ResizeBox: Zh
  },
  props: {
    theme: {
      type: String,
      default: "light"
    },
    collapsed: {
      type: Boolean,
      default: void 0
    },
    defaultCollapsed: {
      type: Boolean
    },
    collapsible: {
      type: Boolean
    },
    width: {
      type: Number,
      default: 200
    },
    collapsedWidth: {
      type: Number,
      default: 48
    },
    reverseArrow: {
      type: Boolean
    },
    breakpoint: {
      type: String
    },
    resizeDirections: {
      type: Array,
      default: void 0
    },
    hideTrigger: {
      type: Boolean
    }
  },
  emits: [
    "collapse",
    "update:collapsed",
    "breakpoint"
  ],
  setup(e, {
    emit: t
  }) {
    const {
      theme: n,
      collapsed: o,
      defaultCollapsed: i,
      collapsible: r,
      hideTrigger: l,
      breakpoint: s,
      collapsedWidth: u,
      resizeDirections: f
    } = ve(e), [d, p] = Vt(i.value, me({
      value: o
    })), h = a(() => f.value ? "ResizeBox" : "div"), k = a(() => r.value && !l.value), y = B("layout-sider"), w = a(() => [y, {
      [`${y}-light`]: n.value === "light",
      [`${y}-has-trigger`]: k.value,
      [`${y}-collapsed`]: o.value
    }]), g = a(() => {
      const {
        width: I,
        collapsedWidth: L
      } = e, M = d.value ? L : I;
      return A(M) ? `${M}px` : String(M);
    }), C = a(() => [`${y}-trigger`, {
      [`${y}-trigger-light`]: n.value === "light"
    }]), P = () => {
      const I = !d.value;
      p(I), t("update:collapsed", I), t("collapse", I, "clickTrigger");
    };
    Kh(s, (I) => {
      const L = !I;
      L !== d.value && (p(L), t("update:collapsed", L), t("collapse", L, "responsive"), t("breakpoint", L));
    });
    const z = x6("__arco_layout_sider"), j = Ge(Fh, void 0);
    return Je(() => {
      var I;
      (I = j == null ? void 0 : j.onSiderMount) == null || I.call(j, z);
    }), Zt(() => {
      var I;
      (I = j == null ? void 0 : j.onSiderUnMount) == null || I.call(j, z);
    }), it(Dh, me({
      theme: n,
      collapsed: d,
      collapsedWidth: u
    })), {
      componentTag: h,
      prefixCls: y,
      classNames: w,
      triggerClassNames: C,
      localCollapsed: d,
      siderWidth: g,
      showTrigger: k,
      toggleTrigger: P
    };
  }
});
const H6 = { key: 0 }, q6 = { key: 1 };
function Z6(e, t, n, o, i, r) {
  const l = J("IconLeft"), s = J("IconRight");
  return v(), oe(sn(e.componentTag), se({
    class: e.classNames,
    style: { width: e.siderWidth }
  }, e.resizeDirections ? { directions: e.resizeDirections } : {}), {
    default: ue(() => [
      $("div", {
        class: m(`${e.prefixCls}-children`)
      }, [
        _(e.$slots, "default")
      ], 2),
      e.showTrigger ? (v(), b("div", {
        key: 0,
        class: m(e.triggerClassNames),
        style: F({ width: e.siderWidth }),
        onClick: t[0] || (t[0] = (...u) => e.toggleTrigger && e.toggleTrigger(...u))
      }, [
        _(e.$slots, "trigger", { collapsed: e.localCollapsed }, () => [
          e.reverseArrow ? (v(), b("div", q6, [
            e.localCollapsed ? (v(), oe(l, { key: 0 })) : (v(), oe(s, { key: 1 }))
          ])) : (v(), b("div", H6, [
            e.localCollapsed ? (v(), oe(s, { key: 1 })) : (v(), oe(l, { key: 0 }))
          ]))
        ])
      ], 6)) : te("v-if", !0)
    ]),
    _: 3
  }, 16, ["class", "style"]);
}
var Hi = /* @__PURE__ */ N(R6, [["render", Z6]]);
const K6 = Object.assign(js, {
  Header: Di,
  Content: xi,
  Footer: Ri,
  Sider: Hi,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + js.name, js), e.component(n + Di.name, Di), e.component(n + xi.name, xi), e.component(n + Ri.name, Ri), e.component(n + Hi.name, Hi);
  }
}), Y6 = S({
  name: "Pager",
  props: {
    pageNumber: {
      type: Number
    },
    current: {
      type: Number
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    style: {
      type: Object
    },
    activeStyle: {
      type: Object
    }
  },
  emits: ["click"],
  setup(e, { emit: t }) {
    const n = B("pagination-item"), o = a(() => e.current === e.pageNumber), i = (s) => {
      e.disabled || t("click", e.pageNumber, s);
    }, r = a(() => [
      n,
      {
        [`${n}-active`]: o.value
      }
    ]), l = a(() => o.value ? e.activeStyle : e.style);
    return {
      prefixCls: n,
      cls: r,
      mergedStyle: l,
      handleClick: i
    };
  }
});
function U6(e, t, n, o, i, r) {
  return v(), b("li", {
    class: m(e.cls),
    style: F(e.mergedStyle),
    onClick: t[0] || (t[0] = (...l) => e.handleClick && e.handleClick(...l))
  }, [
    _(e.$slots, "default", { page: e.pageNumber }, () => [
      Re(Pe(e.pageNumber), 1)
    ])
  ], 6);
}
var G6 = /* @__PURE__ */ N(Y6, [["render", U6]]);
const Yh = (e, { min: t, max: n }) => e < t ? t : e > n ? n : e, X6 = S({
  name: "StepPager",
  components: {
    IconLeft: xn,
    IconRight: bn
  },
  props: {
    pages: {
      type: Number,
      required: !0
    },
    current: {
      type: Number,
      required: !0
    },
    type: {
      type: String,
      required: !0
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    simple: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["click"],
  setup(e, { emit: t }) {
    const n = B("pagination-item"), o = e.type === "next", i = a(() => e.disabled ? e.disabled : !e.pages || o && e.current === e.pages ? !0 : !o && e.current <= 1), r = a(
      () => Yh(e.current + (o ? 1 : -1), {
        min: 1,
        max: e.pages
      })
    ), l = (u) => {
      i.value || t("click", r.value);
    }, s = a(() => [
      n,
      `${n}-${e.type}`,
      {
        [`${n}-disabled`]: i.value
      }
    ]);
    return {
      prefixCls: n,
      cls: s,
      isNext: o,
      handleClick: l
    };
  }
});
function Q6(e, t, n, o, i, r) {
  const l = J("icon-right"), s = J("icon-left");
  return v(), oe(sn(e.simple ? "span" : "li"), {
    class: m(e.cls),
    onClick: e.handleClick
  }, {
    default: ue(() => [
      _(e.$slots, "default", {
        type: e.isNext ? "next" : "previous"
      }, () => [
        e.isNext ? (v(), oe(l, { key: 0 })) : (v(), oe(s, { key: 1 }))
      ])
    ]),
    _: 3
  }, 8, ["class", "onClick"]);
}
var hp = /* @__PURE__ */ N(X6, [["render", Q6]]);
const _6 = S({
  name: "EllipsisPager",
  components: {
    IconMore: Vr
  },
  props: {
    current: {
      type: Number,
      required: !0
    },
    step: {
      type: Number,
      default: 5
    },
    pages: {
      type: Number,
      required: !0
    }
  },
  emits: ["click"],
  setup(e, { emit: t }) {
    const n = B("pagination-item"), o = a(
      () => Yh(e.current + e.step, {
        min: 1,
        max: e.pages
      })
    ), i = (l) => {
      t("click", o.value);
    }, r = a(() => [n, `${n}-ellipsis`]);
    return {
      prefixCls: n,
      cls: r,
      handleClick: i
    };
  }
});
function J6(e, t, n, o, i, r) {
  const l = J("icon-more");
  return v(), b("li", {
    class: m(e.cls),
    onClick: t[0] || (t[0] = (...s) => e.handleClick && e.handleClick(...s))
  }, [
    _(e.$slots, "default", {}, () => [
      c(l)
    ])
  ], 2);
}
var e8 = /* @__PURE__ */ N(_6, [["render", J6]]);
const t8 = S({
  name: "PageJumper",
  components: {
    InputNumber: Vo
  },
  props: {
    current: {
      type: Number,
      required: !0
    },
    simple: {
      type: Boolean,
      default: !1
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    pages: {
      type: Number,
      required: !0
    },
    size: {
      type: String
    },
    onChange: {
      type: Function
    }
  },
  emits: ["change"],
  setup(e, { emit: t }) {
    const n = B("pagination-jumper"), { t: o } = gt(), i = V(e.simple ? e.current : void 0), r = (u) => {
      const f = parseInt(u.toString(), 10);
      return Number.isNaN(f) ? void 0 : String(f);
    }, l = (u) => {
      t("change", i.value), at(() => {
        e.simple || (i.value = void 0);
      });
    };
    ze(
      () => e.current,
      (u) => {
        e.simple && u !== i.value && (i.value = u);
      }
    );
    const s = a(() => [
      n,
      {
        [`${n}-simple`]: e.simple
      }
    ]);
    return {
      prefixCls: n,
      cls: s,
      t: o,
      inputValue: i,
      handleChange: l,
      handleFormatter: r
    };
  }
});
function n8(e, t, n, o, i, r) {
  const l = J("input-number");
  return v(), b("span", {
    class: m(e.cls)
  }, [
    e.simple ? te("v-if", !0) : (v(), b("span", {
      key: 0,
      class: m([`${e.prefixCls}-prepend`, `${e.prefixCls}-text-goto`])
    }, [
      _(e.$slots, "jumper-prepend", {}, () => [
        Re(Pe(e.t("pagination.goto")), 1)
      ])
    ], 2)),
    c(l, {
      modelValue: e.inputValue,
      "onUpdate:modelValue": t[0] || (t[0] = (s) => e.inputValue = s),
      class: m(`${e.prefixCls}-input`),
      min: 1,
      max: e.pages,
      size: e.size,
      disabled: e.disabled,
      "hide-button": "",
      formatter: e.handleFormatter,
      onChange: e.handleChange
    }, null, 8, ["modelValue", "class", "max", "size", "disabled", "formatter", "onChange"]),
    e.$slots["jumper-append"] ? (v(), b("span", {
      key: 1,
      class: m(`${e.prefixCls}-append`)
    }, [
      _(e.$slots, "jumper-append")
    ], 2)) : te("v-if", !0),
    e.simple ? (v(), b(Ae, { key: 2 }, [
      $("span", {
        class: m(`${e.prefixCls}-separator`)
      }, "/", 2),
      $("span", {
        class: m(`${e.prefixCls}-total-page`)
      }, Pe(e.pages), 3)
    ], 64)) : te("v-if", !0)
  ], 2);
}
var kp = /* @__PURE__ */ N(t8, [["render", n8]]);
const l8 = S({
  name: "PageOptions",
  components: {
    ArcoSelect: zo
  },
  props: {
    sizeOptions: {
      type: Array,
      required: !0
    },
    pageSize: Number,
    disabled: Boolean,
    size: {
      type: String
    },
    onChange: {
      type: Function
    },
    selectProps: {
      type: Object
    }
  },
  emits: ["change"],
  setup(e, { emit: t }) {
    const n = B("pagination-options"), { t: o } = gt(), i = a(
      () => e.sizeOptions.map((l) => ({
        value: l,
        label: `${l} ${o("pagination.countPerPage")}`
      }))
    );
    return {
      prefixCls: n,
      options: i,
      handleChange: (l) => {
        t("change", l);
      }
    };
  }
});
function o8(e, t, n, o, i, r) {
  const l = J("arco-select");
  return v(), b("span", {
    class: m(e.prefixCls)
  }, [
    c(l, se({
      "model-value": e.pageSize,
      options: e.options,
      size: e.size,
      disabled: e.disabled
    }, e.selectProps, { onChange: e.handleChange }), null, 16, ["model-value", "options", "size", "disabled", "onChange"])
  ], 2);
}
var i8 = /* @__PURE__ */ N(l8, [["render", o8]]), Ns = S({
  name: "Pagination",
  props: {
    total: {
      type: Number,
      required: !0
    },
    current: Number,
    defaultCurrent: {
      type: Number,
      default: 1
    },
    pageSize: Number,
    defaultPageSize: {
      type: Number,
      default: 10
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    hideOnSinglePage: {
      type: Boolean,
      default: !1
    },
    simple: {
      type: Boolean,
      default: !1
    },
    showTotal: {
      type: Boolean,
      default: !1
    },
    showMore: {
      type: Boolean,
      default: !1
    },
    showJumper: {
      type: Boolean,
      default: !1
    },
    showPageSize: {
      type: Boolean,
      default: !1
    },
    pageSizeOptions: {
      type: Array,
      default: () => [10, 20, 30, 40, 50]
    },
    pageSizeProps: {
      type: Object
    },
    size: {
      type: String
    },
    pageItemStyle: {
      type: Object
    },
    activePageItemStyle: {
      type: Object
    },
    baseSize: {
      type: Number,
      default: 6
    },
    bufferSize: {
      type: Number,
      default: 2
    },
    autoAdjust: {
      type: Boolean,
      default: !0
    }
  },
  emits: {
    "update:current": (e) => !0,
    "update:pageSize": (e) => !0,
    change: (e) => !0,
    pageSizeChange: (e) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const o = B("pagination"), {
      t: i
    } = gt(), {
      disabled: r,
      pageItemStyle: l,
      activePageItemStyle: s,
      size: u
    } = ve(e), {
      mergedSize: f
    } = xt(u), d = V(e.defaultCurrent), p = V(e.defaultPageSize), h = a(() => {
      var L;
      return (L = e.current) != null ? L : d.value;
    }), k = a(() => {
      var L;
      return (L = e.pageSize) != null ? L : p.value;
    }), y = a(() => Math.ceil(e.total / k.value)), w = (L) => {
      L !== h.value && A(L) && !e.disabled && (d.value = L, t("update:current", L), t("change", L));
    }, g = (L) => {
      p.value = L, t("update:pageSize", L), t("pageSizeChange", L);
    }, C = me({
      current: h,
      pages: y,
      disabled: r,
      style: l,
      activeStyle: s,
      onClick: w
    }), P = (L, M = {}) => L === "more" ? c(e8, se(M, C), {
      default: n["page-item-ellipsis"]
    }) : L === "previous" ? c(hp, se({
      type: "previous"
    }, M, C), {
      default: n["page-item-step"]
    }) : L === "next" ? c(hp, se({
      type: "next"
    }, M, C), {
      default: n["page-item-step"]
    }) : c(G6, se(M, C), {
      default: n["page-item"]
    }), z = a(() => {
      const L = [];
      if (y.value < e.baseSize + e.bufferSize * 2)
        for (let M = 1; M <= y.value; M++)
          L.push(P("page", {
            key: M,
            pageNumber: M
          }));
      else {
        let M = 1, E = y.value, K = !1, q = !1;
        h.value > 2 + e.bufferSize && (K = !0, M = Math.min(h.value - e.bufferSize, y.value - 2 * e.bufferSize)), h.value < y.value - (e.bufferSize + 1) && (q = !0, E = Math.max(h.value + e.bufferSize, 2 * e.bufferSize + 1)), K && (L.push(P("page", {
          key: 1,
          pageNumber: 1
        })), L.push(P("more", {
          key: "left-ellipsis-pager",
          step: -(e.bufferSize * 2 + 1)
        })));
        for (let T = M; T <= E; T++)
          L.push(P("page", {
            key: T,
            pageNumber: T
          }));
        q && (L.push(P("more", {
          key: "right-ellipsis-pager",
          step: e.bufferSize * 2 + 1
        })), L.push(P("page", {
          key: y.value,
          pageNumber: y.value
        })));
      }
      return L;
    }), j = () => e.simple ? c("span", {
      class: `${o}-simple`
    }, [P("previous", {
      simple: !0
    }), c(kp, {
      disabled: e.disabled,
      current: h.value,
      size: f.value,
      pages: y.value,
      simple: !0,
      onChange: w
    }, null), P("next", {
      simple: !0
    })]) : c("ul", {
      class: `${o}-list`
    }, [P("previous", {
      simple: !0
    }), z.value, e.showMore && P("more", {
      key: "more",
      step: e.bufferSize * 2 + 1
    }), P("next", {
      simple: !0
    })]);
    ze(k, (L, M) => {
      if (e.autoAdjust && L !== M && h.value > 1) {
        const E = M * (h.value - 1) + 1, K = Math.ceil(E / L);
        K !== h.value && (d.value = K, t("update:current", K), t("change", K));
      }
    }), ze(y, (L, M) => {
      if (e.autoAdjust && L !== M && h.value > 1 && h.value > L) {
        const E = Math.max(L, 1);
        d.value = E, t("update:current", E), t("change", E);
      }
    });
    const I = a(() => [o, `${o}-size-${f.value}`, {
      [`${o}-simple`]: e.simple,
      [`${o}-disabled`]: e.disabled
    }]);
    return () => {
      var L, M;
      return e.hideOnSinglePage && y.value <= 1 ? null : c("div", {
        class: I.value
      }, [e.showTotal && c("span", {
        class: `${o}-total`
      }, [(M = (L = n.total) == null ? void 0 : L.call(n, {
        total: e.total
      })) != null ? M : i("pagination.total", e.total)]), j(), e.showPageSize && c(i8, {
        disabled: e.disabled,
        sizeOptions: e.pageSizeOptions,
        pageSize: k.value,
        size: f.value,
        onChange: g,
        selectProps: e.pageSizeProps
      }, null), !e.simple && e.showJumper && c(kp, {
        disabled: e.disabled,
        current: h.value,
        pages: y.value,
        size: f.value,
        onChange: w
      }, {
        "jumper-prepend": n["jumper-prepend"],
        "jumper-append": n["jumper-append"]
      })]);
    };
  }
});
const e0 = Object.assign(Ns, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ns.name, Ns);
  }
}), r8 = (e, { emit: t }) => {
  var n, o;
  const i = V(
    Qe(e.paginationProps) && (n = e.paginationProps.defaultCurrent) != null ? n : 1
  ), r = V(
    Qe(e.paginationProps) && (o = e.paginationProps.defaultPageSize) != null ? o : 10
  ), l = a(
    () => {
      var d;
      return Qe(e.paginationProps) && (d = e.paginationProps.current) != null ? d : i.value;
    }
  ), s = a(
    () => {
      var d;
      return Qe(e.paginationProps) && (d = e.paginationProps.pageSize) != null ? d : r.value;
    }
  );
  return {
    current: l,
    pageSize: s,
    handlePageChange: (d) => {
      i.value = d, t("pageChange", d);
    },
    handlePageSizeChange: (d) => {
      r.value = d, t("pageSizeChange", d);
    }
  };
};
function gp(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var Os = S({
  name: "List",
  props: {
    data: {
      type: Array
    },
    size: {
      type: String,
      default: "medium"
    },
    bordered: {
      type: Boolean,
      default: !0
    },
    split: {
      type: Boolean,
      default: !0
    },
    loading: {
      type: Boolean,
      default: !1
    },
    hoverable: {
      type: Boolean,
      default: !1
    },
    paginationProps: {
      type: Object
    },
    gridProps: {
      type: Object
    },
    maxHeight: {
      type: [String, Number],
      default: 0
    },
    bottomOffset: {
      type: Number,
      default: 0
    },
    virtualListProps: {
      type: Object
    },
    scrollbar: {
      type: [Object, Boolean],
      default: !0
    }
  },
  emits: {
    scroll: () => !0,
    reachBottom: () => !0,
    pageChange: (e) => !0,
    pageSizeChange: (e) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      scrollbar: o
    } = ve(e), i = B("list"), r = Ge(Kt, void 0), {
      componentRef: l,
      elementRef: s
    } = Wl("containerRef"), u = a(() => e.virtualListProps), {
      displayScrollbar: f,
      scrollbarProps: d
    } = Br(o);
    let p = 0;
    const h = (Z) => {
      const {
        scrollTop: U,
        scrollHeight: H,
        offsetHeight: D
      } = Z.target, R = Math.floor(H - (U + D));
      U > p && R <= e.bottomOffset && t("reachBottom"), t("scroll"), p = U;
    };
    Je(() => {
      if (s.value) {
        const {
          scrollTop: Z,
          scrollHeight: U,
          offsetHeight: H
        } = s.value;
        U <= Z + H && t("reachBottom");
      }
    });
    const {
      current: k,
      pageSize: y,
      handlePageChange: w,
      handlePageSizeChange: g
    } = r8(e, {
      emit: t
    }), C = (Z) => {
      if (!e.paginationProps)
        return Z;
      if (e.paginationProps && Z.length > y.value) {
        const U = (k.value - 1) * y.value;
        return Z.slice(U, U + y.value);
      }
      return Z;
    }, P = (Z) => {
      let U;
      if (!e.gridProps)
        return null;
      const H = C(Z);
      if (e.gridProps.span) {
        const D = [], R = 24 / e.gridProps.span;
        for (let W = 0; W < H.length; W += R) {
          let O;
          const x = W + R, G = Math.floor(W / R);
          D.push(c(uo.Row, {
            key: G,
            class: `${i}-row`,
            gutter: e.gridProps.gutter
          }, gp(O = H.slice(W, x).map((ne, ee) => {
            var Q;
            return c(uo.Col, {
              key: `${G}-${ee}`,
              class: `${i}-col`,
              span: (Q = e.gridProps) == null ? void 0 : Q.span
            }, {
              default: () => {
                var ae;
                return [Ct(ne) ? ne : (ae = n.item) == null ? void 0 : ae.call(n, {
                  item: ne,
                  index: ee
                })];
              }
            });
          })) ? O : {
            default: () => [O]
          }));
        }
        return D;
      }
      return c(uo.Row, {
        class: `${i}-row`,
        gutter: e.gridProps.gutter
      }, gp(U = H.map((D, R) => c(uo.Col, se({
        key: R,
        class: `${i}-col`
      }, Ft(e.gridProps, ["gutter"])), {
        default: () => {
          var W;
          return [Ct(D) ? D : (W = n.item) == null ? void 0 : W.call(n, {
            item: D,
            index: R
          })];
        }
      }))) ? U : {
        default: () => [U]
      });
    }, z = (Z) => C(Z).map((H, D) => {
      var R;
      return Ct(H) ? H : (R = n.item) == null ? void 0 : R.call(n, {
        item: H,
        index: D
      });
    }), j = () => {
      const Z = n.default ? En(n.default()) : e.data;
      return Z && Z.length > 0 ? e.gridProps ? P(Z) : z(Z) : X();
    }, I = () => {
      if (!e.paginationProps)
        return null;
      const Z = Ft(e.paginationProps, ["current", "pageSize", "defaultCurrent", "defaultPageSize"]);
      return c(e0, se({
        class: `${i}-pagination`
      }, Z, {
        current: k.value,
        pageSize: y.value,
        onChange: w,
        onPageSizeChange: g
      }), null);
    }, L = a(() => [i, `${i}-${e.size}`, {
      [`${i}-bordered`]: e.bordered,
      [`${i}-split`]: e.split,
      [`${i}-hover`]: e.hoverable
    }]), M = a(() => {
      if (e.maxHeight)
        return {
          maxHeight: A(e.maxHeight) ? `${e.maxHeight}px` : e.maxHeight,
          overflowY: "auto"
        };
    }), E = a(() => [`${i}-content`, {
      [`${i}-virtual`]: u.value
    }]), K = V(), q = () => {
      var Z;
      const U = C((Z = e.data) != null ? Z : []);
      return U.length ? c(Jl, se({
        ref: K,
        class: E.value,
        data: U
      }, e.virtualListProps, {
        onScroll: h
      }), {
        item: ({
          item: H,
          index: D
        }) => {
          var R;
          return (R = n.item) == null ? void 0 : R.call(n, {
            item: H,
            index: D
          });
        }
      }) : X();
    }, T = () => n["scroll-loading"] ? c("div", {
      class: [`${i}-item`, `${i}-scroll-loading`]
    }, [n["scroll-loading"]()]) : null, X = () => {
      var Z, U, H, D, R;
      return n["scroll-loading"] ? null : (R = (D = (Z = n.empty) == null ? void 0 : Z.call(n)) != null ? D : (H = r == null ? void 0 : (U = r.slots).empty) == null ? void 0 : H.call(U, {
        component: "list"
      })) != null ? R : c(Gn, null, null);
    };
    return {
      virtualListRef: K,
      render: () => {
        const Z = f.value ? In : "div";
        return c("div", {
          class: `${i}-wrapper`
        }, [c(Pn, {
          class: `${i}-spin`,
          loading: e.loading
        }, {
          default: () => [c(Z, se({
            ref: l,
            class: L.value,
            style: M.value
          }, d.value, {
            onScroll: h
          }), {
            default: () => [c("div", {
              class: `${i}-content-wrapper`
            }, [n.header && c("div", {
              class: `${i}-header`
            }, [n.header()]), u.value && !e.gridProps ? c(Ae, null, [q(), T()]) : c("div", {
              role: "list",
              class: E.value
            }, [j(), T()]), n.footer && c("div", {
              class: `${i}-footer`
            }, [n.footer()])])]
          }), I()]
        })]);
      }
    };
  },
  methods: {
    scrollIntoView(e) {
      this.virtualListRef && this.virtualListRef.scrollTo(e);
    }
  },
  render() {
    return this.render();
  }
}), qi = S({
  name: "ListItem",
  props: {
    actionLayout: {
      type: String,
      default: "horizontal"
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("list-item"), o = () => {
      var i;
      const r = (i = t.actions) == null ? void 0 : i.call(t);
      return !r || !r.length ? null : c("ul", {
        class: `${n}-action`
      }, [r.map((l, s) => c("li", {
        key: `${n}-action-${s}`
      }, [l]))]);
    };
    return () => {
      var i, r;
      return c("div", {
        role: "listitem",
        class: n
      }, [c("div", {
        class: `${n}-main`
      }, [(i = t.meta) == null ? void 0 : i.call(t), c("div", {
        class: `${n}-content`
      }, [(r = t.default) == null ? void 0 : r.call(t)]), e.actionLayout === "vertical" && o()]), e.actionLayout === "horizontal" && o(), t.extra && c("div", {
        class: `${n}-extra`
      }, [t.extra()])]);
    };
  }
});
const a8 = S({
  name: "ListItemMeta",
  props: {
    title: String,
    description: String
  },
  setup(e, { slots: t }) {
    const n = B("list-item-meta"), o = !!(e.title || e.description || t.title || t.description);
    return {
      prefixCls: n,
      hasContent: o
    };
  }
});
function s8(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    e.$slots.avatar ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-avatar`)
    }, [
      _(e.$slots, "avatar")
    ], 2)) : te("v-if", !0),
    e.hasContent ? (v(), b("div", {
      key: 1,
      class: m(`${e.prefixCls}-content`)
    }, [
      e.$slots.title || e.title ? (v(), b("div", {
        key: 0,
        class: m(`${e.prefixCls}-title`)
      }, [
        _(e.$slots, "title", {}, () => [
          Re(Pe(e.title), 1)
        ])
      ], 2)) : te("v-if", !0),
      e.$slots.description || e.description ? (v(), b("div", {
        key: 1,
        class: m(`${e.prefixCls}-description`)
      }, [
        _(e.$slots, "description", {}, () => [
          Re(Pe(e.description), 1)
        ])
      ], 2)) : te("v-if", !0)
    ], 2)) : te("v-if", !0)
  ], 2);
}
var Zi = /* @__PURE__ */ N(a8, [["render", s8]]);
const Uh = Object.assign(Os, {
  Item: Object.assign(qi, {
    Meta: Zi
  }),
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Os.name, Os), e.component(n + qi.name, qi), e.component(n + Zi.name, Zi);
  }
}), u8 = [
  "border-width",
  "box-sizing",
  "font-family",
  "font-weight",
  "font-size",
  "font-variant",
  "letter-spacing",
  "line-height",
  "padding-top",
  "padding-bottom",
  "padding-left",
  "padding-right",
  "text-indent",
  "text-rendering",
  "text-transform",
  "white-space",
  "overflow-wrap",
  "width"
], dv = (e) => {
  const t = {};
  return u8.forEach((n) => {
    t[n] = e.getPropertyValue(n);
  }), t;
}, c8 = S({
  name: "Textarea",
  components: { ResizeObserver: jn, IconHover: pt, IconClose: Dt },
  inheritAttrs: !1,
  props: {
    modelValue: String,
    defaultValue: {
      type: String,
      default: ""
    },
    placeholder: String,
    disabled: {
      type: Boolean,
      default: !1
    },
    error: {
      type: Boolean,
      default: !1
    },
    maxLength: {
      type: [Number, Object],
      default: 0
    },
    showWordLimit: {
      type: Boolean,
      default: !1
    },
    allowClear: {
      type: Boolean,
      default: !1
    },
    autoSize: {
      type: [Boolean, Object],
      default: !1
    },
    wordLength: {
      type: Function
    },
    wordSlice: {
      type: Function
    },
    textareaAttrs: {
      type: Object
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    input: (e, t) => !0,
    change: (e, t) => !0,
    clear: (e) => !0,
    focus: (e) => !0,
    blur: (e) => !0
  },
  setup(e, { emit: t, attrs: n }) {
    const { disabled: o, error: i, modelValue: r } = ve(e), l = B("textarea"), {
      mergedDisabled: s,
      mergedError: u,
      eventHandlers: f
    } = mt({ disabled: o, error: i }), d = V(), p = V(), h = V(), k = V(), y = V(e.defaultValue), w = a(() => {
      var re;
      return (re = r.value) != null ? re : y.value;
    }), [g, C] = cm(d);
    ze(r, (re) => {
      (Ve(re) || Jt(re)) && (y.value = "");
    });
    const P = a(
      () => Qe(e.maxLength) && !!e.maxLength.errorOnly
    ), z = a(() => Qe(e.maxLength) ? e.maxLength.length : e.maxLength), j = (re) => {
      var fe;
      return Ne(e.wordLength) ? e.wordLength(re) : (fe = re.length) != null ? fe : 0;
    }, I = a(() => j(w.value)), L = a(
      () => u.value || !!(z.value && P.value && I.value > z.value)
    ), M = V(!1), E = V(!1), K = a(
      () => e.allowClear && !s.value && w.value
    ), q = V(!1), T = V(""), X = () => {
      g(), at(() => {
        d.value && w.value !== d.value.value && (d.value.value = w.value, C());
      });
    }, Y = (re, fe = !0) => {
      var Oe, Be;
      z.value && !P.value && j(re) > z.value && (re = (Be = (Oe = e.wordSlice) == null ? void 0 : Oe.call(e, re, z.value)) != null ? Be : re.slice(0, z.value)), y.value = re, fe && t("update:modelValue", re), X();
    };
    let Z = w.value;
    const U = (re, fe) => {
      var Oe, Be;
      re !== Z && (Z = re, t("change", re, fe), (Be = (Oe = f.value) == null ? void 0 : Oe.onChange) == null || Be.call(Oe, fe));
    }, H = (re) => {
      var fe, Oe;
      E.value = !0, Z = w.value, t("focus", re), (Oe = (fe = f.value) == null ? void 0 : fe.onFocus) == null || Oe.call(fe, re);
    }, D = (re) => {
      var fe, Oe;
      E.value = !1, t("blur", re), (Oe = (fe = f.value) == null ? void 0 : fe.onBlur) == null || Oe.call(fe, re), U(w.value, re);
    }, R = (re) => {
      var fe, Oe;
      const { value: Be } = re.target;
      if (re.type === "compositionend") {
        if (q.value = !1, T.value = "", z.value && !P.value && w.value.length >= z.value && j(Be) > z.value) {
          X();
          return;
        }
        t("input", Be, re), Y(Be), (Oe = (fe = f.value) == null ? void 0 : fe.onInput) == null || Oe.call(fe, re);
      } else
        q.value = !0;
    }, W = (re) => {
      var fe, Oe;
      const { value: Be } = re.target;
      if (q.value)
        T.value = Be;
      else {
        if (z.value && !P.value && w.value.length >= z.value && j(Be) > z.value && re.inputType === "insertText") {
          X();
          return;
        }
        t("input", Be, re), Y(Be), (Oe = (fe = f.value) == null ? void 0 : fe.onInput) == null || Oe.call(fe, re);
      }
    }, O = (re) => {
      Y(""), U("", re), t("clear", re);
    };
    ze(r, (re) => {
      re !== w.value && Y(re ?? "", !1);
    });
    const x = (re) => Ft(n, rl), G = (re) => Wn(n, rl), ne = G(), ee = a(() => {
      const re = {
        ...ne,
        ...e.textareaAttrs
      };
      return L.value && (re["aria-invalid"] = !0), re;
    }), Q = a(() => [
      `${l}-wrapper`,
      {
        [`${l}-focus`]: E.value,
        [`${l}-disabled`]: s.value,
        [`${l}-error`]: L.value,
        [`${l}-scroll`]: M.value
      }
    ]);
    let ae;
    const ge = V(0), Se = V(0), be = a(() => !Qe(e.autoSize) || !e.autoSize.minRows ? 0 : e.autoSize.minRows * ge.value + Se.value), Le = a(() => !Qe(e.autoSize) || !e.autoSize.maxRows ? 0 : e.autoSize.maxRows * ge.value + Se.value), pe = () => {
      const re = dv(ae);
      ge.value = Number.parseInt(re["line-height"] || 0, 10), Se.value = Number.parseInt(re["border-width"] || 0, 10) * 2 + Number.parseInt(re["padding-top"] || 0, 10) + Number.parseInt(re["padding-bottom"] || 0, 10), k.value = re, at(() => {
        var fe;
        const Oe = (fe = h.value) == null ? void 0 : fe.offsetHeight;
        let Be = Oe ?? 0, $e = "hidden";
        be.value && Be < be.value && (Be = be.value), Le.value && Be > Le.value && (Be = Le.value, $e = "auto"), p.value = {
          height: `${Be}px`,
          resize: "none",
          overflow: $e
        };
      });
    };
    Je(() => {
      d.value && (ae = window.getComputedStyle(d.value), e.autoSize && pe()), le();
    });
    const Me = () => {
      e.autoSize && h.value && pe(), le();
    }, ke = (re) => {
      d.value && re.target !== d.value && (re.preventDefault(), d.value.focus());
    }, le = () => {
      d.value && (d.value.scrollHeight > d.value.offsetHeight ? M.value || (M.value = !0) : M.value && (M.value = !1));
    };
    return ze(w, () => {
      e.autoSize && h.value && pe(), le();
    }), {
      prefixCls: l,
      wrapperCls: Q,
      textareaRef: d,
      textareaStyle: p,
      mirrorRef: h,
      mirrorStyle: k,
      computedValue: w,
      showClearBtn: K,
      valueLength: I,
      computedMaxLength: z,
      mergedDisabled: s,
      mergeTextareaAttrs: ee,
      getWrapperAttrs: x,
      getTextareaAttrs: G,
      handleInput: W,
      handleFocus: H,
      handleBlur: D,
      handleComposition: R,
      handleClear: O,
      handleResize: Me,
      handleMousedown: ke
    };
  },
  methods: {
    focus() {
      var e;
      (e = this.$refs.textareaRef) == null || e.focus();
    },
    blur() {
      var e;
      (e = this.$refs.textareaRef) == null || e.blur();
    }
  }
}), d8 = ["disabled", "value", "placeholder"];
function f8(e, t, n, o, i, r) {
  const l = J("resize-observer"), s = J("icon-close"), u = J("icon-hover");
  return v(), b("div", se(e.getWrapperAttrs(e.$attrs), {
    class: e.wrapperCls,
    onMousedown: t[7] || (t[7] = (...f) => e.handleMousedown && e.handleMousedown(...f))
  }), [
    e.autoSize ? (v(), b("div", {
      key: 0,
      ref: "mirrorRef",
      class: m(`${e.prefixCls}-mirror`),
      style: F(e.mirrorStyle)
    }, Pe(`${e.computedValue}
`), 7)) : te("v-if", !0),
    c(l, { onResize: e.handleResize }, {
      default: ue(() => [
        $("textarea", se({ ref: "textareaRef" }, e.mergeTextareaAttrs, {
          disabled: e.mergedDisabled,
          class: e.prefixCls,
          style: e.textareaStyle,
          value: e.computedValue,
          placeholder: e.placeholder,
          onInput: t[0] || (t[0] = (...f) => e.handleInput && e.handleInput(...f)),
          onFocus: t[1] || (t[1] = (...f) => e.handleFocus && e.handleFocus(...f)),
          onBlur: t[2] || (t[2] = (...f) => e.handleBlur && e.handleBlur(...f)),
          onCompositionstart: t[3] || (t[3] = (...f) => e.handleComposition && e.handleComposition(...f)),
          onCompositionupdate: t[4] || (t[4] = (...f) => e.handleComposition && e.handleComposition(...f)),
          onCompositionend: t[5] || (t[5] = (...f) => e.handleComposition && e.handleComposition(...f))
        }), null, 16, d8)
      ]),
      _: 1
    }, 8, ["onResize"]),
    _(e.$slots, "suffix"),
    e.computedMaxLength && e.showWordLimit ? (v(), b("div", {
      key: 1,
      class: m(`${e.prefixCls}-word-limit`)
    }, Pe(e.valueLength) + "/" + Pe(e.computedMaxLength), 3)) : te("v-if", !0),
    e.showClearBtn ? (v(), b("div", {
      key: 2,
      class: m(`${e.prefixCls}-clear-btn`),
      onClick: t[6] || (t[6] = (...f) => e.handleClear && e.handleClear(...f))
    }, [
      c(u, null, {
        default: ue(() => [
          c(s)
        ]),
        _: 1
      })
    ], 2)) : te("v-if", !0)
  ], 16);
}
var Vs = /* @__PURE__ */ N(c8, [["render", f8]]);
const Gh = Object.assign(Vs, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Vs.name, Vs);
  }
}), v8 = (e) => {
  const { value: t, selectionStart: n } = e;
  return t.slice(0, n);
}, p8 = (e, t) => [].concat(t).reduce(
  (o, i) => {
    const r = e.lastIndexOf(i);
    return r > o.location ? {
      location: r,
      prefix: i
    } : o;
  },
  {
    location: -1,
    prefix: ""
  }
), m8 = (e, t) => !t || !e.includes(t);
function h8(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var Ts = S({
  name: "Mention",
  inheritAttrs: !1,
  props: {
    modelValue: String,
    defaultValue: {
      type: String,
      default: ""
    },
    data: {
      type: Array,
      default: () => []
    },
    prefix: {
      type: [String, Array],
      default: "@"
    },
    split: {
      type: String,
      default: " "
    },
    type: {
      type: String,
      default: "input"
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    allowClear: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0,
    search: (e, t) => !0,
    select: (e) => !0,
    clear: (e) => !0,
    focus: (e) => !0,
    blur: (e) => !0
  },
  setup(e, {
    emit: t,
    attrs: n,
    slots: o
  }) {
    const i = B("mention");
    let r;
    const {
      mergedDisabled: l,
      eventHandlers: s
    } = mt({
      disabled: un(e, "disabled")
    }), {
      data: u,
      modelValue: f
    } = ve(e), d = V(), p = V({}), h = V(e.defaultValue), k = a(() => {
      var ne;
      return (ne = e.modelValue) != null ? ne : h.value;
    });
    ze(f, (ne) => {
      (Ve(ne) || Jt(ne)) && (h.value = "");
    });
    const y = a(() => k.value ? [Sl(k.value)] : []), w = V({
      measuring: !1,
      location: -1,
      prefix: "",
      text: ""
    }), g = () => {
      w.value = {
        measuring: !1,
        location: -1,
        prefix: "",
        text: ""
      };
    }, C = V(), P = a(() => w.value.text), z = V(!0), j = (ne, ee) => {
      var Q, ae;
      const ge = v8(ee.target), Se = p8(ge, e.prefix);
      if (Se.location > -1) {
        const be = ge.slice(Se.location + Se.prefix.length);
        m8(be, e.split) ? (L.value = !0, w.value = {
          measuring: !0,
          text: be,
          ...Se
        }, t("search", be, Se.prefix)) : w.value.location > -1 && g();
      } else w.value.location > -1 && g();
      h.value = ne, t("update:modelValue", ne), t("change", ne), (ae = (Q = s.value) == null ? void 0 : Q.onChange) == null || ae.call(Q);
    }, I = (ne) => {
      var ee, Q;
      h.value = "", t("update:modelValue", ""), t("change", ""), (Q = (ee = s.value) == null ? void 0 : ee.onChange) == null || Q.call(ee), t("clear", ne);
    }, L = V(!1), M = a(() => L.value && w.value.measuring && Y.value.length > 0), E = () => {
      U.value = dv(r);
    }, K = (ne) => {
      L.value = ne;
    }, q = (ne, ee) => {
      var Q, ae, ge;
      const {
        value: Se
      } = (Q = X.get(ne)) != null ? Q : {}, be = w.value.location, Le = w.value.location + w.value.text.length;
      let pe = h.value.slice(0, be), Me = h.value.slice(Le + 1);
      pe += !pe || pe.endsWith(e.split) || pe.endsWith(`
`) ? "" : e.split, Me = (!Me || Me.startsWith(e.split) || Me.startsWith(`
`) ? "" : e.split) + Me;
      const ke = `${w.value.prefix}${Se}`, le = `${pe}${ke}${Me}`;
      h.value = le, t("select", Se), t("update:modelValue", le), t("change", le), g(), (ge = (ae = s.value) == null ? void 0 : ae.onChange) == null || ge.call(ae);
    }, {
      validOptions: T,
      optionInfoMap: X,
      validOptionInfos: Y,
      handleKeyDown: Z
    } = Vv({
      options: u,
      inputValue: P,
      filterOption: z,
      popupVisible: M,
      valueKeys: y,
      dropdownRef: d,
      optionRefs: p,
      onSelect: q,
      onPopupVisibleChange: K,
      enterToOpen: !1
    }), U = V();
    Je(() => {
      var ne;
      e.type === "textarea" && ((ne = C.value) != null && ne.textareaRef) && (r = window.getComputedStyle(C.value.textareaRef), U.value = dv(r));
    });
    const H = (ne) => {
      if (Ne(o.option) && ne.value) {
        const ee = X.get(ne.key), Q = o.option;
        return () => Q({
          data: ee
        });
      }
      return () => ne.label;
    }, D = (ne) => c(kl, {
      ref: (ee) => {
        ee != null && ee.$el && (p.value[ne.key] = ee.$el);
      },
      key: ne.key,
      value: ne.value,
      disabled: ne.disabled,
      internal: !0
    }, {
      default: H(ne)
    }), R = () => {
      let ne;
      return c(Ov, {
        ref: d
      }, h8(ne = T.value.map((ee) => D(ee))) ? ne : {
        default: () => [ne]
      });
    }, W = V();
    ze(M, (ne) => {
      e.type === "textarea" && ne && at(() => {
        var ee, Q;
        (ee = C.value) != null && ee.textareaRef && C.value.textareaRef.scrollTop > 0 && ((Q = W.value) == null || Q.scrollTo(0, C.value.textareaRef.scrollTop));
      });
    });
    const O = (ne) => {
      t("focus", ne);
    }, x = (ne) => {
      t("blur", ne);
    };
    return {
      inputRef: C,
      render: () => {
        var ne;
        return e.type === "textarea" ? c("div", {
          class: i
        }, [c(jn, {
          onResize: E
        }, {
          default: () => [c(Gh, se(n, {
            ref: C,
            allowClear: e.allowClear,
            modelValue: k.value,
            disabled: l.value,
            onInput: j,
            onClear: I,
            onFocus: O,
            onBlur: x,
            onKeydown: Z
          }), null)]
        }), w.value.measuring && Y.value.length > 0 && c("div", {
          ref: W,
          style: U.value,
          class: `${i}-measure`
        }, [(ne = k.value) == null ? void 0 : ne.slice(0, w.value.location), c(Tt, {
          trigger: "focus",
          position: "bl",
          popupOffset: 4,
          preventFocus: !0,
          popupVisible: M.value,
          clickToClose: !1,
          onPopupVisibleChange: K
        }, {
          default: () => [c("span", null, [Re("@")])],
          content: R
        })])]) : c(Tt, {
          trigger: "focus",
          position: "bl",
          animationName: "slide-dynamic-origin",
          popupOffset: 4,
          preventFocus: !0,
          popupVisible: M.value,
          clickToClose: !1,
          autoFitPopupWidth: !0,
          autoFitTransformOrigin: !0,
          disabled: l.value,
          onPopupVisibleChange: K
        }, {
          default: () => [c(cl, se(n, {
            ref: C,
            allowClear: e.allowClear,
            modelValue: k.value,
            disabled: l.value,
            onInput: j,
            onClear: I,
            onFocus: O,
            onBlur: x,
            onKeydown: Z
          }), o)],
          content: R
        });
      }
    };
  },
  methods: {
    focus() {
      var e;
      (e = this.inputRef) == null || e.focus();
    },
    blur() {
      var e;
      (e = this.inputRef) == null || e.blur();
    }
  },
  render() {
    return this.render();
  }
});
const k8 = Object.assign(Ts, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ts.name, Ts);
  }
}), t0 = Symbol("MenuInjectionKey"), n0 = Symbol("LevelInjectionKey"), Xh = Symbol("DataCollectorInjectionKey"), g8 = S({
  name: "IconMenuFold",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-menu-fold`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), y8 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function b8(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M42 11H6M42 24H22M42 37H6M13.66 26.912l-4.82-3.118 4.82-3.118v6.236Z" }, null, -1)
  ]), 14, y8);
}
var As = /* @__PURE__ */ N(g8, [["render", b8]]);
const Qh = Object.assign(As, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + As.name, As);
  }
}), C8 = S({
  name: "IconMenuUnfold",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-menu-unfold`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), $8 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function w8(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6 11h36M22 24h20M6 37h36M8 20.882 12.819 24 8 27.118v-6.236Z" }, null, -1)
  ]), 14, $8);
}
var Es = /* @__PURE__ */ N(C8, [["render", w8]]);
const _h = Object.assign(Es, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Es.name, Es);
  }
});
function l0(e) {
  const t = a(() => Hp(e) ? e.value : e);
  it(
    n0,
    me({
      level: t
    })
  );
}
function Eo(e) {
  const { provideNextLevel: t } = e || {}, n = Ge(n0), o = a(() => (n == null ? void 0 : n.level) || 1);
  if (t) {
    const i = a(() => o.value + 1);
    l0(i);
  }
  return {
    level: o
  };
}
function yp(e, t) {
  const n = [], o = (i) => {
    i.forEach((r) => {
      t(r) && n.push(r.key), r.children && o(r.children);
    });
  };
  return o(e), n;
}
function Jh(e = !1) {
  return e ? void 0 : Ge(Xh);
}
function e2(e) {
  const { key: t, type: n } = e, o = V([]), i = Jh(n === "menu");
  return it(Xh, {
    collectSubMenu(l, s, u = !1) {
      const f = {
        key: l,
        children: s
      };
      if (u) {
        const d = o.value.find((p) => p.key === l);
        d ? d.children = s : o.value.push(f);
      } else
        o.value = [...o.value, f];
      u && (n === "popupMenu" ? i == null || i.reportMenuData(o.value) : n === "subMenu" && !Ve(l) && (i == null || i.collectSubMenu(l, o.value, !0)));
    },
    removeSubMenu(l) {
      o.value = o.value.filter((s) => s.key !== l);
    },
    collectMenuItem(l) {
      o.value.push({ key: l });
    },
    removeMenuItem(l) {
      o.value = o.value.filter((s) => s.key !== l);
    },
    reportMenuData(l) {
      o.value = l, n === "subMenu" && !Ve(t) && (i == null || i.collectSubMenu(t, o.value, !0));
    }
  }), n === "subMenu" && !Ve(t) ? (Je(() => {
    i == null || i.collectSubMenu(t, o.value);
  }), Zt(() => {
    i == null || i.removeSubMenu(t);
  })) : n === "popupMenu" && Je(() => {
    i == null || i.reportMenuData(o.value);
  }), {
    menuData: o,
    subMenuKeys: a(() => yp(o.value, (l) => !!l.children)),
    menuItemKeys: a(() => yp(o.value, (l) => !l.children))
  };
}
function S8(e, t) {
  const n = [], o = (i) => {
    for (let r = 0; r < i.length; r++) {
      const l = i[r];
      if (l.key === t)
        return !0;
      if (l.children) {
        if (n.push(l.key), o(l.children))
          return !0;
        n.pop();
      }
    }
    return !1;
  };
  return o(e), n;
}
function z8(e, t) {
  return e.length !== t.length ? !1 : e.toString() === t.toString();
}
function L8(e) {
  const {
    modelValue: t,
    defaultValue: n,
    autoOpen: o,
    autoOpenSelected: i,
    subMenuKeys: r,
    selectedKeys: l,
    menuData: s,
    accordion: u
  } = ve(e), f = V(
    Ve(t.value) ? Ve(n.value) ? [] : n.value : t.value
  ), d = (y) => {
    f.value = y;
  };
  ze(t, () => {
    Ve(t.value) && d([]);
  });
  let p = [];
  Je(() => {
    p = [...r.value];
    let y = [];
    if (o.value && (y = u.value ? r.value.slice(0, 1) : [...r.value]), i.value) {
      const w = l.value.map(
        (g) => S8(s.value, g)
      );
      w.length && (!o.value || u.value) && (y = u.value ? w[0] : [...new Set([].concat(...w))]);
    }
    y.length && d(y);
  });
  let h = !1;
  ze(r, (y, w = []) => {
    if (h || !z8(y, p)) {
      const g = k.value.filter(
        (C) => y.includes(C)
      );
      if (o.value) {
        const C = y.filter((P) => !w.includes(P));
        g.push(...C);
      }
      d(u.value ? g.slice(0, 1) : g);
    }
    h = !0;
  });
  const k = a(() => t.value || f.value);
  return {
    openKeys: k,
    localOpenKeys: f,
    setOpenKeys: d,
    open(y, w) {
      let g = [];
      return k.value.indexOf(y) > -1 ? u.value && w === 1 ? g = [] : g = k.value.filter((C) => C !== y) : u.value && w === 1 ? g = [y] : g = k.value.concat([y]), d(g), g;
    }
  };
}
const j8 = S({
  name: "BaseMenu",
  components: {
    IconMenuFold: Qh,
    IconMenuUnfold: _h
  },
  inheritAttrs: !1,
  props: {
    style: {
      type: Object
    },
    theme: {
      type: String,
      default: "light"
    },
    mode: {
      type: String,
      default: "vertical"
    },
    levelIndent: {
      type: Number
    },
    autoOpen: {
      type: Boolean
    },
    collapsed: {
      type: Boolean,
      default: void 0
    },
    defaultCollapsed: {
      type: Boolean
    },
    collapsedWidth: {
      type: Number
    },
    accordion: {
      type: Boolean
    },
    autoScrollIntoView: {
      type: Boolean
    },
    showCollapseButton: {
      type: Boolean
    },
    selectedKeys: {
      type: Array
    },
    defaultSelectedKeys: {
      type: Array,
      default: () => []
    },
    openKeys: {
      type: Array
    },
    defaultOpenKeys: {
      type: Array,
      default: () => []
    },
    scrollConfig: {
      type: Object
    },
    triggerProps: {
      type: Object
    },
    tooltipProps: {
      type: Object
    },
    autoOpenSelected: {
      type: Boolean
    },
    breakpoint: {
      type: String
    },
    popupMaxHeight: {
      type: [Boolean, Number],
      default: !0
    },
    prefixCls: {
      type: String
    },
    inTrigger: {
      type: Boolean
    },
    siderCollapsed: {
      type: Boolean
    },
    isRoot: {
      type: Boolean
    }
  },
  emits: [
    "update:collapsed",
    "update:selectedKeys",
    "update:openKeys",
    "collapse",
    "menu-item-click",
    "sub-menu-click"
  ],
  setup(e, { emit: t, slots: n }) {
    const {
      style: o,
      mode: i,
      theme: r,
      levelIndent: l,
      accordion: s,
      showCollapseButton: u,
      scrollConfig: f,
      autoScrollIntoView: d,
      collapsedWidth: p,
      autoOpen: h,
      collapsed: k,
      defaultCollapsed: y,
      selectedKeys: w,
      defaultSelectedKeys: g,
      openKeys: C,
      defaultOpenKeys: P,
      triggerProps: z,
      tooltipProps: j,
      autoOpenSelected: I,
      breakpoint: L,
      popupMaxHeight: M,
      prefixCls: E,
      inTrigger: K,
      siderCollapsed: q,
      isRoot: T
    } = ve(e), { subMenuKeys: X, menuData: Y } = e2({
      type: T.value ? "menu" : "popupMenu"
    }), [Z, U] = Vt(
      g.value,
      me({
        value: w
      })
    ), { openKeys: H, setOpenKeys: D, open: R } = L8(
      me({
        modelValue: C,
        defaultValue: P,
        autoOpen: h,
        autoOpenSelected: I,
        selectedKeys: Z,
        subMenuKeys: X,
        menuData: Y,
        accordion: s
      })
    ), [W, O] = Vt(
      y.value,
      me({
        value: k
      })
    ), x = a(
      () => q.value || W.value || i.value === "popButton"
    ), G = a(
      () => ["horizontal", "popButton"].indexOf(i.value) < 0 && !K.value && u.value
    ), ne = (pe, Me) => {
      pe !== W.value && (O(pe), t("update:collapsed", pe), t("collapse", pe, Me));
    }, ee = () => {
      ne(!W.value, "clickTrigger");
    };
    Kh(L, (pe) => {
      ne(!pe, "responsive");
    });
    const Q = a(
      () => (E == null ? void 0 : E.value) || B("menu")
    ), ae = a(() => [
      Q.value,
      `${Q.value}-${r == null ? void 0 : r.value}`,
      {
        [`${Q.value}-horizontal`]: i.value === "horizontal",
        [`${Q.value}-vertical`]: i.value !== "horizontal",
        [`${Q.value}-collapsed`]: x.value,
        [`${Q.value}-pop`]: i.value === "pop" || x.value,
        [`${Q.value}-pop-button`]: i.value === "popButton"
      }
    ]), ge = a(() => {
      const pe = A(p.value) ? `${p.value}px` : void 0, Me = Qe(o.value) ? o.value : void 0, ke = x.value ? pe : Me == null ? void 0 : Me.width;
      return [
        Me ? Ft(Me, ["width"]) : o.value,
        { width: ke }
      ];
    }), Se = Sn(n, "expand-icon-down"), be = Sn(n, "expand-icon-right"), Le = me({
      theme: r,
      mode: i,
      levelIndent: l,
      autoScrollIntoView: d,
      selectedKeys: Z,
      openKeys: H,
      prefixCls: Q,
      scrollConfig: f,
      inTrigger: K,
      collapsed: x,
      triggerProps: z,
      tooltipProps: j,
      popupMaxHeight: M,
      expandIconDown: Se,
      expandIconRight: be,
      onMenuItemClick: (pe) => {
        U([pe]), t("update:selectedKeys", [pe]), t("menu-item-click", pe);
      },
      onSubMenuClick: (pe, Me) => {
        const ke = R(pe, Me);
        D(ke), t("update:openKeys", ke), t("sub-menu-click", pe, ke);
      }
    });
    return it(t0, Le), l0(1), {
      computedPrefixCls: Q,
      classNames: ae,
      computedStyle: ge,
      computedCollapsed: x,
      computedHasCollapseButton: G,
      onCollapseBtnClick: ee
    };
  }
});
function P8(e, t, n, o, i, r) {
  const l = J("IconMenuUnfold"), s = J("IconMenuFold");
  return v(), b("div", se({ class: e.classNames }, e.$attrs, { style: e.computedStyle }), [
    $("div", {
      class: m(`${e.computedPrefixCls}-inner`)
    }, [
      _(e.$slots, "default")
    ], 2),
    e.computedHasCollapseButton ? (v(), b("div", {
      key: 0,
      class: m(`${e.computedPrefixCls}-collapse-button`),
      onClick: t[0] || (t[0] = (...u) => e.onCollapseBtnClick && e.onCollapseBtnClick(...u))
    }, [
      _(e.$slots, "collapse-icon", { collapsed: e.computedCollapsed }, () => [
        e.computedCollapsed ? (v(), oe(l, { key: 0 })) : (v(), oe(s, { key: 1 }))
      ])
    ], 2)) : te("v-if", !0)
  ], 16);
}
var fv = /* @__PURE__ */ N(j8, [["render", P8]]);
function bp(e, t) {
  if (!e || !t)
    return null;
  let n = t;
  n === "float" && (n = "cssFloat");
  try {
    if (document.defaultView) {
      const o = document.defaultView.getComputedStyle(e, "");
      return e.style[n] || o ? o[n] : "";
    }
  } catch {
    return e.style[n];
  }
  return null;
}
function Ml() {
  return Ge(t0) || {};
}
const I8 = /* @__PURE__ */ (() => {
  let e = 0;
  return (t = "") => (e += 1, `${t}${e}`);
})();
function Kr() {
  const e = dn();
  return {
    key: a(
      () => (e == null ? void 0 : e.vnode.key) || I8("__arco_menu")
    )
  };
}
const B8 = S({
  name: "MenuIndent",
  props: {
    level: {
      type: Number,
      default: 1
    }
  },
  setup() {
    const e = B("menu"), t = Ml();
    return {
      prefixCls: e,
      levelIndent: un(t, "levelIndent")
    };
  }
});
function M8(e, t, n, o, i, r) {
  return e.level > 1 ? (v(), b("span", {
    key: 0,
    class: m(`${e.prefixCls}-indent-list`)
  }, [
    (v(!0), b(Ae, null, St(e.level - 1, (l) => (v(), b("span", {
      key: l,
      class: m(`${e.prefixCls}-indent`),
      style: F(`width: ${e.levelIndent}px`)
    }, null, 6))), 128))
  ], 2)) : te("v-if", !0);
}
var Yr = /* @__PURE__ */ N(B8, [["render", M8]]);
const N8 = S({
  name: "ExpandTransition",
  setup() {
    return {
      onBeforeEnter(e) {
        e.style.height = "0";
      },
      onEnter(e) {
        e.style.height = `${e.scrollHeight}px`;
      },
      onAfterEnter(e) {
        e.style.height = "";
      },
      onBeforeLeave(e) {
        e.style.height = `${e.scrollHeight}px`;
      },
      onLeave(e) {
        e.style.height = "0";
      },
      onAfterLeave(e) {
        e.style.height = "";
      }
    };
  }
});
function O8(e, t, n, o, i, r) {
  return v(), oe(on, {
    onBeforeEnter: e.onBeforeEnter,
    onEnter: e.onEnter,
    onAfterEnter: e.onAfterEnter,
    onBeforeLeave: e.onBeforeLeave,
    onLeave: e.onLeave,
    onAfterLeave: e.onAfterLeave
  }, {
    default: ue(() => [
      _(e.$slots, "default")
    ]),
    _: 3
  }, 8, ["onBeforeEnter", "onEnter", "onAfterEnter", "onBeforeLeave", "onLeave", "onAfterLeave"]);
}
var V8 = /* @__PURE__ */ N(N8, [["render", O8]]);
const T8 = S({
  name: "SubMenuInline",
  components: {
    MenuIndent: Yr,
    ExpandTransition: V8
  },
  props: {
    title: {
      type: String
    },
    isChildrenSelected: {
      type: Boolean
    }
  },
  setup(e) {
    const { key: t } = Kr(), { level: n } = Eo({
      provideNextLevel: !0
    }), o = Ml(), i = a(() => o.prefixCls), r = a(() => `${i.value}-inline`), l = a(() => [r.value]), s = a(() => e.isChildrenSelected), u = a(
      () => (o.openKeys || []).indexOf(t.value) > -1
    );
    return {
      prefixCls: r,
      menuPrefixCls: i,
      classNames: l,
      level: n,
      isSelected: s,
      isOpen: u,
      onHeaderClick: () => {
        o.onSubMenuClick && o.onSubMenuClick(t.value, n.value);
      }
    };
  }
});
function A8(e, t, n, o, i, r) {
  const l = J("MenuIndent"), s = J("ExpandTransition");
  return v(), b("div", {
    class: m(e.classNames)
  }, [
    $("div", {
      class: m([
        `${e.prefixCls}-header`,
        {
          [`${e.menuPrefixCls}-selected`]: e.isSelected,
          [`${e.menuPrefixCls}-has-icon`]: e.$slots.icon
        }
      ]),
      onClick: t[0] || (t[0] = (...u) => e.onHeaderClick && e.onHeaderClick(...u))
    }, [
      c(l, { level: e.level }, null, 8, ["level"]),
      e.$slots.icon ? (v(), b(Ae, { key: 0 }, [
        $("span", {
          class: m(`${e.menuPrefixCls}-icon`)
        }, [
          _(e.$slots, "icon")
        ], 2),
        $("span", {
          class: m(`${e.menuPrefixCls}-title`)
        }, [
          _(e.$slots, "title", {}, () => [
            Re(Pe(e.title), 1)
          ])
        ], 2)
      ], 64)) : _(e.$slots, "title", { key: 1 }, () => [
        Re(Pe(e.title), 1)
      ]),
      $("span", {
        class: m([
          `${e.menuPrefixCls}-icon-suffix`,
          {
            "is-open": e.isOpen
          }
        ])
      }, [
        _(e.$slots, "expand-icon-down")
      ], 2)
    ], 2),
    c(s, null, {
      default: ue(() => [
        hn($("div", {
          class: m(`${e.prefixCls}-content`)
        }, [
          _(e.$slots, "default")
        ], 2), [
          [kn, e.isOpen]
        ])
      ]),
      _: 3
    })
  ], 2);
}
var E8 = /* @__PURE__ */ N(T8, [["render", A8]]);
const W8 = S({
  name: "SubMenuPop",
  components: {
    Menu: fv,
    Trigger: Tt,
    MenuIndent: Yr,
    RenderFunction: Xn
  },
  inheritAttrs: !1,
  props: {
    title: {
      type: String
    },
    selectable: {
      type: Boolean
    },
    isChildrenSelected: {
      type: Boolean
    },
    popupMaxHeight: {
      type: [Boolean, Number],
      default: void 0
    }
  },
  setup(e) {
    const { key: t } = Kr(), { level: n } = Eo(), { selectable: o, isChildrenSelected: i, popupMaxHeight: r } = ve(e), l = Ml(), { onSubMenuClick: s, onMenuItemClick: u } = l, f = a(() => l.prefixCls), d = a(() => l.mode), p = a(() => l.selectedKeys || []), h = a(() => `${f.value}-pop`), k = a(
      () => o.value && p.value.includes(t.value) || i.value
    ), y = a(() => [
      `${h.value}`,
      `${h.value}-header`,
      {
        [`${f.value}-selected`]: k.value
      }
    ]), w = a(
      () => d.value === "horizontal" && !l.inTrigger
    ), g = V(!1), C = (I) => {
      g.value = I;
    }, P = B("trigger"), z = a(() => {
      var I;
      return [
        `${h.value}-trigger`,
        {
          [`${h.value}-trigger-dark`]: l.theme === "dark"
        },
        (I = l.triggerProps) == null ? void 0 : I.class
      ];
    }), j = a(
      () => Ft(l.triggerProps || {}, ["class"])
    );
    return {
      menuPrefixCls: f,
      mode: d,
      level: n,
      classNames: y,
      isSelected: k,
      selectedKeys: p,
      needPopOnBottom: w,
      popVisible: g,
      triggerPrefixCls: P,
      triggerClassNames: z,
      triggerProps: j,
      menuContext: l,
      popupMenuStyles: a(() => {
        var I;
        const L = (I = r.value) != null ? I : l.popupMaxHeight;
        return A(L) ? { maxHeight: `${L}px` } : L ? {} : { maxHeight: "unset" };
      }),
      onClick: () => {
        s && s(t.value, n.value), o.value && u && u(t.value);
      },
      onMenuItemClick: (I) => {
        u && u(I), C(!1);
      },
      onVisibleChange: (I) => {
        C(I);
      }
    };
  }
});
function F8(e, t, n, o, i, r) {
  const l = J("MenuIndent"), s = J("RenderFunction"), u = J("Menu"), f = J("Trigger");
  return v(), oe(f, se({
    trigger: "hover",
    class: e.triggerClassNames,
    position: e.needPopOnBottom ? "bl" : "rt",
    "show-arrow": "",
    "animation-class": "fade-in",
    "mouse-enter-delay": 50,
    "mouse-leave-delay": 50,
    "popup-offset": 4,
    "auto-fit-popup-min-width": !0,
    duration: 100
  }, e.triggerProps, {
    "unmount-on-close": !1,
    "popup-visible": e.popVisible,
    onPopupVisibleChange: e.onVisibleChange
  }), {
    content: ue(() => [
      c(u, {
        "in-trigger": "",
        "prefix-cls": `${e.triggerPrefixCls}-menu`,
        "selected-keys": e.selectedKeys,
        theme: e.menuContext.theme,
        "trigger-props": e.menuContext.triggerProps,
        style: F(e.popupMenuStyles),
        onMenuItemClick: e.onMenuItemClick
      }, kt({
        default: ue(() => [
          _(e.$slots, "default")
        ]),
        _: 2
      }, [
        e.menuContext.expandIconDown ? {
          name: "expand-icon-down",
          fn: ue(() => [
            c(s, {
              "render-func": e.menuContext.expandIconDown
            }, null, 8, ["render-func"])
          ]),
          key: "0"
        } : void 0,
        e.menuContext.expandIconRight ? {
          name: "expand-icon-right",
          fn: ue(() => [
            c(s, {
              "render-func": e.menuContext.expandIconRight
            }, null, 8, ["render-func"])
          ]),
          key: "1"
        } : void 0
      ]), 1032, ["prefix-cls", "selected-keys", "theme", "trigger-props", "style", "onMenuItemClick"])
    ]),
    default: ue(() => [
      $("div", se({
        class: [
          e.classNames,
          {
            [`${e.menuPrefixCls}-has-icon`]: e.$slots.icon
          }
        ],
        "aria-haspopup": "true"
      }, e.$attrs, {
        onClick: t[0] || (t[0] = (...d) => e.onClick && e.onClick(...d))
      }), [
        te(" header "),
        c(l, { level: e.level }, null, 8, ["level"]),
        e.$slots.icon ? (v(), b(Ae, { key: 0 }, [
          $("span", {
            class: m(`${e.menuPrefixCls}-icon`)
          }, [
            _(e.$slots, "icon")
          ], 2),
          $("span", {
            class: m(`${e.menuPrefixCls}-title`)
          }, [
            _(e.$slots, "title", {}, () => [
              Re(Pe(e.title), 1)
            ])
          ], 2)
        ], 64)) : _(e.$slots, "title", { key: 1 }, () => [
          Re(Pe(e.title), 1)
        ]),
        te(" suffix "),
        $("span", {
          class: m(`${e.menuPrefixCls}-icon-suffix`)
        }, [
          e.needPopOnBottom ? _(e.$slots, "expand-icon-down", { key: 0 }) : _(e.$slots, "expand-icon-right", { key: 1 })
        ], 2),
        e.isSelected && e.mode === "horizontal" ? (v(), b("div", {
          key: 2,
          class: m(`${e.menuPrefixCls}-selected-label`)
        }, null, 2)) : te("v-if", !0)
      ], 16)
    ]),
    _: 3
  }, 16, ["class", "position", "popup-visible", "onPopupVisibleChange"]);
}
var D8 = /* @__PURE__ */ N(W8, [["render", F8]]), go = S({
  name: "SubMenu",
  props: {
    title: {
      type: String
    },
    selectable: {
      type: Boolean
    },
    popup: {
      type: [Boolean, Function],
      default: !1
    },
    popupMaxHeight: {
      type: [Boolean, Number],
      default: void 0
    }
  },
  setup(e, {
    attrs: t
  }) {
    const {
      key: n
    } = Kr(), {
      level: o
    } = Eo(), {
      popup: i
    } = ve(e), r = Ml(), l = a(() => {
      const {
        mode: d,
        collapsed: p,
        inTrigger: h
      } = r;
      return !!(typeof i.value == "function" ? i.value(o.value) : i.value) || p || h || d !== "vertical";
    }), {
      subMenuKeys: s,
      menuItemKeys: u
    } = e2({
      key: n.value,
      type: "subMenu"
    }), f = a(() => {
      const d = r.selectedKeys || [], p = (h) => {
        for (let k = 0; k < d.length; k++) {
          const y = d[k];
          if (h.includes(y))
            return !0;
        }
        return !1;
      };
      return p(s.value) || p(u.value);
    });
    return {
      subMenuKeys: s,
      menuItemKeys: u,
      isChildrenSelected: f,
      props: e,
      attrs: t,
      computedKey: n,
      computedPopup: l,
      expandIconDown: un(r, "expandIconDown"),
      expandIconRight: un(r, "expandIconRight")
    };
  },
  render() {
    const {
      props: e,
      attrs: t,
      computedKey: n,
      computedPopup: o,
      expandIconDown: i,
      expandIconRight: r,
      isChildrenSelected: l
    } = this, s = {
      ...this.$slots,
      "expand-icon-down": this.$slots["expand-icon-down"] || i || (() => [c(Il, null, null)]),
      "expand-icon-right": this.$slots["expand-icon-right"] || r || (() => [c(bn, null, null)])
    };
    return o ? c(D8, se({
      key: n,
      title: e.title,
      selectable: e.selectable,
      isChildrenSelected: l,
      popupMaxHeight: e.popupMaxHeight
    }, t), s) : c(E8, se({
      key: n,
      title: e.title,
      isChildrenSelected: l
    }, t), s);
  }
});
const x8 = 10;
function Cp(e) {
  return e && +e.getBoundingClientRect().width.toFixed(2);
}
function $p(e) {
  const t = Number(e.replace("px", ""));
  return Number.isNaN(t) ? 0 : t;
}
var R8 = S({
  name: "MenuOverflowWrap",
  setup(e, {
    slots: t
  }) {
    const o = `${Ml().prefixCls}-overflow`, i = `${o}-sub-menu`, r = `${o}-hidden-menu-item`, l = `${o}-sub-menu-mirror`, s = V(), u = V(null), f = V();
    function d() {
      const p = s.value, h = Cp(p), k = [].slice.call(p.children);
      let y = 0, w = 0, g = 0;
      for (let C = 0; C < k.length; C++) {
        const P = k[C], z = P.className.split(" "), j = z.indexOf(i) > -1, I = z.indexOf(l) > -1;
        if (j)
          continue;
        const L = Cp(P) + $p(bp(P, "marginLeft")) + $p(bp(P, "marginRight"));
        if (I) {
          g = L;
          continue;
        }
        if (w += L, w + g + x8 > h) {
          u.value = y - 1;
          return;
        }
        y++;
      }
      u.value = null;
    }
    return Je(() => {
      d(), f.value = new wr((p) => {
        p.forEach(d);
      }), s.value && f.value.observe(s.value);
    }), Zt(() => {
      f.value && f.value.disconnect();
    }), () => {
      const p = (k, y) => {
        const {
          isMirror: w = !1,
          props: g = {}
        } = y || {};
        return c(go, se({
          key: `__arco-menu-overflow-sub-menu${w ? "-mirror" : ""}`,
          class: w ? l : i
        }, g), {
          title: () => c("span", null, [Re("...")]),
          default: () => k
        });
      }, h = () => {
        var k;
        const y = ((k = t.default) == null ? void 0 : k.call(t)) || [], w = Nk(y);
        let g = null;
        const C = p(null, {
          isMirror: !0
        }), P = w.map((z, j) => {
          const I = Kl(z, u.value !== null && j > u.value ? {
            class: r
          } : {
            class: ""
          });
          if (u.value !== null && j === u.value + 1) {
            const L = w.slice(j).map((M) => Kl(M));
            g = p(L);
          }
          return I;
        });
        return [C, ...P, g];
      };
      return c("div", {
        class: `${o}-wrap`,
        ref: s
      }, [h()]);
    };
  }
}), Ws = S({
  name: "Menu",
  components: {
    BaseMenu: fv
  },
  inheritAttrs: !1,
  props: {
    theme: {
      type: String
    },
    mode: {
      type: String,
      default: "vertical"
    }
  },
  setup(e, {
    attrs: t,
    slots: n
  }) {
    const {
      theme: o,
      mode: i
    } = ve(e), r = Ge(Dh, void 0), l = a(() => (r == null ? void 0 : r.collapsed) || !1), s = a(() => (o == null ? void 0 : o.value) || (r == null ? void 0 : r.theme) || "light");
    return it(t0, void 0), it(n0, void 0), () => c(fv, se(e, t, {
      theme: s.value,
      inTrigger: !1,
      siderCollapsed: l.value,
      isRoot: !0
    }), {
      ...n,
      default: i.value === "horizontal" && n.default ? () => c(R8, null, {
        default: () => {
          var u;
          return [(u = n.default) == null ? void 0 : u.call(n)];
        }
      }) : n.default
    });
  }
}), Ki = S({
  name: "MenuItem",
  inheritAttrs: !1,
  props: {
    disabled: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["click"],
  setup(e, {
    emit: t
  }) {
    const {
      key: n
    } = Kr(), {
      level: o
    } = Eo(), i = Ml(), r = V(), l = a(() => (i.selectedKeys || []).indexOf(n.value) > -1), s = Jh();
    Je(() => {
      s == null || s.collectMenuItem(n.value);
    }), Zt(() => {
      s == null || s.removeMenuItem(n.value);
    });
    function u() {
      i.autoScrollIntoView && r.value && l.value && Ch(r.value, {
        behavior: "smooth",
        block: "nearest",
        scrollMode: "if-needed",
        boundary: document.documentElement,
        ...i.scrollConfig || {}
      });
    }
    let f;
    return Je(() => {
      f = setTimeout(() => {
        u();
      }, 500);
    }), Zt(() => {
      clearTimeout(f);
    }), ze([l], () => {
      u();
    }), {
      menuContext: i,
      level: o,
      isSelected: l,
      refItemElement: r,
      onClick(d) {
        e.disabled || (i.onMenuItemClick && i.onMenuItemClick(n.value), t("click", d));
      }
    };
  },
  render() {
    var e, t;
    const {
      level: n,
      menuContext: o,
      disabled: i,
      isSelected: r,
      onClick: l
    } = this, {
      prefixCls: s,
      collapsed: u,
      inTrigger: f,
      mode: d,
      tooltipProps: p
    } = o, h = u && !f && n === 1, k = d === "vertical" && n > 1, y = ((t = (e = this.$slots).default) == null ? void 0 : t.call(e)) || [], w = k && !f && !u, g = this.$slots.icon && this.$slots.icon(), C = [w && c(Yr, {
      level: n
    }, null), g && c("span", {
      class: `${s}-icon`
    }, [g]), w || g ? c("span", {
      class: [`${s}-item-inner`, {
        [`${s}-title`]: g
      }]
    }, [y]) : y].filter(Boolean), P = c("div", se({
      ref: "refItemElement",
      class: [`${s}-item`, {
        [`${s}-disabled`]: i,
        [`${s}-selected`]: r,
        [`${s}-has-icon`]: g
      }]
    }, this.$attrs, {
      onClick: l
    }), [C, r && d === "horizontal" && c("div", {
      class: `${s}-selected-label`
    }, null)]);
    if (h) {
      const z = [`${s}-item-tooltip`, p == null ? void 0 : p.class];
      return c(yn, se({
        trigger: "hover",
        position: "right",
        class: z
      }, Ft(p || {}, ["class"])), {
        default: () => P,
        content: () => y
      });
    }
    return P;
  }
});
const H8 = S({
  name: "MenuItemGroup",
  components: {
    MenuIndent: Yr
  },
  props: {
    title: {
      type: String
    }
  },
  setup() {
    const { level: e } = Eo(), t = a(
      () => e.value === 1 ? e.value + 1 : e.value
    );
    l0(t);
    const n = Ml(), o = a(() => n.prefixCls), i = a(() => [`${o.value}-group`]);
    return {
      prefixCls: o,
      classNames: i,
      level: e
    };
  }
});
function q8(e, t, n, o, i, r) {
  const l = J("MenuIndent");
  return v(), b("div", {
    class: m(e.classNames)
  }, [
    $("div", {
      class: m(`${e.prefixCls}-group-title`)
    }, [
      c(l, { level: e.level }, null, 8, ["level"]),
      _(e.$slots, "title", {}, () => [
        Re(Pe(e.title), 1)
      ])
    ], 2),
    _(e.$slots, "default")
  ], 2);
}
var Yi = /* @__PURE__ */ N(H8, [["render", q8]]);
const Z8 = Object.assign(Ws, {
  Item: Ki,
  ItemGroup: Yi,
  SubMenu: go,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ws.name, Ws), e.component(n + Ki.name, Ki), e.component(n + Yi.name, Yi), e.component(n + go.name, go);
  }
}), K8 = S({
  name: "Message",
  components: {
    AIconHover: pt,
    IconInfoCircleFill: Xl,
    IconCheckCircleFill: ul,
    IconExclamationCircleFill: Dn,
    IconCloseCircleFill: jl,
    IconClose: Dt,
    IconLoading: Yt
  },
  props: {
    type: {
      type: String,
      default: "info"
    },
    closable: {
      type: Boolean,
      default: !1
    },
    showIcon: {
      type: Boolean,
      default: !0
    },
    duration: {
      type: Number,
      default: 3e3
    },
    resetOnUpdate: {
      type: Boolean,
      default: !1
    },
    resetOnHover: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["close"],
  setup(e, { emit: t }) {
    const n = B("message");
    let o = 0;
    const i = () => {
      t("close");
    }, r = () => {
      e.duration > 0 && (o = window.setTimeout(i, e.duration));
    }, l = () => {
      o && (window.clearTimeout(o), o = 0);
    };
    return Je(() => {
      r();
    }), fn(() => {
      e.resetOnUpdate && (l(), r());
    }), Zt(() => {
      l();
    }), {
      handleMouseEnter: () => {
        e.resetOnHover && l();
      },
      handleMouseLeave: () => {
        e.resetOnHover && r();
      },
      prefixCls: n,
      handleClose: i
    };
  }
});
function Y8(e, t, n, o, i, r) {
  const l = J("icon-info-circle-fill"), s = J("icon-check-circle-fill"), u = J("icon-exclamation-circle-fill"), f = J("icon-close-circle-fill"), d = J("icon-loading"), p = J("icon-close"), h = J("a-icon-hover");
  return v(), b("li", {
    role: "alert",
    class: m([
      e.prefixCls,
      `${e.prefixCls}-${e.type}`,
      { [`${e.prefixCls}-closable`]: e.closable }
    ]),
    onMouseenter: t[1] || (t[1] = (...k) => e.handleMouseEnter && e.handleMouseEnter(...k)),
    onMouseleave: t[2] || (t[2] = (...k) => e.handleMouseLeave && e.handleMouseLeave(...k))
  }, [
    e.showIcon && !(e.type === "normal" && !e.$slots.icon) ? (v(), b("span", {
      key: 0,
      class: m(`${e.prefixCls}-icon`)
    }, [
      _(e.$slots, "icon", {}, () => [
        e.type === "info" ? (v(), oe(l, { key: 0 })) : e.type === "success" ? (v(), oe(s, { key: 1 })) : e.type === "warning" ? (v(), oe(u, { key: 2 })) : e.type === "error" ? (v(), oe(f, { key: 3 })) : e.type === "loading" ? (v(), oe(d, { key: 4 })) : te("v-if", !0)
      ])
    ], 2)) : te("v-if", !0),
    $("span", {
      class: m(`${e.prefixCls}-content`)
    }, [
      _(e.$slots, "default")
    ], 2),
    e.closable ? (v(), b("span", {
      key: 1,
      class: m(`${e.prefixCls}-close-btn`),
      onClick: t[0] || (t[0] = (...k) => e.handleClose && e.handleClose(...k))
    }, [
      c(h, null, {
        default: ue(() => [
          c(p)
        ]),
        _: 1
      })
    ], 2)) : te("v-if", !0)
  ], 34);
}
var U8 = /* @__PURE__ */ N(K8, [["render", Y8]]);
function G8(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var X8 = S({
  name: "MessageList",
  props: {
    messages: {
      type: Array,
      default: () => []
    },
    position: {
      type: String,
      default: "top"
    }
  },
  emits: ["close", "afterClose"],
  setup(e, t) {
    const n = B("message-list"), {
      zIndex: o
    } = Ql("message", {
      runOnMounted: !0
    });
    return () => {
      let i;
      return c(jo, {
        class: [n, `${n}-${e.position}`],
        name: "fade-message",
        tag: "ul",
        style: {
          zIndex: o.value
        },
        onAfterLeave: () => t.emit("afterClose")
      }, G8(i = e.messages.map((r) => {
        const l = {
          default: nn(r.content),
          icon: nn(r.icon)
        };
        return c(U8, {
          key: r.id,
          type: r.type,
          duration: r.duration,
          closable: r.closable,
          resetOnUpdate: r.resetOnUpdate,
          resetOnHover: r.resetOnHover,
          onClose: () => t.emit("close", r.id)
        }, l);
      })) ? i : {
        default: () => [i]
      });
    };
  }
});
class Q8 {
  constructor(t, n) {
    this.messageCount = 0, this.add = (r) => {
      var l;
      this.messageCount++;
      const s = (l = r.id) != null ? l : `__arco_message_${this.messageCount}`;
      if (this.messageIds.has(s))
        return this.update(s, r);
      const u = me({ id: s, ...r });
      return this.messages.value.push(u), this.messageIds.add(s), {
        close: () => this.remove(s)
      };
    }, this.update = (r, l) => {
      for (let s = 0; s < this.messages.value.length; s++)
        if (this.messages.value[s].id === r) {
          const u = !Ve(l.duration);
          Object.assign(this.messages.value[s], { ...l, id: r, resetOnUpdate: u });
          break;
        }
      return {
        close: () => this.remove(r)
      };
    }, this.remove = (r) => {
      for (let l = 0; l < this.messages.value.length; l++) {
        const s = this.messages.value[l];
        if (s.id === r) {
          Ne(s.onClose) && s.onClose(r), this.messages.value.splice(l, 1), this.messageIds.delete(r);
          break;
        }
      }
    }, this.clear = () => {
      this.messages.value.splice(0);
    }, this.destroy = () => {
      this.messages.value.length === 0 && this.container && (il(null, this.container), document.body.removeChild(this.container), this.container = null, ql[this.position] = void 0);
    };
    const { position: o = "top" } = t;
    this.container = jr("message"), this.messageIds = /* @__PURE__ */ new Set(), this.messages = V([]), this.position = o;
    const i = c(X8, {
      messages: this.messages.value,
      position: o,
      onClose: this.remove,
      onAfterClose: this.destroy
    });
    (n ?? vv._context) && (i.appContext = n ?? vv._context), il(i, this.container), document.body.appendChild(this.container);
  }
}
const ql = {}, t2 = [...Ir, "loading", "normal"], Ui = t2.reduce((e, t) => (e[t] = (n, o) => {
  zt(n) && (n = { content: n });
  const i = { type: t, ...n }, { position: r = "top" } = i;
  return ql[r] || (ql[r] = new Q8(i, o)), ql[r].add(i);
}, e), {});
Ui.clear = (e) => {
  var t;
  e ? (t = ql[e]) == null || t.clear() : Object.values(ql).forEach((n) => n == null ? void 0 : n.clear());
};
const vv = {
  ...Ui,
  install: (e) => {
    const t = {
      clear: Ui.clear
    };
    for (const n of t2)
      t[n] = (o, i = e._context) => Ui[n](o, i);
    e.config.globalProperties.$message = t;
  },
  _context: null
}, _8 = ({
  modalRef: e,
  wrapperRef: t,
  draggable: n,
  alignCenter: o
}) => {
  const i = V(!1), r = V([0, 0]), l = V([0, 0]), s = V(), u = V([0, 0]), f = V([0, 0]), d = () => {
    var y, w, g;
    if (t.value && e.value) {
      const { top: C, left: P } = t.value.getBoundingClientRect(), { clientWidth: z, clientHeight: j } = t.value, { top: I, left: L, width: M, height: E } = e.value.getBoundingClientRect(), K = o.value ? 0 : (y = e.value) == null ? void 0 : y.offsetTop, q = L - P, T = I - C - K;
      (q !== ((w = l.value) == null ? void 0 : w[0]) || T !== ((g = l.value) == null ? void 0 : g[1])) && (l.value = [q, T]);
      const X = z > M ? z - M : 0, Y = j > E ? j - E - K : 0;
      (X !== f.value[0] || Y !== f.value[1]) && (f.value = [X, Y]), K && (u.value = [0, 0 - K]);
    }
  }, p = (y) => {
    n.value && (y.preventDefault(), i.value = !0, d(), r.value = [y.x, y.y], rt(window, "mousemove", h), rt(window, "mouseup", k), rt(window, "contextmenu", k));
  }, h = (y) => {
    if (i.value) {
      const w = y.x - r.value[0], g = y.y - r.value[1];
      let C = l.value[0] + w, P = l.value[1] + g;
      C < u.value[0] && (C = u.value[0]), C > f.value[0] && (C = f.value[0]), P < u.value[1] && (P = u.value[1]), P > f.value[1] && (P = f.value[1]), s.value = [C, P];
    }
  }, k = () => {
    i.value = !1, ct(window, "mousemove", h), ct(window, "mouseup", k);
  };
  return {
    position: s,
    handleMoveDown: p
  };
};
var J8 = S({
  name: "Modal",
  components: {
    ClientOnly: Mv,
    ArcoButton: Qt,
    IconHover: pt,
    IconClose: Dt,
    IconInfoCircleFill: Xl,
    IconCheckCircleFill: ul,
    IconExclamationCircleFill: Dn,
    IconCloseCircleFill: jl
  },
  inheritAttrs: !1,
  props: {
    visible: {
      type: Boolean,
      default: void 0
    },
    defaultVisible: {
      type: Boolean,
      default: !1
    },
    width: {
      type: [Number, String]
    },
    top: {
      type: [Number, String]
    },
    mask: {
      type: Boolean,
      default: !0
    },
    title: {
      type: String
    },
    titleAlign: {
      type: String,
      default: "center"
    },
    alignCenter: {
      type: Boolean,
      default: !0
    },
    unmountOnClose: Boolean,
    maskClosable: {
      type: Boolean,
      default: !0
    },
    hideCancel: {
      type: Boolean,
      default: !1
    },
    simple: {
      type: Boolean,
      default: (e) => e.notice
    },
    closable: {
      type: Boolean,
      default: !0
    },
    okText: String,
    cancelText: String,
    okLoading: {
      type: Boolean,
      default: !1
    },
    okButtonProps: {
      type: Object
    },
    cancelButtonProps: {
      type: Object
    },
    footer: {
      type: Boolean,
      default: !0
    },
    renderToBody: {
      type: Boolean,
      default: !0
    },
    popupContainer: {
      type: [String, Object],
      default: "body"
    },
    maskStyle: {
      type: Object
    },
    modalClass: {
      type: [String, Array]
    },
    modalStyle: {
      type: Object
    },
    onBeforeOk: {
      type: Function
    },
    onBeforeCancel: {
      type: Function
    },
    escToClose: {
      type: Boolean,
      default: !0
    },
    draggable: {
      type: Boolean,
      default: !1
    },
    fullscreen: {
      type: Boolean,
      default: !1
    },
    maskAnimationName: {
      type: String,
      default: (e) => e.fullscreen ? "fade-in-standard" : "fade-modal"
    },
    modalAnimationName: {
      type: String,
      default: (e) => e.fullscreen ? "zoom-in" : "zoom-modal"
    },
    bodyClass: {
      type: [String, Array]
    },
    bodyStyle: {
      type: [String, Object, Array]
    },
    messageType: {
      type: String
    },
    hideTitle: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:visible": (e) => !0,
    ok: (e) => !0,
    cancel: (e) => !0,
    open: () => !0,
    close: () => !0,
    beforeOpen: () => !0,
    beforeClose: () => !0
  },
  setup(e, {
    emit: t
  }) {
    const {
      fullscreen: n,
      popupContainer: o,
      alignCenter: i
    } = ve(e), r = B("modal"), {
      t: l
    } = gt(), s = V(), u = V(), f = V(e.defaultVisible), d = a(() => {
      var Q;
      return (Q = e.visible) != null ? Q : f.value;
    }), p = V(!1), h = a(() => e.okLoading || p.value), k = a(() => e.draggable && !e.fullscreen), {
      teleportContainer: y,
      containerRef: w
    } = Nv({
      popupContainer: o,
      visible: d
    }), g = V(d.value), C = a(() => e.okText || l("modal.okText")), P = a(() => e.cancelText || l("modal.cancelText")), {
      zIndex: z,
      isLastDialog: j
    } = Ql("dialog", {
      visible: d
    });
    let I = !1;
    const L = (Q) => {
      e.escToClose && Q.key === yt.ESC && j() && Z(Q);
    }, M = () => {
      e.escToClose && !I && (I = !0, rt(document.documentElement, "keydown", L));
    }, E = () => {
      I = !1, ct(document.documentElement, "keydown", L);
    };
    let K = 0;
    const {
      position: q,
      handleMoveDown: T
    } = _8({
      wrapperRef: s,
      modalRef: u,
      draggable: k,
      alignCenter: i
    }), X = () => {
      K++, p.value && (p.value = !1), f.value = !1, t("update:visible", !1);
    }, Y = async (Q) => {
      const ae = K, ge = await new Promise(
        async (Se) => {
          var be;
          if (Ne(e.onBeforeOk)) {
            let Le = e.onBeforeOk((pe = !0) => Se(pe));
            if (($l(Le) || !Xt(Le)) && (p.value = !0), $l(Le))
              try {
                Le = (be = await Le) != null ? be : !0;
              } catch (pe) {
                throw Le = !1, pe;
              }
            Xt(Le) && Se(Le);
          } else
            Se(!0);
        }
      );
      ae === K && (ge ? (t("ok", Q), X()) : p.value && (p.value = !1));
    }, Z = (Q) => {
      var ae;
      let ge = !0;
      Ne(e.onBeforeCancel) && (ge = (ae = e.onBeforeCancel()) != null ? ae : !1), ge && (t("cancel", Q), X());
    }, U = V(!1), H = (Q) => {
      Q.target === s.value && (U.value = !0);
    }, D = (Q) => {
      e.mask && e.maskClosable && U.value && Z(Q);
    }, R = () => {
      d.value && (!Ok(s.value, document.activeElement) && document.activeElement instanceof HTMLElement && document.activeElement.blur(), t("open"));
    }, W = () => {
      d.value || (k.value && (q.value = void 0), g.value = !1, x(), t("close"));
    }, {
      setOverflowHidden: O,
      resetOverflow: x
    } = yh(w);
    Je(() => {
      w.value = Tn(e.popupContainer), d.value && (O(), e.escToClose && M());
    }), _t(() => {
      x(), E();
    }), ze(d, (Q) => {
      f.value !== Q && (f.value = Q), Q ? (t("beforeOpen"), g.value = !0, U.value = !1, O(), M()) : (t("beforeClose"), E());
    }), ze(n, () => {
      q.value && (q.value = void 0);
    });
    const G = a(() => [`${r}-wrapper`, {
      [`${r}-wrapper-align-center`]: e.alignCenter && !e.fullscreen,
      [`${r}-wrapper-moved`]: !!q.value
    }]), ne = a(() => [`${r}`, e.modalClass, {
      [`${r}-simple`]: e.simple,
      [`${r}-draggable`]: k.value,
      [`${r}-fullscreen`]: e.fullscreen
    }]), ee = a(() => {
      var Q;
      const ae = {
        ...(Q = e.modalStyle) != null ? Q : {}
      };
      return e.width && !e.fullscreen && (ae.width = A(e.width) ? `${e.width}px` : e.width), !e.alignCenter && e.top && (ae.top = A(e.top) ? `${e.top}px` : e.top), q.value && (ae.transform = `translate(${q.value[0]}px, ${q.value[1]}px)`), ae;
    });
    return {
      prefixCls: r,
      mounted: g,
      computedVisible: d,
      containerRef: w,
      wrapperRef: s,
      mergedModalStyle: ee,
      okDisplayText: C,
      cancelDisplayText: P,
      zIndex: z,
      handleOk: Y,
      handleCancel: Z,
      handleMaskClick: D,
      handleMaskMouseDown: H,
      handleOpen: R,
      handleClose: W,
      mergedOkLoading: h,
      modalRef: u,
      wrapperCls: G,
      modalCls: ne,
      teleportContainer: y,
      handleMoveDown: T
    };
  }
});
function ew(e, t, n, o, i, r) {
  const l = J("icon-info-circle-fill"), s = J("icon-check-circle-fill"), u = J("icon-exclamation-circle-fill"), f = J("icon-close-circle-fill"), d = J("icon-close"), p = J("icon-hover"), h = J("arco-button"), k = J("client-only");
  return v(), oe(k, null, {
    default: ue(() => [
      (v(), oe(br, {
        to: e.teleportContainer,
        disabled: !e.renderToBody
      }, [
        !e.unmountOnClose || e.computedVisible || e.mounted ? hn((v(), b("div", se({
          key: 0,
          class: `${e.prefixCls}-container`,
          style: { zIndex: e.zIndex }
        }, e.$attrs), [
          c(on, {
            name: e.maskAnimationName,
            appear: ""
          }, {
            default: ue(() => [
              e.mask ? hn((v(), b("div", {
                key: 0,
                ref: "maskRef",
                class: m(`${e.prefixCls}-mask`),
                style: F(e.maskStyle)
              }, null, 6)), [
                [kn, e.computedVisible]
              ]) : te("v-if", !0)
            ]),
            _: 1
          }, 8, ["name"]),
          $("div", {
            ref: "wrapperRef",
            class: m(e.wrapperCls),
            onClick: t[2] || (t[2] = an((...y) => e.handleMaskClick && e.handleMaskClick(...y), ["self"])),
            onMousedown: t[3] || (t[3] = an((...y) => e.handleMaskMouseDown && e.handleMaskMouseDown(...y), ["self"]))
          }, [
            c(on, {
              name: e.modalAnimationName,
              appear: "",
              onAfterEnter: e.handleOpen,
              onAfterLeave: e.handleClose,
              persisted: ""
            }, {
              default: ue(() => [
                hn($("div", {
                  ref: "modalRef",
                  class: m(e.modalCls),
                  style: F(e.mergedModalStyle)
                }, [
                  !e.hideTitle && (e.$slots.title || e.title || e.closable) ? (v(), b("div", {
                    key: 0,
                    class: m(`${e.prefixCls}-header`),
                    onMousedown: t[1] || (t[1] = (...y) => e.handleMoveDown && e.handleMoveDown(...y))
                  }, [
                    e.$slots.title || e.title ? (v(), b("div", {
                      key: 0,
                      class: m([
                        `${e.prefixCls}-title`,
                        `${e.prefixCls}-title-align-${e.titleAlign}`
                      ])
                    }, [
                      e.messageType ? (v(), b("div", {
                        key: 0,
                        class: m(`${e.prefixCls}-title-icon`)
                      }, [
                        e.messageType === "info" ? (v(), oe(l, { key: 0 })) : te("v-if", !0),
                        e.messageType === "success" ? (v(), oe(s, { key: 1 })) : te("v-if", !0),
                        e.messageType === "warning" ? (v(), oe(u, { key: 2 })) : te("v-if", !0),
                        e.messageType === "error" ? (v(), oe(f, { key: 3 })) : te("v-if", !0)
                      ], 2)) : te("v-if", !0),
                      _(e.$slots, "title", {}, () => [
                        Re(Pe(e.title), 1)
                      ])
                    ], 2)) : te("v-if", !0),
                    !e.simple && e.closable ? (v(), b("div", {
                      key: 1,
                      tabindex: "-1",
                      role: "button",
                      "aria-label": "Close",
                      class: m(`${e.prefixCls}-close-btn`),
                      onClick: t[0] || (t[0] = (...y) => e.handleCancel && e.handleCancel(...y))
                    }, [
                      c(p, null, {
                        default: ue(() => [
                          c(d)
                        ]),
                        _: 1
                      })
                    ], 2)) : te("v-if", !0)
                  ], 34)) : te("v-if", !0),
                  $("div", {
                    class: m([`${e.prefixCls}-body`, e.bodyClass]),
                    style: F(e.bodyStyle)
                  }, [
                    _(e.$slots, "default")
                  ], 6),
                  e.footer ? (v(), b("div", {
                    key: 1,
                    class: m(`${e.prefixCls}-footer`)
                  }, [
                    _(e.$slots, "footer", {}, () => [
                      e.hideCancel ? te("v-if", !0) : (v(), oe(h, se({ key: 0 }, e.cancelButtonProps, { onClick: e.handleCancel }), {
                        default: ue(() => [
                          Re(Pe(e.cancelDisplayText), 1)
                        ]),
                        _: 1
                      }, 16, ["onClick"])),
                      c(h, se({ type: "primary" }, e.okButtonProps, {
                        loading: e.mergedOkLoading,
                        onClick: e.handleOk
                      }), {
                        default: ue(() => [
                          Re(Pe(e.okDisplayText), 1)
                        ]),
                        _: 1
                      }, 16, ["loading", "onClick"])
                    ])
                  ], 2)) : te("v-if", !0)
                ], 6), [
                  [kn, e.computedVisible]
                ])
              ]),
              _: 3
            }, 8, ["name", "onAfterEnter", "onAfterLeave"])
          ], 34)
        ], 16)), [
          [kn, e.computedVisible || e.mounted]
        ]) : te("v-if", !0)
      ], 8, ["to", "disabled"]))
    ]),
    _: 3
  });
}
var Gi = /* @__PURE__ */ N(J8, [["render", ew]]);
const Fs = (e, t) => {
  let n = jr("modal");
  const o = () => {
    f.component && (f.component.props.visible = !1), Ne(e.onOk) && e.onOk();
  }, i = () => {
    f.component && (f.component.props.visible = !1), Ne(e.onCancel) && e.onCancel();
  }, r = async () => {
    await at(), n && (il(null, n), document.body.removeChild(n)), n = null, Ne(e.onClose) && e.onClose();
  }, l = () => {
    f.component && (f.component.props.visible = !1);
  }, s = (d) => {
    f.component && Object.entries(d).forEach(([p, h]) => {
      f.component.props[p] = h;
    });
  }, f = c(Gi, {
    ...{
      visible: !0,
      renderToBody: !1,
      unmountOnClose: !0,
      onOk: o,
      onCancel: i,
      onClose: r
    },
    ...Ft(e, ["content", "title", "footer", "visible", "unmountOnClose", "onOk", "onCancel", "onClose"]),
    footer: typeof e.footer == "boolean" ? e.footer : void 0
  }, {
    default: nn(e.content),
    title: nn(e.title),
    footer: typeof e.footer != "boolean" ? nn(e.footer) : void 0
  });
  return (t ?? pv._context) && (f.appContext = t ?? pv._context), il(f, n), document.body.appendChild(n), {
    close: l,
    update: s
  };
}, Ds = {
  open: Fs,
  confirm: (e, t) => {
    const n = {
      simple: !0,
      messageType: "warning",
      ...e
    };
    return Fs(n, t);
  },
  ...Ir.reduce((e, t) => (e[t] = (n, o) => {
    const i = {
      simple: !0,
      hideCancel: !0,
      messageType: t,
      ...n
    };
    return Fs(i, o);
  }, e), {})
}, pv = Object.assign(Gi, {
  ...Ds,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Gi.name, Gi);
    const o = {};
    for (const i of Object.keys(Ds))
      o[i] = (r, l = e._context) => Ds[i](r, l);
    e.config.globalProperties.$modal = o;
  },
  _context: null
}), tw = (e) => e.replace(/\B([A-Z])/g, "-$1").toLowerCase(), nw = S({
  name: "Notification",
  components: {
    AIconHover: pt,
    IconInfoCircleFill: Xl,
    IconCheckCircleFill: ul,
    IconExclamationCircleFill: Dn,
    IconCloseCircleFill: jl,
    IconClose: Dt
  },
  props: {
    type: {
      type: String,
      default: "info"
    },
    showIcon: {
      type: Boolean,
      default: !0
    },
    closable: {
      type: Boolean,
      default: !1
    },
    duration: {
      type: Number,
      default: 3e3
    },
    resetOnUpdate: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["close"],
  setup(e, t) {
    const n = B("notification");
    let o = 0;
    const i = () => {
      t.emit("close");
    };
    return Je(() => {
      e.duration > 0 && (o = window.setTimeout(i, e.duration));
    }), fn(() => {
      e.resetOnUpdate && (o && (window.clearTimeout(o), o = 0), e.duration > 0 && (o = window.setTimeout(i, e.duration)));
    }), Zt(() => {
      o && window.clearTimeout(o);
    }), {
      prefixCls: n,
      handleClose: i
    };
  }
});
function lw(e, t, n, o, i, r) {
  const l = J("icon-info-circle-fill"), s = J("icon-check-circle-fill"), u = J("icon-exclamation-circle-fill"), f = J("icon-close-circle-fill"), d = J("icon-close"), p = J("a-icon-hover");
  return v(), b("li", {
    role: "alert",
    class: m([
      e.prefixCls,
      `${e.prefixCls}-${e.type}`,
      { [`${e.prefixCls}-closable`]: e.closable }
    ])
  }, [
    e.showIcon ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-left`)
    }, [
      $("div", {
        class: m(`${e.prefixCls}-icon`)
      }, [
        _(e.$slots, "icon", {}, () => [
          e.type === "info" ? (v(), oe(l, { key: 0 })) : e.type === "success" ? (v(), oe(s, { key: 1 })) : e.type === "warning" ? (v(), oe(u, { key: 2 })) : e.type === "error" ? (v(), oe(f, { key: 3 })) : te("v-if", !0)
        ])
      ], 2)
    ], 2)) : te("v-if", !0),
    $("div", {
      class: m(`${e.prefixCls}-right`)
    }, [
      e.$slots.default ? (v(), b("div", {
        key: 0,
        class: m(`${e.prefixCls}-title`)
      }, [
        _(e.$slots, "default")
      ], 2)) : te("v-if", !0),
      e.$slots.content ? (v(), b("div", {
        key: 1,
        class: m(`${e.prefixCls}-content`)
      }, [
        _(e.$slots, "content")
      ], 2)) : te("v-if", !0),
      e.$slots.footer ? (v(), b("div", {
        key: 2,
        class: m(`${e.prefixCls}-footer`)
      }, [
        _(e.$slots, "footer")
      ], 2)) : te("v-if", !0)
    ], 2),
    e.closable ? (v(), b("div", {
      key: 1,
      class: m(`${e.prefixCls}-close-btn`),
      onClick: t[0] || (t[0] = (...h) => e.handleClose && e.handleClose(...h))
    }, [
      _(e.$slots, "closeIconElement", {}, () => [
        c(p, null, {
          default: ue(() => [
            _(e.$slots, "closeIcon", {}, () => [
              c(d)
            ])
          ]),
          _: 3
        })
      ])
    ], 2)) : te("v-if", !0)
  ], 2);
}
var ow = /* @__PURE__ */ N(nw, [["render", lw]]);
const iw = [
  "topLeft",
  "topRight",
  "bottomLeft",
  "bottomRight"
];
function rw(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var aw = S({
  name: "NotificationList",
  props: {
    notifications: {
      type: Array,
      default: () => []
    },
    position: {
      type: String,
      default: "topRight",
      validator: (e) => iw.includes(e)
    }
  },
  emits: ["close", "afterClose"],
  setup(e, t) {
    const n = B("notification-list"), o = tw(e.position), {
      zIndex: i
    } = Ql("message", {
      runOnMounted: !0
    }), r = e.position.includes("Right");
    return () => {
      let l;
      return c(jo, {
        class: [n, `${n}-${o}`],
        style: {
          zIndex: i.value
        },
        name: `slide-${r ? "right" : "left"}-notification`,
        onAfterLeave: () => t.emit("afterClose"),
        tag: "ul"
      }, rw(l = e.notifications.map((s) => {
        const u = {
          default: nn(s.title),
          content: nn(s.content),
          icon: nn(s.icon),
          footer: nn(s.footer),
          closeIcon: nn(s.closeIcon),
          closeIconElement: nn(s.closeIconElement)
        };
        return c(ow, {
          key: s.id,
          type: s.type,
          style: s.style,
          class: s.class,
          duration: s.duration,
          closable: s.closable,
          showIcon: s.showIcon,
          resetOnUpdate: s.resetOnUpdate,
          onClose: () => t.emit("close", s.id)
        }, u);
      })) ? l : {
        default: () => [l]
      });
    };
  }
});
class sw {
  constructor(t, n) {
    this.notificationCount = 0, this.add = (r) => {
      var l;
      this.notificationCount++;
      const s = (l = r.id) != null ? l : `__arco_notification_${this.notificationCount}`;
      if (this.notificationIds.has(s))
        return this.update(s, r);
      const u = me({ id: s, ...r });
      return this.notifications.value.push(u), this.notificationIds.add(s), {
        close: () => this.remove(s)
      };
    }, this.update = (r, l) => {
      for (let s = 0; s < this.notifications.value.length; s++)
        if (this.notifications.value[s].id === r) {
          const u = !Ve(l.duration);
          Object.assign(this.notifications.value[s], {
            ...l,
            id: r,
            resetOnUpdate: u
          });
          break;
        }
      return {
        close: () => this.remove(r)
      };
    }, this.remove = (r) => {
      for (let l = 0; l < this.notifications.value.length; l++) {
        const s = this.notifications.value[l];
        if (s.id === r) {
          Ne(s.onClose) && s.onClose(r), this.notifications.value.splice(l, 1), this.notificationIds.delete(r);
          break;
        }
      }
    }, this.clear = () => {
      this.notifications.value.splice(0);
    }, this.destroy = () => {
      this.notifications.value.length === 0 && this.container && (il(null, this.container), document.body.removeChild(this.container), this.container = null, bl[this.position] = void 0);
    };
    const { position: o = "topRight" } = t;
    this.container = jr("notification"), this.notificationIds = /* @__PURE__ */ new Set(), this.notifications = V([]), this.position = o;
    const i = c(aw, {
      notifications: this.notifications.value,
      position: o,
      onClose: this.remove,
      onAfterClose: this.destroy
    });
    (n ?? mv._context) && (i.appContext = n ?? mv._context), il(i, this.container), document.body.appendChild(this.container);
  }
}
const bl = {}, yo = Ir.reduce((e, t) => (e[t] = (n, o) => {
  zt(n) && (n = { content: n });
  const i = { type: t, ...n }, { position: r = "topRight" } = i;
  return bl[r] || (bl[r] = new sw(
    i,
    o
  )), bl[r].add(i);
}, e), {});
yo.remove = (e) => {
  e && Object.values(bl).forEach((t) => t == null ? void 0 : t.remove(e));
};
yo.clear = (e) => {
  var t;
  e ? (t = bl[e]) == null || t.clear() : Object.values(bl).forEach((n) => n == null ? void 0 : n.clear());
};
const mv = {
  ...yo,
  install: (e) => {
    const t = {
      clear: yo.clear
    };
    for (const n of Ir)
      t[n] = (o, i = e._context) => yo[n](o, i);
    e.config.globalProperties.$notification = t;
  },
  _context: null
}, uw = S({
  name: "PageHeader",
  components: { AIconHover: pt, IconLeft: xn },
  props: {
    title: String,
    subtitle: String,
    showBack: {
      type: Boolean,
      default: !0
    }
  },
  emits: [
    "back"
  ],
  setup(e, { emit: t, slots: n }) {
    const o = B("page-header"), i = (l) => {
      t("back", l);
    }, r = a(() => [
      o,
      {
        [`${o}-with-breadcrumb`]: !!n.breadcrumb,
        [`${o}-with-content`]: !!n.default
      }
    ]);
    return {
      prefixCls: o,
      cls: r,
      handleBack: i
    };
  }
});
function cw(e, t, n, o, i, r) {
  const l = J("icon-left"), s = J("a-icon-hover");
  return v(), b("div", {
    class: m(e.cls)
  }, [
    $("div", {
      class: m(`${e.prefixCls}-wrapper`)
    }, [
      e.$slots.breadcrumb ? (v(), b("div", {
        key: 0,
        class: m(`${e.prefixCls}-breadcrumb`)
      }, [
        _(e.$slots, "breadcrumb")
      ], 2)) : te("v-if", !0),
      $("div", {
        class: m(`${e.prefixCls}-header`)
      }, [
        $("span", {
          class: m(`${e.prefixCls}-main`)
        }, [
          e.showBack ? (v(), oe(s, {
            key: 0,
            class: m(`${e.prefixCls}-back-btn`),
            prefix: e.prefixCls,
            onClick: e.handleBack
          }, {
            default: ue(() => [
              _(e.$slots, "back-icon", {}, () => [
                c(l)
              ])
            ]),
            _: 3
          }, 8, ["class", "prefix", "onClick"])) : te("v-if", !0),
          $("span", {
            class: m(`${e.prefixCls}-title`)
          }, [
            _(e.$slots, "title", {}, () => [
              Re(Pe(e.title), 1)
            ])
          ], 2),
          e.$slots.subtitle || e.subtitle ? (v(), b("span", {
            key: 1,
            class: m(`${e.prefixCls}-divider`)
          }, null, 2)) : te("v-if", !0),
          e.$slots.subtitle || e.subtitle ? (v(), b("span", {
            key: 2,
            class: m(`${e.prefixCls}-subtitle`)
          }, [
            _(e.$slots, "subtitle", {}, () => [
              Re(Pe(e.subtitle), 1)
            ])
          ], 2)) : te("v-if", !0)
        ], 2),
        e.$slots.extra ? (v(), b("span", {
          key: 0,
          class: m(`${e.prefixCls}-extra`)
        }, [
          _(e.$slots, "extra")
        ], 2)) : te("v-if", !0)
      ], 2)
    ], 2),
    e.$slots.default ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-content`)
    }, [
      _(e.$slots, "default")
    ], 2)) : te("v-if", !0)
  ], 2);
}
var xs = /* @__PURE__ */ N(uw, [["render", cw]]);
const dw = Object.assign(xs, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + xs.name, xs);
  }
}), fw = S({
  name: "Popconfirm",
  components: {
    ArcoButton: Qt,
    Trigger: Tt,
    IconInfoCircleFill: Xl,
    IconCheckCircleFill: ul,
    IconExclamationCircleFill: Dn,
    IconCloseCircleFill: jl
  },
  props: {
    content: String,
    position: {
      type: String,
      default: "top"
    },
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean,
      default: !1
    },
    type: {
      type: String,
      default: "info"
    },
    okText: String,
    cancelText: String,
    okLoading: {
      type: Boolean,
      default: !1
    },
    okButtonProps: {
      type: Object
    },
    cancelButtonProps: {
      type: Object
    },
    contentClass: {
      type: [String, Array, Object]
    },
    contentStyle: {
      type: Object
    },
    arrowClass: {
      type: [String, Array, Object]
    },
    arrowStyle: {
      type: Object
    },
    popupContainer: {
      type: [String, Object]
    },
    onBeforeOk: {
      type: Function
    },
    onBeforeCancel: {
      type: Function
    }
  },
  emits: {
    "update:popupVisible": (e) => !0,
    popupVisibleChange: (e) => !0,
    ok: () => !0,
    cancel: () => !0
  },
  setup(e, { emit: t }) {
    const n = B("popconfirm"), { t: o } = gt(), i = V(e.defaultPopupVisible), r = a(
      () => {
        var w;
        return (w = e.popupVisible) != null ? w : i.value;
      }
    ), l = V(!1), s = a(() => e.okLoading || l.value);
    let u = 0;
    const f = () => {
      u++, l.value && (l.value = !1), i.value = !1, t("update:popupVisible", !1), t("popupVisibleChange", !1);
    }, d = (w) => {
      w ? (i.value = w, t("update:popupVisible", w), t("popupVisibleChange", w)) : f();
    }, p = async () => {
      const w = u, g = await new Promise(
        async (C) => {
          var P;
          if (Ne(e.onBeforeOk)) {
            let z = e.onBeforeOk((j = !0) => C(j));
            if (($l(z) || !Xt(z)) && (l.value = !0), $l(z))
              try {
                z = (P = await z) != null ? P : !0;
              } catch (j) {
                throw z = !1, j;
              }
            Xt(z) && C(z);
          } else
            C(!0);
        }
      );
      w === u && (g ? (t("ok"), f()) : l.value && (l.value = !1));
    }, h = () => {
      var w;
      let g = !0;
      Ne(e.onBeforeCancel) && (g = (w = e.onBeforeCancel()) != null ? w : !1), g && (t("cancel"), f());
    }, k = a(() => [
      `${n}-popup-content`,
      e.contentClass
    ]), y = a(() => [
      `${n}-popup-arrow`,
      e.arrowClass
    ]);
    return {
      prefixCls: n,
      contentCls: k,
      arrowCls: y,
      computedPopupVisible: r,
      mergedOkLoading: s,
      handlePopupVisibleChange: d,
      handleOk: p,
      handleCancel: h,
      t: o
    };
  }
});
function vw(e, t, n, o, i, r) {
  const l = J("icon-info-circle-fill"), s = J("icon-check-circle-fill"), u = J("icon-exclamation-circle-fill"), f = J("icon-close-circle-fill"), d = J("arco-button"), p = J("trigger");
  return v(), oe(p, {
    class: m(e.prefixCls),
    trigger: "click",
    position: e.position,
    "show-arrow": "",
    "popup-visible": e.computedPopupVisible,
    "popup-offset": 10,
    "popup-container": e.popupContainer,
    "content-class": e.contentCls,
    "content-style": e.contentStyle,
    "arrow-class": e.arrowCls,
    "arrow-style": e.arrowStyle,
    "animation-name": "zoom-in-fade-out",
    "auto-fit-transform-origin": "",
    onPopupVisibleChange: e.handlePopupVisibleChange
  }, {
    content: ue(() => [
      $("div", {
        class: m(`${e.prefixCls}-body`)
      }, [
        $("span", {
          class: m(`${e.prefixCls}-icon`)
        }, [
          _(e.$slots, "icon", {}, () => [
            e.type === "info" ? (v(), oe(l, { key: 0 })) : e.type === "success" ? (v(), oe(s, { key: 1 })) : e.type === "warning" ? (v(), oe(u, { key: 2 })) : e.type === "error" ? (v(), oe(f, { key: 3 })) : te("v-if", !0)
          ])
        ], 2),
        $("span", {
          class: m(`${e.prefixCls}-content`)
        }, [
          _(e.$slots, "content", {}, () => [
            Re(Pe(e.content), 1)
          ])
        ], 2)
      ], 2),
      $("div", {
        class: m(`${e.prefixCls}-footer`)
      }, [
        c(d, se({ size: "mini" }, e.cancelButtonProps, { onClick: e.handleCancel }), {
          default: ue(() => [
            Re(Pe(e.cancelText || e.t("popconfirm.cancelText")), 1)
          ]),
          _: 1
        }, 16, ["onClick"]),
        c(d, se({
          type: "primary",
          size: "mini"
        }, e.okButtonProps, {
          loading: e.mergedOkLoading,
          onClick: e.handleOk
        }), {
          default: ue(() => [
            Re(Pe(e.okText || e.t("popconfirm.okText")), 1)
          ]),
          _: 1
        }, 16, ["loading", "onClick"])
      ], 2)
    ]),
    default: ue(() => [
      _(e.$slots, "default")
    ]),
    _: 3
  }, 8, ["class", "position", "popup-visible", "popup-container", "content-class", "content-style", "arrow-class", "arrow-style", "onPopupVisibleChange"]);
}
var Rs = /* @__PURE__ */ N(fw, [["render", vw]]);
const pw = Object.assign(Rs, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Rs.name, Rs);
  }
}), mw = {
  small: 3,
  medium: 4,
  large: 8
}, hw = (e) => {
  if (e)
    return Qe(e) ? {
      backgroundImage: `linear-gradient(to right, ${Object.keys(e).map((n) => `${e[n]} ${n}`).join(",")})`
    } : {
      backgroundColor: e
    };
}, kw = S({
  name: "ProgressLine",
  components: {
    IconExclamationCircleFill: Dn
  },
  props: {
    percent: {
      type: Number,
      default: 0
    },
    animation: {
      type: Boolean,
      default: !1
    },
    size: {
      type: String,
      default: "medium"
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    width: {
      type: [Number, String],
      default: "100%"
    },
    color: {
      type: [String, Object],
      default: void 0
    },
    trackColor: String,
    formatText: {
      type: Function,
      default: void 0
    },
    status: {
      type: String
    },
    showText: Boolean
  },
  setup(e) {
    const t = B("progress-line"), n = a(() => e.strokeWidth !== 4 ? e.strokeWidth : mw[e.size]), o = a(() => `${ln.times(e.percent, 100)}%`), i = a(() => ({
      width: e.width,
      height: `${n.value}px`,
      backgroundColor: e.trackColor
    })), r = a(() => ({
      width: `${e.percent * 100}%`,
      ...hw(e.color)
    }));
    return {
      prefixCls: t,
      style: i,
      barStyle: r,
      text: o
    };
  }
}), gw = ["aria-valuenow"];
function yw(e, t, n, o, i, r) {
  const l = J("icon-exclamation-circle-fill");
  return v(), b("div", {
    role: "progressbar",
    "aria-valuemin": "0",
    "aria-valuemax": "100",
    "aria-valuenow": e.percent,
    class: m(`${e.prefixCls}-wrapper`)
  }, [
    $("div", {
      class: m(e.prefixCls),
      style: F(e.style)
    }, [
      $("div", {
        class: m(`${e.prefixCls}-bar-buffer`)
      }, null, 2),
      $("div", {
        class: m([`${e.prefixCls}-bar`]),
        style: F(e.barStyle)
      }, null, 6)
    ], 6),
    e.showText ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-text`)
    }, [
      _(e.$slots, "text", { percent: e.percent }, () => [
        Re(Pe(e.text) + " ", 1),
        e.status === "danger" ? (v(), oe(l, { key: 0 })) : te("v-if", !0)
      ])
    ], 2)) : te("v-if", !0)
  ], 10, gw);
}
var bw = /* @__PURE__ */ N(kw, [["render", yw]]);
const Cw = S({
  name: "IconExclamation",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-exclamation`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), $w = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function ww(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M23 9h2v21h-2z" }, null, -1),
    $("path", {
      fill: "currentColor",
      stroke: "none",
      d: "M23 9h2v21h-2z"
    }, null, -1),
    $("path", { d: "M23 37h2v2h-2z" }, null, -1),
    $("path", {
      fill: "currentColor",
      stroke: "none",
      d: "M23 37h2v2h-2z"
    }, null, -1)
  ]), 14, $w);
}
var Hs = /* @__PURE__ */ N(Cw, [["render", ww]]);
const o0 = Object.assign(Hs, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Hs.name, Hs);
  }
}), Sw = S({
  name: "IconCheck",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-check`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), zw = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Lw(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M41.678 11.05 19.05 33.678 6.322 20.95" }, null, -1)
  ]), 14, zw);
}
var qs = /* @__PURE__ */ N(Sw, [["render", Lw]]);
const Wo = Object.assign(qs, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + qs.name, qs);
  }
});
let wp = 0;
const jw = {
  mini: 16,
  small: 48,
  medium: 64,
  large: 80
}, Pw = {
  mini: 4,
  small: 3,
  medium: 4,
  large: 4
}, Iw = S({
  name: "ProgressCircle",
  components: {
    IconExclamation: o0,
    IconCheck: Wo
  },
  props: {
    percent: {
      type: Number,
      default: 0
    },
    type: {
      type: String
    },
    size: {
      type: String,
      default: "medium"
    },
    strokeWidth: {
      type: Number
    },
    width: {
      type: Number,
      default: void 0
    },
    color: {
      type: [String, Object],
      default: void 0
    },
    trackColor: String,
    status: {
      type: String,
      default: void 0
    },
    showText: {
      type: Boolean,
      default: !0
    },
    pathStrokeWidth: {
      type: Number
    }
  },
  setup(e) {
    const t = B("progress-circle"), n = Qe(e.color), o = a(() => {
      var p;
      return (p = e.width) != null ? p : jw[e.size];
    }), i = a(
      () => {
        var p;
        return (p = e.strokeWidth) != null ? p : e.size === "mini" ? o.value / 2 : Pw[e.size];
      }
    ), r = a(
      () => {
        var p;
        return (p = e.pathStrokeWidth) != null ? p : e.size === "mini" ? i.value : Math.max(2, i.value - 2);
      }
    ), l = a(
      () => (o.value - i.value) / 2
    ), s = a(() => Math.PI * 2 * l.value), u = a(() => o.value / 2), f = a(() => (wp += 1, `${t}-linear-gradient-${wp}`)), d = a(() => `${ln.times(e.percent, 100)}%`);
    return {
      prefixCls: t,
      isLinearGradient: n,
      radius: l,
      text: d,
      perimeter: s,
      center: u,
      mergedWidth: o,
      mergedStrokeWidth: i,
      mergedPathStrokeWidth: r,
      linearGradientId: f
    };
  }
}), Bw = ["aria-valuenow"], Mw = ["viewBox"], Nw = { key: 0 }, Ow = ["id"], Vw = ["offset", "stop-color"], Tw = ["cx", "cy", "r", "stroke-width"], Aw = ["cx", "cy", "r", "stroke-width"];
function Ew(e, t, n, o, i, r) {
  const l = J("icon-check"), s = J("icon-exclamation");
  return v(), b("div", {
    role: "progressbar",
    "aria-valuemin": "0",
    "aria-valuemax": "100",
    "aria-valuenow": e.percent,
    class: m(`${e.prefixCls}-wrapper`),
    style: F({ width: `${e.mergedWidth}px`, height: `${e.mergedWidth}px` })
  }, [
    e.type === "circle" && e.size === "mini" && e.status === "success" ? (v(), oe(l, {
      key: 0,
      style: F({ fontSize: e.mergedWidth - 2, color: e.color })
    }, null, 8, ["style"])) : (v(), b("svg", {
      key: 1,
      viewBox: `0 0 ${e.mergedWidth} ${e.mergedWidth}`,
      class: m(`${e.prefixCls}-svg`)
    }, [
      e.isLinearGradient ? (v(), b("defs", Nw, [
        $("linearGradient", {
          id: e.linearGradientId,
          x1: "0",
          y1: "1",
          x2: "0",
          y2: "0"
        }, [
          (v(!0), b(Ae, null, St(Object.keys(e.color), (u) => (v(), b("stop", {
            key: u,
            offset: u,
            "stop-color": e.color[u]
          }, null, 8, Vw))), 128))
        ], 8, Ow)
      ])) : te("v-if", !0),
      $("circle", {
        class: m(`${e.prefixCls}-bg`),
        fill: "none",
        cx: e.center,
        cy: e.center,
        r: e.radius,
        "stroke-width": e.mergedPathStrokeWidth,
        style: F({
          stroke: e.trackColor
        })
      }, null, 14, Tw),
      $("circle", {
        class: m(`${e.prefixCls}-bar`),
        fill: "none",
        cx: e.center,
        cy: e.center,
        r: e.radius,
        "stroke-width": e.mergedStrokeWidth,
        style: F({
          stroke: e.isLinearGradient ? `url(#${e.linearGradientId})` : e.color,
          strokeDasharray: e.perimeter,
          strokeDashoffset: (e.percent >= 1 ? 0 : 1 - e.percent) * e.perimeter
        })
      }, null, 14, Aw)
    ], 10, Mw)),
    e.showText && e.size !== "mini" ? (v(), b("div", {
      key: 2,
      class: m(`${e.prefixCls}-text`)
    }, [
      _(e.$slots, "text", { percent: e.percent }, () => [
        e.status === "danger" ? (v(), oe(s, { key: 0 })) : e.status === "success" ? (v(), oe(l, { key: 1 })) : (v(), b(Ae, { key: 2 }, [
          Re(Pe(e.text), 1)
        ], 64))
      ])
    ], 2)) : te("v-if", !0)
  ], 14, Bw);
}
var Ww = /* @__PURE__ */ N(Iw, [["render", Ew]]);
const Fw = S({
  name: "ProgressSteps",
  components: {
    IconExclamationCircleFill: Dn
  },
  props: {
    steps: {
      type: Number,
      default: 0
    },
    percent: {
      type: Number,
      default: 0
    },
    size: {
      type: String
    },
    color: {
      type: [String, Object],
      default: void 0
    },
    trackColor: String,
    strokeWidth: {
      type: Number
    },
    status: {
      type: String,
      default: void 0
    },
    showText: {
      type: Boolean,
      default: !0
    }
  },
  setup(e) {
    const t = B("progress-steps"), n = a(
      () => {
        var r;
        return ((r = e.strokeWidth) != null ? r : e.size === "small") ? 8 : 4;
      }
    ), o = a(
      () => [...Array(e.steps)].map((r, l) => e.percent > 0 && e.percent > 1 / e.steps * l)
    ), i = a(() => `${ln.times(e.percent, 100)}%`);
    return {
      prefixCls: t,
      stepList: o,
      mergedStrokeWidth: n,
      text: i
    };
  }
}), Dw = ["aria-valuenow"];
function xw(e, t, n, o, i, r) {
  const l = J("icon-exclamation-circle-fill");
  return v(), b("div", {
    role: "progressbar",
    "aria-valuemin": "0",
    "aria-valuemax": "100",
    "aria-valuenow": e.percent,
    class: m(`${e.prefixCls}-wrapper`)
  }, [
    $("div", {
      class: m(e.prefixCls),
      style: F({ height: `${e.mergedStrokeWidth}px` })
    }, [
      (v(!0), b(Ae, null, St(e.stepList, (s, u) => (v(), b("div", {
        key: u,
        class: m([
          `${e.prefixCls}-item`,
          {
            [`${e.prefixCls}-item-active`]: s
          }
        ]),
        style: F({
          backgroundColor: s ? e.color : e.trackColor
        })
      }, null, 6))), 128))
    ], 6),
    e.showText ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-text`)
    }, [
      _(e.$slots, "text", { percent: e.percent }, () => [
        Re(Pe(e.text) + " ", 1),
        e.status === "danger" ? (v(), oe(l, { key: 0 })) : te("v-if", !0)
      ])
    ], 2)) : te("v-if", !0)
  ], 10, Dw);
}
var Rw = /* @__PURE__ */ N(Fw, [["render", xw]]);
const Hw = S({
  name: "Progress",
  components: {
    ProgressLine: bw,
    ProgressCircle: Ww,
    ProgressSteps: Rw
  },
  props: {
    type: {
      type: String,
      default: "line"
    },
    size: {
      type: String
    },
    percent: {
      type: Number,
      default: 0
    },
    steps: {
      type: Number,
      default: 0
    },
    animation: {
      type: Boolean,
      default: !1
    },
    strokeWidth: {
      type: Number
    },
    width: {
      type: [Number, String]
    },
    color: {
      type: [String, Object]
    },
    trackColor: String,
    bufferColor: {
      type: [String, Object]
    },
    showText: {
      type: Boolean,
      default: !0
    },
    status: {
      type: String
    }
  },
  setup(e) {
    const t = B("progress"), { size: n } = ve(e), o = a(() => e.steps > 0 ? "steps" : e.type), i = a(() => e.status || (e.percent >= 1 ? "success" : "normal")), { mergedSize: r } = xt(n);
    return {
      cls: a(() => [
        t,
        `${t}-type-${o.value}`,
        `${t}-size-${r.value}`,
        `${t}-status-${i.value}`
      ]),
      computedStatus: i,
      mergedSize: r
    };
  }
});
function qw(e, t, n, o, i, r) {
  const l = J("progress-steps"), s = J("progress-line"), u = J("progress-circle");
  return v(), b("div", {
    class: m(e.cls)
  }, [
    e.steps > 0 ? (v(), oe(l, {
      key: 0,
      "stroke-width": e.strokeWidth,
      percent: e.percent,
      color: e.color,
      "track-color": e.trackColor,
      width: e.width,
      steps: e.steps,
      size: e.mergedSize,
      "show-text": e.showText
    }, kt({ _: 2 }, [
      e.$slots.text ? {
        name: "text",
        fn: ue((f) => [
          _(e.$slots, "text", dt(Gt(f)))
        ]),
        key: "0"
      } : void 0
    ]), 1032, ["stroke-width", "percent", "color", "track-color", "width", "steps", "size", "show-text"])) : e.type === "line" && e.mergedSize !== "mini" ? (v(), oe(s, {
      key: 1,
      "stroke-width": e.strokeWidth,
      animation: e.animation,
      percent: e.percent,
      color: e.color,
      "track-color": e.trackColor,
      size: e.mergedSize,
      "buffer-color": e.bufferColor,
      width: e.width,
      "show-text": e.showText,
      status: e.computedStatus
    }, kt({ _: 2 }, [
      e.$slots.text ? {
        name: "text",
        fn: ue((f) => [
          _(e.$slots, "text", dt(Gt(f)))
        ]),
        key: "0"
      } : void 0
    ]), 1032, ["stroke-width", "animation", "percent", "color", "track-color", "size", "buffer-color", "width", "show-text", "status"])) : (v(), oe(u, {
      key: 2,
      type: e.type,
      "stroke-width": e.type === "line" ? e.strokeWidth || 4 : e.strokeWidth,
      "path-stroke-width": e.type === "line" ? e.strokeWidth || 4 : e.strokeWidth,
      width: e.width,
      percent: e.percent,
      color: e.color,
      "track-color": e.trackColor,
      size: e.mergedSize,
      "show-text": e.showText,
      status: e.computedStatus
    }, kt({ _: 2 }, [
      e.$slots.text ? {
        name: "text",
        fn: ue((f) => [
          _(e.$slots, "text", dt(Gt(f)))
        ]),
        key: "0"
      } : void 0
    ]), 1032, ["type", "stroke-width", "path-stroke-width", "width", "percent", "color", "track-color", "size", "show-text", "status"]))
  ], 2);
}
var Zs = /* @__PURE__ */ N(Hw, [["render", qw]]);
const n2 = Object.assign(Zs, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Zs.name, Zs);
  }
}), Zw = S({
  name: "IconStarFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-star-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Kw = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Yw(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M22.683 5.415c.568-1.043 2.065-1.043 2.634 0l5.507 10.098a1.5 1.5 0 0 0 1.04.756l11.306 2.117c1.168.219 1.63 1.642.814 2.505l-7.902 8.359a1.5 1.5 0 0 0-.397 1.223l1.48 11.407c.153 1.177-1.058 2.057-2.131 1.548l-10.391-4.933a1.5 1.5 0 0 0-1.287 0l-10.39 4.933c-1.073.51-2.284-.37-2.131-1.548l1.48-11.407a1.5 1.5 0 0 0-.398-1.223L4.015 20.89c-.816-.863-.353-2.286.814-2.505l11.306-2.117a1.5 1.5 0 0 0 1.04-.756l5.508-10.098Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, Kw);
}
var Ks = /* @__PURE__ */ N(Zw, [["render", Yw]]);
const l2 = Object.assign(Ks, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ks.name, Ks);
  }
}), Uw = S({
  name: "IconFaceMehFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-face-meh-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Gw = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Xw(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4 4 12.954 4 24s8.954 20 20 20Zm7.321-26.873a2.625 2.625 0 1 1 0 5.25 2.625 2.625 0 0 1 0-5.25Zm-14.646 0a2.625 2.625 0 1 1 0 5.25 2.625 2.625 0 0 1 0-5.25ZM15.999 30a2 2 0 0 1 2-2h12a2 2 0 1 1 0 4H18a2 2 0 0 1-2-2Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, Gw);
}
var Ys = /* @__PURE__ */ N(Uw, [["render", Xw]]);
const hv = Object.assign(Ys, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ys.name, Ys);
  }
}), Qw = S({
  name: "IconFaceSmileFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-face-smile-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), _w = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Jw(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4 4 12.954 4 24s8.954 20 20 20Zm7.321-26.873a2.625 2.625 0 1 1 0 5.25 2.625 2.625 0 0 1 0-5.25Zm-14.646 0a2.625 2.625 0 1 1 0 5.25 2.625 2.625 0 0 1 0-5.25Zm-.355 9.953a1.91 1.91 0 0 1 2.694.177 6.66 6.66 0 0 0 5.026 2.279c1.918 0 3.7-.81 4.961-2.206a1.91 1.91 0 0 1 2.834 2.558 10.476 10.476 0 0 1-7.795 3.466 10.477 10.477 0 0 1-7.897-3.58 1.91 1.91 0 0 1 .177-2.694Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, _w);
}
var Us = /* @__PURE__ */ N(Qw, [["render", Jw]]);
const o2 = Object.assign(Us, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Us.name, Us);
  }
}), e7 = S({
  name: "IconFaceFrownFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-face-frown-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), t7 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function n7(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4 4 12.954 4 24s8.954 20 20 20Zm7.322-26.873a2.625 2.625 0 1 1 0 5.25 2.625 2.625 0 0 1 0-5.25Zm-14.646 0a2.625 2.625 0 1 1 0 5.25 2.625 2.625 0 0 1 0-5.25ZM31.68 32.88a1.91 1.91 0 0 1-2.694-.176 6.66 6.66 0 0 0-5.026-2.28c-1.918 0-3.701.81-4.962 2.207a1.91 1.91 0 0 1-2.834-2.559 10.476 10.476 0 0 1 7.796-3.465c3.063 0 5.916 1.321 7.896 3.58a1.909 1.909 0 0 1-.176 2.693Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, t7);
}
var Gs = /* @__PURE__ */ N(e7, [["render", n7]]);
const i2 = Object.assign(Gs, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Gs.name, Gs);
  }
});
var Xs = S({
  name: "Rate",
  props: {
    count: {
      type: Number,
      default: 5
    },
    modelValue: {
      type: Number,
      default: void 0
    },
    defaultValue: {
      type: Number,
      default: 0
    },
    allowHalf: {
      type: Boolean,
      default: !1
    },
    allowClear: {
      type: Boolean,
      default: !1
    },
    grading: {
      type: Boolean,
      default: !1
    },
    readonly: {
      type: Boolean,
      default: !1
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    color: {
      type: [String, Object]
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0,
    hoverChange: (e) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      modelValue: o
    } = ve(e), i = B("rate"), {
      mergedDisabled: r,
      eventHandlers: l
    } = mt({
      disabled: un(e, "disabled")
    }), s = V(e.defaultValue), u = V(!1);
    ze(o, (E) => {
      (Ve(E) || Jt(E)) && (s.value = 0);
    });
    const f = V(0), d = a(() => {
      var E;
      return (E = e.modelValue) != null ? E : s.value;
    }), p = a(() => {
      const E = e.allowHalf ? ln.times(ln.round(ln.divide(d.value, 0.5), 0), 0.5) : Math.round(d.value);
      return f.value || E;
    }), h = a(() => r.value || e.readonly), k = a(() => [...Array(e.grading ? 5 : e.count)]), y = a(() => {
      var E;
      if (zt(e.color))
        return k.value.map(() => e.color);
      if (Qe(e.color)) {
        const K = Object.keys(e.color).map((T) => Number(T)).sort((T, X) => X - T);
        let q = (E = K.pop()) != null ? E : k.value.length;
        return k.value.map((T, X) => {
          var Y;
          return X + 1 > q && (q = (Y = K.pop()) != null ? Y : q), e.color[String(q)];
        });
      }
    }), w = () => {
      f.value && (f.value = 0, t("hoverChange", 0));
    }, g = (E, K) => {
      const q = K && e.allowHalf ? E + 0.5 : E + 1;
      q !== f.value && (f.value = q, t("hoverChange", q));
    }, C = (E, K) => {
      var q, T, X, Y;
      const Z = K && e.allowHalf ? E + 0.5 : E + 1;
      u.value = !0, Z !== d.value ? (s.value = Z, t("update:modelValue", Z), t("change", Z), (T = (q = l.value) == null ? void 0 : q.onChange) == null || T.call(q)) : e.allowClear && (s.value = 0, t("update:modelValue", 0), t("change", 0), (Y = (X = l.value) == null ? void 0 : X.onChange) == null || Y.call(X));
    }, P = (E) => {
      u.value && E + 1 >= d.value - 1 && (u.value = !1);
    }, z = (E, K) => E > K ? c(hv, null, null) : K <= 2 ? c(i2, null, null) : K <= 3 ? c(hv, null, null) : c(o2, null, null), j = (E, K = !1) => ({
      role: "radio",
      "aria-checked": E + (K ? 0.5 : 1) <= d.value,
      "aria-setsize": k.value.length,
      "aria-posinset": E + (K ? 0.5 : 1)
    }), I = (E) => e.grading ? z(E, p.value) : n.character ? n.character({
      index: E
    }) : c(l2, null, null), L = (E) => {
      const K = h.value ? {} : {
        onMouseenter: () => g(E, !0),
        onClick: () => C(E, !0)
      }, q = h.value ? {} : {
        onMouseenter: () => g(E, !1),
        onClick: () => C(E, !1)
      }, T = u.value ? {
        animationDelay: `${50 * E}ms`
      } : void 0, X = Math.ceil(p.value) - 1, Y = y.value && e.allowHalf && E + 0.5 === p.value ? {
        color: y.value[X]
      } : void 0, Z = y.value && E + 1 <= p.value ? {
        color: y.value[X]
      } : void 0, U = [`${i}-character`, {
        [`${i}-character-half`]: e.allowHalf && E + 0.5 === p.value,
        [`${i}-character-full`]: E + 1 <= p.value,
        [`${i}-character-scale`]: u.value && E + 1 < d.value
      }];
      return c("div", se({
        class: U,
        style: T
      }, e.allowHalf ? void 0 : j(E), {
        onAnimationend: () => P(E)
      }), [c("div", se({
        class: `${i}-character-left`,
        style: Y
      }, K, e.allowHalf ? j(E, !0) : void 0), [I(E)]), c("div", se({
        class: `${i}-character-right`,
        style: Z
      }, q, e.allowHalf ? j(E) : void 0), [I(E)])]);
    }, M = a(() => [i, {
      [`${i}-readonly`]: e.readonly,
      [`${i}-disabled`]: r.value
    }]);
    return () => c("div", {
      class: M.value,
      onMouseleave: w
    }, [k.value.map((E, K) => L(K))]);
  }
});
const l7 = Object.assign(Xs, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Xs.name, Xs);
  }
}), o7 = S({
  name: "IconInfo",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-info`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), i7 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function r7(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M25 39h-2V18h2z" }, null, -1),
    $("path", {
      fill: "currentColor",
      stroke: "none",
      d: "M25 39h-2V18h2z"
    }, null, -1),
    $("path", { d: "M25 11h-2V9h2z" }, null, -1),
    $("path", {
      fill: "currentColor",
      stroke: "none",
      d: "M25 11h-2V9h2z"
    }, null, -1)
  ]), 14, i7);
}
var Qs = /* @__PURE__ */ N(o7, [["render", r7]]);
const r2 = Object.assign(Qs, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Qs.name, Qs);
  }
});
var a7 = S({
  name: "ResultForbidden",
  render() {
    return c("svg", {
      viewBox: "0 0 213 213",
      height: "100%",
      width: "100%",
      style: {
        fillRule: "evenodd",
        clipRule: "evenodd",
        strokeLinejoin: "round",
        strokeMiterlimit: 2
      }
    }, [c("g", {
      transform: "matrix(1,0,0,1,-871.485,-445.62)"
    }, [c("g", null, [c("g", {
      transform: "matrix(1,0,0,1,-75.2684,-87.3801)"
    }, [c("circle", {
      cx: "1053.23",
      cy: "639.477",
      r: "106.477",
      style: {
        fill: "rgb(235, 238, 246)"
      }
    }, null)]), c("g", {
      transform: "matrix(1,0,0,1,246.523,295.575)"
    }, [c("g", {
      transform: "matrix(0.316667,0,0,0.316667,277.545,71.0298)"
    }, [c("g", {
      transform: "matrix(0.989011,-0.571006,1.14201,0.659341,-335.171,81.4498)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(253, 243, 228)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.164835,-0.0951676,1.14201,0.659341,116.224,-179.163)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(202, 174, 136)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.978261,-0.564799,1.26804e-16,1.30435,-337.046,42.0327)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.267591,-0.154493,3.46856e-17,0.356787,992.686,475.823)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(102, 102, 102)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.28257,-0.740494,1.23317e-16,1.7101,1501.14,624.071)"
    }, [c("g", {
      transform: "matrix(1,0,0,1,-6,-6)"
    }, [c("path", {
      d: "M2.25,10.5C2.25,10.5 1.5,10.5 1.5,9.75C1.5,9 2.25,6.75 6,6.75C9.75,6.75 10.5,9 10.5,9.75C10.5,10.5 9.75,10.5 9.75,10.5L2.25,10.5ZM6,6C7.234,6 8.25,4.984 8.25,3.75C8.25,2.516 7.234,1.5 6,1.5C4.766,1.5 3.75,2.516 3.75,3.75C3.75,4.984 4.766,6 6,6Z",
      style: {
        fill: "white"
      }
    }, null)])]), c("g", {
      transform: "matrix(0.725806,0.419045,1.75755e-17,1.01444,155.314,212.138)"
    }, [c("rect", {
      x: "1663.92",
      y: "-407.511",
      width: "143.183",
      height: "118.292",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.58977,-0.917857,1.15976e-16,2.2425,-1270.46,-614.379)"
    }, [c("rect", {
      x: "1748.87",
      y: "1226.67",
      width: "10.895",
      height: "13.378",
      style: {
        fill: "rgb(132, 97, 0)"
      }
    }, null)])]), c("g", {
      transform: "matrix(0.182997,0.105653,-0.494902,0.285732,814.161,66.3087)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fillOpacity: 0.1
      }
    }, null)]), c("g", {
      transform: "matrix(0.316667,0,0,0.316667,237.301,94.2647)"
    }, [c("g", {
      transform: "matrix(0.989011,-0.571006,1.14201,0.659341,-335.171,81.4498)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(253, 243, 228)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.164835,-0.0951676,1.14201,0.659341,116.224,-179.163)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(202, 174, 136)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.978261,-0.564799,1.26804e-16,1.30435,-337.046,42.0327)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.267591,-0.154493,3.46856e-17,0.356787,992.686,475.823)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(102, 102, 102)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.28257,-0.740494,1.23317e-16,1.7101,1501.14,624.071)"
    }, [c("g", {
      transform: "matrix(1,0,0,1,-6,-6)"
    }, [c("path", {
      d: "M2.25,10.5C2.25,10.5 1.5,10.5 1.5,9.75C1.5,9 2.25,6.75 6,6.75C9.75,6.75 10.5,9 10.5,9.75C10.5,10.5 9.75,10.5 9.75,10.5L2.25,10.5ZM6,6C7.234,6 8.25,4.984 8.25,3.75C8.25,2.516 7.234,1.5 6,1.5C4.766,1.5 3.75,2.516 3.75,3.75C3.75,4.984 4.766,6 6,6Z",
      style: {
        fill: "white"
      }
    }, null)])]), c("g", {
      transform: "matrix(0.725806,0.419045,1.75755e-17,1.01444,155.314,212.138)"
    }, [c("rect", {
      x: "1663.92",
      y: "-407.511",
      width: "143.183",
      height: "118.292",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.58977,-0.917857,1.15976e-16,2.2425,-1270.46,-614.379)"
    }, [c("rect", {
      x: "1748.87",
      y: "1226.67",
      width: "10.895",
      height: "13.378",
      style: {
        fill: "rgb(132, 97, 0)"
      }
    }, null)])]), c("g", {
      transform: "matrix(0.474953,0,0,0.474953,538.938,8.95289)"
    }, [c("g", {
      transform: "matrix(0.180615,0.104278,-0.973879,0.562269,790.347,286.159)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fillOpacity: 0.1
      }
    }, null)]), c("g", {
      transform: "matrix(0.473356,0,0,0.473356,294.481,129.741)"
    }, [c("g", null, [c("g", {
      transform: "matrix(0.1761,-0.101671,1.73518e-16,1.22207,442.564,7.31508)"
    }, [c("rect", {
      x: "202.62",
      y: "575.419",
      width: "124.002",
      height: "259.402",
      style: {
        fill: "rgb(235, 235, 235)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0922781,0.0532768,2.03964e-16,2.20569,405.236,-248.842)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(34, 34, 34)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.147541,-0.0851831,1.52371e-16,1.23446,454.294,-3.8127)"
    }, [c("rect", {
      x: "202.62",
      y: "575.419",
      width: "124.002",
      height: "259.402",
      style: {
        fill: "rgb(51, 51, 51)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0921286,0.0531905,-0.126106,0.0728076,474.688,603.724)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(102, 102, 102)"
      }
    }, null)])])]), c("g", {
      transform: "matrix(0.473356,0,0,0.473356,192.621,188.549)"
    }, [c("g", null, [c("g", {
      transform: "matrix(0.1761,-0.101671,1.73518e-16,1.22207,442.564,7.31508)"
    }, [c("rect", {
      x: "202.62",
      y: "575.419",
      width: "124.002",
      height: "259.402",
      style: {
        fill: "rgb(235, 235, 235)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0922781,0.0532768,2.03964e-16,2.20569,405.236,-248.842)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(34, 34, 34)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.147541,-0.0851831,1.52371e-16,1.23446,454.294,-3.8127)"
    }, [c("rect", {
      x: "202.62",
      y: "575.419",
      width: "124.002",
      height: "259.402",
      style: {
        fill: "rgb(51, 51, 51)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0921286,0.0531905,-0.126106,0.0728076,474.688,603.724)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(102, 102, 102)"
      }
    }, null)])])]), c("g", {
      transform: "matrix(0.668111,0,0,0.668111,-123.979,-49.2109)"
    }, [c("g", {
      transform: "matrix(0.0349225,0.0201625,1.81598e-17,0.220789,974.758,729.412)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(235, 235, 235)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.1164,-0.644557,0,0.220789,42.5091,1294.14)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(235, 235, 235)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0349225,0.0201625,-1.52814,0.882275,1593.11,461.746)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(102, 102, 102)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.1164,-0.644557,0,0.220789,49.4442,1298.14)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(51, 51, 51)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0349225,0.0201625,1.81598e-17,0.220789,753.056,857.412)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(34, 34, 34)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,898.874,529.479)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,930.12,511.44)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,961.365,493.4)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(248, 248, 248)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,992.61,475.361)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(248, 248, 248)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,1023.86,457.321)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(248, 248, 248)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,1056.25,438.617)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,1085.74,421.589)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)])]), c("g", {
      transform: "matrix(0.668111,0,0,0.668111,-123.979,-91.97)"
    }, [c("g", {
      transform: "matrix(0.0349225,0.0201625,1.81598e-17,0.220789,974.758,729.412)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(235, 235, 235)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.1164,-0.644557,0,0.220789,42.5091,1294.14)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(235, 235, 235)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0349225,0.0201625,-1.52814,0.882275,1593.11,461.746)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(102, 102, 102)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.1164,-0.644557,0,0.220789,49.4442,1298.14)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(51, 51, 51)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0349225,0.0201625,1.81598e-17,0.220789,753.056,857.412)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fill: "rgb(34, 34, 34)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,898.874,529.479)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,930.12,511.44)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,961.365,493.4)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(248, 248, 248)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,992.61,475.361)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(248, 248, 248)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,1023.86,457.321)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(248, 248, 248)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,1056.25,438.617)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.142968,-0.0825428,-0.207261,0.478709,1085.74,421.589)"
    }, [c("rect", {
      x: "831",
      y: "1023.79",
      width: "89.214",
      height: "89.214",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)])]), c("g", {
      transform: "matrix(0.701585,5.16096e-35,-5.16096e-35,0.701585,-546.219,-21.3487)"
    }, [c("g", {
      transform: "matrix(0.558202,-0.322278,0,0.882275,1033.27,615.815)"
    }, [c("path", {
      d: "M855.598,410.446C855.598,407.244 852.515,404.643 848.718,404.643L663.891,404.643C660.094,404.643 657.012,407.244 657.012,410.446L657.012,543.92C657.012,547.123 660.094,549.723 663.891,549.723L848.718,549.723C852.515,549.723 855.598,547.123 855.598,543.92L855.598,410.446Z",
      style: {
        fill: "white"
      }
    }, null)]), c("g", {
      transform: "matrix(0.558202,-0.322278,0,0.882275,1035.25,616.977)"
    }, [c("path", {
      d: "M855.598,410.446C855.598,407.244 852.515,404.643 848.718,404.643L663.891,404.643C660.094,404.643 657.012,407.244 657.012,410.446L657.012,543.92C657.012,547.123 660.094,549.723 663.891,549.723L848.718,549.723C852.515,549.723 855.598,547.123 855.598,543.92L855.598,410.446Z",
      style: {
        fill: "white"
      }
    }, null)]), c("g", {
      transform: "matrix(1,0,0,1,418.673,507.243)"
    }, [c("path", {
      d: "M1088.34,192.063C1089.79,191.209 1090.78,191.821 1090.78,191.821L1092.71,192.944C1092.71,192.944 1092.29,192.721 1091.7,192.763C1090.99,192.813 1090.34,193.215 1090.34,193.215C1090.34,193.215 1088.85,192.362 1088.34,192.063Z",
      style: {
        fill: "rgb(248, 248, 248)"
      }
    }, null)]), c("g", {
      transform: "matrix(1,0,0,1,235.984,-39.1315)"
    }, [c("path", {
      d: "M1164.02,805.247C1164.05,802.517 1165.64,799.379 1167.67,798.118L1169.67,799.272C1167.58,800.648 1166.09,803.702 1166.02,806.402L1164.02,805.247Z",
      style: {
        fill: "url(#_Linear1)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.396683,0,0,0.396683,1000.22,516.921)"
    }, [c("path", {
      d: "M1011.2,933.14C1009.31,932.075 1008.05,929.696 1007.83,926.324L1012.87,929.235C1012.87,929.235 1012.96,930.191 1013.04,930.698C1013.16,931.427 1013.42,932.344 1013.62,932.845C1013.79,933.255 1014.59,935.155 1016.22,936.046C1015.83,935.781 1011.19,933.139 1011.19,933.139L1011.2,933.14Z",
      style: {
        fill: "rgb(238, 238, 238)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.253614,-0.146424,4.87691e-17,0.338152,1209.98,830.02)"
    }, [c("circle", {
      cx: "975.681",
      cy: "316.681",
      r: "113.681",
      style: {
        fill: "rgb(245, 63, 63)"
      }
    }, null), c("g", {
      transform: "matrix(1.08844,0,0,0.61677,-99.9184,125.436)"
    }, [c("path", {
      d: "M1062,297.556C1062,296.697 1061.61,296 1061.12,296L915.882,296C915.395,296 915,296.697 915,297.556L915,333.356C915,334.215 915.395,334.912 915.882,334.912L1061.12,334.912C1061.61,334.912 1062,334.215 1062,333.356L1062,297.556Z",
      style: {
        fill: "white"
      }
    }, null)])]), c("g", {
      transform: "matrix(5.57947,-3.22131,0.306277,0.176829,-6260.71,4938.32)"
    }, [c("rect", {
      x: "1335.54",
      y: "694.688",
      width: "18.525",
      height: "6.511",
      style: {
        fill: "rgb(248, 248, 248)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.10726,0.0619268,-1.83335e-14,18.1609,1256.76,-11932.8)"
    }, [c("rect", {
      x: "1335.54",
      y: "694.688",
      width: "18.525",
      height: "6.511",
      style: {
        fill: "rgb(238, 238, 238)"
      }
    }, null)])])]), c("g", {
      transform: "matrix(0.316667,0,0,0.316667,269.139,37.8829)"
    }, [c("g", {
      transform: "matrix(0.989011,-0.571006,1.14201,0.659341,-335.171,81.4498)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(253, 243, 228)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.164835,-0.0951676,1.14201,0.659341,116.224,-179.163)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(202, 174, 136)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.978261,-0.564799,1.26804e-16,1.30435,-337.046,42.0327)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.267591,-0.154493,3.46856e-17,0.356787,992.686,475.823)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(102, 102, 102)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.28257,-0.740494,1.23317e-16,1.7101,1501.14,624.071)"
    }, [c("g", {
      transform: "matrix(1,0,0,1,-6,-6)"
    }, [c("path", {
      d: "M2.25,10.5C2.25,10.5 1.5,10.5 1.5,9.75C1.5,9 2.25,6.75 6,6.75C9.75,6.75 10.5,9 10.5,9.75C10.5,10.5 9.75,10.5 9.75,10.5L2.25,10.5ZM6,6C7.234,6 8.25,4.984 8.25,3.75C8.25,2.516 7.234,1.5 6,1.5C4.766,1.5 3.75,2.516 3.75,3.75C3.75,4.984 4.766,6 6,6Z",
      style: {
        fill: "white"
      }
    }, null)])]), c("g", {
      transform: "matrix(0.725806,0.419045,1.75755e-17,1.01444,155.314,212.138)"
    }, [c("rect", {
      x: "1663.92",
      y: "-407.511",
      width: "143.183",
      height: "118.292",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.58977,-0.917857,1.15976e-16,2.2425,-1270.46,-614.379)"
    }, [c("rect", {
      x: "1748.87",
      y: "1226.67",
      width: "10.895",
      height: "13.378",
      style: {
        fill: "rgb(132, 97, 0)"
      }
    }, null)])])])])]), c("defs", null, [c("linearGradient", {
      id: "_Linear1",
      x1: "0",
      y1: "0",
      x2: "1",
      y2: "0",
      gradientUnits: "userSpaceOnUse",
      gradientTransform: "matrix(-2.64571,4.04098,-4.04098,-2.64571,1167.67,799.269)"
    }, [c("stop", {
      offset: "0",
      style: {
        stopColor: "rgb(248, 248, 248)",
        stopOpacity: 1
      }
    }, null), c("stop", {
      offset: "1",
      style: {
        stopColor: "rgb(248, 248, 248)",
        stopOpacity: 1
      }
    }, null)])])]);
  }
}), s7 = S({
  name: "ResultNotFound",
  render() {
    return c("svg", {
      width: "100%",
      height: "100%",
      viewBox: "0 0 213 213",
      style: {
        fillRule: "evenodd",
        clipRule: "evenodd",
        strokeLinejoin: "round",
        strokeMiterlimit: 2
      }
    }, [c("g", {
      transform: "matrix(1,0,0,1,-1241.95,-445.62)"
    }, [c("g", null, [c("g", {
      transform: "matrix(1,0,0,1,295.2,-87.3801)"
    }, [c("circle", {
      cx: "1053.23",
      cy: "639.477",
      r: "106.477",
      style: {
        fill: "rgb(235, 238, 246)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.38223,0,0,0.38223,1126.12,238.549)"
    }, [c("g", {
      transform: "matrix(0.566536,0.327089,-1.28774,0.74348,763.4,317.171)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fillOpacity: 0.1
      }
    }, null)]), c("g", {
      transform: "matrix(0.29595,0.170867,-0.91077,0.525833,873.797,588.624)"
    }, [c("rect", {
      x: "657.012",
      y: "404.643",
      width: "198.586",
      height: "145.08",
      style: {
        fillOpacity: 0.1
      }
    }, null)]), c("g", {
      transform: "matrix(1,0,0,1,275,-15)"
    }, [c("path", {
      d: "M262.077,959.012L276.923,959.012L273.388,1004.01C273.388,1004.59 273.009,1005.16 272.25,1005.6C270.732,1006.48 268.268,1006.48 266.75,1005.6C265.991,1005.16 265.612,1004.59 265.612,1004.01L262.077,959.012Z",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null), c("g", {
      transform: "matrix(0.866025,-0.5,1,0.57735,0,-45)"
    }, [c("ellipse", {
      cx: "-848.416",
      cy: "1004.25",
      rx: "6.062",
      ry: "5.25",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)])]), c("g", {
      transform: "matrix(1,0,0,1,183.952,-67.5665)"
    }, [c("path", {
      d: "M262.077,959.012L276.923,959.012L273.388,1004.01C273.388,1004.59 273.009,1005.16 272.25,1005.6C270.732,1006.48 268.268,1006.48 266.75,1005.6C265.991,1005.16 265.612,1004.59 265.612,1004.01L262.077,959.012Z",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null), c("g", {
      transform: "matrix(0.866025,-0.5,1,0.57735,0,-45)"
    }, [c("ellipse", {
      cx: "-848.416",
      cy: "1004.25",
      rx: "6.062",
      ry: "5.25",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)])]), c("g", {
      transform: "matrix(1,0,0,1,414,-95.2517)"
    }, [c("path", {
      d: "M262.077,959.012L276.923,959.012L273.388,1004.01C273.388,1004.59 273.009,1005.16 272.25,1005.6C270.732,1006.48 268.268,1006.48 266.75,1005.6C265.991,1005.16 265.612,1004.59 265.612,1004.01L262.077,959.012Z",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null), c("g", {
      transform: "matrix(0.866025,-0.5,1,0.57735,0,-45)"
    }, [c("ellipse", {
      cx: "-848.416",
      cy: "1004.25",
      rx: "6.062",
      ry: "5.25",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)])]), c("g", {
      transform: "matrix(1,0,0,1,322.952,-147.818)"
    }, [c("path", {
      d: "M262.077,959.012L276.923,959.012L273.388,1004.01C273.388,1004.59 273.009,1005.16 272.25,1005.6C270.732,1006.48 268.268,1006.48 266.75,1005.6C265.991,1005.16 265.612,1004.59 265.612,1004.01L262.077,959.012Z",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null), c("g", {
      transform: "matrix(0.866025,-0.5,1,0.57735,0,-45)"
    }, [c("ellipse", {
      cx: "-848.416",
      cy: "1004.25",
      rx: "6.062",
      ry: "5.25",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)])]), c("g", null, [c("g", {
      transform: "matrix(1.42334,-0.821763,1.11271,0.642426,-1439.64,459.621)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(253, 243, 228)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.40786,-0.812831,6.60237e-16,1.99081,-2052.17,-84.7286)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.26159,-0.728382,5.91642e-16,1.78397,-1774.67,11.2303)"
    }, [c("path", {
      d: "M1950.29,1194.38C1950.29,1193.37 1949.41,1192.54 1948.34,1192.54L1846.01,1192.54C1844.93,1192.54 1844.06,1193.37 1844.06,1194.38L1844.06,1282.7C1844.06,1283.72 1844.93,1284.54 1846.01,1284.54L1948.34,1284.54C1949.41,1284.54 1950.29,1283.72 1950.29,1282.7L1950.29,1194.38Z",
      style: {
        fill: "rgb(132, 97, 51)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.2198,-0.704254,5.72043e-16,1.72488,-1697.6,37.2103)"
    }, [c("path", {
      d: "M1950.29,1194.38C1950.29,1193.37 1949.41,1192.54 1948.34,1192.54L1846.01,1192.54C1844.93,1192.54 1844.06,1193.37 1844.06,1194.38L1844.06,1282.7C1844.06,1283.72 1844.93,1284.54 1846.01,1284.54L1948.34,1284.54C1949.41,1284.54 1950.29,1283.72 1950.29,1282.7L1950.29,1194.38Z",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.707187,0.408295,9.06119e-17,1.54833,-733.949,683.612)"
    }, [c("rect", {
      x: "1663.92",
      y: "-407.511",
      width: "143.183",
      height: "118.292",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.64553,-0.950049,1.17482,0.678285,-1632.45,473.879)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(253, 243, 228)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.74666,0.431085,2.3583e-17,0.135259,-816.63,57.1397)"
    }, [c("rect", {
      x: "1663.92",
      y: "-407.511",
      width: "143.183",
      height: "118.292",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.64553,-0.950049,1.17482,0.678285,-1632.45,473.879)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(253, 243, 228)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.750082,0,0,0.750082,163.491,354.191)"
    }, [c("g", {
      transform: "matrix(1.75943,-1.01581,1.75879e-16,0.632893,-2721.54,1876.43)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.290956,-0.167984,2.90849e-17,0.104661,69.4195,919.311)"
    }, [c("path", {
      d: "M1950.29,1238.54C1950.29,1213.15 1944.73,1192.54 1937.88,1192.54L1856.47,1192.54C1849.62,1192.54 1844.06,1213.15 1844.06,1238.54C1844.06,1263.93 1849.62,1284.54 1856.47,1284.54L1937.88,1284.54C1944.73,1284.54 1950.29,1263.93 1950.29,1238.54Z",
      style: {
        fill: "rgb(132, 97, 51)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.262716,-0.151679,8.27418e-18,0.0364999,121.496,970.53)"
    }, [c("path", {
      d: "M1950.29,1238.54C1950.29,1213.15 1948.14,1192.54 1945.5,1192.54L1848.85,1192.54C1846.2,1192.54 1844.06,1213.15 1844.06,1238.54C1844.06,1263.93 1846.2,1284.54 1848.85,1284.54L1945.5,1284.54C1948.14,1284.54 1950.29,1263.93 1950.29,1238.54Z",
      style: {
        fill: "rgb(246, 220, 185)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.77877,-1.02697,0.0581765,0.0335882,-425.293,1228.27)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0369741,0.021347,4.72735e-17,0.492225,456.143,919.985)"
    }, [c("rect", {
      x: "1663.92",
      y: "-407.511",
      width: "143.183",
      height: "118.292",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)])]), c("g", {
      transform: "matrix(0.750082,0,0,0.750082,163.491,309.191)"
    }, [c("g", {
      transform: "matrix(1.75943,-1.01581,1.75879e-16,0.632893,-2721.54,1876.43)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.290956,-0.167984,2.90849e-17,0.104661,69.4195,919.311)"
    }, [c("path", {
      d: "M1950.29,1238.54C1950.29,1213.15 1944.73,1192.54 1937.88,1192.54L1856.47,1192.54C1849.62,1192.54 1844.06,1213.15 1844.06,1238.54C1844.06,1263.93 1849.62,1284.54 1856.47,1284.54L1937.88,1284.54C1944.73,1284.54 1950.29,1263.93 1950.29,1238.54Z",
      style: {
        fill: "rgb(132, 97, 51)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.262716,-0.151679,8.27418e-18,0.0364999,121.496,970.53)"
    }, [c("path", {
      d: "M1950.29,1238.54C1950.29,1213.15 1948.14,1192.54 1945.5,1192.54L1848.85,1192.54C1846.2,1192.54 1844.06,1213.15 1844.06,1238.54C1844.06,1263.93 1846.2,1284.54 1848.85,1284.54L1945.5,1284.54C1948.14,1284.54 1950.29,1263.93 1950.29,1238.54Z",
      style: {
        fill: "rgb(246, 220, 185)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.77877,-1.02697,0.0581765,0.0335882,-425.293,1228.27)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0369741,0.021347,4.72735e-17,0.492225,456.143,919.985)"
    }, [c("rect", {
      x: "1663.92",
      y: "-407.511",
      width: "143.183",
      height: "118.292",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)])]), c("g", {
      transform: "matrix(0.750082,0,0,0.750082,163.491,263.931)"
    }, [c("g", {
      transform: "matrix(1.75943,-1.01581,1.75879e-16,0.632893,-2721.54,1876.43)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.290956,-0.167984,2.90849e-17,0.104661,69.4195,919.311)"
    }, [c("path", {
      d: "M1950.29,1238.54C1950.29,1213.15 1944.73,1192.54 1937.88,1192.54L1856.47,1192.54C1849.62,1192.54 1844.06,1213.15 1844.06,1238.54C1844.06,1263.93 1849.62,1284.54 1856.47,1284.54L1937.88,1284.54C1944.73,1284.54 1950.29,1263.93 1950.29,1238.54Z",
      style: {
        fill: "rgb(132, 97, 51)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.262716,-0.151679,8.27418e-18,0.0364999,121.496,970.53)"
    }, [c("path", {
      d: "M1950.29,1238.54C1950.29,1213.15 1948.14,1192.54 1945.5,1192.54L1848.85,1192.54C1846.2,1192.54 1844.06,1213.15 1844.06,1238.54C1844.06,1263.93 1846.2,1284.54 1848.85,1284.54L1945.5,1284.54C1948.14,1284.54 1950.29,1263.93 1950.29,1238.54Z",
      style: {
        fill: "rgb(246, 220, 185)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.77877,-1.02697,0.0581765,0.0335882,-425.293,1228.27)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0369741,0.021347,4.72735e-17,0.492225,456.143,919.985)"
    }, [c("rect", {
      x: "1663.92",
      y: "-407.511",
      width: "143.183",
      height: "118.292",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)])]), c("path", {
      d: "M555.753,832.474L555.753,921.408L630.693,878.141L630.693,789.207L555.753,832.474Z",
      style: {
        fillOpacity: 0.1
      }
    }, null), c("g", {
      transform: "matrix(0.750082,0,0,0.750082,236.431,272.852)"
    }, [c("g", {
      transform: "matrix(1.64553,-0.950049,1.14552,0.661368,-1606.78,467.933)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(253, 243, 228)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.54477,-0.891873,1.05847,0.611108,-1456.84,490.734)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(132, 97, 51)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.27607,-0.736739,0.751435,0.433841,-970.952,617.519)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.62765,-0.939723,1.42156e-16,0.5,-2476.81,1893.62)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.62765,-0.939723,1.42156e-16,0.5,-2476.81,1893.62)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.728038,0.420333,3.52595e-17,0.377589,-790.978,151.274)"
    }, [c("rect", {
      x: "1663.92",
      y: "-407.511",
      width: "143.183",
      height: "118.292",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.75943,-1.01581,1.75879e-16,0.632893,-2726.83,1873.38)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", null, [c("g", {
      transform: "matrix(1.75943,-1.01581,1.75879e-16,0.632893,-2721.54,1876.43)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.290956,-0.167984,2.90849e-17,0.104661,69.4195,919.311)"
    }, [c("path", {
      d: "M1950.29,1238.54C1950.29,1213.15 1944.73,1192.54 1937.88,1192.54L1856.47,1192.54C1849.62,1192.54 1844.06,1213.15 1844.06,1238.54C1844.06,1263.93 1849.62,1284.54 1856.47,1284.54L1937.88,1284.54C1944.73,1284.54 1950.29,1263.93 1950.29,1238.54Z",
      style: {
        fill: "rgb(132, 97, 51)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.262716,-0.151679,8.27418e-18,0.0364999,121.496,970.53)"
    }, [c("path", {
      d: "M1950.29,1238.54C1950.29,1213.15 1948.14,1192.54 1945.5,1192.54L1848.85,1192.54C1846.2,1192.54 1844.06,1213.15 1844.06,1238.54C1844.06,1263.93 1846.2,1284.54 1848.85,1284.54L1945.5,1284.54C1948.14,1284.54 1950.29,1263.93 1950.29,1238.54Z",
      style: {
        fill: "rgb(246, 220, 185)"
      }
    }, null)]), c("g", {
      transform: "matrix(1.77877,-1.02697,0.0581765,0.0335882,-425.293,1228.27)"
    }, [c("rect", {
      x: "495.52",
      y: "1057.87",
      width: "105.078",
      height: "91",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.0369741,0.021347,4.72735e-17,0.492225,456.143,919.985)"
    }, [c("rect", {
      x: "1663.92",
      y: "-407.511",
      width: "143.183",
      height: "118.292",
      style: {
        fill: "rgb(240, 218, 183)"
      }
    }, null)])])]), c("g", {
      transform: "matrix(1.62765,-0.939723,4.80984e-17,0.173913,-2468.81,2307.87)"
    }, [c("rect", {
      x: "1844.06",
      y: "1192.54",
      width: "106.232",
      height: "92",
      style: {
        fill: "rgb(196, 173, 142)"
      }
    }, null)])]), c("g", null, [c("g", {
      transform: "matrix(0.479077,0.276595,-0.564376,0.325843,598.357,-129.986)"
    }, [c("path", {
      d: "M1776.14,1326C1776.14,1321.19 1772.15,1317.28 1767.24,1317.28L1684.37,1317.28C1679.46,1317.28 1675.47,1321.19 1675.47,1326L1675.47,1395.75C1675.47,1400.56 1679.46,1404.46 1684.37,1404.46L1767.24,1404.46C1772.15,1404.46 1776.14,1400.56 1776.14,1395.75L1776.14,1326Z",
      style: {
        fill: "white"
      }
    }, null)]), c("g", {
      transform: "matrix(2.61622,0,0,2.61622,-2305.73,162.161)"
    }, [c("g", {
      transform: "matrix(1.09915,-0.634597,1.26919,0.73277,-299.167,-62.4615)"
    }, [c("ellipse", {
      cx: "412.719",
      cy: "770.575",
      rx: "6.303",
      ry: "5.459",
      style: {
        fill: "rgb(255, 125, 0)"
      }
    }, null)]), c("g", {
      transform: "matrix(0.238212,-0.137532,0.178659,0.103149,875.064,207.93)"
    }, [c("text", {
      x: "413.474px",
      y: "892.067px",
      style: {
        fontFamily: "NunitoSans-Bold, Nunito Sans",
        fontWeight: 700,
        fontSize: 41.569,
        fill: "white"
      }
    }, [Re("?")])])])])])])])]);
  }
}), u7 = S({
  name: "ResultServerError",
  render() {
    return c("svg", {
      width: "100%",
      height: "100%",
      viewBox: "0 0 213 213",
      style: "fill-rule: evenodd; clip-rule: evenodd; stroke-linejoin: round; stroke-miterlimit: 2;"
    }, [c("g", {
      transform: "matrix(1,0,0,1,-483.054,-445.448)"
    }, [c("g", null, [c("g", {
      transform: "matrix(1,0,0,1,-463.699,-87.5516)"
    }, [c("circle", {
      cx: "1053.23",
      cy: "639.477",
      r: "106.477",
      style: "fill: rgb(235, 238, 246);"
    }, null)]), c("g", {
      transform: "matrix(0.384532,-0.222009,0.444019,0.256354,-0.569781,260.021)"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z",
      style: "fill-opacity: 0.1;"
    }, null)]), c("g", {
      transform: "matrix(0.384532,-0.222009,0.444019,0.256354,-0.569781,218.845)"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.361496,-0.20871,0.41742,0.240997,34.7805,238.807)"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z",
      style: "fill: rgb(0, 85, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.341853,-0.197369,0.394738,0.227902,64.9247,257.804)"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z",
      style: "fill: rgb(29, 105, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.428916,0,0,0.428916,19.0588,329.956)"
    }, [c("clipPath", {
      id: "_clip1"
    }, [c("path", {
      d: "M1461.07,528.445C1461.07,530.876 1459.6,533.196 1456.6,534.928L1342.04,601.072C1335.41,604.896 1323.83,604.415 1316.18,600L1205.33,536C1201.14,533.585 1199,530.489 1199,527.555L1199,559.555C1199,562.489 1201.14,565.585 1205.33,568L1316.18,632C1323.83,636.415 1335.41,636.896 1342.04,633.072L1456.6,566.928C1459.6,565.196 1461.07,562.876 1461.07,560.445L1461.07,528.445Z"
    }, null)]), c("g", {
      "clip-path": "url(#_clip1)"
    }, [c("g", {
      transform: "matrix(2.33146,-0,-0,2.33146,1081.79,269.266)"
    }, [c("use", {
      href: "#_Image2",
      x: "50.54",
      y: "112.301",
      width: "112.406px",
      height: "46.365px",
      transform: "matrix(0.99474,0,0,0.98649,0,0)"
    }, null)])])]), c("g", {
      transform: "matrix(0.347769,0.200785,3.44852e-18,0.545466,52.0929,265.448)"
    }, [c("path", {
      d: "M1480.33,34.813C1480.33,34.162 1479.7,33.634 1478.94,33.634L1396.27,33.634C1395.5,33.634 1394.88,34.162 1394.88,34.813C1394.88,35.464 1395.5,35.993 1396.27,35.993L1478.94,35.993C1479.7,35.993 1480.33,35.464 1480.33,34.813Z",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.347769,0.200785,3.44852e-18,0.545466,52.0929,268.45)"
    }, [c("path", {
      d: "M1480.33,34.813C1480.33,34.162 1479.7,33.634 1478.94,33.634L1396.27,33.634C1395.5,33.634 1394.88,34.162 1394.88,34.813C1394.88,35.464 1395.5,35.993 1396.27,35.993L1478.94,35.993C1479.7,35.993 1480.33,35.464 1480.33,34.813Z",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.347769,0.200785,3.44852e-18,0.545466,52.0929,271.452)"
    }, [c("path", {
      d: "M1480.33,34.813C1480.33,34.162 1479.7,33.634 1478.94,33.634L1396.27,33.634C1395.5,33.634 1394.88,34.162 1394.88,34.813C1394.88,35.464 1395.5,35.993 1396.27,35.993L1478.94,35.993C1479.7,35.993 1480.33,35.464 1480.33,34.813Z",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.360289,-0.208013,-4.39887e-18,0.576941,37.5847,124.262)"
    }, [c("rect", {
      x: "1621.2",
      y: "1370.57",
      width: "57.735",
      height: "5.947",
      style: "fill: rgb(106, 161, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,307.505,420.796)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,310.507,419.062)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,313.509,417.329)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,316.512,415.595)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,319.514,413.862)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.384532,-0.222009,0.444019,0.256354,-0.569781,196.542)"
    }, [c("clipPath", {
      id: "_clip3"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z"
    }, null)]), c("g", {
      "clip-path": "url(#_clip3)"
    }, [c("g", {
      transform: "matrix(1.30028,1.12608,-2.25216,1.95042,68.2716,1030.07)"
    }, [c("use", {
      href: "#_Image4",
      x: "50.54",
      y: "56.312",
      width: "112.406px",
      height: "64.897px",
      transform: "matrix(0.99474,0,0,0.998422,0,0)"
    }, null)])])]), c("g", {
      transform: "matrix(0.361496,-0.20871,0.41742,0.240997,34.7805,216.764)"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z",
      style: "fill: rgb(0, 85, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.341853,-0.197369,0.394738,0.227902,64.9247,235.762)"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z",
      style: "fill: rgb(29, 105, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.428916,0,0,0.428916,19.0588,307.652)"
    }, [c("clipPath", {
      id: "_clip5"
    }, [c("path", {
      d: "M1461.07,528.445C1461.07,530.876 1459.6,533.196 1456.6,534.928L1342.04,601.072C1335.41,604.896 1323.83,604.415 1316.18,600L1205.33,536C1201.14,533.585 1199,530.489 1199,527.555L1199,559.555C1199,562.489 1201.14,565.585 1205.33,568L1316.18,632C1323.83,636.415 1335.41,636.896 1342.04,633.072L1456.6,566.928C1459.6,565.196 1461.07,562.876 1461.07,560.445L1461.07,528.445Z"
    }, null)]), c("g", {
      "clip-path": "url(#_clip5)"
    }, [c("g", {
      transform: "matrix(2.33146,-0,-0,2.33146,1081.79,321.266)"
    }, [c("use", {
      href: "#_Image2",
      x: "50.54",
      y: "89.692",
      width: "112.406px",
      height: "46.365px",
      transform: "matrix(0.99474,0,0,0.98649,0,0)"
    }, null)])])]), c("g", {
      transform: "matrix(0.347769,0.200785,3.44852e-18,0.545466,52.0929,243.144)"
    }, [c("path", {
      d: "M1480.33,34.813C1480.33,34.162 1479.7,33.634 1478.94,33.634L1396.27,33.634C1395.5,33.634 1394.88,34.162 1394.88,34.813C1394.88,35.464 1395.5,35.993 1396.27,35.993L1478.94,35.993C1479.7,35.993 1480.33,35.464 1480.33,34.813Z",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.347769,0.200785,3.44852e-18,0.545466,52.0929,246.146)"
    }, [c("path", {
      d: "M1480.33,34.813C1480.33,34.162 1479.7,33.634 1478.94,33.634L1396.27,33.634C1395.5,33.634 1394.88,34.162 1394.88,34.813C1394.88,35.464 1395.5,35.993 1396.27,35.993L1478.94,35.993C1479.7,35.993 1480.33,35.464 1480.33,34.813Z",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.347769,0.200785,3.44852e-18,0.545466,52.0929,249.149)"
    }, [c("path", {
      d: "M1480.33,34.813C1480.33,34.162 1479.7,33.634 1478.94,33.634L1396.27,33.634C1395.5,33.634 1394.88,34.162 1394.88,34.813C1394.88,35.464 1395.5,35.993 1396.27,35.993L1478.94,35.993C1479.7,35.993 1480.33,35.464 1480.33,34.813Z",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.360289,-0.208013,-4.39887e-18,0.576941,37.5847,101.958)"
    }, [c("rect", {
      x: "1621.2",
      y: "1370.57",
      width: "57.735",
      height: "5.947",
      style: "fill: rgb(106, 161, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,307.505,398.492)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,310.507,396.759)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,313.509,395.025)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,316.512,393.292)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,319.514,391.558)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.384532,-0.222009,0.444019,0.256354,-0.569781,171.832)"
    }, [c("clipPath", {
      id: "_clip6"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z"
    }, null)]), c("g", {
      "clip-path": "url(#_clip6)"
    }, [c("g", {
      transform: "matrix(1.30028,1.12608,-2.25216,1.95042,12.6215,1078.27)"
    }, [c("use", {
      href: "#_Image7",
      x: "50.54",
      y: "31.563",
      width: "112.406px",
      height: "64.897px",
      transform: "matrix(0.99474,0,0,0.998422,0,0)"
    }, null)])])]), c("g", {
      transform: "matrix(0.361496,-0.20871,0.41742,0.240997,34.7805,192.055)"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z",
      style: "fill: rgb(0, 85, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.341853,-0.197369,0.394738,0.227902,64.9247,211.052)"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z",
      style: "fill: rgb(29, 105, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.428916,0,0,0.428916,19.0588,282.943)"
    }, [c("clipPath", {
      id: "_clip8"
    }, [c("path", {
      d: "M1461.07,528.445C1461.07,530.876 1459.6,533.196 1456.6,534.928L1342.04,601.072C1335.41,604.896 1323.83,604.415 1316.18,600L1205.33,536C1201.14,533.585 1199,530.489 1199,527.555L1199,559.555C1199,562.489 1201.14,565.585 1205.33,568L1316.18,632C1323.83,636.415 1335.41,636.896 1342.04,633.072L1456.6,566.928C1459.6,565.196 1461.07,562.876 1461.07,560.445L1461.07,528.445Z"
    }, null)]), c("g", {
      "clip-path": "url(#_clip8)"
    }, [c("g", {
      transform: "matrix(2.33146,-0,-0,2.33146,1081.79,378.876)"
    }, [c("use", {
      href: "#_Image2",
      x: "50.54",
      y: "64.644",
      width: "112.406px",
      height: "46.365px",
      transform: "matrix(0.99474,0,0,0.98649,0,0)"
    }, null)])])]), c("g", {
      transform: "matrix(0.347769,0.200785,3.44852e-18,0.545466,52.0929,218.434)"
    }, [c("path", {
      d: "M1480.33,34.813C1480.33,34.162 1479.7,33.634 1478.94,33.634L1396.27,33.634C1395.5,33.634 1394.88,34.162 1394.88,34.813C1394.88,35.464 1395.5,35.993 1396.27,35.993L1478.94,35.993C1479.7,35.993 1480.33,35.464 1480.33,34.813Z",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.347769,0.200785,3.44852e-18,0.545466,52.0929,221.437)"
    }, [c("path", {
      d: "M1480.33,34.813C1480.33,34.162 1479.7,33.634 1478.94,33.634L1396.27,33.634C1395.5,33.634 1394.88,34.162 1394.88,34.813C1394.88,35.464 1395.5,35.993 1396.27,35.993L1478.94,35.993C1479.7,35.993 1480.33,35.464 1480.33,34.813Z",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.347769,0.200785,3.44852e-18,0.545466,52.0929,224.439)"
    }, [c("path", {
      d: "M1480.33,34.813C1480.33,34.162 1479.7,33.634 1478.94,33.634L1396.27,33.634C1395.5,33.634 1394.88,34.162 1394.88,34.813C1394.88,35.464 1395.5,35.993 1396.27,35.993L1478.94,35.993C1479.7,35.993 1480.33,35.464 1480.33,34.813Z",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.360289,-0.208013,-4.39887e-18,0.576941,37.5847,77.2484)"
    }, [c("rect", {
      x: "1621.2",
      y: "1370.57",
      width: "57.735",
      height: "5.947",
      style: "fill: rgb(106, 161, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,307.505,373.782)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: white;"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,310.507,372.049)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,313.509,370.316)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,316.512,368.582)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.185726,-0.107229,-1.84168e-18,0.247635,319.514,366.849)"
    }, [c("ellipse", {
      cx: "1566.31",
      cy: "1372.3",
      rx: "4",
      ry: "3.464",
      style: "fill: rgb(64, 128, 255);"
    }, null)]), c("g", {
      transform: "matrix(0.365442,-0.210988,0.421976,0.243628,28.7259,185.45)"
    }, [c("clipPath", {
      id: "_clip9"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z"
    }, null)]), c("g", {
      "clip-path": "url(#_clip9)"
    }, [c("g", {
      transform: "matrix(1.36821,1.1849,-2.36981,2.05231,5.46929,1071.93)"
    }, [c("use", {
      href: "#_Image10",
      x: "53.151",
      y: "30.14",
      width: "106.825px",
      height: "61.676px",
      transform: "matrix(0.998367,0,0,0.994768,0,0)"
    }, null)])])]), c("g", {
      transform: "matrix(0.365442,-0.210988,0.421976,0.243628,28.7259,183.729)"
    }, [c("path", {
      d: "M84.299,1269.38C84.299,1261.99 78.301,1256 70.913,1256L-56.874,1256C-64.261,1256 -70.259,1261.99 -70.259,1269.38L-70.259,1376.46C-70.259,1383.85 -64.261,1389.85 -56.874,1389.85L70.913,1389.85C78.301,1389.85 84.299,1383.85 84.299,1376.46L84.299,1269.38Z",
      style: 'fill: url("#_Linear11");'
    }, null)]), c("g", {
      transform: "matrix(0.407622,0,0,0.407622,47.38,278)"
    }, [c("clipPath", {
      id: "_clip12"
    }, [c("path", {
      d: "M1461.07,554.317C1461.07,556.747 1459.6,559.067 1456.6,560.8L1342.04,626.943C1335.41,630.767 1323.83,630.287 1316.18,625.871L1205.33,561.871C1201.14,559.456 1199,556.361 1199,553.426L1199,559.555C1199,562.489 1201.14,565.585 1205.33,568L1316.18,632C1323.83,636.415 1335.41,636.896 1342.04,633.072L1456.6,566.928C1459.6,565.196 1461.07,562.876 1461.07,560.445L1461.07,554.317Z"
    }, null)]), c("g", {
      "clip-path": "url(#_clip12)"
    }, [c("g", {
      transform: "matrix(2.45325,-0,-0,2.45325,1068.82,410.793)"
    }, [c("use", {
      href: "#_Image13",
      x: "53.151",
      y: "58.978",
      width: "106.825px",
      height: "33.517px",
      transform: "matrix(0.998367,0,0,0.985808,0,0)"
    }, null)])])]), c("g", {
      transform: "matrix(0.371452,-0.214458,2.38096e-17,0.495269,-19.3677,248.256)"
    }, [c("clipPath", {
      id: "_clip14"
    }, [c("path", {
      d: "M1776.14,1326C1776.14,1321.19 1772.23,1317.28 1767.42,1317.28L1684.19,1317.28C1679.38,1317.28 1675.47,1321.19 1675.47,1326L1675.47,1395.75C1675.47,1400.56 1679.38,1404.46 1684.19,1404.46L1767.42,1404.46C1772.23,1404.46 1776.14,1400.56 1776.14,1395.75L1776.14,1326Z"
    }, null)]), c("g", {
      "clip-path": "url(#_clip14)"
    }, [c("g", {
      transform: "matrix(2.69214,1.16573,-1.29422e-16,2.0191,1352.59,983.841)"
    }, [c("use", {
      href: "#_Image15",
      x: "121.882",
      y: "76.034",
      width: "37.393px",
      height: "61.803px",
      transform: "matrix(0.984021,0,0,0.996825,0,0)"
    }, null)])])]), c("g", {
      transform: "matrix(0.371452,-0.214458,2.38096e-17,0.495269,-15.0786,249.972)"
    }, [c("path", {
      d: "M1776.14,1326C1776.14,1321.19 1772.23,1317.28 1767.42,1317.28L1684.19,1317.28C1679.38,1317.28 1675.47,1321.19 1675.47,1326L1675.47,1395.75C1675.47,1400.56 1679.38,1404.46 1684.19,1404.46L1767.42,1404.46C1772.23,1404.46 1776.14,1400.56 1776.14,1395.75L1776.14,1326Z",
      style: "fill: white; stop-opacity: 0.9;"
    }, null)]), c("g", {
      transform: "matrix(0.220199,-0.127132,1.41145e-17,0.293599,339.708,327.53)"
    }, [c("path", {
      d: "M1306.5,1286.73C1307.09,1285.72 1308.6,1285.48 1310.36,1286.12C1312.13,1286.76 1313.84,1288.16 1314.73,1289.7C1326.44,1309.98 1355.4,1360.15 1363.73,1374.57C1364.33,1375.61 1364.49,1376.61 1364.18,1377.35C1363.87,1378.09 1363.11,1378.5 1362.07,1378.5C1346.41,1378.5 1288.17,1378.5 1264.07,1378.5C1262.42,1378.5 1260.37,1377.48 1258.9,1375.94C1257.44,1374.41 1256.88,1372.67 1257.5,1371.6C1268.1,1353.25 1296.8,1303.53 1306.5,1286.73Z"
    }, null)]), c("g", {
      transform: "matrix(0.254264,-0.1468,1.22235e-17,0.254264,329.57,364.144)"
    }, [c("text", {
      x: "1170.88px",
      y: "1451.42px",
      style: 'font-family: NunitoSans-Bold, "Nunito Sans"; font-weight: 700; font-size: 41.569px; fill: white; fill-opacity: 0.9;'
    }, [Re("!")])])])]), c("defs", null, [c("image", {
      id: "_Image2",
      width: "113px",
      height: "47px",
      href: "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAHEAAAAvCAYAAADU+iVXAAAACXBIWXMAAA7EAAAOxAGVKw4bAAABVUlEQVR4nO2aQRKCMAxFxUN4O+9/DNw4CoiTliZN8vPfQlm00ykvP3aQ5fFc11sjy/L+/nx8r3ffm7Fn845jz+aJa23XOJvfs9Zh7NBawv3YrSGtdbj+x10egkFzpRrNt+SSxMgbqkiZJCJDiQDoSmSfdYFJ3JD18GMmcXhDTHUzNZIIXhA1JIJDib0MptqiKbhKzHqQiAaT6IlSFVIiAJQIACUGpLfLhpfIw49Ml8T2v4/JTPySyIJQI3w7JTIYEp2fong3FXWJ3huqCEYSNUlYhZRoyaSCoEQAKHESlqF0kZj9NBgNJhEASgSAEgNx9WfCTmLxpygzYRIBmCORsTIlXxJZED/kk0h+KC1x9E2FKG86qEkMsh8/HG9A6SSGYqAIKDEinUIpUSDDYXiqxAw3JCNMIgDXJTIWYdBJIvukK2ynARit4XASUZ6izCScRFWKCH0BfLM84oTw1Z8AAAAASUVORK5CYII="
    }, null), c("image", {
      id: "_Image4",
      width: "113px",
      height: "65px",
      href: "data:image/png;base64, "
    }, null), c("image", {
      id: "_Image7",
      width: "113px",
      height: "65px",
      href: "data:image/png;base64, "
    }, null), c("image", {
      id: "_Image10",
      width: "107px",
      height: "62px",
      href: "data:image/png;base64, "
    }, null), c("linearGradient", {
      id: "_Linear11",
      x1: "0",
      y1: "0",
      x2: "1",
      y2: "0",
      gradientUnits: "userSpaceOnUse",
      gradientTransform: "matrix(-118.47,-106.79,210.785,-180.125,69.2121,1372.7)"
    }, [c("stop", {
      offset: "0",
      style: "stop-color: rgb(64, 128, 255); stop-opacity: 1;"
    }, null), c("stop", {
      offset: "1",
      style: "stop-color: rgb(64, 128, 255); stop-opacity: 1;"
    }, null)]), c("image", {
      id: "_Image13",
      width: "107px",
      height: "34px",
      href: "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAGsAAAAiCAYAAABY6CeoAAAACXBIWXMAAA7EAAAOxAGVKw4bAAABFElEQVRoge2aQRKDMAhFmx6it/P+x7Ab64xOmaAG8vnwFnWhiOGFOG3TPsu6vpS0djpuH61zXoz5F3s6r4rRxipiftddeUbp3t18QozEu3/JfdSzgCy5VWpTWcVYSlaPqcvDEUpZQPUdCqUsSAbMoJIViJIVCBNZrO+MHtbjrs4KRMkKBJUs9uXXTxZ7JR2g6ix27sly6BIxReIOHdpZWevoNe68y2DAmTVXFmDBAB9pJ29nBYRCln5jgkVyv1QUsrIAJyvtvg1F7iGykF/KlniPG66zKDCyWLI2IqwOJSsQz2URbqZEpTorEDCypn6xnciVYT+SlbS+08Zt01lJfv7xBmYZLPpgy6p/pA9gyxIArKMLXxexLNiBCThLAAAAAElFTkSuQmCC"
    }, null), c("image", {
      id: "_Image15",
      width: "38px",
      height: "62px",
      href: "data:image/png;base64,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"
    }, null)])]);
  }
});
const c7 = [
  "info",
  "success",
  "warning",
  "error",
  "403",
  "404",
  "500",
  null
], d7 = S({
  name: "Result",
  components: {
    IconInfo: r2,
    IconCheck: Wo,
    IconExclamation: o0,
    IconClose: Dt,
    ResultForbidden: a7,
    ResultNotFound: s7,
    ResultServerError: u7
  },
  props: {
    status: {
      type: String,
      default: "info",
      validator: (e) => c7.includes(e)
    },
    title: String,
    subtitle: String
  },
  setup() {
    return {
      prefixCls: B("result")
    };
  }
});
function f7(e, t, n, o, i, r) {
  const l = J("icon-info"), s = J("icon-check"), u = J("icon-exclamation"), f = J("icon-close"), d = J("result-forbidden"), p = J("result-not-found"), h = J("result-server-error");
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    $("div", {
      class: m([
        `${e.prefixCls}-icon`,
        {
          [`${e.prefixCls}-icon-${e.status}`]: e.status,
          [`${e.prefixCls}-icon-custom`]: e.status === null
        }
      ])
    }, [
      $("div", {
        class: m(`${e.prefixCls}-icon-tip`)
      }, [
        _(e.$slots, "icon", {}, () => [
          e.status === "info" ? (v(), oe(l, { key: 0 })) : e.status === "success" ? (v(), oe(s, { key: 1 })) : e.status === "warning" ? (v(), oe(u, { key: 2 })) : e.status === "error" ? (v(), oe(f, { key: 3 })) : e.status === "403" ? (v(), oe(d, { key: 4 })) : e.status === "404" ? (v(), oe(p, { key: 5 })) : e.status === "500" ? (v(), oe(h, { key: 6 })) : te("v-if", !0)
        ])
      ], 2)
    ], 2),
    e.title || e.$slots.title ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-title`)
    }, [
      _(e.$slots, "title", {}, () => [
        Re(Pe(e.title), 1)
      ])
    ], 2)) : te("v-if", !0),
    e.subtitle || e.$slots.subtitle ? (v(), b("div", {
      key: 1,
      class: m(`${e.prefixCls}-subtitle`)
    }, [
      _(e.$slots, "subtitle", {}, () => [
        Re(Pe(e.subtitle), 1)
      ])
    ], 2)) : te("v-if", !0),
    e.$slots.extra ? (v(), b("div", {
      key: 2,
      class: m(`${e.prefixCls}-extra`)
    }, [
      _(e.$slots, "extra")
    ], 2)) : te("v-if", !0),
    e.$slots.default ? (v(), b("div", {
      key: 3,
      class: m(`${e.prefixCls}-content`)
    }, [
      _(e.$slots, "default")
    ], 2)) : te("v-if", !0)
  ], 2);
}
var _s = /* @__PURE__ */ N(d7, [["render", f7]]);
const v7 = Object.assign(_s, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + _s.name, _s);
  }
}), p7 = S({
  name: "Skeleton",
  props: {
    loading: {
      type: Boolean,
      default: !0
    },
    animation: {
      type: Boolean,
      default: !1
    }
  },
  setup(e) {
    const t = B("skeleton"), n = a(() => [
      t,
      {
        [`${t}-animation`]: e.animation
      }
    ]);
    return {
      prefixCls: t,
      cls: n
    };
  }
});
function m7(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.cls)
  }, [
    e.loading ? _(e.$slots, "default", { key: 0 }) : _(e.$slots, "content", { key: 1 })
  ], 2);
}
var Js = /* @__PURE__ */ N(p7, [["render", m7]]);
const h7 = S({
  name: "SkeletonLine",
  props: {
    rows: {
      type: Number,
      default: 1
    },
    widths: {
      type: Array,
      default: () => []
    },
    lineHeight: {
      type: Number,
      default: 20
    },
    lineSpacing: {
      type: Number,
      default: 15
    }
  },
  setup(e) {
    const t = B("skeleton-line"), n = [];
    for (let o = 0; o < e.rows; o++) {
      const i = {};
      A(e.widths[o]) ? i.width = `${e.widths[o]}px` : zt(e.widths[o]) && (i.width = String(e.widths[o])), i.height = `${e.lineHeight}px`, o > 0 && (i.marginTop = `${e.lineSpacing}px`), n.push(i);
    }
    return {
      prefixCls: t,
      lines: n
    };
  }
});
function k7(e, t, n, o, i, r) {
  return v(!0), b(Ae, null, St(e.lines, (l, s) => (v(), b("ul", {
    key: s,
    class: m(e.prefixCls)
  }, [
    $("li", {
      class: m(`${e.prefixCls}-row`),
      style: F(l)
    }, null, 6)
  ], 2))), 128);
}
var Xi = /* @__PURE__ */ N(h7, [["render", k7]]);
const g7 = S({
  name: "SkeletonShape",
  props: {
    shape: {
      type: String,
      default: "square"
    },
    size: {
      type: String,
      default: "medium"
    }
  },
  setup(e) {
    const t = B("skeleton-shape"), n = a(() => [
      t,
      `${t}-${e.shape}`,
      `${t}-${e.size}`
    ]);
    return {
      prefixCls: t,
      cls: n
    };
  }
});
function y7(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.cls)
  }, null, 2);
}
var Qi = /* @__PURE__ */ N(g7, [["render", y7]]);
const b7 = Object.assign(Js, {
  Line: Xi,
  Shape: Qi,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Js.name, Js), e.component(n + Xi.name, Xi), e.component(n + Qi.name, Qi);
  }
}), C7 = S({
  name: "SliderButton",
  components: {
    Tooltip: yn
  },
  inheritAttrs: !1,
  props: {
    direction: {
      type: String,
      default: "horizontal"
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    min: {
      type: Number,
      required: !0
    },
    max: {
      type: Number,
      required: !0
    },
    formatTooltip: {
      type: Function
    },
    value: [String, Number],
    tooltipPosition: {
      type: String
    },
    showTooltip: {
      type: Boolean,
      default: !0
    }
  },
  emits: ["movestart", "moving", "moveend"],
  setup(e, { emit: t }) {
    const n = B("slider-btn"), o = V(!1), i = (p) => {
      e.disabled || (p.preventDefault(), o.value = !0, rt(window, "mousemove", r), rt(window, "touchmove", r), rt(window, "mouseup", l), rt(window, "contextmenu", l), rt(window, "touchend", l), t("movestart"));
    }, r = (p) => {
      let h, k;
      p.type.startsWith("touch") ? (k = p.touches[0].clientY, h = p.touches[0].clientX) : (k = p.clientY, h = p.clientX), t("moving", h, k);
    }, l = () => {
      o.value = !1, ct(window, "mousemove", r), ct(window, "mouseup", l), ct(window, "touchend", l), t("moveend");
    }, s = a(() => [n]), u = a(
      () => {
        var p;
        return ((p = e.tooltipPosition) != null ? p : e.direction === "vertical") ? "right" : "top";
      }
    ), f = a(
      () => {
        var p, h;
        return (h = (p = e.formatTooltip) == null ? void 0 : p.call(e, e.value)) != null ? h : `${e.value}`;
      }
    ), d = a(
      () => e.showTooltip ? o.value ? !0 : void 0 : !1
    );
    return {
      prefixCls: n,
      cls: s,
      tooltipContent: f,
      mergedTooltipPosition: u,
      popupVisible: d,
      handleMouseDown: i
    };
  }
}), $7 = ["aria-disabled", "aria-valuemax", "aria-valuemin", "aria-valuenow", "aria-valuetext"];
function w7(e, t, n, o, i, r) {
  const l = J("tooltip");
  return v(), oe(l, {
    "popup-visible": e.popupVisible,
    position: e.mergedTooltipPosition,
    content: e.tooltipContent
  }, {
    default: ue(() => [
      $("div", se(e.$attrs, {
        tabindex: "0",
        role: "slider",
        "aria-disabled": e.disabled,
        "aria-valuemax": e.max,
        "aria-valuemin": e.min,
        "aria-valuenow": e.value,
        "aria-valuetext": e.tooltipContent,
        class: e.cls,
        onMousedown: t[0] || (t[0] = (...s) => e.handleMouseDown && e.handleMouseDown(...s)),
        onTouchstart: t[1] || (t[1] = (...s) => e.handleMouseDown && e.handleMouseDown(...s)),
        onContextmenu: t[2] || (t[2] = an(() => {
        }, ["prevent"])),
        onClick: t[3] || (t[3] = an(() => {
        }, ["stop"]))
      }), null, 16, $7)
    ]),
    _: 1
  }, 8, ["popup-visible", "position", "content"]);
}
var S7 = /* @__PURE__ */ N(C7, [["render", w7]]);
const ll = (e, [t, n]) => {
  const o = Math.max((e - t) / (n - t), 0);
  return `${ln.round(o * 100, 2)}%`;
}, Ur = (e, t) => t === "vertical" ? { bottom: e } : { left: e }, z7 = S({
  name: "SliderDots",
  props: {
    data: {
      type: Array,
      required: !0
    },
    min: {
      type: Number,
      required: !0
    },
    max: {
      type: Number,
      required: !0
    },
    direction: {
      type: String,
      default: "horizontal"
    }
  },
  setup(e) {
    return {
      prefixCls: B("slider"),
      getStyle: (o) => Ur(
        ll(o, [e.min, e.max]),
        e.direction
      )
    };
  }
});
function L7(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(`${e.prefixCls}-dots`)
  }, [
    (v(!0), b(Ae, null, St(e.data, (l, s) => (v(), b("div", {
      key: s,
      class: m(`${e.prefixCls}-dot-wrapper`),
      style: F(e.getStyle(l.key))
    }, [
      $("div", {
        class: m([
          `${e.prefixCls}-dot`,
          { [`${e.prefixCls}-dot-active`]: l.isActive }
        ])
      }, null, 2)
    ], 6))), 128))
  ], 2);
}
var j7 = /* @__PURE__ */ N(z7, [["render", L7]]);
const P7 = S({
  name: "SliderMarks",
  props: {
    data: {
      type: Array,
      required: !0
    },
    min: {
      type: Number,
      required: !0
    },
    max: {
      type: Number,
      required: !0
    },
    direction: {
      type: String,
      default: "horizontal"
    }
  },
  setup(e) {
    return {
      prefixCls: B("slider"),
      getStyle: (o) => Ur(
        ll(o, [e.min, e.max]),
        e.direction
      )
    };
  }
});
function I7(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(`${e.prefixCls}-marks`)
  }, [
    (v(!0), b(Ae, null, St(e.data, (l, s) => (v(), b("div", {
      key: s,
      "aria-hidden": "true",
      class: m(`${e.prefixCls}-mark`),
      style: F(e.getStyle(l.key))
    }, Pe(l.content), 7))), 128))
  ], 2);
}
var B7 = /* @__PURE__ */ N(P7, [["render", I7]]);
const M7 = S({
  name: "SliderTicks",
  props: {
    value: {
      type: Array,
      required: !0
    },
    step: {
      type: Number,
      required: !0
    },
    min: {
      type: Number,
      required: !0
    },
    max: {
      type: Number,
      required: !0
    },
    direction: {
      type: String,
      default: "horizontal"
    }
  },
  setup(e) {
    const t = B("slider"), n = a(() => {
      const i = [], r = Math.floor((e.max - e.min) / e.step);
      for (let l = 0; l <= r; l++) {
        const s = ln.plus(l * e.step, e.min);
        s <= e.min || s >= e.max || i.push({
          key: s,
          isActive: s >= e.value[0] && s <= e.value[1]
        });
      }
      return i;
    });
    return {
      prefixCls: t,
      steps: n,
      getStyle: (i) => Ur(
        ll(i, [e.min, e.max]),
        e.direction
      )
    };
  }
});
function N7(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(`${e.prefixCls}-ticks`)
  }, [
    (v(!0), b(Ae, null, St(e.steps, (l, s) => (v(), b("div", {
      key: s,
      class: m([
        `${e.prefixCls}-tick`,
        { [`${e.prefixCls}-tick-active`]: l.isActive }
      ]),
      style: F(e.getStyle(l.key))
    }, null, 6))), 128))
  ], 2);
}
var O7 = /* @__PURE__ */ N(M7, [["render", N7]]);
const V7 = S({
  name: "SliderInput",
  components: {
    InputNumber: Vo
  },
  props: {
    modelValue: {
      type: Array,
      required: !0
    },
    min: {
      type: Number
    },
    max: {
      type: Number
    },
    step: {
      type: Number
    },
    disabled: {
      type: Boolean
    },
    range: {
      type: Boolean
    }
  },
  emits: ["startChange", "endChange"],
  setup(e, { emit: t }) {
    return {
      prefixCls: B("slider")
    };
  }
});
function T7(e, t, n, o, i, r) {
  const l = J("input-number");
  return v(), b("div", {
    class: m(`${e.prefixCls}-input`)
  }, [
    e.range ? (v(), b(Ae, { key: 0 }, [
      c(l, {
        min: e.min,
        max: e.max,
        step: e.step,
        disabled: e.disabled,
        "model-value": e.modelValue[0],
        "hide-button": "",
        onChange: t[0] || (t[0] = (s) => e.$emit("startChange", s))
      }, null, 8, ["min", "max", "step", "disabled", "model-value"]),
      $("div", {
        class: m(`${e.prefixCls}-input-hyphens`)
      }, null, 2)
    ], 64)) : te("v-if", !0),
    c(l, {
      min: e.min,
      max: e.max,
      step: e.step,
      disabled: e.disabled,
      "model-value": e.modelValue[1],
      "hide-button": "",
      onChange: t[1] || (t[1] = (s) => e.$emit("endChange", s))
    }, null, 8, ["min", "max", "step", "disabled", "model-value"])
  ], 2);
}
var A7 = /* @__PURE__ */ N(V7, [["render", T7]]);
const E7 = S({
  name: "Slider",
  components: {
    SliderButton: S7,
    SliderDots: j7,
    SliderMarks: B7,
    SliderTicks: O7,
    SliderInput: A7
  },
  props: {
    modelValue: {
      type: [Number, Array],
      default: void 0
    },
    defaultValue: {
      type: [Number, Array],
      default: 0
    },
    step: {
      type: Number,
      default: 1
    },
    min: {
      type: Number,
      default: 0
    },
    marks: {
      type: Object
    },
    max: {
      type: Number,
      default: 100
    },
    direction: {
      type: String,
      default: "horizontal"
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    showTicks: {
      type: Boolean,
      default: !1
    },
    showInput: {
      type: Boolean,
      default: !1
    },
    range: {
      type: Boolean,
      default: !1
    },
    formatTooltip: {
      type: Function
    },
    showTooltip: {
      type: Boolean,
      default: !0
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0
  },
  setup(e, { emit: t }) {
    const { modelValue: n } = ve(e), o = B("slider"), { mergedDisabled: i, eventHandlers: r } = mt({
      disabled: un(e, "disabled")
    }), l = V(null), s = V(), u = e.modelValue ? e.modelValue : e.defaultValue, f = V(He(u) ? u[0] : 0), d = V(
      He(u) ? u[1] : u
    );
    ze(n, (T) => {
      var X, Y, Z, U, H;
      He(T) ? (f.value = (Y = (X = T[0]) != null ? X : e.min) != null ? Y : 0, d.value = (U = (Z = T[1]) != null ? Z : e.min) != null ? U : 0) : d.value = (H = T ?? e.min) != null ? H : 0;
    });
    const p = () => {
      var T, X;
      e.range ? (t("update:modelValue", [f.value, d.value]), t("change", [f.value, d.value])) : (t("update:modelValue", d.value), t("change", d.value)), (X = (T = r.value) == null ? void 0 : T.onChange) == null || X.call(T);
    }, h = (T) => {
      T = T ?? e.min, f.value = T, p();
    }, k = (T) => {
      T = T ?? e.min, d.value = T, p();
    }, y = a(() => {
      var T, X, Y;
      return e.range ? He(e.modelValue) ? e.modelValue : [f.value, (T = e.modelValue) != null ? T : d.value] : Ve(e.modelValue) ? [f.value, d.value] : He(e.modelValue) ? [(X = e.min) != null ? X : 0, e.modelValue[1]] : [(Y = e.min) != null ? Y : 0, e.modelValue];
    }), w = a(
      () => Object.keys(e.marks || {}).map((T) => {
        var X;
        const Y = Number(T);
        return {
          key: Y,
          content: (X = e.marks) == null ? void 0 : X[Y],
          isActive: Y >= y.value[0] && Y <= y.value[1]
        };
      })
    ), g = (T) => Ur(
      ll(T, [e.min, e.max]),
      e.direction
    ), C = V(!1), P = () => {
      C.value = !0, l.value && (s.value = l.value.getBoundingClientRect());
    };
    function z(T, X) {
      if (!s.value)
        return 0;
      const { left: Y, top: Z, width: U, height: H } = s.value, D = e.direction === "horizontal" ? U : H, R = D * e.step / (e.max - e.min);
      let W = e.direction === "horizontal" ? T - Y : Z + H - X;
      W < 0 && (W = 0), W > D && (W = D);
      const O = Math.round(W / R);
      return ln.plus(e.min, ln.times(O, e.step));
    }
    const j = (T, X) => {
      d.value = z(T, X), p();
    }, I = (T) => {
      if (i.value)
        return;
      const { clientX: X, clientY: Y } = T;
      l.value && (s.value = l.value.getBoundingClientRect()), d.value = z(X, Y), p();
    };
    function L([T, X]) {
      return T > X && ([T, X] = [X, T]), e.direction === "vertical" ? {
        bottom: ll(T, [e.min, e.max]),
        top: ll(e.max + e.min - X, [
          e.min,
          e.max
        ])
      } : {
        left: ll(T, [e.min, e.max]),
        right: ll(e.max + e.min - X, [
          e.min,
          e.max
        ])
      };
    }
    const M = (T, X) => {
      f.value = z(T, X), p();
    }, E = () => {
      C.value = !1;
    }, K = a(() => [
      o,
      {
        [`${o}-vertical`]: e.direction === "vertical",
        [`${o}-with-marks`]: !!e.marks
      }
    ]), q = a(() => [
      `${o}-track`,
      {
        [`${o}-track-disabled`]: i.value,
        [`${o}-track-vertical`]: e.direction === "vertical"
      }
    ]);
    return {
      prefixCls: o,
      cls: K,
      trackCls: q,
      trackRef: l,
      computedValue: y,
      mergedDisabled: i,
      markList: w,
      getBtnStyle: g,
      getBarStyle: L,
      handleClick: I,
      handleMoveStart: P,
      handleEndMoving: j,
      handleMoveEnd: E,
      handleStartMoving: M,
      handleStartChange: h,
      handleEndChange: k
    };
  }
});
function W7(e, t, n, o, i, r) {
  const l = J("slider-ticks"), s = J("slider-dots"), u = J("slider-marks"), f = J("slider-button"), d = J("slider-input");
  return v(), b("div", {
    class: m(e.cls)
  }, [
    $("div", {
      ref: "trackRef",
      class: m(e.trackCls),
      onClick: t[0] || (t[0] = (...p) => e.handleClick && e.handleClick(...p))
    }, [
      $("div", {
        class: m(`${e.prefixCls}-bar`),
        style: F(e.getBarStyle(e.computedValue))
      }, null, 6),
      e.showTicks ? (v(), oe(l, {
        key: 0,
        value: e.computedValue,
        step: e.step,
        min: e.min,
        max: e.max,
        direction: e.direction
      }, null, 8, ["value", "step", "min", "max", "direction"])) : te("v-if", !0),
      e.marks ? (v(), oe(s, {
        key: 1,
        data: e.markList,
        min: e.min,
        max: e.max,
        direction: e.direction
      }, null, 8, ["data", "min", "max", "direction"])) : te("v-if", !0),
      e.marks ? (v(), oe(u, {
        key: 2,
        data: e.markList,
        min: e.min,
        max: e.max,
        direction: e.direction
      }, null, 8, ["data", "min", "max", "direction"])) : te("v-if", !0),
      e.range ? (v(), oe(f, {
        key: 3,
        style: F(e.getBtnStyle(e.computedValue[0])),
        value: e.computedValue[0],
        direction: e.direction,
        disabled: e.mergedDisabled,
        min: e.min,
        max: e.max,
        "format-tooltip": e.formatTooltip,
        "show-tooltip": e.showTooltip,
        onMovestart: e.handleMoveStart,
        onMoving: e.handleStartMoving,
        onMoveend: e.handleMoveEnd
      }, null, 8, ["style", "value", "direction", "disabled", "min", "max", "format-tooltip", "show-tooltip", "onMovestart", "onMoving", "onMoveend"])) : te("v-if", !0),
      c(f, {
        style: F(e.getBtnStyle(e.computedValue[1])),
        value: e.computedValue[1],
        direction: e.direction,
        disabled: e.mergedDisabled,
        min: e.min,
        max: e.max,
        "format-tooltip": e.formatTooltip,
        "show-tooltip": e.showTooltip,
        onMovestart: e.handleMoveStart,
        onMoving: e.handleEndMoving,
        onMoveend: e.handleMoveEnd
      }, null, 8, ["style", "value", "direction", "disabled", "min", "max", "format-tooltip", "show-tooltip", "onMovestart", "onMoving", "onMoveend"])
    ], 2),
    e.showInput ? (v(), oe(d, {
      key: 0,
      "model-value": e.computedValue,
      min: e.min,
      max: e.max,
      step: e.step,
      range: e.range,
      disabled: e.disabled,
      onStartChange: e.handleStartChange,
      onEndChange: e.handleEndChange
    }, null, 8, ["model-value", "min", "max", "step", "range", "disabled", "onStartChange", "onEndChange"])) : te("v-if", !0)
  ], 2);
}
var eu = /* @__PURE__ */ N(E7, [["render", W7]]);
const F7 = Object.assign(eu, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + eu.name, eu);
  }
});
var tu = S({
  name: "Space",
  props: {
    align: {
      type: String
    },
    direction: {
      type: String,
      default: "horizontal"
    },
    size: {
      type: [Number, String, Array],
      default: "small"
    },
    wrap: {
      type: Boolean
    },
    fill: {
      type: Boolean
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("space"), o = a(() => {
      var s;
      return (s = e.align) != null ? s : e.direction === "horizontal" ? "center" : "";
    }), i = a(() => [n, {
      [`${n}-${e.direction}`]: e.direction,
      [`${n}-align-${o.value}`]: o.value,
      [`${n}-wrap`]: e.wrap,
      [`${n}-fill`]: e.fill
    }]);
    function r(s) {
      if (A(s))
        return s;
      switch (s) {
        case "mini":
          return 4;
        case "small":
          return 8;
        case "medium":
          return 16;
        case "large":
          return 24;
        default:
          return 8;
      }
    }
    const l = (s) => {
      const u = {}, f = `${r(He(e.size) ? e.size[0] : e.size)}px`, d = `${r(He(e.size) ? e.size[1] : e.size)}px`;
      return s ? e.wrap ? {
        marginBottom: d
      } : {} : (e.direction === "horizontal" && (u.marginRight = f), (e.direction === "vertical" || e.wrap) && (u.marginBottom = d), u);
    };
    return () => {
      var s;
      const u = En((s = t.default) == null ? void 0 : s.call(t), !0).filter((f) => f.type !== ek);
      return c("div", {
        class: i.value
      }, [u.map((f, d) => {
        var p, h;
        const k = t.split && d > 0;
        return c(Ae, {
          key: (p = f.key) != null ? p : `item-${d}`
        }, [k && c("div", {
          class: `${n}-item-split`,
          style: l(!1)
        }, [(h = t.split) == null ? void 0 : h.call(t)]), c("div", {
          class: `${n}-item`,
          style: l(d === u.length - 1)
        }, [f])]);
      })]);
    };
  }
});
const D7 = Object.assign(tu, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + tu.name, tu);
  }
});
function a2(e) {
  const t = zt(e) ? parseFloat(e) : e;
  let n = "";
  return A(e) || String(t) === e ? n = t > 1 ? "px" : "%" : n = "px", {
    size: t,
    unit: n,
    isPx: n === "px"
  };
}
function _o({
  size: e,
  defaultSize: t,
  containerSize: n
}) {
  const o = a2(e ?? t);
  return o.isPx ? o.size : o.size * n;
}
function x7(e, t) {
  return parseFloat(e) / parseFloat(t);
}
const R7 = S({
  name: "Split",
  components: {
    ResizeTrigger: Rh
  },
  props: {
    component: {
      type: String,
      default: "div"
    },
    direction: {
      type: String,
      default: "horizontal"
    },
    size: {
      type: [Number, String],
      default: void 0
    },
    defaultSize: {
      type: [Number, String],
      default: 0.5
    },
    min: {
      type: [Number, String]
    },
    max: {
      type: [Number, String]
    },
    disabled: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    moveStart: (e) => !0,
    moving: (e) => !0,
    moveEnd: (e) => !0,
    "update:size": (e) => !0
  },
  setup(e, { emit: t }) {
    const { direction: n, size: o, defaultSize: i, min: r, max: l } = ve(e), s = V(0), u = V(), f = B("split"), [d, p] = Vt(
      i.value,
      me({
        value: o
      })
    ), h = a(() => a2(d.value)), k = a(() => n.value === "horizontal"), y = a(() => [
      f,
      {
        [`${f}-horizontal`]: k.value,
        [`${f}-vertical`]: !k.value
      }
    ]), w = a(() => {
      const { size: K, unit: q, isPx: T } = h.value;
      return {
        flex: `0 0 calc(${T ? K : K * 100}${q} - ${s.value / 2}px)`
      };
    }), g = {
      startPageX: 0,
      startPageY: 0,
      startContainerSize: 0,
      startSize: 0
    };
    async function C() {
      const K = () => {
        var q, T;
        return k.value ? (q = u.value) == null ? void 0 : q.clientWidth : ((T = u.value) == null ? void 0 : T.clientHeight) || 0;
      };
      return (!u.value || K()) && await at(), K();
    }
    function P(K, q) {
      if (!q)
        return;
      const T = h.value.isPx ? `${K}px` : x7(K, q);
      d.value !== T && (p(T), t("update:size", T));
    }
    function z(K, q) {
      const T = _o({
        size: K,
        containerSize: q
      }), X = _o({
        size: r.value,
        defaultSize: "0px",
        containerSize: q
      }), Y = _o({
        size: l.value,
        defaultSize: `${q}px`,
        containerSize: q
      });
      let Z = T;
      return Z = Math.max(Z, X), Z = Math.min(Z, Y), Z;
    }
    function j({
      startContainerSize: K,
      startSize: q,
      startPosition: T,
      endPosition: X
    }) {
      const Y = _o({
        size: q,
        containerSize: K
      });
      return z(
        `${Y + (X - T)}px`,
        K
      );
    }
    function I(K) {
      t("moving", K);
      const q = k.value ? j({
        startContainerSize: g.startContainerSize,
        startSize: g.startSize,
        startPosition: g.startPageX,
        endPosition: K.pageX
      }) : j({
        startContainerSize: g.startContainerSize,
        startSize: g.startSize,
        startPosition: g.startPageY,
        endPosition: K.pageY
      });
      P(q, g.startContainerSize);
    }
    function L(K) {
      ct(window, "mousemove", I), ct(window, "mouseup", L), ct(window, "contextmenu", L), document.body.style.cursor = "default", t("moveEnd", K);
    }
    async function M(K) {
      t("moveStart", K), g.startPageX = K.pageX, g.startPageY = K.pageY, g.startContainerSize = await C(), g.startSize = d.value, rt(window, "mousemove", I), rt(window, "mouseup", L), rt(window, "contextmenu", L), document.body.style.cursor = k.value ? "col-resize" : "row-resize";
    }
    function E(K) {
      const { width: q, height: T } = K.contentRect;
      s.value = k.value ? q : T;
    }
    return Je(async () => {
      const K = await C(), q = z(d.value, K);
      P(q, K);
    }), {
      prefixCls: f,
      classNames: y,
      isHorizontal: k,
      wrapperRef: u,
      onMoveStart: M,
      onTriggerResize: E,
      firstPaneStyles: w
    };
  }
});
function H7(e, t, n, o, i, r) {
  const l = J("ResizeTrigger");
  return v(), oe(sn(e.component), {
    ref: "wrapperRef",
    class: m(e.classNames)
  }, {
    default: ue(() => [
      $("div", {
        class: m([`${e.prefixCls}-pane`, `${e.prefixCls}-pane-first`]),
        style: F(e.firstPaneStyles)
      }, [
        _(e.$slots, "first")
      ], 6),
      e.disabled ? te("v-if", !0) : (v(), oe(l, {
        key: 0,
        "prefix-cls": `${e.prefixCls}-trigger`,
        direction: e.isHorizontal ? "vertical" : "horizontal",
        onMousedown: e.onMoveStart,
        onResize: e.onTriggerResize
      }, {
        default: ue(() => [
          _(e.$slots, "resize-trigger")
        ]),
        icon: ue(() => [
          _(e.$slots, "resize-trigger-icon")
        ]),
        _: 3
      }, 8, ["prefix-cls", "direction", "onMousedown", "onResize"])),
      $("div", {
        class: m([`${e.prefixCls}-pane`, `${e.prefixCls}-pane-second`])
      }, [
        _(e.$slots, "second")
      ], 2)
    ]),
    _: 3
  }, 8, ["class"]);
}
var nu = /* @__PURE__ */ N(R7, [["render", H7]]);
const q7 = Object.assign(nu, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + nu.name, nu);
  }
}), Z7 = S({
  name: "Statistic",
  props: {
    title: String,
    value: {
      type: [Number, Object]
    },
    format: {
      type: String,
      default: "HH:mm:ss"
    },
    extra: String,
    start: {
      type: Boolean,
      default: !0
    },
    precision: {
      type: Number,
      default: 0
    },
    separator: String,
    showGroupSeparator: {
      type: Boolean,
      default: !1
    },
    animation: {
      type: Boolean,
      default: !1
    },
    animationDuration: {
      type: Number,
      default: 2e3
    },
    valueFrom: {
      type: Number,
      default: void 0
    },
    placeholder: {
      type: String
    },
    valueStyle: {
      type: Object
    }
  },
  setup(e) {
    var t;
    const n = B("statistic"), o = a(() => A(e.value) ? e.value : 0), i = V((t = e.valueFrom) != null ? t : e.value), r = V(null), { value: l } = ve(e), s = a(() => Ve(e.value)), u = (d = ((h) => (h = e.valueFrom) != null ? h : 0)(), p = o.value) => {
      var h;
      d !== p && (r.value = new Pl({
        from: {
          value: d
        },
        to: {
          value: p
        },
        duration: e.animationDuration,
        easing: "quartOut",
        onUpdate: (k) => {
          i.value = k.value;
        },
        onFinish: () => {
          i.value = p;
        }
      }), (h = r.value) == null || h.start());
    }, f = a(() => {
      let d = i.value;
      if (A(d)) {
        A(e.precision) && (d = ln.round(d, e.precision).toFixed(e.precision));
        const p = String(d).split("."), h = e.showGroupSeparator ? Number(p[0]).toLocaleString("en-US") : p[0], k = p[1];
        return {
          isNumber: !0,
          integer: h,
          decimal: k
        };
      }
      return e.format && (d = Ut(d).format(e.format)), {
        isNumber: !1,
        value: d
      };
    });
    return Je(() => {
      e.animation && e.start && u();
    }), ze(
      () => e.start,
      (d) => {
        d && e.animation && !r.value && u();
      }
    ), ze(l, (d) => {
      var p;
      r.value && ((p = r.value) == null || p.stop(), r.value = null), i.value = d, e.animation && e.start && u();
    }), {
      prefixCls: n,
      showPlaceholder: s,
      formatValue: f
    };
  }
}), K7 = { key: 0 };
function Y7(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    e.title || e.$slots.title ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-title`)
    }, [
      _(e.$slots, "title", {}, () => [
        Re(Pe(e.title), 1)
      ])
    ], 2)) : te("v-if", !0),
    $("div", {
      class: m(`${e.prefixCls}-content`)
    }, [
      $("div", {
        class: m(`${e.prefixCls}-value`),
        style: F(e.valueStyle)
      }, [
        e.showPlaceholder ? (v(), b("span", K7, Pe(e.placeholder), 1)) : (v(), b(Ae, { key: 1 }, [
          e.$slots.prefix ? (v(), b("span", {
            key: 0,
            class: m(`${e.prefixCls}-prefix`)
          }, [
            _(e.$slots, "prefix")
          ], 2)) : te("v-if", !0),
          e.formatValue.isNumber ? (v(), b(Ae, { key: 1 }, [
            $("span", {
              class: m(`${e.prefixCls}-value-integer`)
            }, Pe(e.formatValue.integer), 3),
            e.formatValue.decimal ? (v(), b("span", {
              key: 0,
              class: m(`${e.prefixCls}-value-decimal`)
            }, " ." + Pe(e.formatValue.decimal), 3)) : te("v-if", !0)
          ], 64)) : (v(), b(Ae, { key: 2 }, [
            Re(Pe(e.formatValue.value), 1)
          ], 64)),
          e.$slots.suffix ? (v(), b("span", {
            key: 3,
            class: m(`${e.prefixCls}-suffix`)
          }, [
            _(e.$slots, "suffix")
          ], 2)) : te("v-if", !0)
        ], 64))
      ], 6),
      e.extra || e.$slots.extra ? (v(), b("div", {
        key: 0,
        class: m(`${e.prefixCls}-extra`)
      }, [
        _(e.$slots, "extra", {}, () => [
          Re(Pe(e.extra), 1)
        ])
      ], 2)) : te("v-if", !0)
    ], 2)
  ], 2);
}
var lu = /* @__PURE__ */ N(Z7, [["render", Y7]]);
const U7 = [
  ["Y", 1e3 * 60 * 60 * 24 * 365],
  ["M", 1e3 * 60 * 60 * 24 * 30],
  ["D", 1e3 * 60 * 60 * 24],
  ["H", 1e3 * 60 * 60],
  ["m", 1e3 * 60],
  ["s", 1e3],
  ["S", 1]
];
function ou(e, t) {
  let n = e;
  return U7.reduce((o, [i, r]) => {
    if (o.indexOf(i) !== -1) {
      const l = Math.floor(n / r);
      return n -= l * r, o.replace(new RegExp(`${i}+`, "g"), (s) => {
        const u = s.length;
        return String(l).padStart(u, "0");
      });
    }
    return o;
  }, t);
}
const G7 = S({
  name: "Countdown",
  props: {
    title: String,
    value: {
      type: Number,
      default: () => Date.now() + 3e5
    },
    now: {
      type: Number,
      default: () => Date.now()
    },
    format: {
      type: String,
      default: "HH:mm:ss"
    },
    start: {
      type: Boolean,
      default: !0
    },
    valueStyle: {
      type: Object
    }
  },
  emits: {
    finish: () => !0
  },
  setup(e, { emit: t }) {
    const n = B("statistic"), { start: o, value: i, now: r, format: l } = ve(e), s = V(
      ou(
        Math.max(Ut(e.value).diff(Ut(e.now), "millisecond"), 0),
        e.format
      )
    );
    ze([i, r, l], () => {
      const p = ou(
        Math.max(Ut(e.value).diff(Ut(e.now), "millisecond"), 0),
        e.format
      );
      p !== s.value && (s.value = p);
    });
    const u = V(0), f = () => {
      u.value && (window.clearInterval(u.value), u.value = 0);
    }, d = () => {
      Ut(e.value).valueOf() < Date.now() || (u.value = window.setInterval(() => {
        const p = Ut(e.value).diff(Ut(), "millisecond");
        p <= 0 && (f(), t("finish")), s.value = ou(Math.max(p, 0), e.format);
      }, 1e3 / 30));
    };
    return Je(() => {
      e.start && d();
    }), _t(() => {
      f();
    }), ze(o, (p) => {
      p && !u.value && d();
    }), {
      prefixCls: n,
      displayValue: s
    };
  }
});
function X7(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m([`${e.prefixCls}`, `${e.prefixCls}-countdown`])
  }, [
    e.title || e.$slots.title ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-title`)
    }, [
      _(e.$slots, "title", {}, () => [
        Re(Pe(e.title), 1)
      ])
    ], 2)) : te("v-if", !0),
    $("div", {
      class: m(`${e.prefixCls}-content`)
    }, [
      $("div", {
        class: m(`${e.prefixCls}-value`),
        style: F(e.valueStyle)
      }, Pe(e.displayValue), 7)
    ], 2)
  ], 2);
}
var _i = /* @__PURE__ */ N(G7, [["render", X7]]);
const Q7 = Object.assign(lu, {
  Countdown: _i,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + lu.name, lu), e.component(n + _i.name, _i);
  }
}), s2 = Symbol("ArcoSteps"), _7 = S({
  name: "Steps",
  props: {
    type: {
      type: String,
      default: "default"
    },
    direction: {
      type: String,
      default: "horizontal"
    },
    labelPlacement: {
      type: String,
      default: "horizontal"
    },
    current: {
      type: Number,
      default: void 0
    },
    defaultCurrent: {
      type: Number,
      default: 1
    },
    status: {
      type: String,
      default: "process"
    },
    lineLess: {
      type: Boolean,
      default: !1
    },
    small: {
      type: Boolean,
      default: !1
    },
    changeable: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:current": (e) => !0,
    change: (e, t) => !0
  },
  setup(e, { emit: t, slots: n }) {
    const { type: o, lineLess: i } = ve(e), r = B("steps"), l = V(e.defaultCurrent), s = a(() => {
      var C;
      return (C = e.current) != null ? C : l.value;
    }), u = a(
      () => ["navigation", "arrow"].includes(e.type) ? "horizontal" : e.direction
    ), f = a(() => e.type === "dot" ? u.value === "vertical" ? "horizontal" : "vertical" : e.type === "navigation" ? "horizontal" : e.labelPlacement), d = (C) => C < s.value ? "finish" : C > s.value ? "wait" : e.status, p = (C, P) => {
      e.changeable && (l.value = C, t("update:current", C), t("change", C, P));
    }, h = me(/* @__PURE__ */ new Map()), k = a(
      () => Array.from(h.values()).filter((C) => C.status === "error").map((C) => C.step)
    ), y = (C, P) => {
      h.set(C, P);
    }, w = (C) => {
      h.delete(C);
    }, g = a(() => [
      r,
      `${r}-${u.value}`,
      `${r}-label-${f.value}`,
      `${r}-mode-${o.value}`,
      {
        [`${r}-changeable`]: e.changeable,
        [`${r}-size-small`]: e.small && e.type !== "dot",
        [`${r}-line-less`]: i.value
      }
    ]);
    return it(
      s2,
      me({
        type: o,
        direction: u,
        labelPlacement: f,
        lineLess: i,
        current: s,
        errorSteps: k,
        getStatus: d,
        addItem: y,
        removeItem: w,
        onClick: p,
        parentCls: r
      })
    ), {
      cls: g
    };
  }
});
function J7(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.cls)
  }, [
    _(e.$slots, "default")
  ], 2);
}
var iu = /* @__PURE__ */ N(_7, [["render", J7]]);
const eS = S({
  name: "Step",
  components: {
    IconCheck: Wo,
    IconClose: Dt
  },
  props: {
    title: String,
    description: String,
    status: {
      type: String
    },
    disabled: {
      type: Boolean,
      default: !1
    }
  },
  setup(e) {
    const t = B("steps-item"), n = dn(), o = B("steps-icon"), i = Ge(s2, void 0), r = a(() => {
      var y;
      return (y = i == null ? void 0 : i.type) != null ? y : "default";
    }), l = V(), { computedIndex: s } = Tv({
      itemRef: l,
      selector: `.${t}`,
      parentClassName: i == null ? void 0 : i.parentCls
    }), u = a(() => s.value + 1), f = a(
      () => {
        var y, w;
        return (w = (y = e.status) != null ? y : i == null ? void 0 : i.getStatus(u.value)) != null ? w : "process";
      }
    ), d = a(
      () => {
        var y;
        return (y = i == null ? void 0 : i.errorSteps.includes(u.value + 1)) != null ? y : !1;
      }
    );
    n && (i == null || i.addItem(
      n.uid,
      me({
        step: u,
        status: f
      })
    )), _t(() => {
      n && (i == null || i.removeItem(n.uid));
    });
    const p = a(
      () => !(i != null && i.lineLess) && ((i == null ? void 0 : i.labelPlacement) === "vertical" || (i == null ? void 0 : i.direction) === "vertical")
    ), h = (y) => {
      e.disabled || i == null || i.onClick(u.value, y);
    }, k = a(() => [
      t,
      `${t}-${f.value}`,
      {
        [`${t}-active`]: u.value === (i == null ? void 0 : i.current),
        [`${t}-next-error`]: d.value,
        [`${t}-disabled`]: e.disabled
      }
    ]);
    return {
      prefixCls: t,
      iconCls: o,
      cls: k,
      itemRef: l,
      showTail: p,
      stepNumber: u,
      computedStatus: f,
      type: r,
      handleClick: h
    };
  }
});
function tS(e, t, n, o, i, r) {
  const l = J("icon-check"), s = J("icon-close");
  return v(), b("div", {
    ref: "itemRef",
    class: m(e.cls),
    onClick: t[0] || (t[0] = (...u) => e.handleClick && e.handleClick(...u))
  }, [
    e.showTail ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-tail`)
    }, null, 2)) : te("v-if", !0),
    e.type !== "arrow" ? (v(), b("div", {
      key: 1,
      class: m(`${e.prefixCls}-node`)
    }, [
      _(e.$slots, "node", {
        step: e.stepNumber,
        status: e.computedStatus
      }, () => [
        e.type !== "dot" ? (v(), b("div", {
          key: 0,
          class: m(e.iconCls)
        }, [
          _(e.$slots, "icon", {
            step: e.stepNumber,
            status: e.computedStatus
          }, () => [
            e.computedStatus === "finish" ? (v(), oe(l, { key: 0 })) : e.computedStatus === "error" ? (v(), oe(s, { key: 1 })) : (v(), b(Ae, { key: 2 }, [
              Re(Pe(e.stepNumber), 1)
            ], 64))
          ])
        ], 2)) : te("v-if", !0)
      ])
    ], 2)) : te("v-if", !0),
    $("div", {
      class: m(`${e.prefixCls}-content`)
    }, [
      $("div", {
        class: m(`${e.prefixCls}-title`)
      }, [
        _(e.$slots, "default", {}, () => [
          Re(Pe(e.title), 1)
        ])
      ], 2),
      e.description || e.$slots.description ? (v(), b("div", {
        key: 0,
        class: m(`${e.prefixCls}-description`)
      }, [
        _(e.$slots, "description", {}, () => [
          Re(Pe(e.description), 1)
        ])
      ], 2)) : te("v-if", !0)
    ], 2)
  ], 2);
}
var Ji = /* @__PURE__ */ N(eS, [["render", tS]]);
const nS = Object.assign(iu, {
  Step: Ji,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + iu.name, iu), e.component(n + Ji.name, Ji);
  }
}), lS = S({
  name: "Switch",
  components: {
    IconLoading: Yt
  },
  props: {
    modelValue: {
      type: [String, Number, Boolean],
      default: void 0
    },
    defaultChecked: {
      type: Boolean,
      default: !1
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    loading: {
      type: Boolean,
      default: !1
    },
    type: {
      type: String,
      default: "circle"
    },
    size: {
      type: String
    },
    checkedValue: {
      type: [String, Number, Boolean],
      default: !0
    },
    uncheckedValue: {
      type: [String, Number, Boolean],
      default: !1
    },
    checkedColor: {
      type: String
    },
    uncheckedColor: {
      type: String
    },
    beforeChange: {
      type: Function
    },
    checkedText: {
      type: String
    },
    uncheckedText: {
      type: String
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e, t) => !0,
    focus: (e) => !0,
    blur: (e) => !0
  },
  setup(e, { emit: t }) {
    const { disabled: n, size: o, modelValue: i } = ve(e), r = B("switch"), { mergedSize: l } = xt(o), { mergedDisabled: s, mergedSize: u, eventHandlers: f } = mt({
      disabled: n,
      size: l
    }), d = V(
      e.defaultChecked ? e.checkedValue : e.uncheckedValue
    ), p = a(
      () => {
        var j;
        return ((j = e.modelValue) != null ? j : d.value) === e.checkedValue;
      }
    ), h = V(!1), k = a(() => h.value || e.loading), y = (j, I) => {
      var L, M;
      d.value = j ? e.checkedValue : e.uncheckedValue, t("update:modelValue", d.value), t("change", d.value, I), (M = (L = f.value) == null ? void 0 : L.onChange) == null || M.call(L, I);
    }, w = async (j) => {
      if (k.value || s.value)
        return;
      const I = !p.value, L = I ? e.checkedValue : e.uncheckedValue, M = e.beforeChange;
      if (Ne(M)) {
        h.value = !0;
        try {
          const E = await M(L);
          (E ?? !0) && y(I, j);
        } finally {
          h.value = !1;
        }
      } else
        y(I, j);
    }, g = (j) => {
      var I, L;
      t("focus", j), (L = (I = f.value) == null ? void 0 : I.onFocus) == null || L.call(I, j);
    }, C = (j) => {
      var I, L;
      t("blur", j), (L = (I = f.value) == null ? void 0 : I.onBlur) == null || L.call(I, j);
    };
    ze(i, (j) => {
      (Ve(j) || Jt(j)) && (d.value = e.uncheckedValue);
    });
    const P = a(() => [
      r,
      `${r}-type-${e.type}`,
      {
        [`${r}-small`]: u.value === "small" || u.value === "mini",
        [`${r}-checked`]: p.value,
        [`${r}-disabled`]: s.value,
        [`${r}-loading`]: k.value,
        [`${r}-custom-color`]: e.type === "line" && (e.checkedColor || e.uncheckedColor)
      }
    ]), z = a(() => {
      if (p.value && e.checkedColor)
        return e.type === "line" ? { "--custom-color": e.checkedColor } : { backgroundColor: e.checkedColor };
      if (!p.value && e.uncheckedColor)
        return e.type === "line" ? { "--custom-color": e.uncheckedColor } : { backgroundColor: e.uncheckedColor };
    });
    return {
      prefixCls: r,
      cls: P,
      mergedDisabled: s,
      buttonStyle: z,
      computedCheck: p,
      computedLoading: k,
      handleClick: w,
      handleFocus: g,
      handleBlur: C
    };
  }
}), oS = ["aria-checked", "disabled"];
function iS(e, t, n, o, i, r) {
  const l = J("icon-loading");
  return v(), b("button", {
    type: "button",
    role: "switch",
    "aria-checked": e.computedCheck,
    class: m(e.cls),
    style: F(e.buttonStyle),
    disabled: e.mergedDisabled,
    onClick: t[0] || (t[0] = (...s) => e.handleClick && e.handleClick(...s)),
    onFocus: t[1] || (t[1] = (...s) => e.handleFocus && e.handleFocus(...s)),
    onBlur: t[2] || (t[2] = (...s) => e.handleBlur && e.handleBlur(...s))
  }, [
    $("span", {
      class: m(`${e.prefixCls}-handle`)
    }, [
      $("span", {
        class: m(`${e.prefixCls}-handle-icon`)
      }, [
        e.computedLoading ? (v(), oe(l, { key: 0 })) : (v(), b(Ae, { key: 1 }, [
          e.computedCheck ? _(e.$slots, "checked-icon", { key: 0 }) : _(e.$slots, "unchecked-icon", { key: 1 })
        ], 64))
      ], 2)
    ], 2),
    te("  prettier-ignore  "),
    e.type !== "line" && e.size !== "small" && (e.$slots.checked || e.checkedText || e.$slots.unchecked || e.uncheckedText) ? (v(), b(Ae, { key: 0 }, [
      $("span", {
        class: m(`${e.prefixCls}-text-holder`)
      }, [
        e.computedCheck ? _(e.$slots, "checked", { key: 0 }, () => [
          Re(Pe(e.checkedText), 1)
        ]) : _(e.$slots, "unchecked", { key: 1 }, () => [
          Re(Pe(e.uncheckedText), 1)
        ])
      ], 2),
      $("span", {
        class: m(`${e.prefixCls}-text`)
      }, [
        e.computedCheck ? _(e.$slots, "checked", { key: 0 }, () => [
          Re(Pe(e.checkedText), 1)
        ]) : _(e.$slots, "unchecked", { key: 1 }, () => [
          Re(Pe(e.uncheckedText), 1)
        ])
      ], 2)
    ], 64)) : te("v-if", !0)
  ], 46, oS);
}
var ru = /* @__PURE__ */ N(lS, [["render", iS]]);
const rS = Object.assign(ru, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + ru.name, ru);
  }
}), aS = (e) => {
  let t = 0;
  const n = (o) => {
    if (He(o) && o.length > 0)
      for (const i of o)
        i.children ? n(i.children) : t += 1;
  };
  return n(e), t;
}, u2 = (e) => {
  let t = 0;
  if (He(e) && e.length > 0) {
    t = 1;
    for (const n of e)
      if (n.children) {
        const o = u2(n.children);
        o > 0 && (t = Math.max(t, o + 1));
      }
  }
  return t;
}, Sp = (e, t) => {
  let { parent: n } = e;
  for (; n; )
    n.fixed === t && (t === "left" ? n.isLastLeftFixed = !0 : n.isFirstRightFixed = !0), n = n.parent;
}, sS = (e, t, n) => {
  const o = u2(e);
  t.clear();
  const i = [], r = [...Array(o)].map(
    () => []
  );
  let l, s;
  const u = (f, {
    level: d = 0,
    parent: p,
    fixed: h
  } = {}) => {
    var k;
    for (const y of f) {
      const w = { ...y, parent: p };
      if (He(w.children)) {
        const g = aS(w.children);
        g > 1 && (w.colSpan = g), r[d].push(w), u(w.children, {
          level: d + 1,
          parent: w,
          fixed: w.fixed
        });
      } else {
        const g = o - d;
        g > 1 && (w.rowSpan = g), (h || w.fixed) && (w.fixed = (k = w.fixed) != null ? k : h, w.fixed === "left" ? l = i.length : Ve(s) && (s = i.length)), (Ve(w.dataIndex) || Jt(w.dataIndex)) && (w.dataIndex = `__arco_data_index_${i.length}`), n[w.dataIndex] && (w._resizeWidth = n[w.dataIndex]), t.set(w.dataIndex, w), i.push(w), r[d].push(w);
      }
    }
  };
  return u(e), Ve(l) || (i[l].isLastLeftFixed = !0, Sp(i[l], "left")), Ve(s) || (i[s].isFirstRightFixed = !0, Sp(i[s], "right")), { dataColumns: i, groupColumns: r };
}, uS = (e, t) => {
  for (let n = 0; n < e.length; n++)
    if (e[n].name === t)
      return n;
  return -1;
}, cS = (e, t) => {
  var n;
  const o = uS(t, e.name);
  if (o <= 0)
    return 0;
  let i = 0;
  const r = t.slice(0, o);
  for (const l of r)
    i += (n = l.width) != null ? n : 0;
  return i;
}, i0 = (e) => e.children && e.children.length > 0 ? i0(e.children[0]) : e, dS = (e) => e.children && e.children.length > 0 ? i0(e.children[e.children.length - 1]) : e, fS = (e, {
  dataColumns: t,
  operations: n
}) => {
  var o, i, r;
  let l = 0;
  if (e.fixed === "left") {
    for (const f of n)
      l += (o = f.width) != null ? o : 40;
    const u = i0(e);
    for (const f of t) {
      if (u.dataIndex === f.dataIndex)
        break;
      l += (r = (i = f._resizeWidth) != null ? i : f.width) != null ? r : 0;
    }
    return l;
  }
  const s = dS(e);
  for (let u = t.length - 1; u > 0; u--) {
    const f = t[u];
    if (s.dataIndex === f.dataIndex)
      break;
    f.fixed === "right" && (l += f.width);
  }
  return l;
}, c2 = (e, t) => t.fixed ? [
  `${e}-col-fixed-left`,
  {
    [`${e}-col-fixed-left-last`]: t.isLastLeftFixed
  }
] : [], d2 = (e, t) => t.fixed === "left" ? [
  `${e}-col-fixed-left`,
  {
    [`${e}-col-fixed-left-last`]: t.isLastLeftFixed
  }
] : t.fixed === "right" ? [
  `${e}-col-fixed-right`,
  {
    [`${e}-col-fixed-right-first`]: t.isFirstRightFixed
  }
] : [], f2 = (e, {
  dataColumns: t,
  operations: n
}) => {
  if (e.fixed) {
    const o = `${fS(e, { dataColumns: t, operations: n })}px`;
    return e.fixed === "left" ? {
      left: o
    } : {
      right: o
    };
  }
  return {};
}, v2 = (e, t) => e.fixed ? {
  left: `${cS(e, t)}px`
} : {};
function p2(e) {
  return e.map((t) => {
    const n = { ...t };
    return n.children && (n.children = p2(n.children)), n;
  });
}
function m2(e) {
  return e.map((t) => {
    const n = t.raw;
    return t.children && n.children && (n.children = m2(t.children)), t.raw;
  });
}
const r0 = (e) => {
  const t = [];
  if (e.children)
    for (const n of e.children)
      n.isLeaf ? t.push(n.key) : t.push(...r0(n));
  return t;
}, vS = (e, t) => {
  let n = !1, o = !1;
  const i = t.filter(
    (r) => e.includes(r)
  );
  return i.length > 0 && (i.length >= t.length ? n = !0 : o = !0), {
    checked: n,
    indeterminate: o
  };
}, ro = (e, t, n = !1) => n ? e.filter((o) => !t.includes(o)) : Array.from(new Set(e.concat(t))), pS = (e) => {
  const t = [];
  for (let n = 0; n < e.length; n++)
    t[n] = e[e.length - 1 - n];
  return t;
}, mS = ({
  selectedKeys: e,
  defaultSelectedKeys: t,
  rowSelection: n,
  currentAllRowKeys: o,
  currentAllEnabledRowKeys: i,
  emit: r
}) => {
  var l, s, u;
  const f = a(() => {
    var z;
    return ((z = n.value) == null ? void 0 : z.type) === "radio";
  }), d = V(
    (u = (s = t.value) != null ? s : (l = n.value) == null ? void 0 : l.defaultSelectedRowKeys) != null ? u : []
  ), p = a(
    () => {
      var z, j, I;
      return (I = (j = e.value) != null ? j : (z = n.value) == null ? void 0 : z.selectedRowKeys) != null ? I : d.value;
    }
  ), h = a(
    () => p.value.filter((z) => o.value.includes(z))
  );
  return {
    isRadio: f,
    selectedRowKeys: p,
    currentSelectedRowKeys: h,
    handleSelectAll: (z) => {
      const j = ro(
        p.value,
        i.value,
        !z
      );
      d.value = j, r("selectAll", z), r("selectionChange", j), r("update:selectedKeys", j);
    },
    handleSelect: (z, j) => {
      const I = f.value ? [j.key] : ro(p.value, [j.key], !z);
      d.value = I, r("select", I, j.key, j.raw), r("selectionChange", I), r("update:selectedKeys", I);
    },
    handleSelectAllLeafs: (z, j) => {
      const I = ro(p.value, r0(z), !j);
      d.value = I, r("select", I, z.key, z.raw), r("selectionChange", I), r("update:selectedKeys", I);
    },
    select: (z, j = !0) => {
      const I = [].concat(z), L = f.value ? I : ro(p.value, I, !j);
      d.value = L, r("selectionChange", L), r("update:selectedKeys", L);
    },
    selectAll: (z = !0) => {
      const j = ro(
        p.value,
        i.value,
        !z
      );
      d.value = j, r("selectionChange", j), r("update:selectedKeys", j);
    },
    clearSelected: () => {
      d.value = [], r("selectionChange", []), r("update:selectedKeys", []);
    }
  };
}, hS = ({
  expandedKeys: e,
  defaultExpandedKeys: t,
  defaultExpandAllRows: n,
  expandable: o,
  allRowKeys: i,
  emit: r
}) => {
  const s = V((() => {
    var h, k;
    return t.value ? t.value : (h = o.value) != null && h.defaultExpandedRowKeys ? o.value.defaultExpandedRowKeys : n.value || (k = o.value) != null && k.defaultExpandAllRows ? [...i.value] : [];
  })()), u = a(
    () => {
      var h, k, y;
      return (y = (k = e.value) != null ? k : (h = o.value) == null ? void 0 : h.expandedRowKeys) != null ? y : s.value;
    }
  );
  return {
    expandedRowKeys: u,
    handleExpand: (h, k) => {
      const w = u.value.includes(h) ? u.value.filter((g) => h !== g) : u.value.concat(h);
      s.value = w, r("expand", h, k), r("expandedChange", w), r("update:expandedKeys", w);
    },
    expand: (h, k = !0) => {
      const y = [].concat(h), w = k ? u.value.concat(y) : u.value.filter((g) => !y.includes(g));
      s.value = w, r("expandedChange", w), r("update:expandedKeys", w);
    },
    expandAll: (h = !0) => {
      const k = h ? [...i.value] : [];
      s.value = k, r("expandedChange", k), r("update:expandedKeys", k);
    }
  };
}, kS = (e, t) => {
  var n, o;
  const i = V(
    Qe(e.pagination) && (n = e.pagination.defaultCurrent) != null ? n : 1
  ), r = V(
    Qe(e.pagination) && (o = e.pagination.defaultPageSize) != null ? o : 10
  ), l = a(
    () => {
      var d;
      return Qe(e.pagination) && (d = e.pagination.pageSize) != null ? d : r.value;
    }
  );
  return {
    page: a(
      () => {
        var d;
        return Qe(e.pagination) && (d = e.pagination.current) != null ? d : i.value;
      }
    ),
    pageSize: l,
    handlePageChange: (d) => {
      i.value = d, t("pageChange", d);
    },
    handlePageSizeChange: (d) => {
      r.value = d, t("pageSizeChange", d);
    }
  };
}, gS = S({
  name: "ColGroup",
  props: {
    dataColumns: {
      type: Array,
      required: !0
    },
    operations: {
      type: Array,
      required: !0
    },
    columnWidth: {
      type: Object
    }
  },
  setup() {
    return {
      fixedWidth: (t, n) => {
        if (t) {
          const o = Math.max(t, n || 0);
          return {
            width: `${t}px`,
            minWidth: `${o}px`,
            maxWidth: `${t}px`
          };
        }
        if (n)
          return { minWidth: `${n}px` };
      }
    };
  }
});
function yS(e, t, n, o, i, r) {
  return v(), b("colgroup", null, [
    (v(!0), b(Ae, null, St(e.operations, (l) => (v(), b("col", {
      key: `arco-col-${l.name}`,
      class: m(`arco-table-${l.name}-col`),
      style: F(e.fixedWidth(l.width))
    }, null, 6))), 128)),
    (v(!0), b(Ae, null, St(e.dataColumns, (l) => (v(), b("col", {
      key: `arco-col-${l.dataIndex}`,
      style: F(
        e.fixedWidth(
          e.columnWidth && l.dataIndex && e.columnWidth[l.dataIndex] || l.width,
          l.minWidth
        )
      )
    }, null, 4))), 128))
  ]);
}
var Jo = /* @__PURE__ */ N(gS, [["render", yS]]), bo = S({
  name: "Thead",
  setup(e, {
    slots: t
  }) {
    return () => {
      var n, o;
      return c((o = (n = t.thead) == null ? void 0 : n.call(t)[0]) != null ? o : "thead", null, {
        default: t.default
      });
    };
  }
}), Co = S({
  name: "Tbody",
  setup(e, {
    slots: t
  }) {
    return () => {
      var n, o;
      return c((o = (n = t.tbody) == null ? void 0 : n.call(t)[0]) != null ? o : "tbody", null, {
        default: t.default
      });
    };
  }
}), Kn = S({
  name: "Tr",
  props: {
    expand: {
      type: Boolean
    },
    empty: {
      type: Boolean
    },
    checked: {
      type: Boolean
    },
    rowIndex: Number,
    record: {
      type: Object,
      default: () => ({})
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("table"), o = a(() => [`${n}-tr`, {
      [`${n}-tr-expand`]: e.expand,
      [`${n}-tr-empty`]: e.empty,
      [`${n}-tr-checked`]: e.checked
    }]);
    return () => {
      var i, r, l;
      return c((l = (r = t.tr) == null ? void 0 : r.call(t, {
        rowIndex: e.rowIndex,
        record: (i = e.record) == null ? void 0 : i.raw
      })[0]) != null ? l : "tr", {
        class: o.value
      }, {
        default: t.default
      });
    };
  }
});
const bS = S({
  name: "IconCaretDown",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-caret-down`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), CS = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function $S(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M24.938 34.829a1.2 1.2 0 0 1-1.875 0L9.56 17.949c-.628-.785-.069-1.949.937-1.949h27.007c1.006 0 1.565 1.164.937 1.95L24.937 34.829Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, CS);
}
var au = /* @__PURE__ */ N(bS, [["render", $S]]);
const a0 = Object.assign(au, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + au.name, au);
  }
}), wS = S({
  name: "IconCaretUp",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-caret-up`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), SS = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function zS(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M23.063 13.171a1.2 1.2 0 0 1 1.875 0l13.503 16.88c.628.785.069 1.949-.937 1.949H10.497c-1.006 0-1.565-1.164-.937-1.95l13.503-16.879Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, SS);
}
var su = /* @__PURE__ */ N(wS, [["render", zS]]);
const h2 = Object.assign(su, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + su.name, su);
  }
}), LS = S({
  name: "IconFilter",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-filter`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), jS = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function PS(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M30 42V22.549a1 1 0 0 1 .463-.844l10.074-6.41A1 1 0 0 0 41 14.45V8a1 1 0 0 0-1-1H8a1 1 0 0 0-1 1v6.451a1 1 0 0 0 .463.844l10.074 6.41a1 1 0 0 1 .463.844V37" }, null, -1)
  ]), 14, jS);
}
var uu = /* @__PURE__ */ N(LS, [["render", PS]]);
const k2 = Object.assign(uu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + uu.name, uu);
  }
}), IS = ({
  column: e,
  tableCtx: t
}) => {
  const n = a(() => {
    var f;
    if (e.value.dataIndex && e.value.dataIndex === ((f = t.sorter) == null ? void 0 : f.field))
      return t.sorter.direction;
  }), o = a(
    () => {
      var f, d, p;
      return (p = (d = (f = e.value) == null ? void 0 : f.sortable) == null ? void 0 : d.sortDirections) != null ? p : [];
    }
  ), i = a(() => o.value.length > 0), r = a(() => o.value.includes("ascend")), l = a(
    () => o.value.includes("descend")
  ), s = a(() => {
    var f, d;
    return n.value ? n.value === o.value[0] && (d = o.value[1]) != null ? d : "" : (f = o.value[0]) != null ? f : "";
  });
  return {
    sortOrder: n,
    hasSorter: i,
    hasAscendBtn: r,
    hasDescendBtn: l,
    nextSortOrder: s,
    handleClickSorter: (f) => {
      var d;
      e.value.dataIndex && ((d = t.onSorterChange) == null || d.call(
        t,
        e.value.dataIndex,
        s.value,
        f
      ));
    }
  };
}, BS = ({
  column: e,
  tableCtx: t
}) => {
  const n = a(() => {
    var k;
    return e.value.dataIndex && ((k = t.filters) != null && k[e.value.dataIndex]) ? t.filters[e.value.dataIndex] : [];
  }), o = V(!1), i = a(() => n.value.length > 0), r = a(
    () => {
      var k;
      return !!((k = e.value.filterable) != null && k.multiple);
    }
  ), l = V(n.value);
  ze(n, (k) => {
    He(k) && String(k) !== String(l.value) && (l.value = k);
  });
  const s = (k) => {
    o.value = k;
  }, u = (k) => {
    l.value = k;
  };
  return {
    filterPopupVisible: o,
    isFilterActive: i,
    isMultipleFilter: r,
    columnFilterValue: l,
    handleFilterPopupVisibleChange: s,
    setFilterValue: u,
    handleCheckboxFilterChange: (k) => {
      u(k);
    },
    handleRadioFilterChange: (k) => {
      u([k]);
    },
    handleFilterConfirm: (k) => {
      var y;
      e.value.dataIndex && ((y = t.onFilterChange) == null || y.call(
        t,
        e.value.dataIndex,
        l.value,
        k
      )), s(!1);
    },
    handleFilterReset: (k) => {
      var y;
      u([]), e.value.dataIndex && ((y = t.onFilterChange) == null || y.call(
        t,
        e.value.dataIndex,
        l.value,
        k
      )), s(!1);
    }
  };
}, to = Symbol("ArcoTable"), zp = Symbol("ArcoTableColumn");
function Lp(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var g2 = S({
  name: "AutoTooltip",
  inheritAttrs: !1,
  props: {
    tooltipProps: {
      type: Object
    }
  },
  setup(e, {
    attrs: t,
    slots: n
  }) {
    const o = B("auto-tooltip"), i = V(), r = V(), l = V(""), s = V(!1), u = () => {
      if (i.value && r.value) {
        const h = r.value.offsetWidth > i.value.offsetWidth;
        h !== s.value && (s.value = h);
      }
    }, f = () => {
      var h;
      (h = r.value) != null && h.textContent && r.value.textContent !== l.value && (l.value = r.value.textContent);
    }, d = () => {
      f(), u();
    };
    Je(() => {
      f(), u();
    }), fn(() => {
      f(), u();
    });
    const p = () => c("span", se({
      ref: i,
      class: o
    }, t), [c(al, {
      onResize: d
    }, {
      default: () => {
        var h;
        return [c("span", {
          ref: r,
          class: `${o}-content`
        }, [(h = n.default) == null ? void 0 : h.call(n)])];
      }
    })]);
    return () => {
      let h;
      if (s.value) {
        let k;
        return c(yn, se({
          content: l.value,
          onResize: d
        }, e.tooltipProps), Lp(k = p()) ? k : {
          default: () => [k]
        });
      }
      return c(al, {
        onResize: d
      }, Lp(h = p()) ? h : {
        default: () => [h]
      });
    };
  }
});
function cu(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var $o = S({
  name: "Th",
  props: {
    column: {
      type: Object,
      default: () => ({})
    },
    operations: {
      type: Array,
      default: () => []
    },
    dataColumns: {
      type: Array,
      default: () => []
    },
    resizable: Boolean
  },
  setup(e, {
    slots: t
  }) {
    const {
      column: n
    } = ve(e), o = B("table"), {
      t: i
    } = gt(), r = Ge(to, {}), l = a(() => {
      var D;
      return ((D = e.column) == null ? void 0 : D.dataIndex) && r.resizingColumn === e.column.dataIndex;
    }), s = a(() => {
      var D;
      if (Qe((D = e.column) == null ? void 0 : D.tooltip))
        return e.column.tooltip;
    }), u = a(() => {
      var D;
      return (D = e.column) != null && D.filterable && Xt(e.column.filterable.alignLeft) ? e.column.filterable.alignLeft : r.filterIconAlignLeft;
    }), {
      sortOrder: f,
      hasSorter: d,
      hasAscendBtn: p,
      hasDescendBtn: h,
      nextSortOrder: k,
      handleClickSorter: y
    } = IS({
      column: n,
      tableCtx: r
    }), {
      filterPopupVisible: w,
      isFilterActive: g,
      isMultipleFilter: C,
      columnFilterValue: P,
      handleFilterPopupVisibleChange: z,
      setFilterValue: j,
      handleCheckboxFilterChange: I,
      handleRadioFilterChange: L,
      handleFilterConfirm: M,
      handleFilterReset: E
    } = BS({
      column: n,
      tableCtx: r
    }), K = () => {
      var D, R, W, O, x;
      let G, ne;
      const {
        filterable: ee
      } = e.column;
      return (D = e.column.slots) != null && D["filter-content"] ? (R = e.column.slots) == null ? void 0 : R["filter-content"]({
        filterValue: P.value,
        setFilterValue: j,
        handleFilterConfirm: M,
        handleFilterReset: E
      }) : ee != null && ee.slotName ? (O = (W = r == null ? void 0 : r.slots) == null ? void 0 : W[ee == null ? void 0 : ee.slotName]) == null ? void 0 : O.call(W, {
        filterValue: P.value,
        setFilterValue: j,
        handleFilterConfirm: M,
        handleFilterReset: E
      }) : ee != null && ee.renderContent ? ee.renderContent({
        filterValue: P.value,
        setFilterValue: j,
        handleFilterConfirm: M,
        handleFilterReset: E
      }) : c("div", {
        class: `${o}-filters-content`
      }, [c("ul", {
        class: `${o}-filters-list`
      }, [(x = ee == null ? void 0 : ee.filters) == null ? void 0 : x.map((Q, ae) => {
        var ge;
        return c("li", {
          class: `${o}-filters-item`,
          key: ae
        }, [C.value ? c(Ln, {
          value: Q.value,
          modelValue: P.value,
          uninjectGroupContext: !0,
          onChange: I
        }, {
          default: () => [Q.text]
        }) : c(Ul, {
          value: Q.value,
          modelValue: (ge = P.value[0]) != null ? ge : "",
          uninjectGroupContext: !0,
          onChange: L
        }, {
          default: () => [Q.text]
        })]);
      })]), c("div", {
        class: `${o}-filters-bottom`
      }, [c(Qt, {
        size: "mini",
        onClick: E
      }, cu(G = i("table.resetText")) ? G : {
        default: () => [G]
      }), c(Qt, {
        type: "primary",
        size: "mini",
        onClick: M
      }, cu(ne = i("table.okText")) ? ne : {
        default: () => [ne]
      })])]);
    }, q = () => {
      const {
        filterable: D
      } = e.column;
      return D ? c(Tt, se({
        popupVisible: w.value,
        trigger: "click",
        autoFitPosition: !0,
        popupOffset: u.value ? 4 : 0,
        onPopupVisibleChange: z
      }, D.triggerProps), {
        default: () => [c(pt, {
          class: [`${o}-filters`, {
            [`${o}-filters-active`]: g.value,
            [`${o}-filters-open`]: w.value,
            [`${o}-filters-align-left`]: u.value
          }],
          disabled: !u.value,
          onClick: (R) => R.stopPropagation()
        }, {
          default: () => {
            var R, W, O, x, G;
            return [(G = (x = (W = (R = e.column.slots) == null ? void 0 : R["filter-icon"]) == null ? void 0 : W.call(R)) != null ? x : (O = D.icon) == null ? void 0 : O.call(D)) != null ? G : c(k2, null, null)];
          }
        })],
        content: K
      }) : null;
    }, T = a(() => {
      var D, R;
      const W = [`${o}-cell`, `${o}-cell-align-${(R = (D = e.column) == null ? void 0 : D.align) != null ? R : e.column.children ? "center" : "left"}`];
      return d.value && W.push(`${o}-cell-with-sorter`, {
        [`${o}-cell-next-ascend`]: k.value === "ascend",
        [`${o}-cell-next-descend`]: k.value === "descend"
      }), u.value && W.push(`${o}-cell-with-filter`), W;
    }), X = () => {
      var D, R, W, O, x, G;
      return t.default ? t.default() : (D = e.column) != null && D.titleSlotName && ((R = r.slots) != null && R[e.column.titleSlotName]) ? (O = (W = r.slots)[e.column.titleSlotName]) == null ? void 0 : O.call(W, {
        column: e.column
      }) : (G = (x = e.column) == null ? void 0 : x.slots) != null && G.title ? e.column.slots.title() : Ne(e.column.title) ? e.column.title() : e.column.title;
    }, Y = () => {
      var D, R, W;
      let O;
      return c("span", {
        class: T.value,
        onClick: d.value ? y : void 0
      }, [(D = e.column) != null && D.ellipsis && ((R = e.column) != null && R.tooltip) ? c(g2, {
        class: `${o}-th-title`,
        tooltipProps: s.value
      }, cu(O = X()) ? O : {
        default: () => [O]
      }) : c("span", {
        class: [`${o}-th-title`, {
          [`${o}-text-ellipsis`]: (W = e.column) == null ? void 0 : W.ellipsis
        }]
      }, [X()]), d.value && c("span", {
        class: `${o}-sorter`
      }, [p.value && c("div", {
        class: [`${o}-sorter-icon`, {
          [`${o}-sorter-icon-active`]: f.value === "ascend"
        }]
      }, [c(h2, null, null)]), h.value && c("div", {
        class: [`${o}-sorter-icon`, {
          [`${o}-sorter-icon-active`]: f.value === "descend"
        }]
      }, [c(a0, null, null)])]), u.value && q()]);
    }, Z = a(() => {
      var D, R;
      return {
        ...f2(e.column, {
          dataColumns: e.dataColumns,
          operations: e.operations
        }),
        ...(D = e.column) == null ? void 0 : D.cellStyle,
        ...(R = e.column) == null ? void 0 : R.headerCellStyle
      };
    }), U = a(() => {
      var D, R;
      return [`${o}-th`, {
        [`${o}-col-sorted`]: !!f.value,
        [`${o}-th-resizing`]: l.value
      }, ...d2(o, e.column), (D = e.column) == null ? void 0 : D.cellClass, (R = e.column) == null ? void 0 : R.headerCellClass];
    }), H = (D) => {
      var R, W, O;
      (R = e.column) != null && R.dataIndex && ((O = r.onThMouseDown) == null || O.call(r, (W = e.column) == null ? void 0 : W.dataIndex, D));
    };
    return () => {
      var D, R, W, O;
      const x = (D = e.column.colSpan) != null ? D : 1, G = (R = e.column.rowSpan) != null ? R : 1;
      return c((O = (W = t.th) == null ? void 0 : W.call(t, {
        column: e.column
      })[0]) != null ? O : "th", {
        class: U.value,
        style: Z.value,
        colspan: x > 1 ? x : void 0,
        rowspan: G > 1 ? G : void 0
      }, {
        default: () => [Y(), !u.value && q(), e.resizable && c("span", {
          class: `${o}-column-handle`,
          onMousedown: H
        }, null)]
      });
    };
  }
});
function MS(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var ol = S({
  name: "Td",
  props: {
    rowIndex: Number,
    record: {
      type: Object,
      default: () => ({})
    },
    column: {
      type: Object,
      default: () => ({})
    },
    type: {
      type: String,
      default: "normal"
    },
    operations: {
      type: Array,
      default: () => []
    },
    dataColumns: {
      type: Array,
      default: () => []
    },
    colSpan: {
      type: Number,
      default: 1
    },
    rowSpan: {
      type: Number,
      default: 1
    },
    isFixedExpand: {
      type: Boolean,
      default: !1
    },
    containerWidth: {
      type: Number
    },
    showExpandBtn: {
      type: Boolean,
      default: !1
    },
    indentSize: {
      type: Number,
      default: 0
    },
    renderExpandBtn: {
      type: Function
    },
    summary: {
      type: Boolean,
      default: !1
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("table"), o = a(() => {
      var g;
      if (Qe((g = e.column) == null ? void 0 : g.tooltip))
        return e.column.tooltip;
    }), i = a(() => {
      var g, C;
      return ((g = e.column) == null ? void 0 : g.dataIndex) && ((C = p.sorter) == null ? void 0 : C.field) === e.column.dataIndex;
    }), r = a(() => {
      var g;
      return ((g = e.column) == null ? void 0 : g.dataIndex) && p.resizingColumn === e.column.dataIndex;
    }), l = () => {
      var g, C, P, z, j, I;
      return e.summary ? Ne((g = e.column) == null ? void 0 : g.summaryCellClass) ? e.column.summaryCellClass((C = e.record) == null ? void 0 : C.raw) : (P = e.column) == null ? void 0 : P.summaryCellClass : Ne((z = e.column) == null ? void 0 : z.bodyCellClass) ? e.column.bodyCellClass((j = e.record) == null ? void 0 : j.raw) : (I = e.column) == null ? void 0 : I.bodyCellClass;
    }, s = a(() => {
      var g;
      return [`${n}-td`, {
        [`${n}-col-sorted`]: i.value,
        [`${n}-td-resizing`]: r.value
      }, ...d2(n, e.column), (g = e.column) == null ? void 0 : g.cellClass, l()];
    }), u = () => {
      var g, C, P, z, j, I;
      return e.summary ? Ne((g = e.column) == null ? void 0 : g.summaryCellStyle) ? e.column.summaryCellStyle((C = e.record) == null ? void 0 : C.raw) : (P = e.column) == null ? void 0 : P.summaryCellStyle : Ne((z = e.column) == null ? void 0 : z.bodyCellStyle) ? e.column.bodyCellStyle((j = e.record) == null ? void 0 : j.raw) : (I = e.column) == null ? void 0 : I.bodyCellStyle;
    }, f = a(() => {
      var g;
      const C = f2(e.column, {
        dataColumns: e.dataColumns,
        operations: e.operations
      }), P = u();
      return {
        ...C,
        ...(g = e.column) == null ? void 0 : g.cellStyle,
        ...P
      };
    }), d = a(() => {
      if (e.isFixedExpand && e.containerWidth)
        return {
          width: `${e.containerWidth}px`
        };
    }), p = Ge(to, {}), h = () => {
      var g, C, P, z, j, I, L, M;
      if (t.default)
        return t.default();
      const E = {
        record: (g = e.record) == null ? void 0 : g.raw,
        column: e.column,
        rowIndex: (C = e.rowIndex) != null ? C : -1
      };
      return t.cell ? t.cell(E) : (P = e.column.slots) != null && P.cell ? e.column.slots.cell(E) : e.column.render ? e.column.render(E) : e.column.slotName && ((z = p.slots) != null && z[e.column.slotName]) ? (I = (j = p.slots)[e.column.slotName]) == null ? void 0 : I.call(j, E) : String((M = yl((L = e.record) == null ? void 0 : L.raw, e.column.dataIndex)) != null ? M : "");
    }, k = V(!1), y = (g) => {
      var C, P;
      Ne(p.loadMore) && !((C = e.record) != null && C.isLeaf) && !((P = e.record) != null && P.children) && (k.value = !0, new Promise((z) => {
        var j;
        (j = p.loadMore) == null || j.call(p, e.record.raw, z);
      }).then((z) => {
        var j;
        (j = p.addLazyLoadData) == null || j.call(p, z, e.record), k.value = !1;
      })), g.stopPropagation();
    }, w = () => {
      var g, C, P, z, j, I;
      let L;
      return c("span", {
        class: [`${n}-cell`, `${n}-cell-align-${(C = (g = e.column) == null ? void 0 : g.align) != null ? C : "left"}`, {
          [`${n}-cell-fixed-expand`]: e.isFixedExpand,
          [`${n}-cell-expand-icon`]: e.showExpandBtn
        }],
        style: d.value
      }, [e.indentSize > 0 && c("span", {
        style: {
          paddingLeft: `${e.indentSize}px`
        }
      }, null), e.showExpandBtn && c("span", {
        class: `${n}-cell-inline-icon`,
        onClick: y
      }, [k.value ? c(Yt, null, null) : (P = e.renderExpandBtn) == null ? void 0 : P.call(e, e.record, !1)]), (z = e.column) != null && z.ellipsis && ((j = e.column) != null && j.tooltip) ? c(g2, {
        class: `${n}-td-content`,
        tooltipProps: o.value
      }, MS(L = h()) ? L : {
        default: () => [L]
      }) : c("span", {
        class: [`${n}-td-content`, {
          [`${n}-text-ellipsis`]: (I = e.column) == null ? void 0 : I.ellipsis
        }]
      }, [h()])]);
    };
    return () => {
      var g, C, P, z;
      return c((z = (P = t.td) == null ? void 0 : P.call(t, {
        record: (g = e.record) == null ? void 0 : g.raw,
        column: e.column,
        rowIndex: (C = e.rowIndex) != null ? C : -1
      })[0]) != null ? z : "td", {
        class: s.value,
        style: f.value,
        rowspan: e.rowSpan > 1 ? e.rowSpan : void 0,
        colspan: e.colSpan > 1 ? e.colSpan : void 0
      }, {
        default: () => [w()]
      });
    };
  }
}), NS = S({
  name: "OperationTh",
  props: {
    operationColumn: {
      type: Object,
      required: !0
    },
    operations: {
      type: Array,
      required: !0
    },
    rowSpan: {
      type: Number,
      default: 1
    },
    selectAll: {
      type: Boolean,
      default: !1
    }
  },
  setup(e) {
    const t = B("table"), n = Ge(to, {}), o = a(() => {
      var s, u, f, d;
      let p = !1, h = !1;
      const y = ((u = (s = n.currentSelectedRowKeys) == null ? void 0 : s.filter((g) => {
        var C, P;
        return (P = (C = n.currentAllEnabledRowKeys) == null ? void 0 : C.includes(g)) != null ? P : !0;
      })) != null ? u : []).length, w = (d = (f = n.currentAllEnabledRowKeys) == null ? void 0 : f.length) != null ? d : 0;
      return y > 0 && (y >= w ? p = !0 : h = !0), {
        checked: p,
        indeterminate: h
      };
    }), i = () => e.selectAll ? c(Ln, {
      modelValue: o.value.checked,
      indeterminate: o.value.indeterminate,
      uninjectGroupContext: !0,
      onChange: (s) => {
        var u;
        (u = n.onSelectAll) == null || u.call(n, s);
      }
    }, {
      default: Ne(e.operationColumn.title) ? e.operationColumn.title() : e.operationColumn.title
    }) : e.operationColumn.title ? Ne(e.operationColumn.title) ? e.operationColumn.title() : e.operationColumn.title : null, r = a(() => v2(e.operationColumn, e.operations)), l = a(() => [`${t}-th`, `${t}-operation`, {
      [`${t}-checkbox`]: e.selectAll
    }, ...c2(t, e.operationColumn)]);
    return () => c("th", {
      class: l.value,
      style: r.value,
      rowspan: e.rowSpan > 1 ? e.rowSpan : void 0
    }, [c("span", {
      class: `${t}-cell`
    }, [i()])]);
  }
}), jp = S({
  name: "OperationTd",
  components: {
    Checkbox: Ln,
    Radio: Ul,
    IconPlus: zl,
    IconMinus: Fr
  },
  props: {
    operationColumn: {
      type: Object,
      required: !0
    },
    operations: {
      type: Array,
      required: !0
    },
    record: {
      type: Object,
      required: !0
    },
    hasExpand: {
      type: Boolean,
      default: !1
    },
    selectedRowKeys: {
      type: Array
    },
    renderExpandBtn: {
      type: Function
    },
    colSpan: {
      type: Number,
      default: 1
    },
    rowSpan: {
      type: Number,
      default: 1
    },
    summary: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["select"],
  setup(e, {
    emit: t,
    slots: n
  }) {
    const o = B("table"), i = Ge(to, {}), r = a(() => v2(e.operationColumn, e.operations)), l = a(() => [`${o}-td`, `${o}-operation`, {
      [`${o}-checkbox`]: e.operationColumn.name === "selection-checkbox",
      [`${o}-radio`]: e.operationColumn.name === "selection-radio",
      [`${o}-expand`]: e.operationColumn.name === "expand",
      [`${o}-drag-handle`]: e.operationColumn.name === "drag-handle"
    }, ...c2(o, e.operationColumn)]), s = a(() => r0(e.record)), u = a(() => {
      var d;
      return vS((d = i.currentSelectedRowKeys) != null ? d : [], s.value);
    }), f = () => {
      var d, p, h, k, y, w;
      if (e.summary)
        return null;
      if (e.operationColumn.render)
        return e.operationColumn.render(e.record.raw);
      if (e.operationColumn.name === "selection-checkbox") {
        const g = e.record.key;
        return !i.checkStrictly && !e.record.isLeaf ? c(Ln, {
          modelValue: u.value.checked,
          indeterminate: u.value.indeterminate,
          disabled: !!e.record.disabled,
          uninjectGroupContext: !0,
          onChange: (C) => {
            var P;
            return (P = i.onSelectAllLeafs) == null ? void 0 : P.call(i, e.record, C);
          },
          onClick: (C) => C.stopPropagation()
        }, null) : c(Ln, {
          modelValue: (p = (d = e.selectedRowKeys) == null ? void 0 : d.includes(g)) != null ? p : !1,
          disabled: !!e.record.disabled,
          uninjectGroupContext: !0,
          onChange: (C) => {
            var P;
            return (P = i.onSelect) == null ? void 0 : P.call(i, C, e.record);
          },
          onClick: (C) => C.stopPropagation()
        }, null);
      }
      if (e.operationColumn.name === "selection-radio") {
        const g = e.record.key;
        return c(Ul, {
          modelValue: (k = (h = e.selectedRowKeys) == null ? void 0 : h.includes(g)) != null ? k : !1,
          disabled: !!e.record.disabled,
          uninjectGroupContext: !0,
          onChange: (C) => {
            var P;
            return (P = i.onSelect) == null ? void 0 : P.call(i, C, e.record);
          },
          onClick: (C) => C.stopPropagation()
        }, null);
      }
      return e.operationColumn.name === "expand" ? e.hasExpand && e.renderExpandBtn ? e.renderExpandBtn(e.record) : null : e.operationColumn.name === "drag-handle" ? (w = (y = n["drag-handle-icon"]) == null ? void 0 : y.call(n)) != null ? w : c(Zr, null, null) : null;
    };
    return () => c("td", {
      class: l.value,
      style: r.value,
      rowspan: e.rowSpan > 1 ? e.rowSpan : void 0,
      colspan: e.colSpan > 1 ? e.colSpan : void 0
    }, [c("span", {
      class: `${o}-cell`
    }, [f()])]);
  }
});
const OS = (e) => {
  const t = a(() => {
    if (e.value)
      return e.value.type === "handle" ? "handle" : "row";
  }), n = me({
    dragging: !1,
    sourceKey: "",
    sourcePath: [],
    targetPath: [],
    data: {}
  }), o = () => {
    n.dragging = !1, n.sourceKey = "", n.sourcePath = [], n.targetPath = [], n.data = {};
  };
  return {
    dragType: t,
    dragState: n,
    handleDragStart: (d, p, h, k) => {
      if (d.dataTransfer && (d.dataTransfer.effectAllowed = "move", d.target && d.target.tagName === "TD")) {
        const { parentElement: y } = d.target;
        y && y.tagName === "TR" && d.dataTransfer.setDragImage(y, 0, 0);
      }
      n.dragging = !0, n.sourceKey = p, n.sourcePath = h, n.targetPath = [...h], n.data = k;
    },
    handleDragEnter: (d, p) => {
      d.dataTransfer && (d.dataTransfer.dropEffect = "move"), n.targetPath.toString() !== p.toString() && (n.targetPath = p), d.preventDefault();
    },
    handleDragLeave: (d) => {
    },
    handleDragover: (d) => {
      d.dataTransfer && (d.dataTransfer.dropEffect = "move"), d.preventDefault();
    },
    handleDragEnd: (d) => {
      var p;
      ((p = d.dataTransfer) == null ? void 0 : p.dropEffect) === "none" && o();
    },
    handleDrop: (d) => {
      o(), d.preventDefault();
    }
  };
}, VS = (e, t) => {
  const n = V(""), o = me({}), i = (s, u) => {
    u.preventDefault(), n.value = s, rt(window, "mousemove", l), rt(window, "mouseup", r), rt(window, "contextmenu", r);
  }, r = () => {
    n.value = "", ct(window, "mousemove", l), ct(window, "mouseup", r), ct(window, "contextmenu", r);
  }, l = (s) => {
    const u = e.value[n.value];
    if (u) {
      const { clientX: f } = s, { x: d } = u.getBoundingClientRect();
      let p = Math.ceil(f - d);
      p < 40 && (p = 40), o[n.value] = p, t("columnResize", n.value, p);
    }
  };
  return {
    resizingColumn: n,
    columnWidth: o,
    handleThMouseDown: i,
    handleThMouseUp: r
  };
}, TS = ({
  columns: e,
  onFilterChange: t
}) => {
  const n = V(Pp(e.value));
  ze(e, (l) => {
    const s = Pp(l);
    _l(s, n.value) || (n.value = s);
  });
  const o = a(() => {
    var l, s;
    const u = {};
    for (const f of e.value)
      if (f.dataIndex) {
        const d = (s = (l = f.filterable) == null ? void 0 : l.filteredValue) != null ? s : n.value[f.dataIndex];
        d && (u[f.dataIndex] = d);
      }
    return u;
  });
  return {
    _filters: n,
    computedFilters: o,
    resetFilters: (l) => {
      var s;
      const u = l ? [].concat(l) : [], f = {};
      for (const d of e.value)
        if (d.dataIndex && d.filterable && (u.length === 0 || u.includes(d.dataIndex))) {
          const p = (s = d.filterable.defaultFilteredValue) != null ? s : [];
          f[d.dataIndex] = p, t(d.dataIndex, p);
        }
      n.value = f;
    },
    clearFilters: (l) => {
      const s = l ? [].concat(l) : [], u = {};
      for (const f of e.value)
        if (f.dataIndex && f.filterable && (s.length === 0 || s.includes(f.dataIndex))) {
          const d = [];
          u[f.dataIndex] = d, t(f.dataIndex, d);
        }
      n.value = u;
    }
  };
}, Pp = (e) => {
  var t;
  const n = {};
  for (const o of e)
    o.dataIndex && ((t = o.filterable) != null && t.defaultFilteredValue) && (n[o.dataIndex] = o.filterable.defaultFilteredValue);
  return n;
}, AS = ({
  columns: e,
  onSorterChange: t
}) => {
  const n = V(Ip(e.value));
  ze(e, (l) => {
    const s = Ip(l);
    _l(s, n.value) || (n.value = s);
  });
  const o = a(() => {
    var l;
    for (const s of e.value)
      if (s.dataIndex && s.sortable) {
        const u = zt(s.sortable.sortOrder) ? s.sortable.sortOrder : ((l = n.value) == null ? void 0 : l.field) === s.dataIndex ? n.value.direction : "";
        if (u)
          return {
            field: s.dataIndex,
            direction: u
          };
      }
  });
  return {
    _sorter: n,
    computedSorter: o,
    resetSorters: () => {
      var l;
      let s;
      for (const u of e.value)
        u.dataIndex && u.sortable && (!s && u.sortable.defaultSortOrder && (s = {
          field: u.dataIndex,
          direction: u.sortable.defaultSortOrder
        }), t(u.dataIndex, (l = u.sortable.defaultSortOrder) != null ? l : ""));
      n.value = s;
    },
    clearSorters: () => {
      for (const l of e.value)
        l.dataIndex && l.sortable && t(l.dataIndex, "");
    }
  };
}, Ip = (e) => {
  var t;
  for (const n of e)
    if (n.dataIndex && ((t = n.sortable) != null && t.defaultSortOrder))
      return {
        field: n.dataIndex,
        direction: n.sortable.defaultSortOrder
      };
}, Bp = ({
  spanMethod: e,
  data: t,
  columns: n
}) => {
  const o = (s, u) => {
    s == null || s.forEach((f, d) => {
      var p;
      f.hasSubtree && ((p = f.children) != null && p.length) && o(f.children || [], u), n.value.forEach((h, k) => {
        var y, w;
        const { rowspan: g = 1, colspan: C = 1 } = (w = (y = e.value) == null ? void 0 : y.call(e, {
          record: f.raw,
          column: h,
          rowIndex: d,
          columnIndex: k
        })) != null ? w : {};
        (g > 1 || C > 1) && (u[`${d}-${k}-${f.key}`] = [g, C], Array.from({ length: g }).forEach((P, z) => {
          var j;
          if (d + z < s.length) {
            const { key: I } = (j = s[d + z]) != null ? j : {};
            Array.from({ length: C }).forEach((L, M) => {
              k + M < n.value.length && `${d}-${k}-${f.key}` != `${d + z}-${k + M}-${I}` && (i.value[`${d + z}-${k + M}-${I}`] = [0, 0]);
            });
          }
        }));
      });
    });
  };
  let i = V({});
  const r = a(() => {
    const s = {};
    return i.value = {}, e.value && o(t.value, s), s;
  }), l = a(() => {
    const s = [];
    for (const u of Object.keys(i.value))
      s.push(u);
    return s;
  });
  return {
    tableSpan: r,
    removedCells: l
  };
};
function ES(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
const Mp = {
  wrapper: !0,
  cell: !1,
  headerCell: !1,
  bodyCell: !1
};
var du = S({
  name: "Table",
  props: {
    columns: {
      type: Array,
      default: () => []
    },
    data: {
      type: Array,
      default: () => []
    },
    bordered: {
      type: [Boolean, Object],
      default: !0
    },
    hoverable: {
      type: Boolean,
      default: !0
    },
    stripe: {
      type: Boolean,
      default: !1
    },
    size: {
      type: String,
      default: () => {
        var e, t;
        return (t = (e = Ge(Kt, void 0)) == null ? void 0 : e.size) != null ? t : "large";
      }
    },
    tableLayoutFixed: {
      type: Boolean,
      default: !1
    },
    loading: {
      type: [Boolean, Object],
      default: !1
    },
    rowSelection: {
      type: Object
    },
    expandable: {
      type: Object
    },
    scroll: {
      type: Object
    },
    pagination: {
      type: [Boolean, Object],
      default: !0
    },
    pagePosition: {
      type: String,
      default: "br"
    },
    indentSize: {
      type: Number,
      default: 16
    },
    rowKey: {
      type: String,
      default: "key"
    },
    showHeader: {
      type: Boolean,
      default: !0
    },
    virtualListProps: {
      type: Object
    },
    spanMethod: {
      type: Function
    },
    spanAll: {
      type: Boolean,
      default: !1
    },
    components: {
      type: Object
    },
    loadMore: {
      type: Function
    },
    filterIconAlignLeft: {
      type: Boolean,
      default: !1
    },
    hideExpandButtonOnEmpty: {
      type: Boolean,
      default: !1
    },
    rowClass: {
      type: [String, Array, Object, Function]
    },
    draggable: {
      type: Object
    },
    rowNumber: {
      type: [Boolean, Object]
    },
    columnResizable: {
      type: Boolean
    },
    summary: {
      type: [Boolean, Function]
    },
    summaryText: {
      type: String,
      default: "Summary"
    },
    summarySpanMethod: {
      type: Function
    },
    selectedKeys: {
      type: Array
    },
    defaultSelectedKeys: {
      type: Array
    },
    expandedKeys: {
      type: Array
    },
    defaultExpandedKeys: {
      type: Array
    },
    defaultExpandAllRows: {
      type: Boolean,
      default: !1
    },
    stickyHeader: {
      type: [Boolean, Number],
      default: !1
    },
    scrollbar: {
      type: [Object, Boolean],
      default: !0
    },
    showEmptyTree: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    "update:selectedKeys": (e) => !0,
    "update:expandedKeys": (e) => !0,
    expand: (e, t) => !0,
    expandedChange: (e) => !0,
    select: (e, t, n) => !0,
    selectAll: (e) => !0,
    selectionChange: (e) => !0,
    sorterChange: (e, t) => !0,
    filterChange: (e, t) => !0,
    pageChange: (e) => !0,
    pageSizeChange: (e) => !0,
    change: (e, t, n) => !0,
    cellMouseEnter: (e, t, n) => !0,
    cellMouseLeave: (e, t, n) => !0,
    cellClick: (e, t, n) => !0,
    rowClick: (e, t) => !0,
    headerClick: (e, t) => !0,
    columnResize: (e, t) => !0,
    rowDblclick: (e, t) => !0,
    cellDblclick: (e, t, n) => !0,
    rowContextmenu: (e, t) => !0,
    cellContextmenu: (e, t, n) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      columns: o,
      rowKey: i,
      rowSelection: r,
      expandable: l,
      loadMore: s,
      filterIconAlignLeft: u,
      selectedKeys: f,
      defaultSelectedKeys: d,
      expandedKeys: p,
      defaultExpandedKeys: h,
      defaultExpandAllRows: k,
      spanMethod: y,
      draggable: w,
      summarySpanMethod: g,
      scrollbar: C,
      showEmptyTree: P
    } = ve(e), z = B("table"), j = Ge(Kt, void 0), I = a(() => Qe(e.bordered) ? {
      ...Mp,
      ...e.bordered
    } : {
      ...Mp,
      wrapper: e.bordered
    }), {
      children: L,
      components: M
    } = Oo("TableColumn"), E = a(() => {
      var ie, de;
      return (de = (ie = r.value) == null ? void 0 : ie.checkStrictly) != null ? de : !0;
    }), {
      displayScrollbar: K,
      scrollbarProps: q
    } = Br(C), T = a(() => {
      var ie, de, we, Te;
      const We = !!((ie = e.scroll) != null && ie.x || (de = e.scroll) != null && de.minWidth), Ye = !!((we = e.scroll) != null && we.y || (Te = e.scroll) != null && Te.maxHeight);
      return {
        x: We,
        y: Ye
      };
    }), X = V(), Y = V({}), {
      componentRef: Z,
      elementRef: U
    } = Wl("containerRef"), {
      componentRef: H,
      elementRef: D
    } = Wl("containerRef"), {
      elementRef: R
    } = Wl("viewportRef"), {
      componentRef: W,
      elementRef: O
    } = Wl("containerRef"), x = a(() => G.value ? Ho.value ? R.value : D.value : U.value), G = a(() => T.value.y || e.stickyHeader || Ho.value || T.value.x && Mt.value.length === 0), ne = me(/* @__PURE__ */ new Map()), ee = V();
    ze([M, ne], ([ie, de]) => {
      if (ie.length > 0) {
        const we = [];
        ie.forEach((Te) => {
          const We = de.get(Te);
          We && we.push(We);
        }), ee.value = we;
      } else
        ee.value = void 0;
    });
    const Q = /* @__PURE__ */ new Map(), ae = V([]), ge = V([]), {
      resizingColumn: Se,
      columnWidth: be,
      handleThMouseDown: Le
    } = VS(Y, t);
    ze([o, ee, be], ([ie, de]) => {
      var we;
      const Te = sS((we = de ?? ie) != null ? we : [], Q, be);
      ae.value = Te.dataColumns, ge.value = Te.groupColumns;
    }, {
      immediate: !0,
      deep: !0
    });
    const pe = a(() => ["tl", "top", "tr"].includes(e.pagePosition)), Me = V(!1), ke = V(!1), le = V(!1);
    Wt(() => {
      var ie, de, we;
      let Te = !1, We = !1, Ye = !1;
      ((ie = e.rowSelection) != null && ie.fixed || (de = e.expandable) != null && de.fixed || (we = e.draggable) != null && we.fixed) && (Te = !0);
      for (const lt of ae.value)
        lt.fixed === "left" ? (Te = !0, Ye = !0) : lt.fixed === "right" && (We = !0);
      Te !== Me.value && (Me.value = Te), We !== ke.value && (ke.value = We), Ye !== le.value && (le.value = Ye);
    });
    const re = a(() => {
      for (const ie of ae.value)
        if (ie.ellipsis)
          return !0;
      return !1;
    }), fe = (ie) => {
      const de = {
        type: ie,
        page: On.value,
        pageSize: vl.value,
        sorter: st.value,
        filters: he.value,
        dragTarget: ie === "drag" ? Cn.data : void 0
      };
      t("change", Fo.value, de, _n.value);
    }, Oe = (ie, de) => {
      $e.value = {
        ...he.value,
        [ie]: de
      }, t("filterChange", ie, de), fe("filter");
    }, Be = (ie, de) => {
      tt.value = de ? {
        field: ie,
        direction: de
      } : void 0, t("sorterChange", ie, de), fe("sorter");
    }, {
      _filters: $e,
      computedFilters: he,
      resetFilters: Ue,
      clearFilters: et
    } = TS({
      columns: ae,
      onFilterChange: Oe
    }), {
      _sorter: tt,
      computedSorter: st,
      resetSorters: $t,
      clearSorters: vn
    } = AS({
      columns: ae,
      onSorterChange: Be
    }), ye = /* @__PURE__ */ new Set(), ce = a(() => {
      const ie = [];
      ye.clear();
      const de = (we) => {
        if (He(we) && we.length > 0)
          for (const Te of we)
            ie.push(Te[i.value]), Te.disabled && ye.add(Te[i.value]), Te.children && de(Te.children);
      };
      return de(e.data), ie;
    }), Ce = a(() => {
      const ie = [], de = (we) => {
        for (const Te of we)
          ie.push(Te.key), Te.children && de(Te.children);
      };
      return de(Mt.value), ie;
    }), qe = a(() => {
      const ie = [], de = (we) => {
        for (const Te of we)
          Te.disabled || ie.push(Te.key), Te.children && de(Te.children);
      };
      return de(Mt.value), ie;
    }), {
      selectedRowKeys: Lt,
      currentSelectedRowKeys: bt,
      handleSelect: en,
      handleSelectAllLeafs: Ie,
      handleSelectAll: Ee,
      select: Ze,
      selectAll: Xe,
      clearSelected: _e
    } = mS({
      selectedKeys: f,
      defaultSelectedKeys: d,
      rowSelection: r,
      currentAllRowKeys: Ce,
      currentAllEnabledRowKeys: qe,
      emit: t
    }), {
      expandedRowKeys: nt,
      handleExpand: Rt,
      expand: tn,
      expandAll: no
    } = hS({
      expandedKeys: p,
      defaultExpandedKeys: h,
      defaultExpandAllRows: k,
      expandable: l,
      allRowKeys: ce,
      emit: t
    }), dl = me({}), Nl = (ie, de) => {
      ie && (dl[de.key] = ie);
    }, Rn = (ie) => {
      var de, we;
      for (const Te of Object.keys(he.value)) {
        const We = he.value[Te], Ye = Q.get(Te);
        if (Ye && ((de = Ye.filterable) != null && de.filter) && We.length > 0) {
          const lt = (we = Ye.filterable) == null ? void 0 : we.filter(We, ie.raw);
          if (!lt)
            return lt;
        }
      }
      return !0;
    }, {
      dragType: Mn,
      dragState: Cn,
      handleDragStart: xe,
      handleDragEnter: ot,
      handleDragover: jt,
      handleDragEnd: Nn,
      handleDrop: Hn
    } = OS(w), Qn = a(() => {
      var ie;
      const de = (we) => {
        const Te = [];
        for (const We of we) {
          const Ye = {
            raw: We,
            key: We[e.rowKey],
            disabled: We.disabled,
            expand: We.expand,
            isLeaf: We.isLeaf
          };
          We.children ? (Ye.isLeaf = !1, Ye.children = de(We.children)) : e.loadMore && !We.isLeaf ? (Ye.isLeaf = !1, dl[Ye.key] && (Ye.children = de(dl[Ye.key]))) : Ye.isLeaf = !0, Ye.hasSubtree = !!(Ye.children ? !e.hideExpandButtonOnEmpty || Ye.children.length > 0 : e.loadMore && !Ye.isLeaf), Te.push(Ye);
        }
        return Te;
      };
      return de((ie = e.data) != null ? ie : []);
    }), fl = a(() => {
      const ie = (de) => de.filter((we) => Rn(we) ? (we.children && (we.children = ie(we.children)), !0) : !1);
      return Object.keys(he.value).length > 0 ? ie(Qn.value) : Qn.value;
    }), _n = a(() => {
      var ie, de, we;
      const Te = p2(fl.value);
      if (Te.length > 0) {
        if ((ie = st.value) != null && ie.field) {
          const lt = Q.get(st.value.field);
          if (lt && ((de = lt.sortable) == null ? void 0 : de.sorter) !== !0) {
            const {
              field: ut,
              direction: vt
            } = st.value;
            Te.sort((Nt, Jn) => {
              var qn;
              const ia = yl(Nt.raw, ut), ft = yl(Jn.raw, ut);
              if ((qn = lt.sortable) != null && qn.sorter && Ne(lt.sortable.sorter))
                return lt.sortable.sorter(Nt.raw, Jn.raw, {
                  dataIndex: ut,
                  direction: vt
                });
              const Vn = ia > ft ? 1 : -1;
              return vt === "descend" ? -Vn : Vn;
            });
          }
        }
        const {
          sourcePath: We,
          targetPath: Ye
        } = Cn;
        if (Cn.dragging && Ye.length && Ye.toString() !== We.toString() && We.length === Ye.length && We.slice(0, -1).toString() === Ye.slice(0, -1).toString()) {
          let lt = Te;
          for (let ut = 0; ut < We.length; ut++) {
            const vt = We[ut];
            if (ut >= We.length - 1) {
              const Jn = lt[vt], qn = Ye[ut];
              qn > vt ? (lt.splice(qn + 1, 0, Jn), lt.splice(vt, 1)) : (lt.splice(qn, 0, Jn), lt.splice(vt + 1, 1));
            } else
              lt = (we = lt[vt].children) != null ? we : [];
          }
        }
      }
      return Te;
    }), {
      page: On,
      pageSize: vl,
      handlePageChange: Jr,
      handlePageSizeChange: ea
    } = kS(e, t), ta = a(() => {
      var ie, de;
      return (de = (ie = r.value) == null ? void 0 : ie.onlyCurrent) != null ? de : !1;
    });
    ze(On, (ie, de) => {
      ie !== de && ta.value && _e();
    });
    const Mt = a(() => e.pagination && _n.value.length > vl.value ? _n.value.slice((On.value - 1) * vl.value, On.value * vl.value) : _n.value), Fo = a(() => m2(Mt.value)), na = () => ae.value.reduce((ie, de, we) => {
      if (de.dataIndex)
        if (we === 0)
          mr(ie, de.dataIndex, e.summaryText, {
            addPath: !0
          });
        else {
          let Te = 0, We = !1;
          Mt.value.forEach((Ye) => {
            if (de.dataIndex) {
              const lt = yl(Ye.raw, de.dataIndex);
              A(lt) ? Te += lt : !Ve(lt) && !Jt(lt) && (We = !0);
            }
          }), mr(ie, de.dataIndex, We ? "" : Te, {
            addPath: !0
          });
        }
      return ie;
    }, {}), Do = (ie) => ie && ie.length > 0 ? ie.map((de) => ({
      raw: de,
      key: de[e.rowKey]
    })) : [], $n = a(() => e.summary ? Ne(e.summary) ? Do(e.summary({
      columns: ae.value,
      data: Fo.value
    })) : Do([na()]) : []), Ol = V(0), Vl = V(!0), Tl = V(!0), je = () => {
      let ie = !0, de = !0;
      const we = x.value;
      we && (ie = Ol.value === 0, de = Math.ceil(Ol.value + we.offsetWidth) >= we.scrollWidth), ie !== Vl.value && (Vl.value = ie), de !== Tl.value && (Tl.value = de);
    }, Ke = () => Vl.value && Tl.value ? `${z}-scroll-position-both` : Vl.value ? `${z}-scroll-position-left` : Tl.value ? `${z}-scroll-position-right` : `${z}-scroll-position-middle`, ht = () => {
      const ie = [];
      return Me.value && ie.push(`${z}-has-fixed-col-left`), ke.value && ie.push(`${z}-has-fixed-col-right`), ie;
    }, wt = (ie) => {
      ie.target.scrollLeft !== Ol.value && (Ol.value = ie.target.scrollLeft), je();
    }, At = (ie) => {
      wt(ie);
      const {
        scrollLeft: de
      } = ie.target;
      O.value && (O.value.scrollLeft = de), X.value && (X.value.scrollLeft = de);
    }, pn = (ie, de) => {
      t("rowClick", ie.raw, de);
    }, xo = (ie, de) => {
      t("rowDblclick", ie.raw, de);
    }, W2 = (ie, de) => {
      t("rowContextmenu", ie.raw, de);
    }, m0 = (ie, de, we) => {
      t("cellClick", ie.raw, de, we);
    }, h0 = So((ie, de, we) => {
      t("cellMouseEnter", ie.raw, de, we);
    }, 30), k0 = So((ie, de, we) => {
      t("cellMouseLeave", ie.raw, de, we);
    }, 30), g0 = (ie, de, we) => {
      t("cellDblclick", ie.raw, de, we);
    }, y0 = (ie, de, we) => {
      t("cellContextmenu", ie.raw, de, we);
    }, F2 = (ie, de) => {
      t("headerClick", ie, de);
    }, Et = a(() => {
      var ie, de;
      const we = [], Te = Me.value || ke.value;
      let We, Ye, lt;
      ((ie = e.draggable) == null ? void 0 : ie.type) === "handle" && (We = {
        name: "drag-handle",
        title: e.draggable.title,
        width: e.draggable.width,
        fixed: e.draggable.fixed || Te
      }, we.push(We)), e.expandable && (Ye = {
        name: "expand",
        title: e.expandable.title,
        width: e.expandable.width,
        fixed: e.expandable.fixed || Te
      }, we.push(Ye)), e.rowSelection && (lt = {
        name: e.rowSelection.type === "radio" ? "selection-radio" : "selection-checkbox",
        title: e.rowSelection.title,
        width: e.rowSelection.width,
        fixed: e.rowSelection.fixed || Te
      }, we.push(lt)), !le.value && we.length > 0 && we[we.length - 1].fixed && (we[we.length - 1].isLastLeftFixed = !0);
      const ut = (de = e.components) == null ? void 0 : de.operations;
      return Ne(ut) ? ut({
        dragHandle: We,
        expand: Ye,
        selection: lt
      }) : we;
    }), D2 = a(() => {
      var ie, de, we, Te;
      if (T.value.x) {
        const We = {
          width: A((ie = e.scroll) == null ? void 0 : ie.x) ? `${(de = e.scroll) == null ? void 0 : de.x}px` : (we = e.scroll) == null ? void 0 : we.x
        };
        return (Te = e.scroll) != null && Te.minWidth && (We.minWidth = A(e.scroll.minWidth) ? `${e.scroll.minWidth}px` : e.scroll.minWidth), We;
      }
    }), Ro = a(() => {
      var ie, de, we, Te;
      if (T.value.x && Mt.value.length > 0) {
        const We = {
          width: A((ie = e.scroll) == null ? void 0 : ie.x) ? `${(de = e.scroll) == null ? void 0 : de.x}px` : (we = e.scroll) == null ? void 0 : we.x
        };
        return (Te = e.scroll) != null && Te.minWidth && (We.minWidth = A(e.scroll.minWidth) ? `${e.scroll.minWidth}px` : e.scroll.minWidth), We;
      }
    });
    it(to, me({
      loadMore: s,
      addLazyLoadData: Nl,
      slots: n,
      sorter: st,
      filters: he,
      filterIconAlignLeft: u,
      resizingColumn: Se,
      checkStrictly: E,
      currentAllEnabledRowKeys: qe,
      currentSelectedRowKeys: bt,
      addColumn: (ie, de) => {
        ne.set(ie, de);
      },
      removeColumn: (ie) => {
        ne.delete(ie);
      },
      onSelectAll: Ee,
      onSelect: en,
      onSelectAllLeafs: Ie,
      onSorterChange: Be,
      onFilterChange: Oe,
      onThMouseDown: Le
    }));
    const b0 = a(() => [z, `${z}-size-${e.size}`, {
      [`${z}-border`]: I.value.wrapper,
      [`${z}-border-cell`]: I.value.cell,
      [`${z}-border-header-cell`]: !I.value.cell && I.value.headerCell,
      [`${z}-border-body-cell`]: !I.value.cell && I.value.bodyCell,
      [`${z}-stripe`]: e.stripe,
      [`${z}-hover`]: e.hoverable,
      [`${z}-dragging`]: Cn.dragging,
      [`${z}-type-selection`]: !!e.rowSelection,
      [`${z}-empty`]: e.data && Mt.value.length === 0,
      [`${z}-layout-fixed`]: e.tableLayoutFixed || T.value.x || G.value || re.value
    }]), x2 = a(() => [`${z}-pagination`, {
      [`${z}-pagination-left`]: e.pagePosition === "tl" || e.pagePosition === "bl",
      [`${z}-pagination-center`]: e.pagePosition === "top" || e.pagePosition === "bottom",
      [`${z}-pagination-right`]: e.pagePosition === "tr" || e.pagePosition === "br",
      [`${z}-pagination-top`]: pe.value
    }]), R2 = a(() => {
      const ie = ht();
      return T.value.x && ie.push(Ke()), G.value && ie.push(`${z}-scroll-y`), ie;
    }), Ho = a(() => !!e.virtualListProps), la = V({}), C0 = () => {
      const ie = {};
      for (const de of Object.keys(Y.value))
        ie[de] = Y.value[de].offsetWidth;
      la.value = ie;
    }, lo = V(!1), $0 = () => D.value ? D.value.offsetWidth > D.value.clientWidth : !1, H2 = () => {
      const ie = $0();
      lo.value !== ie && (lo.value = ie), je(), C0();
    };
    Je(() => {
      lo.value = $0(), C0();
    });
    const q2 = a(() => Qe(e.loading) ? e.loading : {
      loading: e.loading
    }), w0 = () => c(Kn, {
      empty: !0
    }, {
      default: () => [c(ol, {
        colSpan: ae.value.length + Et.value.length
      }, {
        default: () => {
          var ie, de, we, Te, We;
          return [(We = (Te = (ie = n.empty) == null ? void 0 : ie.call(n)) != null ? Te : (we = j == null ? void 0 : (de = j.slots).empty) == null ? void 0 : we.call(de, {
            component: "table"
          })) != null ? We : c(Gn, null, null)];
        }
      })]
    }), Z2 = (ie) => {
      var de;
      if (ie.expand)
        return Ne(ie.expand) ? ie.expand() : ie.expand;
      if (n["expand-row"])
        return n["expand-row"]({
          record: ie.raw
        });
      if ((de = e.expandable) != null && de.expandedRowRender)
        return e.expandable.expandedRowRender(ie.raw);
    }, S0 = a(() => [].concat(Et.value, ae.value)), K2 = a(() => e.spanAll ? S0.value : ae.value), {
      tableSpan: z0,
      removedCells: L0
    } = Bp({
      spanMethod: y,
      data: Mt,
      columns: K2
    }), {
      tableSpan: j0,
      removedCells: P0
    } = Bp({
      spanMethod: g,
      data: $n,
      columns: S0
    }), qo = (ie) => {
      if (!(!Ho.value || !ie || !la.value[ie]))
        return {
          width: `${la.value[ie]}px`
        };
    }, Y2 = (ie, de) => c(Kn, {
      key: `table-summary-${de}`,
      class: [`${z}-tr-summary`, Ne(e.rowClass) ? e.rowClass(ie.raw, de) : e.rowClass],
      onClick: (we) => pn(ie, we)
    }, {
      default: () => [Et.value.map((we, Te) => {
        var We;
        const Ye = `${de}-${Te}-${ie.key}`, [lt, ut] = (We = j0.value[Ye]) != null ? We : [1, 1];
        if (P0.value.includes(Ye))
          return null;
        const vt = qo(we.name);
        return c(jp, {
          style: vt,
          operationColumn: we,
          operations: Et.value,
          record: ie,
          rowSpan: lt,
          colSpan: ut,
          summary: !0
        }, null);
      }), ae.value.map((we, Te) => {
        var We;
        const Ye = `${de}-${Et.value.length + Te}-${ie.key}`, [lt, ut] = (We = j0.value[Ye]) != null ? We : [1, 1];
        if (P0.value.includes(Ye))
          return null;
        const vt = qo(we.dataIndex);
        return c(ol, {
          key: `td-${Ye}`,
          style: vt,
          rowIndex: de,
          record: ie,
          column: we,
          operations: Et.value,
          dataColumns: ae.value,
          rowSpan: lt,
          colSpan: ut,
          summary: !0,
          onClick: (Nt) => m0(ie, we, Nt),
          onDblclick: (Nt) => g0(ie, we, Nt),
          onMouseenter: (Nt) => h0(ie, we, Nt),
          onMouseleave: (Nt) => k0(ie, we, Nt),
          onContextmenu: (Nt) => y0(ie, we, Nt)
        }, {
          td: n.td,
          cell: n["summary-cell"]
        });
      })],
      tr: n.tr
    }), I0 = () => $n.value && $n.value.length > 0 ? c("tfoot", null, [$n.value.map((ie, de) => Y2(ie, de))]) : null, B0 = (ie, de = !0) => {
      var we, Te, We, Ye, lt;
      const ut = ie.key, vt = nt.value.includes(ut);
      return c("button", {
        type: "button",
        class: `${z}-expand-btn`,
        onClick: (Nt) => {
          Rt(ut, ie.raw), de && Nt.stopPropagation();
        }
      }, [(lt = (Ye = (we = n["expand-icon"]) == null ? void 0 : we.call(n, {
        expanded: vt,
        record: ie.raw
      })) != null ? Ye : (We = (Te = e.expandable) == null ? void 0 : Te.icon) == null ? void 0 : We.call(Te, vt, ie.raw)) != null ? lt : vt ? c(Fr, null, null) : c(zl, null, null)]);
    }, U2 = (ie, {
      indentSize: de,
      indexPath: we,
      allowDrag: Te,
      expandContent: We
    }) => {
      var Ye, lt;
      if (ie.hasSubtree)
        return ((Ye = ie.children) == null ? void 0 : Ye.length) === 0 && P.value ? w0() : (lt = ie.children) == null ? void 0 : lt.map((ut, vt) => oa(ut, vt, {
          indentSize: de,
          indexPath: we,
          allowDrag: Te
        }));
      if (We) {
        const ut = x.value;
        return c(Kn, {
          key: `${ie.key}-expand`,
          expand: !0
        }, {
          default: () => [c(ol, {
            isFixedExpand: Me.value || ke.value,
            containerWidth: ut == null ? void 0 : ut.clientWidth,
            colSpan: ae.value.length + Et.value.length
          }, ES(We) ? We : {
            default: () => [We]
          })]
        });
      }
      return null;
    }, oa = (ie, de, {
      indentSize: we = 0,
      indexPath: Te,
      allowDrag: We = !0
    } = {}) => {
      var Ye;
      const lt = ie.key, ut = (Te ?? []).concat(de), vt = Z2(ie), Nt = nt.value.includes(lt), Jn = Cn.sourceKey === ie.key, qn = Mn.value ? {
        draggable: We,
        onDragstart: (ft) => {
          We && xe(ft, ie.key, ut, ie.raw);
        },
        onDragend: (ft) => {
          We && Nn(ft);
        }
      } : {}, ia = Mn.value ? {
        onDragenter: (ft) => {
          We && ot(ft, ut);
        },
        onDragover: (ft) => {
          We && jt(ft);
        },
        onDrop: (ft) => {
          We && (fe("drag"), Hn(ft));
        }
      } : {};
      return c(Ae, null, [c(Kn, se({
        key: lt,
        class: [{
          [`${z}-tr-draggable`]: Mn.value === "row",
          [`${z}-tr-drag`]: Jn
        }, Ne(e.rowClass) ? e.rowClass(ie.raw, de) : e.rowClass],
        rowIndex: de,
        record: ie,
        checked: e.rowSelection && ((Ye = Lt.value) == null ? void 0 : Ye.includes(lt)),
        onClick: (ft) => pn(ie, ft),
        onDblclick: (ft) => xo(ie, ft),
        onContextmenu: (ft) => W2(ie, ft)
      }, Mn.value === "row" ? qn : {}, ia), {
        default: () => [Et.value.map((ft, Vn) => {
          var oo;
          const io = `${de}-${Vn}-${ie.key}`, [ra, aa] = e.spanAll ? (oo = z0.value[io]) != null ? oo : [1, 1] : [1, 1];
          if (e.spanAll && L0.value.includes(io))
            return null;
          const sa = qo(ft.name);
          return c(jp, se({
            key: `operation-td-${Vn}`,
            style: sa,
            operationColumn: ft,
            operations: Et.value,
            record: ie,
            hasExpand: !!vt,
            selectedRowKeys: bt.value,
            rowSpan: ra,
            colSpan: aa,
            renderExpandBtn: B0
          }, Mn.value === "handle" ? qn : {}), {
            "drag-handle-icon": n["drag-handle-icon"]
          });
        }), ae.value.map((ft, Vn) => {
          var oo;
          const io = `${de}-${e.spanAll ? Et.value.length + Vn : Vn}-${ie.key}`, [ra, aa] = (oo = z0.value[io]) != null ? oo : [1, 1];
          if (L0.value.includes(io))
            return null;
          const sa = Vn === 0 ? {
            showExpandBtn: ie.hasSubtree,
            indentSize: ie.hasSubtree ? we - 20 : we
          } : {}, Q2 = qo(ft.dataIndex);
          return c(ol, se({
            key: `td-${Vn}`,
            style: Q2,
            rowIndex: de,
            record: ie,
            column: ft,
            operations: Et.value,
            dataColumns: ae.value,
            rowSpan: ra,
            renderExpandBtn: B0,
            colSpan: aa
          }, sa, {
            onClick: (Zn) => m0(ie, ft, Zn),
            onDblclick: (Zn) => g0(ie, ft, Zn),
            onMouseenter: (Zn) => h0(ie, ft, Zn),
            onMouseleave: (Zn) => k0(ie, ft, Zn),
            onContextmenu: (Zn) => y0(ie, ft, Zn)
          }), {
            td: n.td
          });
        })],
        tr: n.tr
      }), Nt && U2(ie, {
        indentSize: we + e.indentSize,
        indexPath: ut,
        allowDrag: We && !Jn,
        expandContent: vt
      })]);
    }, M0 = () => {
      const ie = Mt.value.some((de) => !!de.hasSubtree);
      return c(Co, null, {
        default: () => [Mt.value.length > 0 ? Mt.value.map((de, we) => oa(de, we, {
          indentSize: ie ? 20 : 0
        })) : w0()],
        tbody: n.tbody
      });
    }, N0 = () => c(bo, null, {
      default: () => [ge.value.map((ie, de) => c(Kn, {
        key: `header-row-${de}`
      }, {
        default: () => [de === 0 && Et.value.map((we, Te) => {
          var We;
          return c(NS, {
            key: `operation-th-${Te}`,
            ref: (Ye) => {
              Ye != null && Ye.$el && we.name && (Y.value[we.name] = Ye.$el);
            },
            operationColumn: we,
            operations: Et.value,
            selectAll: !!(we.name === "selection-checkbox" && ((We = e.rowSelection) != null && We.showCheckedAll)),
            rowSpan: ge.value.length
          }, null);
        }), ie.map((we, Te) => {
          const We = e.columnResizable && !!we.dataIndex && Te < ie.length - 1;
          return c($o, {
            key: `th-${Te}`,
            ref: (Ye) => {
              Ye != null && Ye.$el && we.dataIndex && (Y.value[we.dataIndex] = Ye.$el);
            },
            column: we,
            operations: Et.value,
            dataColumns: ae.value,
            resizable: We,
            onClick: (Ye) => F2(we, Ye)
          }, {
            th: n.th
          });
        })]
      }))],
      thead: n.thead
    }), G2 = () => {
      var ie, de;
      if (G.value) {
        const we = A(e.stickyHeader) ? `${e.stickyHeader}px` : void 0, Te = [(ie = q.value) == null ? void 0 : ie.outerClass];
        e.stickyHeader && Te.push(`${z}-header-sticky`);
        const We = {
          top: we,
          ...(de = q.value) == null ? void 0 : de.outerStyle
        }, Ye = K.value ? In : "div";
        return c(Ae, null, [e.showHeader && c(Ye, se({
          ref: W,
          class: [`${z}-header`, {
            [`${z}-header-sticky`]: e.stickyHeader && !K.value
          }],
          style: {
            overflowY: lo.value ? "scroll" : void 0,
            top: K.value ? void 0 : we
          }
        }, C.value ? {
          hide: Mt.value.length !== 0,
          disableVertical: !0,
          ...q.value,
          outerClass: Te,
          outerStyle: We
        } : void 0), {
          default: () => [c("table", {
            class: `${z}-element`,
            style: D2.value,
            cellpadding: 0,
            cellspacing: 0
          }, [c(Jo, {
            dataColumns: ae.value,
            operations: Et.value,
            columnWidth: be
          }, null), N0()])]
        }), c(jn, {
          onResize: H2
        }, {
          default: () => {
            var lt, ut;
            return [Ho.value && Mt.value.length ? c(Jl, se({
              ref: (vt) => {
                vt != null && vt.$el && (D.value = vt.$el);
              },
              class: `${z}-body`,
              data: Mt.value,
              itemKey: "_key",
              component: {
                list: "table",
                content: "tbody"
              },
              listAttrs: {
                class: `${z}-element`,
                style: Ro.value
              },
              paddingPosition: "list",
              height: "auto"
            }, e.virtualListProps, {
              onScroll: At
            }), {
              item: ({
                item: vt,
                index: Nt
              }) => oa(vt, Nt)
            }) : c(Ye, se({
              ref: H,
              class: `${z}-body`,
              style: {
                maxHeight: A((lt = e.scroll) == null ? void 0 : lt.y) ? `${(ut = e.scroll) == null ? void 0 : ut.y}px` : "100%"
              }
            }, C.value ? {
              outerStyle: {
                display: "flex",
                minHeight: "0"
              },
              ...q.value
            } : void 0, {
              onScroll: At
            }), {
              default: () => [c("table", {
                class: `${z}-element`,
                style: Ro.value,
                cellpadding: 0,
                cellspacing: 0
              }, [Mt.value.length !== 0 && c(Jo, {
                dataColumns: ae.value,
                operations: Et.value,
                columnWidth: be
              }, null), M0()])]
            })];
          }
        }), $n.value && $n.value.length > 0 && c("div", {
          ref: X,
          class: `${z}-tfoot`,
          style: {
            overflowY: lo.value ? "scroll" : "hidden"
          }
        }, [c("table", {
          class: `${z}-element`,
          style: Ro.value,
          cellpadding: 0,
          cellspacing: 0
        }, [c(Jo, {
          dataColumns: ae.value,
          operations: Et.value,
          columnWidth: be
        }, null), I0()])])]);
      }
      return c(jn, {
        onResize: () => je()
      }, {
        default: () => [c("table", {
          class: `${z}-element`,
          cellpadding: 0,
          cellspacing: 0,
          style: Ro.value
        }, [c(Jo, {
          dataColumns: ae.value,
          operations: Et.value,
          columnWidth: be
        }, null), e.showHeader && N0(), M0(), $n.value && $n.value.length > 0 && I0()])]
      });
    }, O0 = (ie) => {
      var de;
      const we = (de = e.scroll) != null && de.maxHeight ? {
        maxHeight: e.scroll.maxHeight
      } : void 0, Te = K.value ? In : "div";
      return c(Ae, null, [c("div", {
        class: [`${z}-container`, R2.value]
      }, [c(Te, se({
        ref: Z,
        class: [`${z}-content`, {
          [`${z}-content-scroll-x`]: !G.value
        }],
        style: we
      }, C.value ? {
        outerStyle: {
          height: "100%"
        },
        ...q.value
      } : void 0, {
        onScroll: wt
      }), {
        default: () => [ie ? c("table", {
          class: `${z}-element`,
          cellpadding: 0,
          cellspacing: 0
        }, [ie()]) : G2()]
      })]), n.footer && c("div", {
        class: `${z}-footer`
      }, [n.footer()])]);
    }, V0 = () => {
      var ie, de;
      const we = Qe(e.pagination) ? Ft(e.pagination, ["current", "pageSize", "defaultCurrent", "defaultPageSize"]) : {};
      return c("div", {
        class: x2.value
      }, [(ie = n["pagination-left"]) == null ? void 0 : ie.call(n), c(e0, se({
        total: fl.value.length,
        current: On.value,
        pageSize: vl.value,
        onChange: (Te) => {
          Jr(Te), fe("pagination");
        },
        onPageSizeChange: (Te) => {
          ea(Te), fe("pagination");
        }
      }, we), null), (de = n["pagination-right"]) == null ? void 0 : de.call(n)]);
    }, X2 = a(() => {
      var ie, de;
      if (zt((ie = e.scroll) == null ? void 0 : ie.y))
        return {
          height: (de = e.scroll) == null ? void 0 : de.y
        };
    });
    return {
      render: () => {
        var ie;
        return n.default ? c("div", {
          class: b0.value
        }, [O0(n.default)]) : (L.value = (ie = n.columns) == null ? void 0 : ie.call(n), c("div", {
          class: b0.value,
          style: X2.value
        }, [L.value, c(Pn, q2.value, {
          default: () => [e.pagination !== !1 && (Mt.value.length > 0 || _n.value.length > 0) && pe.value && V0(), O0(), e.pagination !== !1 && (Mt.value.length > 0 || _n.value.length > 0) && !pe.value && V0()]
        })]));
      },
      selfExpand: tn,
      selfExpandAll: no,
      selfSelect: Ze,
      selfSelectAll: Xe,
      selfResetFilters: Ue,
      selfClearFilters: et,
      selfResetSorters: $t,
      selfClearSorters: vn
    };
  },
  methods: {
    selectAll(e) {
      return this.selfSelectAll(e);
    },
    select(e, t) {
      return this.selfSelect(e, t);
    },
    expandAll(e) {
      return this.selfExpandAll(e);
    },
    expand(e, t) {
      return this.selfExpand(e, t);
    },
    resetFilters(e) {
      return this.selfResetFilters(e);
    },
    clearFilters(e) {
      return this.selfClearFilters(e);
    },
    resetSorters() {
      return this.selfResetSorters();
    },
    clearSorters() {
      return this.selfClearSorters();
    }
  },
  render() {
    return this.render();
  }
});
const wn = (e, t) => {
  const n = un(e, t), o = V(n.value);
  return ze(n, (i, r) => {
    _l(i, r) || (o.value = i);
  }), o;
};
var er = S({
  name: "TableColumn",
  props: {
    dataIndex: String,
    title: String,
    width: Number,
    minWidth: Number,
    align: {
      type: String
    },
    fixed: {
      type: String
    },
    ellipsis: {
      type: Boolean,
      default: !1
    },
    sortable: {
      type: Object,
      default: void 0
    },
    filterable: {
      type: Object,
      default: void 0
    },
    cellClass: {
      type: [String, Array, Object]
    },
    headerCellClass: {
      type: [String, Array, Object]
    },
    bodyCellClass: {
      type: [String, Array, Object, Function]
    },
    summaryCellClass: {
      type: [String, Array, Object, Function]
    },
    cellStyle: {
      type: Object
    },
    headerCellStyle: {
      type: Object
    },
    bodyCellStyle: {
      type: [Object, Function]
    },
    summaryCellStyle: {
      type: [Object, Function]
    },
    index: {
      type: Number
    },
    tooltip: {
      type: [Boolean, Object],
      default: !1
    }
  },
  setup(e, {
    slots: t
  }) {
    var n;
    const {
      dataIndex: o,
      title: i,
      width: r,
      align: l,
      fixed: s,
      ellipsis: u,
      index: f,
      minWidth: d
    } = ve(e), p = wn(e, "sortable"), h = wn(e, "filterable"), k = wn(e, "cellClass"), y = wn(e, "headerCellClass"), w = wn(e, "bodyCellClass"), g = wn(e, "summaryCellClass"), C = wn(e, "cellStyle"), P = wn(e, "headerCellStyle"), z = wn(e, "bodyCellStyle"), j = wn(e, "summaryCellStyle"), I = wn(e, "tooltip"), L = dn(), M = Ge(to, {}), E = Ge(zp, void 0), {
      children: K,
      components: q
    } = Oo("TableColumn"), T = me(/* @__PURE__ */ new Map());
    it(zp, {
      addChild: (H, D) => {
        T.set(H, D);
      },
      removeChild: (H) => {
        T.delete(H);
      }
    });
    const Z = V();
    ze([q, T], ([H, D]) => {
      if (H.length > 0) {
        const R = [];
        H.forEach((W) => {
          const O = D.get(W);
          O && R.push(O);
        }), Z.value = R;
      } else
        Z.value = void 0;
    });
    const U = me({
      dataIndex: o,
      title: i,
      width: r,
      minWidth: d,
      align: l,
      fixed: s,
      ellipsis: u,
      sortable: p,
      filterable: h,
      cellClass: k,
      headerCellClass: y,
      bodyCellClass: w,
      summaryCellClass: g,
      cellStyle: C,
      headerCellStyle: P,
      bodyCellStyle: z,
      summaryCellStyle: j,
      index: f,
      tooltip: I,
      children: Z,
      slots: t
    });
    return L && (E ? E.addChild(L.uid, U) : (n = M.addColumn) == null || n.call(M, L.uid, U)), _t(() => {
      var H;
      L && (E ? E.removeChild(L.uid) : (H = M.removeColumn) == null || H.call(M, L.uid));
    }), () => {
      var H;
      return K.value = (H = t.default) == null ? void 0 : H.call(t), K.value;
    };
  }
});
const WS = Object.assign(du, {
  Thead: bo,
  Tbody: Co,
  Tr: Kn,
  Th: $o,
  Td: ol,
  Column: er,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + du.name, du), e.component(n + bo.name, bo), e.component(n + Co.name, Co), e.component(n + Kn.name, Kn), e.component(n + $o.name, $o), e.component(n + ol.name, ol), e.component(n + er.name, er);
  }
}), FS = ({
  direction: e,
  type: t,
  offset: n
}) => e === "vertical" ? { transform: `translateY(${-n}px)` } : { transform: `translateX(${-n}px)` }, DS = (e, t) => {
  const { scrollTop: n, scrollLeft: o } = e;
  t === "horizontal" && o && e.scrollTo({ left: -1 * o }), t === "vertical" && n && e.scrollTo({ top: -1 * n });
}, s0 = Symbol("ArcoTabs"), xS = S({
  name: "TabsTab",
  components: {
    IconHover: pt,
    IconClose: Dt
  },
  props: {
    tab: {
      type: Object,
      required: !0
    },
    active: Boolean,
    editable: Boolean
  },
  emits: ["click", "delete"],
  setup(e, { emit: t }) {
    const n = B("tabs-tab"), o = Ge(s0, {}), i = (f) => {
      e.tab.disabled || t("click", e.tab.key, f);
    }, r = (f) => {
      f.key === "Enter" && i(f);
    }, l = a(() => Object.assign(
      o.trigger === "click" ? { onClick: i } : { onMouseover: i },
      { onKeydown: r }
    )), s = (f) => {
      e.tab.disabled || t("delete", e.tab.key, f);
    }, u = a(() => [
      n,
      {
        [`${n}-active`]: e.active,
        [`${n}-closable`]: e.editable && e.tab.closable,
        [`${n}-disabled`]: e.tab.disabled
      }
    ]);
    return {
      prefixCls: n,
      cls: u,
      eventHandlers: l,
      handleDelete: s
    };
  }
});
function RS(e, t, n, o, i, r) {
  const l = J("icon-close"), s = J("icon-hover");
  return v(), b("div", se({
    tabindex: "0",
    class: e.cls
  }, e.eventHandlers), [
    $("span", {
      class: m(`${e.prefixCls}-title`)
    }, [
      _(e.$slots, "default")
    ], 2),
    e.editable && e.tab.closable ? (v(), oe(s, {
      key: 0,
      class: m(`${e.prefixCls}-close-btn`),
      onClick: an(e.handleDelete, ["stop"])
    }, {
      default: ue(() => [
        c(l)
      ]),
      _: 1
    }, 8, ["class", "onClick"])) : te("v-if", !0)
  ], 16);
}
var HS = /* @__PURE__ */ N(xS, [["render", RS]]);
function qS(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var Np = S({
  name: "TabsButton",
  props: {
    type: {
      type: String,
      default: "next"
    },
    direction: {
      type: String,
      default: "horizontal"
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    onClick: {
      type: Function
    }
  },
  emits: ["click"],
  setup(e, {
    emit: t
  }) {
    const n = B("tabs-nav-button"), o = (l) => {
      e.disabled || t("click", e.type, l);
    }, i = () => e.direction === "horizontal" ? e.type === "next" ? c(bn, null, null) : c(xn, null, null) : e.type === "next" ? c(Il, null, null) : c(Ar, null, null), r = a(() => [n, {
      [`${n}-disabled`]: e.disabled,
      [`${n}-left`]: e.direction === "horizontal" && e.type === "previous",
      [`${n}-right`]: e.direction === "horizontal" && e.type === "next",
      [`${n}-up`]: e.direction === "vertical" && e.type === "previous",
      [`${n}-down`]: e.direction === "vertical" && e.type === "next"
    }]);
    return () => {
      let l;
      return c("div", {
        class: r.value,
        onClick: o
      }, [c(pt, {
        disabled: e.disabled
      }, qS(l = i()) ? l : {
        default: () => [l]
      })]);
    };
  }
});
const ZS = S({
  name: "TabsNavInk",
  props: {
    activeTabRef: {
      type: Object
    },
    direction: {
      type: String
    },
    disabled: Boolean,
    animation: Boolean
  },
  setup(e) {
    const { activeTabRef: t } = ve(e), n = B("tabs-nav-ink"), o = V(0), i = V(0), r = a(() => e.direction === "vertical" ? {
      top: `${o.value}px`,
      height: `${i.value}px`
    } : {
      left: `${o.value}px`,
      width: `${i.value}px`
    }), l = () => {
      if (t.value) {
        const u = e.direction === "vertical" ? t.value.offsetTop : t.value.offsetLeft, f = e.direction === "vertical" ? t.value.offsetHeight : t.value.offsetWidth;
        (u !== o.value || f !== i.value) && (o.value = u, i.value = f);
      }
    };
    Je(() => {
      at(() => l());
    }), fn(() => {
      l();
    });
    const s = a(() => [
      n,
      {
        [`${n}-animation`]: e.animation,
        [`${n}-disabled`]: e.disabled
      }
    ]);
    return {
      prefixCls: n,
      cls: s,
      style: r
    };
  }
});
function KS(e, t, n, o, i, r) {
  return v(), b("div", {
    class: m(e.cls),
    style: F(e.style)
  }, null, 6);
}
var YS = /* @__PURE__ */ N(ZS, [["render", KS]]), US = S({
  name: "TabsNav",
  props: {
    tabs: {
      type: Array,
      required: !0
    },
    direction: {
      type: String,
      required: !0
    },
    type: {
      type: String,
      required: !0
    },
    activeKey: {
      type: [String, Number]
    },
    activeIndex: {
      type: Number,
      required: !0
    },
    position: {
      type: String,
      required: !0
    },
    size: {
      type: String,
      required: !0
    },
    showAddButton: {
      type: Boolean,
      default: !1
    },
    editable: {
      type: Boolean,
      default: !1
    },
    animation: {
      type: Boolean,
      required: !0
    },
    headerPadding: {
      type: Boolean,
      default: !0
    },
    scrollPosition: {
      type: String,
      default: "auto"
    }
  },
  emits: ["click", "add", "delete"],
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      tabs: o,
      activeKey: i,
      activeIndex: r,
      direction: l,
      scrollPosition: s
    } = ve(e), u = B("tabs-nav"), f = V(), d = V(), p = V({}), h = a(() => {
      if (!Ve(i.value))
        return p.value[i.value];
    }), k = V(), y = a(() => e.editable && ["line", "card", "card-gutter"].includes(e.type)), w = V(!1), g = V(0), C = V(0), P = V(0), z = () => {
      var W, O, x;
      return (x = l.value === "vertical" ? (W = f.value) == null ? void 0 : W.offsetHeight : (O = f.value) == null ? void 0 : O.offsetWidth) != null ? x : 0;
    }, j = () => !d.value || !f.value ? 0 : l.value === "vertical" ? d.value.offsetHeight - f.value.offsetHeight : d.value.offsetWidth - f.value.offsetWidth, I = () => {
      w.value = L(), w.value ? (g.value = z(), C.value = j(), P.value > C.value && (P.value = C.value)) : P.value = 0;
    }, L = () => f.value && d.value ? e.direction === "vertical" ? d.value.offsetHeight > f.value.offsetHeight : d.value.offsetWidth > f.value.offsetWidth : !1, M = (W) => {
      (!f.value || !d.value || W < 0) && (W = 0), P.value = Math.min(W, C.value);
    }, E = () => {
      if (!h.value || !f.value || !w.value)
        return;
      DS(f.value, l.value);
      const W = l.value === "horizontal", O = W ? "offsetLeft" : "offsetTop", x = W ? "offsetWidth" : "offsetHeight", G = h.value[O], ne = h.value[x], ee = f.value[x], Q = window.getComputedStyle(h.value), ae = W ? s.value === "end" ? "marginRight" : "marginLeft" : s.value === "end" ? "marginBottom" : "marginTop", ge = parseFloat(Q[ae]) || 0;
      s.value === "auto" ? G < P.value ? M(G - ge) : G + ne > P.value + ee && M(G + ne - ee + ge) : s.value === "center" ? M(G + (ne - ee + ge) / 2) : s.value === "start" ? M(G - ge) : s.value === "end" ? M(G + ne - ee + ge) : A(s.value) && M(G - s.value);
    }, K = (W) => {
      if (!w.value)
        return;
      W.preventDefault();
      const {
        deltaX: O,
        deltaY: x
      } = W;
      Math.abs(O) > Math.abs(x) ? M(P.value + O) : M(P.value + x);
    }, q = (W, O) => {
      t("click", W, O);
    }, T = (W, O) => {
      t("delete", W, O), at(() => {
        delete p.value[W];
      });
    }, X = (W) => {
      const O = W === "previous" ? P.value - g.value : P.value + g.value;
      M(O);
    }, Y = () => {
      I(), k.value && k.value.$forceUpdate();
    };
    ze(o, () => {
      at(() => {
        I();
      });
    }), ze([r, s], () => {
      setTimeout(() => {
        E();
      }, 0);
    }), Je(() => {
      I(), f.value && rt(f.value, "wheel", K, {
        passive: !1
      });
    }), Zt(() => {
      f.value && ct(f.value, "wheel", K);
    });
    const Z = () => !y.value || !e.showAddButton ? null : c("div", {
      class: `${u}-add-btn`,
      onClick: (W) => t("add", W)
    }, [c(pt, null, {
      default: () => [c(zl, null, null)]
    })]), U = a(() => [u, `${u}-${e.direction}`, `${u}-${e.position}`, `${u}-size-${e.size}`, `${u}-type-${e.type}`]), H = a(() => [`${u}-tab-list`, {
      [`${u}-tab-list-no-padding`]: !e.headerPadding && ["line", "text"].includes(e.type) && e.direction === "horizontal"
    }]), D = a(() => FS({
      direction: e.direction,
      type: e.type,
      offset: P.value
    })), R = a(() => [`${u}-tab`, {
      [`${u}-tab-scroll`]: w.value
    }]);
    return () => {
      var W;
      return c("div", {
        class: U.value
      }, [w.value && c(Np, {
        type: "previous",
        direction: e.direction,
        disabled: P.value <= 0,
        onClick: X
      }, null), c(jn, {
        onResize: () => I()
      }, {
        default: () => [c("div", {
          class: R.value,
          ref: f
        }, [c(jn, {
          onResize: Y
        }, {
          default: () => [c("div", {
            ref: d,
            class: H.value,
            style: D.value
          }, [e.tabs.map((O, x) => c(HS, {
            key: O.key,
            ref: (G) => {
              G != null && G.$el && (p.value[O.key] = G.$el);
            },
            active: O.key === i.value,
            tab: O,
            editable: e.editable,
            onClick: q,
            onDelete: T
          }, {
            default: () => {
              var G, ne, ee;
              return [(ee = (ne = (G = O.slots).title) == null ? void 0 : ne.call(G)) != null ? ee : O.title];
            }
          })), e.type === "line" && h.value && c(YS, {
            ref: k,
            activeTabRef: h.value,
            direction: e.direction,
            disabled: !1,
            animation: e.animation
          }, null)])]
        }), !w.value && Z()])]
      }), w.value && c(Np, {
        type: "next",
        direction: e.direction,
        disabled: P.value >= C.value,
        onClick: X
      }, null), c("div", {
        class: `${u}-extra`
      }, [w.value && Z(), (W = n.extra) == null ? void 0 : W.call(n)])]);
    };
  }
}), fu = S({
  name: "Tabs",
  props: {
    activeKey: {
      type: [String, Number],
      default: void 0
    },
    defaultActiveKey: {
      type: [String, Number],
      default: void 0
    },
    position: {
      type: String,
      default: "top"
    },
    size: {
      type: String
    },
    type: {
      type: String,
      default: "line"
    },
    direction: {
      type: String,
      default: "horizontal"
    },
    editable: {
      type: Boolean,
      default: !1
    },
    showAddButton: {
      type: Boolean,
      default: !1
    },
    destroyOnHide: {
      type: Boolean,
      default: !1
    },
    lazyLoad: {
      type: Boolean,
      default: !1
    },
    justify: {
      type: Boolean,
      default: !1
    },
    animation: {
      type: Boolean,
      default: !1
    },
    headerPadding: {
      type: Boolean,
      default: !0
    },
    autoSwitch: {
      type: Boolean,
      default: !1
    },
    hideContent: {
      type: Boolean,
      default: !1
    },
    trigger: {
      type: String,
      default: "click"
    },
    scrollPosition: {
      type: [String, Number],
      default: "auto"
    }
  },
  emits: {
    "update:activeKey": (e) => !0,
    change: (e) => !0,
    tabClick: (e, t) => !0,
    add: (e) => !0,
    delete: (e, t) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      size: o,
      lazyLoad: i,
      destroyOnHide: r,
      trigger: l
    } = ve(e), s = B("tabs"), {
      mergedSize: u
    } = xt(o), f = a(() => e.direction === "vertical" ? "left" : e.position), d = a(() => ["left", "right"].includes(f.value) ? "vertical" : "horizontal"), {
      children: p,
      components: h
    } = Oo("TabPane"), k = me(/* @__PURE__ */ new Map()), y = a(() => {
      const T = [];
      return h.value.forEach((X) => {
        const Y = k.get(X);
        Y && T.push(Y);
      }), T;
    }), w = a(() => y.value.map((T) => T.key)), g = (T, X) => {
      k.set(T, X);
    }, C = (T) => {
      k.delete(T);
    }, P = V(e.defaultActiveKey), z = a(() => {
      var T;
      const X = (T = e.activeKey) != null ? T : P.value;
      return Ve(X) ? w.value[0] : X;
    }), j = a(() => {
      const T = w.value.indexOf(z.value);
      return T === -1 ? 0 : T;
    });
    it(s0, me({
      lazyLoad: i,
      destroyOnHide: r,
      activeKey: z,
      addItem: g,
      removeItem: C,
      trigger: l
    }));
    const I = (T) => {
      T !== z.value && (P.value = T, t("update:activeKey", T), t("change", T));
    }, L = (T, X) => {
      I(T), t("tabClick", T, X);
    }, M = (T) => {
      t("add", T), e.autoSwitch && at(() => {
        const X = w.value[w.value.length - 1];
        I(X);
      });
    }, E = (T, X) => {
      t("delete", T, X);
    }, K = () => c("div", {
      class: [`${s}-content`, {
        [`${s}-content-hide`]: e.hideContent
      }]
    }, [c("div", {
      class: [`${s}-content-list`, {
        [`${s}-content-animation`]: e.animation
      }],
      style: {
        marginLeft: `-${j.value * 100}%`
      }
    }, [p.value])]), q = a(() => [s, `${s}-${d.value}`, `${s}-${f.value}`, `${s}-type-${e.type}`, `${s}-size-${u.value}`, {
      [`${s}-justify`]: e.justify
    }]);
    return () => {
      var T;
      return p.value = (T = n.default) == null ? void 0 : T.call(n), c("div", {
        class: q.value
      }, [f.value === "bottom" && K(), c(US, {
        tabs: y.value,
        activeKey: z.value,
        activeIndex: j.value,
        direction: d.value,
        position: f.value,
        editable: e.editable,
        animation: e.animation,
        showAddButton: e.showAddButton,
        headerPadding: e.headerPadding,
        scrollPosition: e.scrollPosition,
        size: u.value,
        type: e.type,
        onClick: L,
        onAdd: M,
        onDelete: E
      }, {
        extra: n.extra
      }), f.value !== "bottom" && K()]);
    };
  }
});
const GS = S({
  name: "TabPane",
  props: {
    title: String,
    disabled: {
      type: Boolean,
      default: !1
    },
    closable: {
      type: Boolean,
      default: !0
    },
    destroyOnHide: {
      type: Boolean,
      default: !1
    }
  },
  setup(e, { slots: t }) {
    var n;
    const { title: o, disabled: i, closable: r } = ve(e), l = dn(), s = B("tabs"), u = Ge(s0, {}), f = V(), d = a(() => l == null ? void 0 : l.vnode.key), p = a(() => d.value === u.activeKey), h = V(u.lazyLoad ? p.value : !0), k = me({
      key: d,
      title: o,
      disabled: i,
      closable: r,
      slots: t
    });
    return l != null && l.uid && ((n = u.addItem) == null || n.call(u, l.uid, k)), _t(() => {
      var y;
      l != null && l.uid && ((y = u.removeItem) == null || y.call(u, l.uid));
    }), ze(p, (y) => {
      y ? h.value || (h.value = !0) : (e.destroyOnHide || u.destroyOnHide) && (h.value = !1);
    }), fn(() => {
      k.slots = { ...t };
    }), {
      prefixCls: s,
      active: p,
      itemRef: f,
      mounted: h
    };
  }
});
function XS(e, t, n, o, i, r) {
  return v(), b("div", {
    ref: "itemRef",
    class: m([
      `${e.prefixCls}-content-item`,
      { [`${e.prefixCls}-content-item-active`]: e.active }
    ])
  }, [
    e.mounted ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-pane`)
    }, [
      _(e.$slots, "default")
    ], 2)) : te("v-if", !0)
  ], 2);
}
var tr = /* @__PURE__ */ N(GS, [["render", XS]]);
const QS = Object.assign(fu, {
  TabPane: tr,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + fu.name, fu), e.component(n + tr.name, tr);
  }
});
function _S(e) {
  const { modelValue: t, defaultValue: n, format: o, isRange: i } = ve(e);
  function r() {
    return i.value ? [] : void 0;
  }
  function l(g) {
    if (!Ve(g))
      return i.value ? He(g) ? g : [g, void 0] : g;
  }
  const s = a(() => {
    const g = l(t.value);
    return cn(g, o.value);
  }), u = a(() => {
    const g = l(n.value);
    return cn(g, o.value);
  }), [f, d] = Ht(
    Ve(s.value) ? Ve(u.value) ? r() : u.value : s.value
  );
  ze(s, () => {
    Ve(s.value) && d(r());
  });
  const p = a(
    () => s.value || f.value
  ), [h, k] = Ht(p.value);
  ze([p], () => {
    k(p.value);
  });
  const [y, w] = Ht();
  return ze([h], () => {
    w(void 0);
  }), {
    computedValue: p,
    panelValue: h,
    inputValue: y,
    setValue: d,
    setPanelValue: k,
    setInputValue: w
  };
}
var JS = S({
  name: "TimePickerRangePanel",
  components: {
    Panel: vr
  },
  props: {
    value: {
      type: Array
    },
    displayIndex: {
      type: Number,
      default: 0
    }
  },
  emits: ["select", "confirm", "update:displayIndex", "display-index-change"],
  setup(e, {
    emit: t
  }) {
    const {
      value: n,
      displayIndex: o
    } = ve(e), i = V(o.value);
    ze(o, () => {
      i.value = o.value;
    });
    const r = a(() => n != null && n.value ? n.value[i.value] : void 0);
    function l(u) {
      const f = Ve(n) || Ve(n == null ? void 0 : n.value) ? [] : [...n.value];
      f[i.value] = u, t("select", f);
    }
    function s() {
      if (so(n == null ? void 0 : n.value))
        t("confirm", n == null ? void 0 : n.value);
      else {
        const u = (i.value + 1) % 2;
        i.value = u, t("display-index-change", u), t("update:displayIndex", u);
      }
    }
    return {
      displayValue: r,
      onSelect: l,
      onConfirm: s
    };
  },
  render() {
    const e = {
      ...this.$attrs,
      isRange: !0,
      value: this.displayValue,
      onSelect: this.onSelect,
      onConfirm: this.onConfirm
    };
    return c(vr, e, this.$slots);
  }
});
const e9 = S({
  name: "TimePicker",
  components: {
    Trigger: Tt,
    DateInput: _m,
    DateRangeInput: gh,
    Panel: vr,
    RangePanel: JS,
    IconClockCircle: Yv
  },
  inheritAttrs: !1,
  props: {
    type: {
      type: String,
      default: "time"
    },
    modelValue: {
      type: [String, Number, Date, Array]
    },
    defaultValue: {
      type: [String, Number, Date, Array]
    },
    disabled: {
      type: Boolean
    },
    allowClear: {
      type: Boolean,
      default: !0
    },
    readonly: {
      type: Boolean
    },
    error: {
      type: Boolean
    },
    format: {
      type: String,
      default: "HH:mm:ss"
    },
    placeholder: {
      type: [String, Array]
    },
    size: {
      type: String
    },
    popupContainer: {
      type: [String, Object]
    },
    use12Hours: {
      type: Boolean
    },
    step: {
      type: Object
    },
    disabledHours: {
      type: Function
    },
    disabledMinutes: {
      type: Function
    },
    disabledSeconds: {
      type: Function
    },
    hideDisabledOptions: {
      type: Boolean
    },
    disableConfirm: {
      type: Boolean
    },
    position: {
      type: String,
      default: "bl"
    },
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean,
      default: !1
    },
    triggerProps: {
      type: Object
    },
    unmountOnClose: {
      type: Boolean
    }
  },
  emits: {
    change: (e, t) => !0,
    "update:modelValue": (e) => !0,
    select: (e, t) => !0,
    clear: () => !0,
    "popup-visible-change": (e) => !0,
    "update:popupVisible": (e) => !0
  },
  setup(e, { emit: t }) {
    const {
      type: n,
      format: o,
      use12Hours: i,
      modelValue: r,
      defaultValue: l,
      popupVisible: s,
      defaultPopupVisible: u,
      disabled: f,
      placeholder: d,
      disableConfirm: p,
      disabledHours: h,
      disabledMinutes: k,
      disabledSeconds: y
    } = ve(e), { mergedDisabled: w, eventHandlers: g } = mt({ disabled: f }), C = a(() => n.value === "time-range"), P = B("timepicker"), z = V(), { format: j, use12Hours: I } = Kv(
      me({
        format: o,
        use12Hours: i
      })
    ), {
      computedValue: L,
      panelValue: M,
      inputValue: E,
      setValue: K,
      setPanelValue: q,
      setInputValue: T
    } = _S(
      me({
        modelValue: r,
        defaultValue: l,
        isRange: C,
        format: j
      })
    ), [X, Y] = Vt(
      u.value,
      me({ value: s })
    ), Z = (le) => {
      le !== X.value && (Y(le), t("popup-visible-change", le), t("update:popupVisible", le));
    }, { t: U } = gt(), [H, D] = Ht(0), R = a(() => {
      const le = d == null ? void 0 : d.value;
      return C.value ? Ve(le) ? U("datePicker.rangePlaceholder.time") : He(le) ? le : [le, le] : Ve(le) ? U("datePicker.placeholder.time") : le;
    }), W = oh(
      me({
        disabledHours: h,
        disabledMinutes: k,
        disabledSeconds: y
      })
    );
    function O(le) {
      var re, fe;
      if (Wv(le, L.value)) {
        const Oe = An(le, j.value), Be = rn(le);
        t("update:modelValue", Oe), t("change", Oe, Be), (fe = (re = g.value) == null ? void 0 : re.onChange) == null || fe.call(re);
      }
    }
    function x(le, re) {
      if (W(le))
        return;
      let fe = le;
      if (He(le)) {
        const Oe = Pt();
        fe = le.map((Be) => (Be && (Be = Be.year(Oe.year()), Be = Be.month(Oe.month()), Be = Be.date(Oe.date())), Be)), so(fe) && (fe = wo(fe)), (fe == null ? void 0 : fe.length) === 0 && (fe = void 0);
      }
      O(fe), K(fe), re !== X.value && Z(re);
    }
    function G(le, re) {
      q(le), re !== X.value && Z(re);
    }
    function ne(le) {
      z.value && z.value.focus && z.value.focus(le);
    }
    function ee(le) {
      w.value || (Z(le), le && at(() => {
        ne(H.value);
      }));
    }
    function Q(le) {
      const re = An(le, j.value), fe = rn(le);
      t("select", re, fe), p.value && (!C.value || so(le)) ? x(le, !0) : (G(le, !0), T(void 0));
    }
    function ae(le) {
      x(le, !1);
    }
    function ge() {
      x(M.value || L.value, !1);
    }
    function Se() {
      if (so(M.value))
        x(M.value, !1);
      else {
        const le = (H.value + 1) % 2;
        D(le), ne(le);
      }
    }
    function be(le) {
      Z(!0);
      const re = le.target.value;
      if (T(re), !fr(re, j.value))
        return;
      const fe = Pt(re, j.value);
      W(fe) || (p.value ? x(fe, !0) : G(fe, !0));
    }
    function Le(le) {
      Z(!0);
      const re = le.target.value, fe = He(E.value) ? [...E.value] : He(M.value) && An(M.value, j.value) || [];
      if (fe[H.value] = re, T(fe), !fr(re, j.value))
        return;
      const Oe = Pt(re, j.value);
      if (W(Oe))
        return;
      const Be = He(M.value) ? [...M.value] : [];
      Be[H.value] = Oe, p.value && so(Be) ? x(Be, !0) : G(Be, !0);
    }
    function pe(le) {
      le.stopPropagation(), q(void 0), x(void 0, C.value);
    }
    ze(X, (le, re) => {
      le !== re && q(L.value), le || T(void 0);
    });
    const Me = a(() => C.value ? {
      focusedIndex: H.value,
      onFocusedIndexChange: (le) => {
        D(le);
      },
      onChange: Le,
      onPressEnter: Se
    } : {
      onChange: be,
      onPressEnter: ge
    }), ke = a(() => C.value ? {
      displayIndex: H.value,
      onDisplayIndexChange: (le) => {
        D(le), ne(le);
      }
    } : {});
    return {
      refInput: z,
      isRange: C,
      prefixCls: P,
      panelVisible: X,
      focusedInputIndex: H,
      computedPlaceholder: R,
      panelValue: M,
      inputValue: E,
      computedFormat: j,
      computedUse12Hours: I,
      inputProps: Me,
      panelProps: ke,
      mergedDisabled: w,
      onPanelVisibleChange: ee,
      onInputClear: pe,
      onPanelSelect: Q,
      onPanelConfirm: ae,
      onPanelClick: () => {
        ne(H.value);
      }
    };
  }
});
function t9(e, t, n, o, i, r) {
  const l = J("IconClockCircle"), s = J("Trigger");
  return v(), oe(s, se({
    trigger: "click",
    "animation-name": "slide-dynamic-origin",
    "auto-fit-transform-origin": "",
    "click-to-close": !1,
    position: e.position,
    disabled: e.mergedDisabled || e.readonly,
    "popup-offset": 4,
    "popup-visible": e.panelVisible,
    "prevent-focus": !0,
    "unmount-on-close": e.unmountOnClose,
    "popup-container": e.popupContainer
  }, { ...e.triggerProps }, { onPopupVisibleChange: e.onPanelVisibleChange }), {
    content: ue(() => [
      $("div", {
        class: m(`${e.prefixCls}-container`),
        onClick: t[0] || (t[0] = (...u) => e.onPanelClick && e.onPanelClick(...u))
      }, [
        (v(), oe(sn(e.isRange ? "RangePanel" : "Panel"), se(e.panelProps, {
          value: e.panelValue,
          visible: e.panelVisible,
          format: e.computedFormat,
          "use12-hours": e.computedUse12Hours,
          step: e.step,
          "disabled-hours": e.disabledHours,
          "disabled-minutes": e.disabledMinutes,
          "disabled-seconds": e.disabledSeconds,
          "hide-disabled-options": e.hideDisabledOptions,
          "hide-footer": e.disableConfirm,
          onSelect: e.onPanelSelect,
          onConfirm: e.onPanelConfirm
        }), kt({ _: 2 }, [
          e.$slots.extra ? {
            name: "extra-footer",
            fn: ue(() => [
              _(e.$slots, "extra")
            ]),
            key: "0"
          } : void 0
        ]), 1040, ["value", "visible", "format", "use12-hours", "step", "disabled-hours", "disabled-minutes", "disabled-seconds", "hide-disabled-options", "hide-footer", "onSelect", "onConfirm"]))
      ], 2)
    ]),
    default: ue(() => [
      (v(), oe(sn(e.isRange ? "DateRangeInput" : "DateInput"), se({
        ...e.$attrs,
        ...e.inputProps
      }, {
        ref: "refInput",
        "input-value": e.inputValue,
        value: e.panelValue,
        size: e.size,
        focused: e.panelVisible,
        format: e.computedFormat,
        visible: e.panelVisible,
        disabled: e.mergedDisabled,
        error: e.error,
        readonly: e.readonly,
        editable: !e.readonly,
        "allow-clear": e.allowClear && !e.readonly,
        placeholder: e.computedPlaceholder,
        onClear: e.onInputClear
      }), kt({
        "suffix-icon": ue(() => [
          _(e.$slots, "suffix-icon", {}, () => [
            c(l)
          ])
        ]),
        _: 2
      }, [
        e.$slots.prefix ? {
          name: "prefix",
          fn: ue(() => [
            _(e.$slots, "prefix")
          ]),
          key: "0"
        } : void 0
      ]), 1040, ["input-value", "value", "size", "focused", "format", "visible", "disabled", "error", "readonly", "editable", "allow-clear", "placeholder", "onClear"]))
    ]),
    _: 3
  }, 16, ["position", "disabled", "popup-visible", "unmount-on-close", "popup-container", "onPopupVisibleChange"]);
}
var vu = /* @__PURE__ */ N(e9, [["render", t9]]);
const n9 = Object.assign(vu, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + vu.name, vu);
  }
}), y2 = Symbol("ArcoTimeline"), l9 = (e, t, n, o) => {
  let i = ["left", "right"];
  n === "horizontal" && (i = ["top", "bottom"]);
  const r = t === "alternate" ? o || i[e % 2] : t;
  return i.indexOf(r) > -1 ? r : i[0];
}, o9 = S({
  name: "TimelineItem",
  props: {
    dotColor: {
      type: String
    },
    dotType: {
      type: String,
      default: "solid"
    },
    lineType: {
      type: String,
      default: "solid"
    },
    lineColor: {
      type: String
    },
    label: {
      type: String
    },
    position: {
      type: String
    }
  },
  setup(e) {
    const t = B("timeline-item"), n = dn(), o = Ge(y2, {}), i = a(
      () => {
        var h, k, y;
        return (y = (k = o.items) == null ? void 0 : k.indexOf((h = n == null ? void 0 : n.uid) != null ? h : -1)) != null ? y : -1;
      }
    ), r = a(() => {
      var h;
      return (h = o == null ? void 0 : o.direction) != null ? h : "vertical";
    }), l = a(() => {
      var h;
      return (h = o == null ? void 0 : o.labelPosition) != null ? h : "same";
    }), s = a(() => {
      const { items: h = [], reverse: k, labelPosition: y, mode: w = "left" } = o, g = r.value, C = l9(
        i.value,
        w,
        g,
        e.position
      );
      return [
        t,
        {
          [`${t}-${g}-${C}`]: g,
          [`${t}-label-${y}`]: y,
          [`${t}-last`]: i.value === (k === !0 ? 0 : h.length - 1)
        }
      ];
    }), u = a(() => [
      `${t}-dot-line`,
      `${t}-dot-line-is-${r.value}`
    ]), f = a(() => {
      const { direction: h } = o || {};
      return {
        [h === "horizontal" ? "borderTopStyle" : "borderLeftStyle"]: e.lineType,
        ...e.lineColor ? { borderColor: e.lineColor } : {}
      };
    }), d = a(() => [`${t}-dot`, `${t}-dot-${e.dotType}`]), p = a(() => ({
      [e.dotType === "solid" ? "backgroundColor" : "borderColor"]: e.dotColor
    }));
    return {
      cls: s,
      dotLineCls: u,
      dotTypeCls: d,
      prefixCls: t,
      computedDotLineStyle: f,
      computedDotStyle: p,
      labelPosition: l
    };
  }
});
function i9(e, t, n, o, i, r) {
  return v(), b("div", {
    role: "listitem",
    class: m(e.cls)
  }, [
    $("div", {
      class: m(`${e.prefixCls}-dot-wrapper`)
    }, [
      $("div", {
        class: m(e.dotLineCls),
        style: F(e.computedDotLineStyle)
      }, null, 6),
      $("div", {
        class: m(`${e.prefixCls}-dot-content`)
      }, [
        e.$slots.dot ? (v(), b("div", {
          key: 0,
          class: m(`${e.prefixCls}-dot-custom`)
        }, [
          _(e.$slots, "dot")
        ], 2)) : (v(), b("div", {
          key: 1,
          class: m(e.dotTypeCls),
          style: F(e.computedDotStyle)
        }, null, 6))
      ], 2)
    ], 2),
    $("div", {
      class: m(`${e.prefixCls}-content-wrapper`)
    }, [
      e.$slots.default ? (v(), b("div", {
        key: 0,
        class: m(`${e.prefixCls}-content`)
      }, [
        _(e.$slots, "default")
      ], 2)) : te("v-if", !0),
      e.labelPosition !== "relative" ? (v(), b("div", {
        key: 1,
        class: m(`${e.prefixCls}-label`)
      }, [
        e.$slots.label ? _(e.$slots, "label", { key: 0 }) : (v(), b(Ae, { key: 1 }, [
          Re(Pe(e.label), 1)
        ], 64))
      ], 2)) : te("v-if", !0)
    ], 2),
    e.labelPosition === "relative" ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-label`)
    }, [
      e.$slots.label ? _(e.$slots, "label", { key: 0 }) : (v(), b(Ae, { key: 1 }, [
        Re(Pe(e.label), 1)
      ], 64))
    ], 2)) : te("v-if", !0)
  ], 2);
}
var Zl = /* @__PURE__ */ N(o9, [["render", i9]]), pu = S({
  name: "Timeline",
  components: {
    Item: Zl,
    Spin: Pn
  },
  props: {
    reverse: {
      type: Boolean
    },
    direction: {
      type: String,
      default: "vertical"
    },
    mode: {
      type: String,
      default: "left"
    },
    pending: {
      type: [Boolean, String]
    },
    labelPosition: {
      type: String,
      default: "same"
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("timeline"), o = a(() => e.pending || t.pending), {
      children: i,
      components: r
    } = Oo("TimelineItem"), {
      reverse: l,
      direction: s,
      labelPosition: u,
      mode: f
    } = ve(e), d = me({
      items: r,
      direction: s,
      reverse: l,
      labelPosition: u,
      mode: f
    });
    it(y2, d);
    const p = a(() => [n, `${n}-${e.mode}`, `${n}-direction-${e.direction}`, {
      [`${n}-is-reverse`]: e.reverse
    }]);
    return () => {
      var h, k;
      return o.value ? i.value = (h = t.default) == null ? void 0 : h.call(t).concat(c(Zl, {
        lineType: "dashed"
      }, {
        default: () => [e.pending !== !0 && c("div", null, [e.pending])],
        dot: () => {
          var y, w;
          return (w = (y = t.dot) == null ? void 0 : y.call(t)) != null ? w : c(Pn, {
            size: 12
          }, null);
        }
      })) : i.value = (k = t.default) == null ? void 0 : k.call(t), c("div", {
        role: "list",
        class: p.value
      }, [i.value]);
    };
  }
});
const r9 = Object.assign(pu, {
  Item: Zl,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + pu.name, pu), e.component(n + Zl.name, Zl);
  }
}), a9 = S({
  name: "IconDelete",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-delete`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), s9 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function u9(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M5 11h5.5m0 0v29a1 1 0 0 0 1 1h25a1 1 0 0 0 1-1V11m-27 0H16m21.5 0H43m-5.5 0H32m-16 0V7h16v4m-16 0h16M20 18v15m8-15v15" }, null, -1)
  ]), 14, s9);
}
var mu = /* @__PURE__ */ N(a9, [["render", u9]]);
const Gr = Object.assign(mu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + mu.name, mu);
  }
}), u0 = Symbol("ArcoTransfer");
var c9 = S({
  name: "TransferListItem",
  props: {
    type: {
      type: String
    },
    data: {
      type: Object,
      required: !0
    },
    allowClear: {
      type: Boolean
    },
    disabled: {
      type: Boolean
    },
    draggable: {
      type: Boolean
    },
    simple: Boolean
  },
  setup(e) {
    const t = B("transfer-list-item"), n = Ge(u0, void 0), o = () => {
      e.simple && !e.disabled && (n == null || n.moveTo([e.data.value], e.type === "target" ? "source" : "target"));
    }, i = a(() => [t, {
      [`${t}-disabled`]: e.disabled,
      [`${t}-draggable`]: e.draggable
    }]), r = () => {
      n == null || n.moveTo([e.data.value], "source");
    };
    return () => {
      var l, s, u;
      return c("div", {
        class: i.value,
        onClick: o
      }, [e.allowClear || e.simple ? c("span", {
        class: `${t}-content`
      }, [(u = (s = n == null ? void 0 : (l = n.slots).item) == null ? void 0 : s.call(l, {
        label: e.data.label,
        value: e.data.value
      })) != null ? u : e.data.label]) : c(Ln, {
        class: [`${t}-content`, `${t}-checkbox`],
        modelValue: n == null ? void 0 : n.selected,
        value: e.data.value,
        onChange: (f) => n == null ? void 0 : n.onSelect(f),
        uninjectGroupContext: !0,
        disabled: e.disabled
      }, {
        default: () => {
          var f, d, p;
          return [(p = (d = n == null ? void 0 : (f = n.slots).item) == null ? void 0 : d.call(f, {
            label: e.data.label,
            value: e.data.value
          })) != null ? p : e.data.label];
        }
      }), e.allowClear && !e.disabled && c(pt, {
        class: `${t}-remove-btn`,
        onClick: r
      }, {
        default: () => [c(Dt, null, null)]
      })]);
    };
  }
});
const d9 = S({
  name: "TransferView",
  components: {
    Empty: ii,
    Checkbox: Ln,
    IconHover: pt,
    IconDelete: Gr,
    InputSearch: cl.Search,
    List: Uh,
    TransferListItem: c9,
    Scrollbar: In
  },
  props: {
    type: {
      type: String
    },
    dataInfo: {
      type: Object,
      required: !0
    },
    title: String,
    data: {
      type: Array,
      required: !0
    },
    disabled: Boolean,
    allowClear: Boolean,
    selected: {
      type: Array,
      required: !0
    },
    showSearch: Boolean,
    showSelectAll: Boolean,
    simple: Boolean,
    inputSearchProps: {
      type: Object
    }
  },
  emits: ["search"],
  setup(e, { emit: t }) {
    const n = B("transfer-view"), o = V(""), i = Ge(u0, void 0), r = a(() => e.dataInfo.selected.length), l = a(() => e.dataInfo.data.length), s = a(
      () => e.dataInfo.selected.length > 0 && e.dataInfo.selected.length === e.dataInfo.allValidValues.length
    ), u = a(
      () => e.dataInfo.selected.length > 0 && e.dataInfo.selected.length < e.dataInfo.allValidValues.length
    ), f = (k) => {
      k ? i == null || i.onSelect([
        ...e.selected,
        ...e.dataInfo.allValidValues
      ]) : i == null || i.onSelect(
        e.selected.filter(
          (y) => !e.dataInfo.allValidValues.includes(y)
        )
      );
    }, d = a(
      () => e.dataInfo.data.filter((k) => o.value ? k.label.includes(o.value) : !0)
    );
    return {
      prefixCls: n,
      filteredData: d,
      filter: o,
      checked: s,
      indeterminate: u,
      countSelected: r,
      countRendered: l,
      handleSelectAllChange: f,
      handleSearch: (k) => {
        t("search", k, e.type);
      },
      handleClear: () => {
        i == null || i.moveTo(e.dataInfo.allValidValues, "source");
      },
      transferCtx: i
    };
  }
});
function f9(e, t, n, o, i, r) {
  const l = J("checkbox"), s = J("icon-delete"), u = J("icon-hover"), f = J("input-search"), d = J("transfer-list-item"), p = J("list"), h = J("Scrollbar"), k = J("Empty");
  return v(), b("div", {
    class: m(e.prefixCls)
  }, [
    $("div", {
      class: m(`${e.prefixCls}-header`)
    }, [
      _(e.$slots, "title", {
        countTotal: e.dataInfo.data.length,
        countSelected: e.dataInfo.selected.length,
        searchValue: e.filter,
        checked: e.checked,
        indeterminate: e.indeterminate,
        onSelectAllChange: e.handleSelectAllChange,
        onClear: e.handleClear
      }, () => [
        $("span", {
          class: m(`${e.prefixCls}-header-title`)
        }, [
          e.allowClear || e.simple || !e.showSelectAll ? (v(), b("span", {
            key: 0,
            class: m(`${e.prefixCls}-header-title-simple`)
          }, Pe(e.title), 3)) : (v(), oe(l, {
            key: 1,
            "model-value": e.checked,
            indeterminate: e.indeterminate,
            disabled: e.disabled,
            "uninject-group-context": "",
            onChange: e.handleSelectAllChange
          }, {
            default: ue(() => [
              Re(Pe(e.title), 1)
            ]),
            _: 1
          }, 8, ["model-value", "indeterminate", "disabled", "onChange"]))
        ], 2),
        e.allowClear ? (v(), oe(u, {
          key: 0,
          disabled: e.disabled,
          class: m(`${e.prefixCls}-header-clear-btn`),
          onClick: e.handleClear
        }, {
          default: ue(() => [
            c(s)
          ]),
          _: 1
        }, 8, ["disabled", "class", "onClick"])) : e.simple ? te("v-if", !0) : (v(), b("span", {
          key: 1,
          class: m(`${e.prefixCls}-header-count`)
        }, Pe(e.dataInfo.selected.length) + " / " + Pe(e.dataInfo.data.length), 3))
      ])
    ], 2),
    e.showSearch ? (v(), b("div", {
      key: 0,
      class: m(`${e.prefixCls}-search`)
    }, [
      c(f, se({
        modelValue: e.filter,
        "onUpdate:modelValue": t[0] || (t[0] = (y) => e.filter = y),
        disabled: e.disabled
      }, e.inputSearchProps, { onChange: e.handleSearch }), null, 16, ["modelValue", "disabled", "onChange"])
    ], 2)) : te("v-if", !0),
    $("div", {
      class: m(`${e.prefixCls}-body`)
    }, [
      e.filteredData.length > 0 ? (v(), oe(h, { key: 0 }, {
        default: ue(() => {
          var y, w;
          return [
            _(e.$slots, "default", {
              data: e.filteredData,
              selectedKeys: (y = e.transferCtx) == null ? void 0 : y.selected,
              onSelect: (w = e.transferCtx) == null ? void 0 : w.onSelect
            }, () => [
              c(p, {
                class: m(`${e.prefixCls}-list`),
                bordered: !1,
                scrollbar: !1
              }, {
                default: ue(() => [
                  (v(!0), b(Ae, null, St(e.filteredData, (g) => (v(), oe(d, {
                    key: g.value,
                    type: e.type,
                    data: g,
                    simple: e.simple,
                    "allow-clear": e.allowClear,
                    disabled: e.disabled || g.disabled
                  }, null, 8, ["type", "data", "simple", "allow-clear", "disabled"]))), 128))
                ]),
                _: 1
              }, 8, ["class"])
            ])
          ];
        }),
        _: 3
      })) : (v(), oe(k, {
        key: 1,
        class: m(`${e.prefixCls}-empty`)
      }, null, 8, ["class"]))
    ], 2)
  ], 2);
}
var v9 = /* @__PURE__ */ N(d9, [["render", f9]]);
const p9 = S({
  name: "Transfer",
  components: {
    ArcoButton: Qt,
    TransferView: v9,
    IconLeft: xn,
    IconRight: bn
  },
  props: {
    data: {
      type: Array,
      default: () => []
    },
    modelValue: {
      type: Array,
      default: void 0
    },
    defaultValue: {
      type: Array,
      default: () => []
    },
    selected: {
      type: Array,
      default: void 0
    },
    defaultSelected: {
      type: Array,
      default: () => []
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    simple: {
      type: Boolean,
      default: !1
    },
    oneWay: {
      type: Boolean,
      default: !1
    },
    showSearch: {
      type: Boolean,
      default: !1
    },
    showSelectAll: {
      type: Boolean,
      default: !0
    },
    title: {
      type: Array,
      default: () => ["Source", "Target"]
    },
    sourceInputSearchProps: {
      type: Object
    },
    targetInputSearchProps: {
      type: Object
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    "update:selected": (e) => !0,
    change: (e) => !0,
    select: (e) => !0,
    search: (e, t) => !0
  },
  setup(e, { emit: t, slots: n }) {
    const { mergedDisabled: o, eventHandlers: i } = mt({
      disabled: un(e, "disabled")
    }), r = B("transfer"), l = V(e.defaultValue), s = a(() => {
      var P;
      return (P = e.modelValue) != null ? P : l.value;
    }), u = V(e.defaultSelected), f = a(() => {
      var P;
      return (P = e.selected) != null ? P : u.value;
    }), d = a(() => {
      var P;
      return (P = e.title) == null ? void 0 : P[0];
    }), p = a(() => {
      var P;
      return (P = e.title) == null ? void 0 : P[1];
    }), h = a(() => {
      const P = {
        data: [],
        allValidValues: [],
        selected: [],
        validSelected: []
      }, z = {
        data: [],
        allValidValues: [],
        selected: [],
        validSelected: []
      };
      for (const j of e.data)
        s.value.includes(j.value) ? (z.data.push(j), j.disabled || z.allValidValues.push(j.value), f.value.includes(j.value) && (z.selected.push(j.value), j.disabled || z.validSelected.push(j.value))) : (P.data.push(j), j.disabled || P.allValidValues.push(j.value), f.value.includes(j.value) && (P.selected.push(j.value), j.disabled || P.validSelected.push(j.value)));
      return {
        sourceInfo: P,
        targetInfo: z
      };
    }), k = (P, z) => {
      t("search", P, z);
    }, y = (P, z) => {
      var j, I;
      const L = z === "target" ? [...s.value, ...P] : s.value.filter((M) => !P.includes(M));
      g(
        h.value[z === "target" ? "targetInfo" : "sourceInfo"].selected
      ), l.value = L, t("update:modelValue", L), t("change", L), (I = (j = i.value) == null ? void 0 : j.onChange) == null || I.call(j);
    }, w = (P) => {
      const z = P === "target" ? h.value.sourceInfo.validSelected : h.value.targetInfo.validSelected;
      y(z, P);
    }, g = (P) => {
      u.value = P, t("update:selected", P), t("select", P);
    };
    it(
      u0,
      me({
        selected: f,
        slots: n,
        moveTo: y,
        onSelect: g
      })
    );
    const C = a(() => [
      r,
      {
        [`${r}-simple`]: e.simple,
        [`${r}-disabled`]: o.value
      }
    ]);
    return {
      prefixCls: r,
      cls: C,
      dataInfo: h,
      computedSelected: f,
      mergedDisabled: o,
      sourceTitle: d,
      targetTitle: p,
      handleClick: w,
      handleSearch: k
    };
  }
});
function m9(e, t, n, o, i, r) {
  const l = J("transfer-view"), s = J("icon-right"), u = J("arco-button"), f = J("icon-left");
  return v(), b("div", {
    class: m(e.cls)
  }, [
    c(l, {
      type: "source",
      class: m(`${e.prefixCls}-view-source`),
      title: e.sourceTitle,
      "data-info": e.dataInfo.sourceInfo,
      data: e.dataInfo.sourceInfo.data,
      disabled: e.mergedDisabled,
      selected: e.computedSelected,
      "show-search": e.showSearch,
      "show-select-all": e.showSelectAll,
      simple: e.simple,
      "input-search-props": e.sourceInputSearchProps,
      onSearch: e.handleSearch
    }, kt({ _: 2 }, [
      e.$slots.source ? {
        name: "default",
        fn: ue((d) => [
          _(e.$slots, "source", dt(Gt(d)))
        ]),
        key: "0"
      } : void 0,
      e.$slots["source-title"] ? {
        name: "title",
        fn: ue((d) => [
          _(e.$slots, "source-title", dt(Gt(d)))
        ]),
        key: "1"
      } : void 0
    ]), 1032, ["class", "title", "data-info", "data", "disabled", "selected", "show-search", "show-select-all", "simple", "input-search-props", "onSearch"]),
    e.simple ? te("v-if", !0) : (v(), b("div", {
      key: 0,
      class: m([`${e.prefixCls}-operations`])
    }, [
      c(u, {
        tabindex: "-1",
        "aria-label": "Move selected right",
        size: "small",
        shape: "round",
        disabled: e.dataInfo.sourceInfo.validSelected.length === 0,
        onClick: t[0] || (t[0] = (d) => e.handleClick("target"))
      }, {
        icon: ue(() => [
          _(e.$slots, "to-target-icon", {}, () => [
            c(s)
          ])
        ]),
        _: 3
      }, 8, ["disabled"]),
      e.oneWay ? te("v-if", !0) : (v(), oe(u, {
        key: 0,
        tabindex: "-1",
        "aria-label": "Move selected left",
        size: "small",
        shape: "round",
        disabled: e.dataInfo.targetInfo.validSelected.length === 0,
        onClick: t[1] || (t[1] = (d) => e.handleClick("source"))
      }, {
        icon: ue(() => [
          _(e.$slots, "to-source-icon", {}, () => [
            c(f)
          ])
        ]),
        _: 3
      }, 8, ["disabled"]))
    ], 2)),
    c(l, {
      type: "target",
      class: m(`${e.prefixCls}-view-target`),
      title: e.targetTitle,
      "data-info": e.dataInfo.targetInfo,
      data: e.dataInfo.targetInfo.data,
      disabled: e.mergedDisabled,
      selected: e.computedSelected,
      "allow-clear": e.oneWay,
      "show-search": e.showSearch,
      "show-select-all": e.showSelectAll,
      simple: e.simple,
      "input-search-props": e.targetInputSearchProps,
      onSearch: e.handleSearch
    }, kt({ _: 2 }, [
      e.$slots.target ? {
        name: "default",
        fn: ue((d) => [
          _(e.$slots, "target", dt(Gt(d)))
        ]),
        key: "0"
      } : void 0,
      e.$slots["target-title"] ? {
        name: "title",
        fn: ue((d) => [
          _(e.$slots, "target-title", dt(Gt(d)))
        ]),
        key: "1"
      } : void 0
    ]), 1032, ["class", "title", "data-info", "data", "disabled", "selected", "allow-clear", "show-search", "show-select-all", "simple", "input-search-props", "onSearch"])
  ], 2);
}
var hu = /* @__PURE__ */ N(p9, [["render", m9]]);
const h9 = Object.assign(hu, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + hu.name, hu);
  }
}), b2 = Symbol("TreeInjectionKey");
function k9(e) {
  const t = [];
  function n(o) {
    o && o.forEach((i) => {
      t.push(i), n(i.children);
    });
  }
  return n(e), t;
}
function g9(e) {
  const t = /* @__PURE__ */ new Map();
  return e.forEach((n) => {
    t.set(n.key, n);
  }), t;
}
function kv(e) {
  return e.selectable && !e.disabled;
}
function Op(e) {
  return !e.isLeaf && e.children;
}
function y9(e) {
  return Xt(e.isLeaf) ? e.isLeaf : !e.children;
}
function gv(e) {
  return Set.prototype.add.bind(e);
}
function yv(e) {
  return Set.prototype.delete.bind(e);
}
function Cl(e) {
  return e.disabled || e.disableCheckbox ? !1 : !!e.checkable;
}
function c0(e) {
  var t;
  const n = [];
  return (t = e.children) == null || t.forEach((o) => {
    Cl(o) && n.push(o.key, ...c0(o));
  }), n;
}
function C2(e) {
  var t;
  const { node: n, checkedKeySet: o, indeterminateKeySet: i } = e;
  let r = n.parent;
  for (; r; ) {
    if (Cl(r)) {
      const l = r.key, s = ((t = r.children) == null ? void 0 : t.filter(Cl)) || [];
      let u = 0;
      const f = s.length;
      s.some(({ key: d }) => {
        if (o.has(d))
          u += 1;
        else if (i.has(d))
          return u += 0.5, !0;
        return !1;
      }), u && u !== f ? i.add(l) : i.delete(l), u && u === f ? o.add(l) : o.delete(l);
    }
    r = r.parent;
  }
}
function bv(e) {
  const {
    node: t,
    checked: n,
    checkedKeys: o,
    indeterminateKeys: i,
    checkStrictly: r = !1
  } = e, { key: l } = t, s = new Set(o), u = new Set(i);
  if (n ? s.add(l) : s.delete(l), u.delete(l), !r) {
    const f = c0(t);
    n ? f.forEach(gv(s)) : f.forEach(yv(s)), f.forEach(yv(u)), C2({ node: t, checkedKeySet: s, indeterminateKeySet: u });
  }
  return [[...s], [...u]];
}
function b9(e) {
  const { initCheckedKeys: t, key2TreeNode: n, checkStrictly: o, onlyCheckLeaf: i } = e, r = /* @__PURE__ */ new Set(), l = /* @__PURE__ */ new Set(), s = /* @__PURE__ */ new Set();
  return o ? t.forEach(gv(r)) : t.forEach((u) => {
    var f;
    const d = n.get(u);
    if (!d || l.has(u) || i && ((f = d.children) != null && f.length))
      return;
    const p = c0(d);
    p.forEach(gv(l)), p.forEach(yv(s)), r.add(u), s.delete(u), C2({ node: d, checkedKeySet: r, indeterminateKeySet: s });
  }), [[...r, ...l], [...s]];
}
function Xr() {
  return Ge(b2) || {};
}
const C9 = S({
  name: "IconFile",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-file`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), $9 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function w9(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M16 21h16m-16 8h10m11 13H11a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h21l7 7v27a2 2 0 0 1-2 2Z" }, null, -1)
  ]), 14, $9);
}
var ku = /* @__PURE__ */ N(C9, [["render", w9]]);
const d0 = Object.assign(ku, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ku.name, ku);
  }
});
var S9 = S({
  name: "TreeNodeSwitcher",
  components: {
    IconLoading: Yt,
    RenderFunction: Xn
  },
  props: {
    prefixCls: String,
    loading: Boolean,
    showLine: Boolean,
    treeNodeData: {
      type: Object
    },
    icons: {
      type: Object
    },
    nodeStatus: {
      type: Object
    }
  },
  emits: ["click"],
  setup(e, {
    slots: t,
    emit: n
  }) {
    const {
      icons: o,
      nodeStatus: i,
      treeNodeData: r
    } = ve(e), l = Xr(), s = Sn(t, "switcher-icon"), u = Sn(t, "loading-icon");
    return {
      getSwitcherIcon: () => {
        var f, d, p;
        const h = (d = (f = o == null ? void 0 : o.value) == null ? void 0 : f.switcherIcon) != null ? d : s.value;
        return h ? h(i.value) : (p = l.switcherIcon) == null ? void 0 : p.call(l, r.value, i.value);
      },
      getLoadingIcon: () => {
        var f, d, p;
        const h = (d = (f = o == null ? void 0 : o.value) == null ? void 0 : f.loadingIcon) != null ? d : u.value;
        return h ? h(i.value) : (p = l.loadingIcon) == null ? void 0 : p.call(l, r.value, i.value);
      },
      onClick(f) {
        n("click", f);
      }
    };
  },
  render() {
    var e, t, n;
    const {
      prefixCls: o,
      getSwitcherIcon: i,
      getLoadingIcon: r,
      onClick: l,
      nodeStatus: s = {},
      loading: u,
      showLine: f
    } = this, {
      expanded: d,
      isLeaf: p
    } = s;
    if (u)
      return (e = r()) != null ? e : mn(Yt);
    let h = null, k = !1;
    if (p)
      f && (h = (n = i()) != null ? n : mn(d0));
    else {
      const w = f ? mn("span", {
        class: `${o}-${d ? "minus" : "plus"}-icon`
      }) : mn(a0);
      h = (t = i()) != null ? t : w, k = !f;
    }
    if (!h)
      return null;
    const y = mn("span", {
      class: `${o}-switcher-icon`,
      onClick: l
    }, h);
    return k ? mn(pt, {
      class: `${o}-icon-hover`
    }, () => y) : y;
  }
});
const $2 = /* @__PURE__ */ (() => {
  let e = 0;
  return () => (e += 1, `__arco_tree${e}`);
})();
function z9(e, t) {
  return !!(Ve(e) ? t : e);
}
function L9(e, t) {
  const n = { ...e };
  return t && Object.keys(t).forEach((i) => {
    const r = t[i];
    r !== i && (n[i] = e[r], delete n[r]);
  }), n;
}
function Vp({
  subEnable: e,
  superEnable: t,
  isLeaf: n,
  treeNodeData: o,
  level: i
}) {
  return Ve(e) ? Ne(t) ? t(o, { isLeaf: n, level: i }) : t ?? !1 : e;
}
function j9(e) {
  var t, n;
  const { treeNodeData: o, parentNode: i, isTail: r = !0, treeProps: l } = e, { fieldNames: s } = l || {}, u = L9(o, s), f = l.loadMore ? !!u.isLeaf : !((t = u.children) != null && t.length), d = i ? i.level + 1 : 0, p = {
    ...Ft(u, ["children"]),
    key: (n = u.key) != null ? n : $2(),
    selectable: Vp({
      subEnable: u.selectable,
      superEnable: l == null ? void 0 : l.selectable,
      isLeaf: f,
      level: d,
      treeNodeData: o
    }),
    disabled: !!u.disabled,
    disableCheckbox: !!u.disableCheckbox,
    checkable: Vp({
      subEnable: u.checkable,
      superEnable: l == null ? void 0 : l.checkable,
      isLeaf: f,
      level: d,
      treeNodeData: o
    }),
    isLeaf: f,
    isTail: r,
    blockNode: !!(l != null && l.blockNode),
    showLine: !!(l != null && l.showLine),
    level: d,
    lineless: i ? [...i.lineless, i.isTail] : [],
    draggable: z9(u.draggable, l == null ? void 0 : l.draggable)
  };
  return {
    ...p,
    treeNodeProps: p,
    treeNodeData: o,
    parent: i,
    parentKey: i == null ? void 0 : i.key,
    pathParentKeys: i ? [...i.pathParentKeys, i.key] : []
  };
}
function P9(e, t) {
  function n(o, i) {
    if (!o)
      return;
    const { fieldNames: r } = t, l = [];
    return o.forEach((s, u) => {
      const f = j9({
        treeNodeData: s,
        treeProps: t,
        parentNode: i,
        isTail: u === o.length - 1
      });
      f.children = n(
        s[(r == null ? void 0 : r.children) || "children"],
        f
      ), l.push(f);
    }), l;
  }
  return n(e);
}
function w2() {
  const e = dn(), t = () => {
    var o;
    return (o = e == null ? void 0 : e.vnode.key) != null ? o : $2();
  }, n = V(t());
  return fn(() => {
    n.value = t();
  }), n;
}
function I9(e) {
  const { key: t, refTitle: n } = ve(e), o = Xr(), i = V(!1), r = V(!1), l = V(!1), s = V(0), u = wl((f) => {
    if (!n.value)
      return;
    const d = n.value.getBoundingClientRect(), p = window.pageYOffset + d.top, { pageY: h } = f, k = d.height / 4, y = h - p;
    s.value = y < k ? -1 : y < d.height - k ? 0 : 1, l.value = o.allowDrop ? o.allowDrop(t.value, s.value) : !0;
  });
  return {
    isDragOver: i,
    isDragging: r,
    isAllowDrop: l,
    dropPosition: s,
    setDragStatus(f, d) {
      switch (f) {
        case "dragStart":
          r.value = !0, s.value = 0, o.onDragStart && o.onDragStart(t.value, d);
          break;
        case "dragEnd":
          r.value = !1, i.value = !1, s.value = 0, u.cancel(), o.onDragEnd && o.onDragEnd(t.value, d);
          break;
        case "dragOver":
          i.value = !0, u(d), o.onDragOver && o.onDragOver(t.value, d);
          break;
        case "dragLeave":
          i.value = !1, s.value = 0, u.cancel(), o.onDragLeave && o.onDragLeave(t.value, d);
          break;
        case "drop":
          o.onDrop && o.onDrop(t.value, s.value, d), i.value = !1, s.value = 0, u.cancel();
          break;
      }
    }
  };
}
function B9(e) {
  return He(e) ? e : [e];
}
const M9 = S({
  name: "BaseTreeNode",
  components: {
    NodeSwitcher: S9,
    Checkbox: Ln,
    RenderFunction: Xn,
    IconDragDotVertical: Zr
  },
  props: {
    title: {
      type: String
    },
    selectable: {
      type: Boolean
    },
    disabled: {
      type: Boolean
    },
    disableCheckbox: {
      type: Boolean
    },
    checkable: {
      type: Boolean
    },
    draggable: {
      type: Boolean
    },
    isLeaf: {
      type: Boolean
    },
    icon: {
      type: Function
    },
    switcherIcon: {
      type: Function
    },
    loadingIcon: {
      type: Function
    },
    dragIcon: {
      type: Function
    },
    isTail: {
      type: Boolean
    },
    blockNode: {
      type: Boolean
    },
    showLine: {
      type: Boolean
    },
    level: {
      type: Number,
      default: 0
    },
    lineless: {
      type: Array,
      default: () => []
    }
  },
  setup(e) {
    const t = w2(), n = B("tree-node"), o = Xr(), i = a(
      () => {
        var D;
        return (D = o.key2TreeNode) == null ? void 0 : D.get(t.value);
      }
    ), r = a(() => i.value.treeNodeData), l = a(() => i.value.children), s = a(() => {
      var D;
      const R = (D = o.treeProps) == null ? void 0 : D.actionOnNodeClick;
      return R ? B9(R) : [];
    }), { isLeaf: u, isTail: f, selectable: d, disabled: p, disableCheckbox: h, draggable: k } = ve(e), y = a(() => {
      var D;
      return [
        `${n}`,
        {
          [`${n}-selected`]: E.value,
          [`${n}-is-leaf`]: u.value,
          [`${n}-is-tail`]: f.value,
          [`${n}-expanded`]: K.value,
          [`${n}-disabled-selectable`]: !d.value && !((D = o.treeProps) != null && D.disableSelectActionOnly),
          [`${n}-disabled`]: p.value
        }
      ];
    }), w = V(), { isDragOver: g, isDragging: C, isAllowDrop: P, dropPosition: z, setDragStatus: j } = I9(
      me({
        key: t,
        refTitle: w
      })
    ), I = a(() => [
      `${n}-title`,
      {
        [`${n}-title-draggable`]: k.value,
        [`${n}-title-gap-top`]: g.value && P.value && z.value < 0,
        [`${n}-title-gap-bottom`]: g.value && P.value && z.value > 0,
        [`${n}-title-highlight`]: !C.value && g.value && P.value && z.value === 0,
        [`${n}-title-dragging`]: C.value,
        [`${n}-title-block`]: i.value.blockNode
      }
    ]), L = a(
      () => {
        var D, R;
        return (R = (D = o.checkedKeys) == null ? void 0 : D.includes) == null ? void 0 : R.call(D, t.value);
      }
    ), M = a(
      () => {
        var D, R;
        return (R = (D = o.indeterminateKeys) == null ? void 0 : D.includes) == null ? void 0 : R.call(D, t.value);
      }
    ), E = a(
      () => {
        var D, R;
        return (R = (D = o.selectedKeys) == null ? void 0 : D.includes) == null ? void 0 : R.call(D, t.value);
      }
    ), K = a(
      () => {
        var D, R;
        return (R = (D = o.expandedKeys) == null ? void 0 : D.includes) == null ? void 0 : R.call(D, t.value);
      }
    ), q = a(
      () => {
        var D, R;
        return (R = (D = o.loadingKeys) == null ? void 0 : D.includes) == null ? void 0 : R.call(D, t.value);
      }
    ), T = a(() => o.dragIcon), X = a(() => o.nodeIcon);
    function Y(D) {
      var R, W;
      u.value || (!((R = l.value) != null && R.length) && Ne(o.onLoadMore) ? o.onLoadMore(t.value) : (W = o == null ? void 0 : o.onExpand) == null || W.call(o, !K.value, t.value, D));
    }
    const Z = me({
      loading: q,
      checked: L,
      selected: E,
      indeterminate: M,
      expanded: K,
      isLeaf: u
    }), U = a(
      () => o.nodeTitle ? () => {
        var D;
        return (D = o.nodeTitle) == null ? void 0 : D.call(o, r.value, Z);
      } : void 0
    ), H = a(
      () => o.nodeExtra ? () => {
        var D;
        return (D = o.nodeExtra) == null ? void 0 : D.call(o, r.value, Z);
      } : void 0
    );
    return {
      nodekey: t,
      refTitle: w,
      prefixCls: n,
      classNames: y,
      titleClassNames: I,
      indeterminate: M,
      checked: L,
      expanded: K,
      selected: E,
      treeTitle: U,
      treeNodeData: r,
      loading: q,
      treeDragIcon: T,
      treeNodeIcon: X,
      extra: H,
      nodeStatus: Z,
      onCheckboxChange(D, R) {
        var W;
        h.value || p.value || (W = o.onCheck) == null || W.call(o, D, t.value, R);
      },
      onTitleClick(D) {
        var R;
        s.value.includes("expand") && Y(D), !(!d.value || p.value) && ((R = o.onSelect) == null || R.call(o, t.value, D));
      },
      onSwitcherClick: Y,
      onDragStart(D) {
        var R;
        if (k.value) {
          D.stopPropagation(), j("dragStart", D);
          try {
            (R = D.dataTransfer) == null || R.setData("text/plain", "");
          } catch {
          }
        }
      },
      onDragEnd(D) {
        k.value && (D.stopPropagation(), j("dragEnd", D));
      },
      onDragOver(D) {
        k && (D.stopPropagation(), D.preventDefault(), j("dragOver", D));
      },
      onDragLeave(D) {
        k.value && (D.stopPropagation(), j("dragLeave", D));
      },
      onDrop(D) {
        !k.value || !P.value || (D.stopPropagation(), D.preventDefault(), j("drop", D));
      }
    };
  }
}), N9 = ["data-level", "data-key"], O9 = ["draggable"];
function V9(e, t, n, o, i, r) {
  const l = J("NodeSwitcher"), s = J("Checkbox"), u = J("RenderFunction"), f = J("IconDragDotVertical");
  return v(), b("div", {
    class: m(e.classNames),
    "data-level": e.level,
    "data-key": e.nodekey
  }, [
    te(" 缩进 "),
    $("span", {
      class: m(`${e.prefixCls}-indent`)
    }, [
      (v(!0), b(Ae, null, St(e.level, (d) => (v(), b("span", {
        key: d,
        class: m([
          `${e.prefixCls}-indent-block`,
          {
            [`${e.prefixCls}-indent-block-lineless`]: e.lineless[d - 1]
          }
        ])
      }, null, 2))), 128))
    ], 2),
    te(" switcher "),
    $("span", {
      class: m([
        `${e.prefixCls}-switcher`,
        {
          [`${e.prefixCls}-switcher-expanded`]: e.expanded
        }
      ])
    }, [
      c(l, {
        "prefix-cls": e.prefixCls,
        loading: e.loading,
        "show-line": e.showLine,
        "tree-node-data": e.treeNodeData,
        icons: {
          switcherIcon: e.switcherIcon,
          loadingIcon: e.loadingIcon
        },
        "node-status": e.nodeStatus,
        onClick: e.onSwitcherClick
      }, kt({ _: 2 }, [
        e.$slots["switcher-icon"] ? {
          name: "switcher-icon",
          fn: ue(() => [
            te(" @slot 定制 switcher 图标，会覆盖 Tree 的配置 "),
            _(e.$slots, "switcher-icon")
          ]),
          key: "0"
        } : void 0,
        e.$slots["loading-icon"] ? {
          name: "loading-icon",
          fn: ue(() => [
            te(" @slot 定制 loading 图标，会覆盖 Tree 的配置 "),
            _(e.$slots, "loading-icon")
          ]),
          key: "1"
        } : void 0
      ]), 1032, ["prefix-cls", "loading", "show-line", "tree-node-data", "icons", "node-status", "onClick"])
    ], 2),
    te(" checkbox "),
    e.checkable ? (v(), oe(s, {
      key: 0,
      disabled: e.disableCheckbox || e.disabled,
      "model-value": e.checked,
      indeterminate: e.indeterminate,
      "uninject-group-context": "",
      onChange: e.onCheckboxChange
    }, null, 8, ["disabled", "model-value", "indeterminate", "onChange"])) : te("v-if", !0),
    te(" 内容 "),
    $("span", {
      ref: "refTitle",
      class: m(e.titleClassNames),
      draggable: e.draggable,
      onDragstart: t[0] || (t[0] = (...d) => e.onDragStart && e.onDragStart(...d)),
      onDragend: t[1] || (t[1] = (...d) => e.onDragEnd && e.onDragEnd(...d)),
      onDragover: t[2] || (t[2] = (...d) => e.onDragOver && e.onDragOver(...d)),
      onDragleave: t[3] || (t[3] = (...d) => e.onDragLeave && e.onDragLeave(...d)),
      onDrop: t[4] || (t[4] = (...d) => e.onDrop && e.onDrop(...d)),
      onClick: t[5] || (t[5] = (...d) => e.onTitleClick && e.onTitleClick(...d))
    }, [
      e.$slots.icon || e.icon || e.treeNodeIcon ? (v(), b("span", {
        key: 0,
        class: m([`${e.prefixCls}-icon`, `${e.prefixCls}-custom-icon`])
      }, [
        te(" 节点图标 "),
        e.$slots.icon ? _(e.$slots, "icon", dt(se({ key: 0 }, e.nodeStatus))) : e.icon ? (v(), oe(u, se({
          key: 1,
          "render-func": e.icon
        }, e.nodeStatus), null, 16, ["render-func"])) : e.treeNodeIcon ? (v(), oe(u, se({
          key: 2,
          "render-func": e.treeNodeIcon,
          node: e.treeNodeData
        }, e.nodeStatus), null, 16, ["render-func", "node"])) : te("v-if", !0)
      ], 2)) : te("v-if", !0),
      $("span", {
        class: m(`${e.prefixCls}-title-text`)
      }, [
        e.treeTitle ? (v(), oe(u, {
          key: 0,
          "render-func": e.treeTitle
        }, null, 8, ["render-func"])) : (v(), b(Ae, { key: 1 }, [
          te(" 标题，treeTitle 优先级高于节点的 title "),
          _(e.$slots, "title", { title: e.title }, () => [
            Re(Pe(e.title), 1)
          ])
        ], 2112)),
        e.draggable ? (v(), b("span", {
          key: 2,
          class: m([`${e.prefixCls}-icon`, `${e.prefixCls}-drag-icon`])
        }, [
          te(" 拖拽图标 "),
          e.$slots["drag-icon"] ? _(e.$slots, "drag-icon", dt(se({ key: 0 }, e.nodeStatus))) : e.dragIcon ? (v(), oe(u, se({
            key: 1,
            "render-func": e.dragIcon
          }, e.nodeStatus), null, 16, ["render-func"])) : e.treeDragIcon ? (v(), oe(u, se({
            key: 2,
            "render-func": e.treeDragIcon,
            node: e.treeNodeData
          }, e.nodeStatus), null, 16, ["render-func", "node"])) : (v(), oe(f, { key: 3 }))
        ], 2)) : te("v-if", !0)
      ], 2)
    ], 42, O9),
    te(" 额外 "),
    e.extra ? (v(), oe(u, {
      key: 1,
      "render-func": e.extra
    }, null, 8, ["render-func"])) : te("v-if", !0)
  ], 10, N9);
}
var Cv = /* @__PURE__ */ N(M9, [["render", V9]]);
const T9 = S({
  name: "ExpandTransition",
  props: {
    expanded: Boolean
  },
  emits: ["end"],
  setup(e, { emit: t }) {
    return {
      onEnter(n) {
        const o = `${n.scrollHeight}px`;
        n.style.height = e.expanded ? "0" : o, n.offsetHeight, n.style.height = e.expanded ? o : "0";
      },
      onAfterEnter(n) {
        n.style.height = e.expanded ? "" : "0", t("end");
      },
      onBeforeLeave(n) {
        n.style.display = "none";
      }
    };
  }
});
function A9(e, t, n, o, i, r) {
  return v(), oe(on, {
    onEnter: e.onEnter,
    onAfterEnter: e.onAfterEnter,
    onBeforeLeave: e.onBeforeLeave
  }, {
    default: ue(() => [
      _(e.$slots, "default")
    ]),
    _: 3
  }, 8, ["onEnter", "onAfterEnter", "onBeforeLeave"]);
}
var E9 = /* @__PURE__ */ N(T9, [["render", A9]]);
const W9 = S({
  name: "TransitionNodeList",
  components: {
    ExpandTransition: E9,
    BaseTreeNode: Cv
  },
  props: {
    nodeKey: {
      type: [String, Number],
      required: !0
    }
  },
  setup(e) {
    const n = [`${B("tree")}-node-list`], o = Xr(), { nodeKey: i } = ve(e), r = a(
      () => {
        var u, f;
        return (f = (u = o.expandedKeys) == null ? void 0 : u.includes) == null ? void 0 : f.call(u, i.value);
      }
    ), l = a(() => {
      var u;
      const f = new Set(o.expandedKeys || []), d = (u = o.flattenTreeData) == null ? void 0 : u.filter((p) => {
        var h, k;
        return (h = p.pathParentKeys) != null && h.includes(i.value) ? !o.filterTreeNode || ((k = o.filterTreeNode) == null ? void 0 : k.call(o, p.treeNodeData)) : !1;
      });
      return d == null ? void 0 : d.filter((p) => {
        var h;
        if (r.value)
          return (h = p.pathParentKeys) == null ? void 0 : h.every(
            (y) => f.has(y)
          );
        const k = p.pathParentKeys.indexOf(i.value);
        return p.pathParentKeys.slice(k + 1).every((y) => f.has(y));
      });
    }), s = a(
      () => {
        var u, f;
        return ((u = o.currentExpandKeys) == null ? void 0 : u.includes(i.value)) && ((f = l.value) == null ? void 0 : f.length);
      }
    );
    return {
      classNames: n,
      visibleNodeList: l,
      show: s,
      expanded: r,
      onTransitionEnd() {
        var u;
        (u = o.onExpandEnd) == null || u.call(o, i.value);
      }
    };
  }
});
function F9(e, t, n, o, i, r) {
  const l = J("BaseTreeNode"), s = J("ExpandTransition");
  return v(), oe(s, {
    expanded: e.expanded,
    onEnd: e.onTransitionEnd
  }, {
    default: ue(() => [
      e.show ? (v(), b("div", {
        key: 0,
        class: m(e.classNames)
      }, [
        (v(!0), b(Ae, null, St(e.visibleNodeList, (u) => (v(), oe(l, se({
          key: u.key,
          ref_for: !0
        }, u.treeNodeProps), null, 16))), 128))
      ], 2)) : te("v-if", !0)
    ]),
    _: 1
  }, 8, ["expanded", "onEnd"]);
}
var D9 = /* @__PURE__ */ N(W9, [["render", F9]]), x9 = S({
  name: "TreeNode",
  inheritAttrs: !1,
  props: {
    ...Cv.props
  },
  setup(e, {
    slots: t,
    attrs: n
  }) {
    const o = w2();
    return () => c(Ae, null, [c(Cv, se(e, n, {
      key: o.value
    }), t), c(D9, {
      key: o.value,
      nodeKey: o.value
    }, null)]);
  }
});
function R9(e) {
  const {
    defaultCheckedKeys: t,
    checkedKeys: n,
    key2TreeNode: o,
    checkStrictly: i,
    halfCheckedKeys: r,
    onlyCheckLeaf: l
  } = ve(e), s = V(!1), u = V([]), f = V([]), d = V(), p = V(), h = (y) => b9({
    initCheckedKeys: y,
    key2TreeNode: o.value,
    checkStrictly: i.value,
    onlyCheckLeaf: l.value
  }), k = (y) => {
    const w = h(y);
    [u.value, f.value] = w;
  };
  return k(n.value || (t == null ? void 0 : t.value) || []), Wt(() => {
    n.value ? [d.value, p.value] = h(n.value) : s.value && (d.value = void 0, p.value = void 0, u.value = [], f.value = []), s.value || (s.value = !0);
  }), {
    checkedKeys: a(
      () => d.value || u.value
    ),
    indeterminateKeys: a(() => i.value && r.value ? r.value : p.value || f.value),
    setCheckedState(y, w, g = !1) {
      return g ? k(y) : (u.value = y, f.value = w), [u.value, f.value];
    }
  };
}
function S2(e) {
  const {
    treeData: t,
    fieldNames: n,
    selectable: o,
    showLine: i,
    blockNode: r,
    checkable: l,
    loadMore: s,
    draggable: u
  } = ve(e), f = V([]);
  Wt(() => {
    var h, k;
    f.value = P9(t.value || [], {
      selectable: (h = o == null ? void 0 : o.value) != null ? h : !1,
      showLine: !!(i != null && i.value),
      blockNode: !!(r != null && r.value),
      checkable: (k = l == null ? void 0 : l.value) != null ? k : !1,
      fieldNames: n == null ? void 0 : n.value,
      loadMore: !!(s != null && s.value),
      draggable: !!(u != null && u.value)
    });
  });
  const d = a(() => k9(f.value)), p = a(() => g9(d.value));
  return { treeData: f, flattenTreeData: d, key2TreeNode: p };
}
const H9 = S({
  name: "Tree",
  components: {
    VirtualList: Jl,
    TreeNode: x9
  },
  props: {
    size: {
      type: String,
      default: "medium"
    },
    blockNode: {
      type: Boolean
    },
    defaultExpandAll: {
      type: Boolean,
      default: !0
    },
    multiple: {
      type: Boolean
    },
    checkable: {
      type: [Boolean, String, Function],
      default: !1
    },
    selectable: {
      type: [Boolean, Function],
      default: !0
    },
    checkStrictly: {
      type: Boolean
    },
    checkedStrategy: {
      type: String,
      default: "all"
    },
    defaultSelectedKeys: {
      type: Array
    },
    selectedKeys: {
      type: Array
    },
    defaultCheckedKeys: {
      type: Array
    },
    checkedKeys: {
      type: Array
    },
    defaultExpandedKeys: {
      type: Array
    },
    expandedKeys: {
      type: Array
    },
    data: {
      type: Array,
      default: () => []
    },
    fieldNames: {
      type: Object
    },
    showLine: {
      type: Boolean
    },
    loadMore: {
      type: Function
    },
    draggable: {
      type: Boolean
    },
    allowDrop: {
      type: Function
    },
    filterTreeNode: {
      type: Function
    },
    searchValue: {
      type: String,
      default: ""
    },
    virtualListProps: {
      type: Object
    },
    defaultExpandSelected: {
      type: Boolean
    },
    defaultExpandChecked: {
      type: Boolean
    },
    autoExpandParent: {
      type: Boolean,
      default: !0
    },
    halfCheckedKeys: {
      type: Array
    },
    onlyCheckLeaf: {
      type: Boolean,
      default: !1
    },
    animation: {
      type: Boolean,
      default: !0
    },
    actionOnNodeClick: {
      type: String
    },
    disableSelectActionOnly: {
      type: Boolean,
      default: !1
    }
  },
  emits: {
    select: (e, t) => !0,
    "update:selectedKeys": (e) => !0,
    check: (e, t) => !0,
    "update:checkedKeys": (e) => !0,
    "update:halfCheckedKeys": (e) => !0,
    expand: (e, t) => !0,
    "update:expandedKeys": (e) => !0,
    dragStart: (e, t) => !0,
    dragEnd: (e, t) => !0,
    dragOver: (e, t) => !0,
    dragLeave: (e, t) => !0,
    drop: (e) => !0
  },
  setup(e, { emit: t, slots: n }) {
    const {
      data: o,
      showLine: i,
      multiple: r,
      loadMore: l,
      checkStrictly: s,
      checkedKeys: u,
      defaultCheckedKeys: f,
      selectedKeys: d,
      defaultSelectedKeys: p,
      expandedKeys: h,
      defaultExpandedKeys: k,
      checkedStrategy: y,
      selectable: w,
      checkable: g,
      blockNode: C,
      fieldNames: P,
      size: z,
      defaultExpandAll: j,
      filterTreeNode: I,
      draggable: L,
      allowDrop: M,
      defaultExpandSelected: E,
      defaultExpandChecked: K,
      autoExpandParent: q,
      halfCheckedKeys: T,
      onlyCheckLeaf: X,
      animation: Y
    } = ve(e), Z = B("tree"), U = a(() => [
      `${Z}`,
      {
        [`${Z}-checkable`]: g.value,
        [`${Z}-show-line`]: i.value
      },
      `${Z}-size-${z.value}`
    ]), H = Sn(n, "switcher-icon"), D = Sn(n, "loading-icon"), R = Sn(n, "drag-icon"), W = Sn(n, "icon"), O = Sn(n, "title"), x = Sn(n, "extra"), { treeData: G, flattenTreeData: ne, key2TreeNode: ee } = S2(
      me({
        treeData: o,
        selectable: w,
        showLine: i,
        blockNode: C,
        checkable: g,
        fieldNames: P,
        loadMore: l,
        draggable: L
      })
    ), { checkedKeys: Q, indeterminateKeys: ae, setCheckedState: ge } = R9(
      me({
        defaultCheckedKeys: f,
        checkedKeys: u,
        checkStrictly: s,
        key2TreeNode: ee,
        halfCheckedKeys: T,
        onlyCheckLeaf: X
      })
    ), [Se, be] = Vt(
      (p == null ? void 0 : p.value) || [],
      me({
        value: d
      })
    ), Le = V([]), pe = V();
    function Me() {
      if (k != null && k.value) {
        const Ie = /* @__PURE__ */ new Set([]);
        return k.value.forEach((Ee) => {
          if (Ie.has(Ee))
            return;
          const Ze = ee.value.get(Ee);
          Ze && [
            ...q.value ? Ze.pathParentKeys : [],
            Ee
          ].forEach((Xe) => Ie.add(Xe));
        }), [...Ie];
      }
      if (j.value)
        return ne.value.filter((Ie) => Ie.children && Ie.children.length).map((Ie) => Ie.key);
      if (E.value || K.value) {
        const Ie = /* @__PURE__ */ new Set([]), Ee = (Ze) => {
          Ze.forEach((Xe) => {
            const _e = ee.value.get(Xe);
            _e && (_e.pathParentKeys || []).forEach((nt) => Ie.add(nt));
          });
        };
        return E.value && Ee(Se.value), K.value && Ee(Q.value), [...Ie];
      }
      return [];
    }
    const [ke, le] = Vt(
      Me(),
      me({
        value: h
      })
    ), re = V([]), fe = a(() => {
      const Ie = new Set(ke.value), Ee = new Set(re.value);
      return ne.value.filter((Ze) => {
        var Xe;
        if (!(!I || !I.value || (I == null ? void 0 : I.value(Ze.treeNodeData))))
          return !1;
        const nt = Ve(Ze.parentKey), Rt = (Xe = Ze.pathParentKeys) == null ? void 0 : Xe.every(
          (tn) => Ie.has(tn) && !Ee.has(tn)
        );
        return nt || Rt;
      });
    });
    function Oe(Ie, Ee = y.value) {
      let Ze = [...Ie];
      return Ee === "parent" ? Ze = Ie.filter((Xe) => {
        const _e = ee.value.get(Xe);
        return _e && !(!Ve(_e.parentKey) && Ie.includes(_e.parentKey));
      }) : Ee === "child" && (Ze = Ie.filter((Xe) => {
        var _e, nt;
        return !((nt = (_e = ee.value.get(Xe)) == null ? void 0 : _e.children) != null && nt.length);
      })), Ze;
    }
    function Be(Ie) {
      return Ie.map((Ee) => {
        var Ze;
        return ((Ze = ee.value.get(Ee)) == null ? void 0 : Ze.treeNodeData) || void 0;
      }).filter(Boolean);
    }
    function $e(Ie) {
      const {
        targetKey: Ee,
        targetChecked: Ze,
        newCheckedKeys: Xe,
        newIndeterminateKeys: _e,
        event: nt
      } = Ie, Rt = Ee ? ee.value.get(Ee) : void 0, tn = Oe(Xe);
      t("update:checkedKeys", tn), t("update:halfCheckedKeys", _e), t("check", tn, {
        checked: Ze,
        node: Rt == null ? void 0 : Rt.treeNodeData,
        checkedNodes: Be(tn),
        halfCheckedKeys: _e,
        halfCheckedNodes: Be(_e),
        e: nt
      });
    }
    function he(Ie) {
      const { targetKey: Ee, targetSelected: Ze, newSelectedKeys: Xe, event: _e } = Ie, nt = Ee ? ee.value.get(Ee) : void 0;
      t("update:selectedKeys", Xe), t("select", Xe, {
        selected: Ze,
        node: nt == null ? void 0 : nt.treeNodeData,
        selectedNodes: Be(Xe),
        e: _e
      });
    }
    function Ue(Ie) {
      const { targetKey: Ee, targetExpanded: Ze, newExpandedKeys: Xe, event: _e } = Ie, nt = Ee ? ee.value.get(Ee) : void 0;
      t("expand", Xe, {
        expanded: Ze,
        node: nt == null ? void 0 : nt.treeNodeData,
        expandedNodes: Be(Xe),
        e: _e
      }), t("update:expandedKeys", Xe);
    }
    function et(Ie) {
      const [Ee, Ze] = ge(
        Ie,
        [],
        !0
      );
      $e({ newCheckedKeys: Ee, newIndeterminateKeys: Ze });
    }
    function tt(Ie) {
      let Ee = Ie;
      !r.value && Ie.length > 1 && (Ee = [Ie[0]]), be(Ee), he({
        newSelectedKeys: Ee
      });
    }
    function st(Ie) {
      re.value = [], le(Ie), Ue({ newExpandedKeys: Ie });
    }
    function $t(Ie, Ee, Ze) {
      if (!Ie.length)
        return;
      let Xe = [...Q.value], _e = [...ae.value];
      Ie.forEach((nt) => {
        const Rt = ee.value.get(nt);
        Rt && ([Xe, _e] = bv({
          node: Rt,
          checked: Ee,
          checkedKeys: [...Xe],
          indeterminateKeys: [..._e],
          checkStrictly: s.value
        }));
      }), ge(Xe, _e), $e({
        targetKey: Ze,
        targetChecked: Ve(Ze) ? void 0 : Ee,
        newCheckedKeys: Xe,
        newIndeterminateKeys: _e
      });
    }
    function vn(Ie, Ee, Ze) {
      if (!Ie.length)
        return;
      let Xe;
      if (r.value) {
        const _e = new Set(Se.value);
        Ie.forEach((nt) => {
          Ee ? _e.add(nt) : _e.delete(nt);
        }), Xe = [..._e];
      } else
        Xe = Ee ? [Ie[0]] : [];
      be(Xe), he({
        targetKey: Ze,
        targetSelected: Ve(Ze) ? void 0 : Ee,
        newSelectedKeys: Xe
      });
    }
    function ye(Ie, Ee, Ze) {
      const Xe = new Set(ke.value);
      Ie.forEach((nt) => {
        Ee ? Xe.add(nt) : Xe.delete(nt), Lt(nt);
      });
      const _e = [...Xe];
      le(_e), Ue({
        targetKey: Ze,
        targetExpanded: Ve(Ze) ? void 0 : Ee,
        newExpandedKeys: _e
      });
    }
    function ce(Ie, Ee, Ze) {
      const Xe = ee.value.get(Ee);
      if (!Xe)
        return;
      const [_e, nt] = bv({
        node: Xe,
        checked: Ie,
        checkedKeys: Q.value,
        indeterminateKeys: ae.value,
        checkStrictly: s.value
      });
      ge(_e, nt), $e({
        targetKey: Ee,
        targetChecked: Ie,
        newCheckedKeys: _e,
        newIndeterminateKeys: nt,
        event: Ze
      });
    }
    function Ce(Ie, Ee) {
      if (!ee.value.get(Ie))
        return;
      let Xe, _e;
      if (r.value) {
        const nt = new Set(Se.value);
        _e = !nt.has(Ie), _e ? nt.add(Ie) : nt.delete(Ie), Xe = [...nt];
      } else
        _e = !0, Xe = [Ie];
      be(Xe), he({
        targetKey: Ie,
        targetSelected: _e,
        newSelectedKeys: Xe,
        event: Ee
      });
    }
    function qe(Ie, Ee, Ze) {
      if (re.value.includes(Ee) || !ee.value.get(Ee))
        return;
      const _e = new Set(ke.value);
      Ie ? _e.add(Ee) : _e.delete(Ee);
      const nt = [..._e];
      le(nt), Y.value && re.value.push(Ee), Ue({
        targetKey: Ee,
        targetExpanded: Ie,
        newExpandedKeys: nt,
        event: Ze
      });
    }
    function Lt(Ie) {
      const Ee = re.value.indexOf(Ie);
      re.value.splice(Ee, 1);
    }
    const bt = a(
      () => l != null && l.value ? async (Ie) => {
        if (!Ne(l.value))
          return;
        const Ee = ee.value.get(Ie);
        if (!Ee)
          return;
        const { treeNodeData: Ze } = Ee;
        Le.value = [.../* @__PURE__ */ new Set([...Le.value, Ie])];
        try {
          await l.value(Ze), Le.value = Le.value.filter((Xe) => Xe !== Ie), qe(!0, Ie), Q.value.includes(Ie) && ce(!0, Ie);
        } catch (Xe) {
          Le.value = Le.value.filter((_e) => _e !== Ie), console.error("[tree]load data error: ", Xe);
        }
      } : void 0
    ), en = me({
      treeProps: e,
      switcherIcon: H,
      loadingIcon: D,
      dragIcon: R,
      nodeIcon: W,
      nodeTitle: O,
      nodeExtra: x,
      treeData: G,
      flattenTreeData: ne,
      key2TreeNode: ee,
      checkedKeys: Q,
      indeterminateKeys: ae,
      selectedKeys: Se,
      expandedKeys: ke,
      loadingKeys: Le,
      currentExpandKeys: re,
      onLoadMore: bt,
      filterTreeNode: I,
      onCheck: ce,
      onSelect: Ce,
      onExpand: qe,
      onExpandEnd: Lt,
      allowDrop(Ie, Ee) {
        const Ze = ee.value.get(Ie);
        return Ze && Ne(M.value) ? !!M.value({
          dropNode: Ze.treeNodeData,
          dropPosition: Ee
        }) : !0;
      },
      onDragStart(Ie, Ee) {
        const Ze = ee.value.get(Ie);
        pe.value = Ze, Ze && t("dragStart", Ee, Ze.treeNodeData);
      },
      onDragEnd(Ie, Ee) {
        const Ze = ee.value.get(Ie);
        pe.value = void 0, Ze && t("dragEnd", Ee, Ze.treeNodeData);
      },
      onDragOver(Ie, Ee) {
        const Ze = ee.value.get(Ie);
        Ze && t("dragOver", Ee, Ze.treeNodeData);
      },
      onDragLeave(Ie, Ee) {
        const Ze = ee.value.get(Ie);
        Ze && t("dragLeave", Ee, Ze.treeNodeData);
      },
      onDrop(Ie, Ee, Ze) {
        const Xe = ee.value.get(Ie);
        pe.value && Xe && !(Xe.key === pe.value.key || Xe.pathParentKeys.includes(pe.value.key || "")) && t("drop", {
          e: Ze,
          dragNode: pe.value.treeNodeData,
          dropNode: Xe.treeNodeData,
          dropPosition: Ee
        });
      }
    });
    return it(b2, en), {
      classNames: U,
      visibleTreeNodeList: fe,
      treeContext: en,
      virtualListRef: V(),
      computedSelectedKeys: Se,
      computedExpandedKeys: ke,
      computedCheckedKeys: Q,
      computedIndeterminateKeys: ae,
      getPublicCheckedKeys: Oe,
      getNodes: Be,
      internalCheckNodes: $t,
      internalSetCheckedKeys: et,
      internalSelectNodes: vn,
      internalSetSelectedKeys: tt,
      internalExpandNodes: ye,
      internalSetExpandedKeys: st
    };
  },
  methods: {
    toggleCheck(e, t) {
      const { key2TreeNode: n, onCheck: o, checkedKeys: i } = this.treeContext, r = !i.includes(e), l = n.get(e);
      l && Cl(l) && o(r, e, t);
    },
    scrollIntoView(e) {
      this.virtualListRef && this.virtualListRef.scrollTo(e);
    },
    getSelectedNodes() {
      return this.getNodes(this.computedSelectedKeys);
    },
    getCheckedNodes(e = {}) {
      const { checkedStrategy: t, includeHalfChecked: n } = e, o = this.getPublicCheckedKeys(
        this.computedCheckedKeys,
        t
      );
      return [
        ...this.getNodes(o),
        ...n ? this.getHalfCheckedNodes() : []
      ];
    },
    getHalfCheckedNodes() {
      return this.getNodes(this.computedIndeterminateKeys);
    },
    getExpandedNodes() {
      return this.getNodes(this.computedExpandedKeys);
    },
    checkAll(e = !0) {
      const { key2TreeNode: t } = this.treeContext, n = e ? [...t.keys()].filter((o) => {
        const i = t.get(o);
        return i && Cl(i);
      }) : [];
      this.internalSetCheckedKeys(n);
    },
    checkNode(e, t = !0, n = !1) {
      const { checkStrictly: o, treeContext: i } = this, { key2TreeNode: r } = i, l = He(e), s = (l ? e : [e]).filter((u) => {
        const f = r.get(u);
        return f && Cl(f) && (o || !n || y9(f));
      });
      this.internalCheckNodes(s, t, l ? void 0 : e);
    },
    selectAll(e = !0) {
      const { key2TreeNode: t } = this.treeContext, n = e ? [...t.keys()].filter((o) => {
        const i = t.get(o);
        return i && kv(i);
      }) : [];
      this.internalSetSelectedKeys(n);
    },
    selectNode(e, t = !0) {
      const { key2TreeNode: n } = this.treeContext, o = He(e), i = (o ? e : [e]).filter((r) => {
        const l = n.get(r);
        return l && kv(l);
      });
      this.internalSelectNodes(i, t, o ? void 0 : e);
    },
    expandAll(e = !0) {
      const { key2TreeNode: t } = this.treeContext, n = e ? [...t.keys()].filter((o) => {
        const i = t.get(o);
        return i && Op(i);
      }) : [];
      this.internalSetExpandedKeys(n);
    },
    expandNode(e, t = !0) {
      const { key2TreeNode: n } = this.treeContext, o = He(e), i = (o ? e : [e]).filter((r) => {
        const l = n.get(r);
        return l && Op(l);
      });
      this.internalExpandNodes(i, t, o ? void 0 : e);
    }
  }
});
function q9(e, t, n, o, i, r) {
  const l = J("TreeNode"), s = J("VirtualList");
  return v(), b("div", {
    class: m(e.classNames)
  }, [
    e.virtualListProps ? (v(), oe(s, se({
      key: 0,
      ref: "virtualListRef"
    }, e.virtualListProps, { data: e.visibleTreeNodeList }), {
      item: ue(({ item: u }) => [
        (v(), oe(l, se({
          key: `${e.searchValue}-${u.key}`
        }, u.treeNodeProps), null, 16))
      ]),
      _: 1
    }, 16, ["data"])) : (v(!0), b(Ae, { key: 1 }, St(e.visibleTreeNodeList, (u) => (v(), oe(l, se({
      key: u.key,
      ref_for: !0
    }, u.treeNodeProps), null, 16))), 128))
  ], 2);
}
var gu = /* @__PURE__ */ N(H9, [["render", q9]]);
const $v = Object.assign(gu, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + gu.name, gu);
  }
}), Z9 = S({
  name: "Typography",
  setup() {
    return {
      classNames: [B("typography")]
    };
  }
});
function K9(e, t, n, o, i, r) {
  return v(), b("article", {
    class: m(e.classNames)
  }, [
    _(e.$slots, "default")
  ], 2);
}
var yu = /* @__PURE__ */ N(Z9, [["render", K9]]);
const Y9 = S({
  name: "TypographyEditContent",
  components: {
    Input: cl
  },
  props: {
    text: {
      type: String,
      required: !0
    }
  },
  emits: ["change", "end", "update:text"],
  setup(e, { emit: t }) {
    const o = [`${B("typography")}-edit-content`], i = V();
    function r(s) {
      t("update:text", s), t("change", s);
    }
    function l() {
      t("end");
    }
    return Je(() => {
      if (!i.value || !i.value.$el)
        return;
      const s = i.value.$el.querySelector("input");
      if (!s)
        return;
      s.focus && s.focus();
      const { length: u } = s.value;
      s.setSelectionRange(u, u);
    }), {
      classNames: o,
      inputRef: i,
      onBlur: l,
      onChange: r,
      onEnd: l
    };
  }
});
function U9(e, t, n, o, i, r) {
  const l = J("Input");
  return v(), b("div", {
    class: m(e.classNames)
  }, [
    c(l, {
      ref: "inputRef",
      "auto-size": "",
      "model-value": e.text,
      onBlur: e.onBlur,
      onInput: e.onChange,
      onKeydown: El(e.onEnd, ["enter"])
    }, null, 8, ["model-value", "onBlur", "onInput", "onKeydown"])
  ], 2);
}
var G9 = /* @__PURE__ */ N(Y9, [["render", U9]]);
const X9 = S({
  name: "IconCopy",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-copy`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Q9 = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function _9(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M20 6h18a2 2 0 0 1 2 2v22M8 16v24c0 1.105.891 2 1.996 2h20.007A1.99 1.99 0 0 0 32 40.008V15.997A1.997 1.997 0 0 0 30 14H10a2 2 0 0 0-2 2Z" }, null, -1)
  ]), 14, Q9);
}
var bu = /* @__PURE__ */ N(X9, [["render", _9]]);
const z2 = Object.assign(bu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + bu.name, bu);
  }
}), J9 = S({
  name: "IconEdit",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-edit`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ez = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function tz(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m30.48 19.038 5.733-5.734a1 1 0 0 0 0-1.414l-5.586-5.586a1 1 0 0 0-1.414 0l-5.734 5.734m7 7L15.763 33.754a1 1 0 0 1-.59.286l-6.048.708a1 1 0 0 1-1.113-1.069l.477-6.31a1 1 0 0 1 .29-.631l14.7-14.7m7 7-7-7M6 42h36" }, null, -1)
  ]), 14, ez);
}
var Cu = /* @__PURE__ */ N(J9, [["render", tz]]);
const L2 = Object.assign(Cu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Cu.name, Cu);
  }
}), nz = S({
  name: "TypographyOperations",
  components: {
    Tooltip: yn,
    IconCheckCircleFill: ul,
    IconCopy: z2,
    IconEdit: L2
  },
  props: {
    editable: Boolean,
    copyable: Boolean,
    expandable: Boolean,
    isCopied: Boolean,
    isEllipsis: Boolean,
    expanded: Boolean,
    forceRenderExpand: Boolean,
    editTooltipProps: Object,
    copyTooltipProps: Object
  },
  emits: {
    edit: () => !0,
    copy: () => !0,
    expand: () => !0
  },
  setup(e, { emit: t }) {
    const n = B("typography"), o = a(
      () => e.forceRenderExpand || e.expandable && e.isEllipsis
    ), { t: i } = gt();
    return {
      prefixCls: n,
      showExpand: o,
      t: i,
      onEditClick() {
        t("edit");
      },
      onCopyClick() {
        t("copy");
      },
      onExpandClick() {
        t("expand");
      }
    };
  }
});
function lz(e, t, n, o, i, r) {
  const l = J("IconEdit"), s = J("Tooltip"), u = J("IconCheckCircleFill"), f = J("IconCopy");
  return v(), b(Ae, null, [
    e.editable ? (v(), oe(s, se({
      key: 0,
      content: e.t("typography.edit")
    }, e.editTooltipProps), {
      default: ue(() => [
        $("span", {
          class: m(`${e.prefixCls}-operation-edit`),
          onClick: t[0] || (t[0] = an((...d) => e.onEditClick && e.onEditClick(...d), ["stop"]))
        }, [
          c(l)
        ], 2)
      ]),
      _: 1
    }, 16, ["content"])) : te("v-if", !0),
    e.copyable ? (v(), oe(s, dt(se({ key: 1 }, e.copyTooltipProps)), {
      content: ue(() => [
        _(e.$slots, "copy-tooltip", { copied: e.isCopied }, () => [
          Re(Pe(e.isCopied ? e.t("typography.copied") : e.t("typography.copy")), 1)
        ])
      ]),
      default: ue(() => [
        $("span", {
          class: m({
            [`${e.prefixCls}-operation-copied`]: e.isCopied,
            [`${e.prefixCls}-operation-copy`]: !e.isCopied
          }),
          onClick: t[1] || (t[1] = an((...d) => e.onCopyClick && e.onCopyClick(...d), ["stop"]))
        }, [
          _(e.$slots, "copy-icon", { copied: e.isCopied }, () => [
            e.isCopied ? (v(), oe(u, { key: 0 })) : (v(), oe(f, { key: 1 }))
          ])
        ], 2)
      ]),
      _: 3
    }, 16)) : te("v-if", !0),
    e.showExpand ? (v(), b("a", {
      key: 2,
      class: m(`${e.prefixCls}-operation-expand`),
      onClick: t[2] || (t[2] = an((...d) => e.onExpandClick && e.onExpandClick(...d), ["stop"]))
    }, [
      _(e.$slots, "expand-node", { expanded: e.expanded }, () => [
        Re(Pe(e.expanded ? e.t("typography.collapse") : e.t("typography.expand")), 1)
      ])
    ], 2)) : te("v-if", !0)
  ], 64);
}
var Tp = /* @__PURE__ */ N(nz, [["render", lz]]);
let It;
function oz(e) {
  return Array.prototype.slice.apply(e).map((n) => `${n}: ${e.getPropertyValue(n)};`).join("");
}
function $u(e) {
  if (!e)
    return 0;
  const t = e.match(/^\d*(\.\d*)?/);
  return t ? Number(t[0]) : 0;
}
var iz = (e, t, n, o) => {
  It || (It = document.createElement("div"), document.body.appendChild(It));
  const {
    rows: i,
    suffix: r,
    ellipsisStr: l
  } = t, s = window.getComputedStyle(e), u = oz(s), f = $u(s.lineHeight), d = Math.round(f * i + $u(s.paddingTop) + $u(s.paddingBottom));
  It.setAttribute("style", u), It.setAttribute("aria-hidden", "true"), It.style.height = "auto", It.style.minHeight = "auto", It.style.maxHeight = "auto", It.style.position = "fixed", It.style.left = "0", It.style.top = "-99999999px", It.style.zIndex = "-200", It.style.whiteSpace = "normal";
  const p = qp({
    render() {
      return c("span", null, [n]);
    }
  });
  p.mount(It);
  const h = Array.prototype.slice.apply(It.childNodes[0].cloneNode(!0).childNodes);
  p.unmount(), It.innerHTML = "";
  const k = document.createTextNode(`${l}${r}`);
  It.appendChild(k), h.forEach((C) => {
    It.appendChild(C);
  });
  const y = document.createTextNode(o);
  It.insertBefore(y, k);
  function w() {
    return It.offsetHeight <= d;
  }
  if (w())
    return {
      ellipsis: !1,
      text: o
    };
  function g(C, P = 0, z = o.length, j = 0) {
    const I = Math.floor((P + z) / 2), L = o.slice(0, I);
    if (C.textContent = L, P >= z - 1)
      for (let M = z; M >= P; M -= 1) {
        const E = o.slice(0, M);
        if (C.textContent = E, w() || !E)
          return;
      }
    w() ? g(C, I, z, I) : g(C, P, I, j);
  }
  return g(y), {
    text: y.textContent,
    ellipsis: !0
  };
};
const rz = async (e) => {
  var t;
  if ((t = navigator.clipboard) != null && t.writeText)
    try {
      await navigator.clipboard.writeText(e);
      return;
    } catch (r) {
      console.error(
        r ?? new DOMException("The request is not allowed", "NotAllowedError")
      );
    }
  const n = document.createElement("span");
  n.textContent = e, n.style.whiteSpace = "pre", document.body.appendChild(n);
  const o = window.getSelection(), i = window.document.createRange();
  o == null || o.removeAllRanges(), i.selectNode(n), o == null || o.addRange(i);
  try {
    window.document.execCommand("copy");
  } catch (r) {
    console.error(`execCommand Error: ${r}`);
  }
  o == null || o.removeAllRanges(), window.document.body.removeChild(n);
};
let Al;
function az(e) {
  if (!e)
    return "";
  Al || (Al = document.createElement("div"), Al.setAttribute("aria-hidden", "true"), document.body.appendChild(Al));
  const t = qp({
    render() {
      return c("div", null, [e]);
    }
  });
  t.mount(Al);
  const n = Al.innerText;
  return t.unmount(), n;
}
function j2(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
function sz(e) {
  const {
    bold: t,
    mark: n,
    underline: o,
    delete: i,
    code: r
  } = e, l = [];
  return t && l.push("b"), o && l.push("u"), i && l.push("del"), r && l.push("code"), n && l.push("mark"), l;
}
function Ap(e, t) {
  const {
    mark: n
  } = e, o = sz(e), i = Qe(n) && n.color ? {
    backgroundColor: n.color
  } : {};
  return o.reduce((r, l) => c(l, l === "mark" ? {
    style: i
  } : {}, j2(r) ? r : {
    default: () => [r]
  }), t);
}
function uz(e) {
  const t = !!e.showTooltip, n = Qe(e.showTooltip) && e.showTooltip.type === "popover" ? Av : yn, o = Qe(e.showTooltip) && e.showTooltip.props || {};
  return {
    rows: 1,
    suffix: "",
    ellipsisStr: "...",
    expandable: !1,
    css: !1,
    ...Ft(e, ["showTooltip"]),
    showTooltip: t,
    TooltipComponent: n,
    tooltipProps: o
  };
}
var f0 = S({
  name: "TypographyBase",
  inheritAttrs: !1,
  props: {
    component: {
      type: String,
      required: !0
    },
    type: {
      type: String
    },
    bold: {
      type: Boolean
    },
    mark: {
      type: [Boolean, Object],
      default: !1
    },
    underline: {
      type: Boolean
    },
    delete: {
      type: Boolean
    },
    code: {
      type: Boolean
    },
    disabled: {
      type: Boolean
    },
    editable: {
      type: Boolean
    },
    editing: {
      type: Boolean,
      default: void 0
    },
    defaultEditing: {
      type: Boolean
    },
    editText: {
      type: String
    },
    copyable: {
      type: Boolean
    },
    copyText: {
      type: String
    },
    copyDelay: {
      type: Number,
      default: 3e3
    },
    ellipsis: {
      type: [Boolean, Object],
      default: !1
    },
    editTooltipProps: {
      type: Object
    },
    copyTooltipProps: {
      type: Object
    }
  },
  emits: {
    editStart: () => !0,
    change: (e) => !0,
    "update:editText": (e) => !0,
    editEnd: () => !0,
    "update:editing": (e) => !0,
    copy: (e) => !0,
    ellipsis: (e) => !0,
    expand: (e) => !0
  },
  setup(e, {
    slots: t,
    emit: n,
    attrs: o
  }) {
    const {
      editing: i,
      defaultEditing: r,
      ellipsis: l,
      copyable: s,
      editable: u,
      copyText: f,
      editText: d,
      copyDelay: p,
      component: h
    } = ve(e), k = B("typography"), y = a(() => [k, {
      [`${k}-${e.type}`]: e.type,
      [`${k}-disabled`]: e.disabled
    }]), w = V(), g = V(""), [C, P] = Vt(r.value, me({
      value: i
    })), z = a(() => u.value && C.value);
    function j() {
      n("update:editing", !0), n("editStart"), P(!0);
    }
    function I(Q) {
      n("update:editText", Q), n("change", Q);
    }
    function L() {
      C.value && (n("update:editing", !1), n("editEnd"), P(!1));
    }
    const M = V(!1);
    let E = null;
    function K() {
      var Q;
      const ae = (Q = f.value) != null ? Q : g.value;
      rz(ae || ""), M.value = !0, n("copy", ae), E = setTimeout(() => {
        M.value = !1;
      }, p.value);
    }
    Zt(() => {
      E && clearTimeout(E), E = null;
    });
    const q = V(!1), T = V(!1), X = V(""), Y = a(() => uz(Qe(l.value) && l.value || {}));
    let Z = null;
    function U() {
      const Q = !T.value;
      T.value = Q, n("expand", Q);
    }
    function H(Q = !1) {
      return Y.value.css ? c(Tp, {
        editable: u.value,
        copyable: s.value,
        expandable: Y.value.expandable,
        isCopied: M.value,
        isEllipsis: G.value,
        expanded: T.value,
        forceRenderExpand: Q || T.value,
        editTooltipProps: e.editTooltipProps,
        copyTooltipProps: e.copyTooltipProps,
        onEdit: j,
        onCopy: K,
        onExpand: U
      }, {
        "copy-tooltip": t["copy-tooltip"],
        "copy-icon": t["copy-icon"],
        "expand-node": t["expand-node"]
      }) : c(Tp, {
        editable: u.value,
        copyable: s.value,
        expandable: Y.value.expandable,
        isCopied: M.value,
        isEllipsis: q.value,
        expanded: T.value,
        forceRenderExpand: Q,
        editTooltipProps: e.editTooltipProps,
        copyTooltipProps: e.copyTooltipProps,
        onEdit: j,
        onCopy: K,
        onExpand: U
      }, {
        "copy-tooltip": t["copy-tooltip"],
        "copy-icon": t["copy-icon"],
        "expand-node": t["expand-node"]
      });
    }
    function D() {
      if (!w.value)
        return;
      const {
        ellipsis: Q,
        text: ae
      } = iz(w.value, Y.value, H(!!Y.value.expandable), g.value);
      q.value !== Q && (q.value = Q, Y.value.css || n("ellipsis", Q)), X.value !== ae && (X.value = ae || "");
    }
    function R() {
      l.value && !T.value && (sr(Z), Z = lm(() => {
        D();
      }));
    }
    Zt(() => {
      sr(Z);
    }), ze(() => Y.value.rows, () => {
      R();
    }), ze(l, (Q) => {
      Q ? R() : q.value = !1;
    });
    let W = [];
    const O = () => {
      if (l.value || s.value || u.value) {
        const Q = az(W);
        Q !== g.value && (g.value = Q, R());
      }
    };
    Je(O), fn(O);
    const x = V(), G = V(!1), ne = () => {
      if (w.value && x.value) {
        const Q = x.value.offsetHeight > w.value.offsetHeight;
        Q !== G.value && (G.value = Q, n("ellipsis", Q));
      }
    }, ee = a(() => T.value ? {} : {
      overflow: "hidden",
      "text-overflow": "ellipsis",
      display: "-webkit-box",
      "-webkit-line-clamp": Y.value.rows,
      "-webkit-box-orient": "vertical"
    });
    return () => {
      var Q, ae;
      if (W = ((Q = t.default) == null ? void 0 : Q.call(t)) || [], z.value) {
        const fe = (ae = d.value) != null ? ae : g.value;
        return c(G9, {
          text: fe,
          onChange: (Oe) => {
            Oe !== fe && I(Oe);
          },
          onEnd: L
        }, null);
      }
      const {
        suffix: ge,
        ellipsisStr: Se,
        showTooltip: be,
        tooltipProps: Le,
        TooltipComponent: pe
      } = Y.value, Me = q.value && !T.value, ke = Me && !be ? {
        title: g.value
      } : {}, le = h.value;
      if (Y.value.css) {
        const fe = Ap(e, W), Oe = c(le, se({
          class: y.value,
          ref: w,
          style: ee.value
        }, ke, o), {
          default: () => [c("span", {
            ref: x
          }, [fe])]
        });
        return G.value ? c(pe, se(Le, {
          onResize: () => ne()
        }), {
          default: () => [Oe],
          content: () => g.value
        }) : c(jn, {
          onResize: () => {
            ne();
          }
        }, j2(Oe) ? Oe : {
          default: () => [Oe]
        });
      }
      const re = Ap(e, Me ? X.value : W);
      return c(jn, {
        onResize: () => R()
      }, {
        default: () => [c(le, se({
          class: y.value,
          ref: w
        }, ke, o), {
          default: () => [Me && be ? c(pe, Le, {
            default: () => [c("span", null, [re])],
            content: () => g.value
          }) : re, Me ? Se : null, ge, H()]
        })]
      });
    };
  }
}), nr = S({
  name: "TypographyParagraph",
  inheritAttrs: !1,
  props: {
    blockquote: {
      type: Boolean
    },
    spacing: {
      type: String,
      default: "default"
    }
  },
  setup(e) {
    const {
      blockquote: t,
      spacing: n
    } = ve(e), o = B("typography"), i = a(() => t != null && t.value ? "blockquote" : "div"), r = a(() => [{
      [`${o}-spacing-close`]: (n == null ? void 0 : n.value) === "close"
    }]);
    return {
      component: i,
      classNames: r
    };
  },
  render() {
    const {
      component: e,
      classNames: t
    } = this;
    return c(f0, se({
      class: t
    }, this.$attrs, {
      component: e
    }), this.$slots);
  }
}), lr = S({
  name: "TypographyTitle",
  inheritAttrs: !1,
  props: {
    heading: {
      type: Number,
      default: 1
    }
  },
  setup(e) {
    const {
      heading: t
    } = ve(e);
    return {
      component: a(() => `h${t == null ? void 0 : t.value}`)
    };
  },
  render() {
    const {
      component: e
    } = this;
    return c(f0, se(this.$attrs, {
      component: e
    }), this.$slots);
  }
}), or = S({
  name: "TypographyText",
  inheritAttrs: !1,
  props: {
    ellipsis: {
      type: [Boolean, Object],
      default: !1
    }
  },
  setup(e) {
    const {
      ellipsis: t
    } = ve(e);
    return {
      component: a(() => t != null && t.value ? "div" : "span")
    };
  },
  render() {
    const {
      ellipsis: e,
      component: t
    } = this;
    return c(f0, se(this.$attrs, {
      ellipsis: e,
      component: t
    }), this.$slots);
  }
});
const cz = Object.assign(yu, {
  Paragraph: nr,
  Title: lr,
  Text: or,
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + yu.name, yu), e.component(
      n + nr.name,
      nr
    ), e.component(n + lr.name, lr), e.component(n + or.name, or);
  }
}), Ep = (e) => {
  const t = e.responseText || e.response;
  if (!t)
    return;
  const n = e.getResponseHeader("Content-Type");
  if (n && n.includes("json"))
    try {
      return JSON.parse(t);
    } catch {
      return t;
    }
  return t;
}, dz = (e) => {
  switch (e) {
    case "done":
      return "success";
    case "error":
      return "danger";
    default:
      return "normal";
  }
}, Wp = (e, t) => Ne(e) ? e(t) : e, fz = ({
  fileItem: e,
  action: t,
  name: n,
  data: o,
  headers: i = {},
  withCredentials: r = !1,
  onProgress: l = Dl,
  onSuccess: s = Dl,
  onError: u = Dl
}) => {
  const f = Wp(n, e) || "file", d = Wp(o, e), p = new XMLHttpRequest();
  r && (p.withCredentials = !0), p.upload.onprogress = (k) => {
    const y = k.total > 0 ? ln.round(k.loaded / k.total, 2) : 0;
    l(y, k);
  }, p.onerror = function(y) {
    u(y);
  }, p.onload = () => {
    if (p.status < 200 || p.status >= 300) {
      u(Ep(p));
      return;
    }
    s(Ep(p));
  };
  const h = new FormData();
  if (d)
    for (const k of Object.keys(d))
      h.append(k, d[k]);
  e.file && h.append(f, e.file), p.open("post", t ?? "", !0);
  for (const k of Object.keys(i))
    p.setRequestHeader(k, i[k]);
  return p.send(h), {
    abort() {
      p.abort();
    }
  };
}, P2 = (e, t) => {
  if (t && e) {
    const n = He(t) ? t : t.split(",").map((i) => i.trim()).filter((i) => i), o = (e.name.indexOf(".") > -1 ? `.${e.name.split(".").pop()}` : "").toLowerCase();
    return n.some((i) => {
      const r = i && i.toLowerCase(), l = (e.type || "").toLowerCase(), s = l.split("/")[0];
      if (r === l || `${s}${o.replace(".", "/")}` === r || /^\*(\/\*)?$/.test(r))
        return !0;
      if (/\/\*/.test(r))
        return l.replace(/\/.*$/, "") === r.replace(/\/.*$/, "");
      if (/\..*/.test(r)) {
        let u = [r];
        return (r === ".jpg" || r === ".jpeg") && (u = [".jpg", ".jpeg"]), u.indexOf(o) > -1;
      }
      return !1;
    });
  }
  return !!e;
}, vz = (e, t, n) => {
  const o = [];
  let i = 0;
  const r = () => {
    !i && n(o);
  }, l = (s) => {
    if (i += 1, s != null && s.isFile) {
      s.file((u) => {
        i -= 1, P2(u, t) && (Object.defineProperty(u, "webkitRelativePath", {
          value: s.fullPath.replace(/^\//, "")
        }), o.push(u)), r();
      });
      return;
    }
    if (s != null && s.isDirectory) {
      const u = s.createReader();
      let f = !1;
      const d = () => {
        u.readEntries((p) => {
          f || (i -= 1, f = !0), p.length === 0 ? r() : (d(), p.forEach(l));
        });
      };
      d();
      return;
    }
    i -= 1, r();
  };
  [].slice.call(e).forEach(
    (s) => s.webkitGetAsEntry && l(s.webkitGetAsEntry())
  );
}, pz = (e) => {
  var t;
  return (t = e.type) == null ? void 0 : t.includes("image");
}, wu = (e, t) => {
  if (!e)
    return [];
  const n = Array.from(e);
  return t ? n.filter((o) => P2(o, t)) : n;
}, mz = S({
  name: "IconUpload",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-upload`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), hz = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function kz(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M14.93 17.071 24.001 8l9.071 9.071m-9.07 16.071v-25M40 35v6H8v-6" }, null, -1)
  ]), 14, hz);
}
var Su = /* @__PURE__ */ N(mz, [["render", kz]]);
const Qr = Object.assign(Su, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Su.name, Su);
  }
});
var gz = S({
  name: "UploadButton",
  props: {
    disabled: {
      type: Boolean,
      default: !1
    },
    directory: {
      type: Boolean,
      default: !1
    },
    accept: String,
    listType: {
      type: String
    },
    tip: String,
    draggable: {
      type: Boolean,
      default: !1
    },
    multiple: {
      type: Boolean,
      default: !1
    },
    uploadFiles: {
      type: Function,
      required: !0
    },
    hide: Boolean,
    onButtonClick: {
      type: Function
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("upload"), {
      t: o
    } = gt(), i = V(!1), r = V(null), l = V(null), s = V(0), u = (g) => {
      g === "subtract" ? s.value -= 1 : g === "add" ? s.value += 1 : g === "reset" && (s.value = 0);
    }, f = (g) => {
      if (!e.disabled) {
        if (Ne(e.onButtonClick)) {
          const C = e.onButtonClick(g);
          if ($l(C)) {
            C.then((P) => {
              e.uploadFiles(wu(P));
            });
            return;
          }
        }
        r.value && r.value.click();
      }
    }, d = (g) => {
      const C = g.target;
      C.files && e.uploadFiles(wu(C.files)), C.value = "";
    }, p = (g) => {
      var C, P;
      if (g.preventDefault(), i.value = !1, u("reset"), !e.disabled)
        if (e.directory && ((C = g.dataTransfer) != null && C.items))
          vz(g.dataTransfer.items, e.accept, (z) => {
            e.uploadFiles(z);
          });
        else {
          const z = wu((P = g.dataTransfer) == null ? void 0 : P.files, e.accept);
          e.uploadFiles(e.multiple ? z : z.slice(0, 1));
        }
    }, h = (g) => {
      g.preventDefault(), u("subtract"), s.value === 0 && (i.value = !1, u("reset"));
    }, k = (g) => {
      g.preventDefault(), !e.disabled && !i.value && (i.value = !0);
    }, y = () => t.default ? c("span", null, [t.default()]) : e.listType === "picture-card" ? c("div", {
      class: `${n}-picture-card`
    }, [c("div", {
      class: `${n}-picture-card-text`
    }, [c(zl, null, null)]), e.tip && c("div", {
      class: `${n}-tip`
    }, [e.tip])]) : e.draggable ? c("div", {
      class: [`${n}-drag`, {
        [`${n}-drag-active`]: i.value
      }]
    }, [c("div", null, [c(zl, null, null)]), c("div", {
      class: `${n}-drag-text`
    }, [i.value ? o("upload.dragHover") : o("upload.drag")]), e.tip && c("div", {
      class: `${n}-tip`
    }, [e.tip])]) : c(Qt, {
      type: "primary",
      disabled: e.disabled
    }, {
      default: () => [o("upload.buttonText")],
      icon: () => c(Qr, null, null)
    }), w = a(() => [n, {
      [`${n}-type-picture-card`]: e.listType === "picture-card",
      [`${n}-draggable`]: e.draggable,
      [`${n}-disabled`]: e.disabled,
      [`${n}-hide`]: e.hide
    }]);
    return () => c("span", {
      ref: l,
      class: w.value,
      onClick: f,
      onDragenter: () => {
        u("add");
      },
      onDrop: p,
      onDragover: k,
      onDragleave: h
    }, [c("input", se({
      ref: r,
      type: "file",
      style: {
        display: "none"
      },
      disabled: e.disabled,
      accept: e.accept,
      multiple: e.multiple
    }, e.directory ? {
      webkitdirectory: "webkitdirectory"
    } : {}, {
      onChange: d
    }), null), y()]);
  }
});
const yz = S({
  name: "IconPause",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-pause`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), bz = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Cz(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M14 12h4v24h-4zM30 12h4v24h-4z" }, null, -1),
    $("path", {
      fill: "currentColor",
      stroke: "none",
      d: "M14 12h4v24h-4zM30 12h4v24h-4z"
    }, null, -1)
  ]), 14, bz);
}
var zu = /* @__PURE__ */ N(yz, [["render", Cz]]);
const I2 = Object.assign(zu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + zu.name, zu);
  }
}), $z = S({
  name: "IconPlayArrowFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-play-arrow-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), wz = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Sz(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M17.533 10.974a1 1 0 0 0-1.537.844v24.356a1 1 0 0 0 1.537.844L36.67 24.84a1 1 0 0 0 0-1.688L17.533 10.974Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, wz);
}
var Lu = /* @__PURE__ */ N($z, [["render", Sz]]);
const B2 = Object.assign(Lu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Lu.name, Lu);
  }
}), _r = Symbol("ArcoUpload");
var M2 = S({
  name: "UploadProgress",
  props: {
    file: {
      type: Object,
      required: !0
    },
    listType: {
      type: String,
      required: !0
    }
  },
  setup(e) {
    const t = B("upload-progress"), {
      t: n
    } = gt(), o = Ge(_r, void 0), i = () => {
      var l, s, u, f, d, p, h, k, y, w, g;
      return e.file.status === "error" ? c("span", {
        class: [o == null ? void 0 : o.iconCls, `${o == null ? void 0 : o.iconCls}-upload`],
        onClick: () => o == null ? void 0 : o.onUpload(e.file)
      }, [o != null && o.showRetryButton && ((d = (s = o == null ? void 0 : (l = o.slots)["retry-icon"]) == null ? void 0 : s.call(l)) != null ? d : (f = (u = o == null ? void 0 : o.customIcon) == null ? void 0 : u.retryIcon) != null && f.call(u)) || e.listType === "picture-card" ? c(Qr, null, null) : n("upload.retry")]) : e.file.status === "done" ? c("span", {
        class: [o == null ? void 0 : o.iconCls, `${o == null ? void 0 : o.iconCls}-success`]
      }, [(g = (w = (h = o == null ? void 0 : (p = o.slots)["success-icon"]) == null ? void 0 : h.call(p)) != null ? w : (y = (k = o == null ? void 0 : o.customIcon) == null ? void 0 : k.successIcon) == null ? void 0 : y.call(k)) != null ? g : c(Wo, null, null)]) : e.file.status === "init" ? c(yn, {
        content: n("upload.start")
      }, {
        default: () => {
          var C, P, z, j, I, L;
          return [c("span", {
            class: [o == null ? void 0 : o.iconCls, `${o == null ? void 0 : o.iconCls}-start`],
            onClick: () => o == null ? void 0 : o.onUpload(e.file)
          }, [(L = (I = (P = o == null ? void 0 : (C = o.slots)["start-icon"]) == null ? void 0 : P.call(C)) != null ? I : (j = (z = o == null ? void 0 : o.customIcon) == null ? void 0 : z.startIcon) == null ? void 0 : j.call(z)) != null ? L : c(B2, null, null)])];
        }
      }) : (o == null ? void 0 : o.showCancelButton) && c(yn, {
        content: n("upload.cancel")
      }, {
        default: () => {
          var C, P, z, j, I, L;
          return [c("span", {
            class: [o == null ? void 0 : o.iconCls, `${o == null ? void 0 : o.iconCls}-cancel`],
            onClick: () => o == null ? void 0 : o.onAbort(e.file)
          }, [(L = (I = (P = o == null ? void 0 : (C = o.slots)["cancel-icon"]) == null ? void 0 : P.call(C)) != null ? I : (j = (z = o == null ? void 0 : o.customIcon) == null ? void 0 : z.cancelIcon) == null ? void 0 : j.call(z)) != null ? L : c(I2, null, null)])];
        }
      });
    }, r = () => {
      var l;
      if (["init", "uploading"].includes((l = e.file.status) != null ? l : "")) {
        const s = dz(e.file.status);
        return c(n2, {
          type: "circle",
          size: "mini",
          showText: !1,
          status: s,
          percent: e.file.percent
        }, null);
      }
      return null;
    };
    return () => c("span", {
      class: t
    }, [r(), i()]);
  }
});
const zz = S({
  name: "IconFilePdf",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-file-pdf`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Lz = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function jz(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M11 42h26a2 2 0 0 0 2-2V13.828a2 2 0 0 0-.586-1.414l-5.828-5.828A2 2 0 0 0 31.172 6H11a2 2 0 0 0-2 2v32a2 2 0 0 0 2 2Z" }, null, -1),
    $("path", { d: "M22.305 21.028c.874 1.939 3.506 6.265 4.903 8.055 1.747 2.237 3.494 2.685 4.368 2.237.873-.447 1.21-4.548-7.425-2.685-7.523 1.623-7.424 3.58-6.988 4.476.728 1.193 2.522 2.627 5.678-6.266C25.699 18.79 24.489 17 23.277 17c-1.409 0-2.538.805-.972 4.028Z" }, null, -1)
  ]), 14, Lz);
}
var ju = /* @__PURE__ */ N(zz, [["render", jz]]);
const N2 = Object.assign(ju, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ju.name, ju);
  }
}), Pz = S({
  name: "IconFileImage",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-file-image`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Iz = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Bz(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m26 33 5-6v6h-5Zm0 0-3-4-4 4h7Zm11 9H11a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h21l7 7v27a2 2 0 0 1-2 2ZM17 19h1v1h-1v-1Z" }, null, -1)
  ]), 14, Iz);
}
var Pu = /* @__PURE__ */ N(Pz, [["render", Bz]]);
const O2 = Object.assign(Pu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Pu.name, Pu);
  }
}), Mz = S({
  name: "IconFileVideo",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-file-video`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Nz = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Oz(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M37 42H11a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h21l7 7v27a2 2 0 0 1-2 2Z" }, null, -1),
    $("path", { d: "M22 27.796v-6l5 3-5 3Z" }, null, -1)
  ]), 14, Nz);
}
var Iu = /* @__PURE__ */ N(Mz, [["render", Oz]]);
const V2 = Object.assign(Iu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Iu.name, Iu);
  }
}), Vz = S({
  name: "IconFileAudio",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-file-audio`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Tz = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Az(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M37 42H11a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h21l7 7v27a2 2 0 0 1-2 2Z" }, null, -1),
    $("path", {
      d: "M25 30a3 3 0 1 1-6 0 3 3 0 0 1 6 0Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M25 30a3 3 0 1 1-6 0 3 3 0 0 1 6 0Zm0 0-.951-12.363a.5.5 0 0 1 .58-.532L30 18" }, null, -1)
  ]), 14, Tz);
}
var Bu = /* @__PURE__ */ N(Vz, [["render", Az]]);
const T2 = Object.assign(Bu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Bu.name, Bu);
  }
});
var Fp = S({
  name: "UploadListItem",
  props: {
    file: {
      type: Object,
      required: !0
    },
    listType: {
      type: String,
      required: !0
    }
  },
  setup(e) {
    const n = `${B("upload-list")}-item`, {
      t: o
    } = gt(), i = Ge(_r, void 0), r = () => {
      var l, s;
      let u = "";
      if (e.file.file && e.file.file.type)
        u = e.file.file.type;
      else {
        const f = (s = (l = e.file.name) == null ? void 0 : l.split(".")[1]) != null ? s : "";
        ["png", "jpg", "jpeg", "bmp", "gif", "webp"].includes(f) ? u = "image" : ["mp4", "m2v", "mkv", "m4v", "mov"].includes(f) ? u = "video" : ["mp3", "wav", "wmv", "m4a", "acc", "flac"].includes(f) && (u = "audio");
      }
      return u.includes("image") ? c(O2, null, null) : u.includes("pdf") ? c(N2, null, null) : u.includes("audio") ? c(T2, null, null) : u.includes("video") ? c(V2, null, null) : c(d0, null, null);
    };
    return () => {
      var l, s, u, f, d, p, h, k, y, w, g, C, P, z, j, I, L, M, E, K, q, T, X;
      return c("div", {
        class: [n, `${n}-${e.file.status}`]
      }, [c("div", {
        class: `${n}-content`
      }, [(i == null ? void 0 : i.listType) === "picture" && c("span", {
        class: `${n}-thumbnail`
      }, [(u = (s = i == null ? void 0 : (l = i.slots).image) == null ? void 0 : s.call(l, {
        fileItem: e.file
      })) != null ? u : c("img", se({
        src: e.file.url,
        alt: e.file.name
      }, i != null && i.imageLoading ? {
        loading: i.imageLoading
      } : void 0), null)]), c("div", {
        class: `${n}-name`
      }, [(i == null ? void 0 : i.listType) === "text" && c("span", {
        class: `${n}-file-icon`
      }, [(y = (k = (d = i == null ? void 0 : (f = i.slots)["file-icon"]) == null ? void 0 : d.call(f, {
        fileItem: e.file
      })) != null ? k : (h = (p = i == null ? void 0 : i.customIcon) == null ? void 0 : p.fileIcon) == null ? void 0 : h.call(p, e.file)) != null ? y : r()]), i != null && i.showLink && e.file.url ? c("a", se({
        class: `${n}-name-link`,
        target: "_blank",
        href: e.file.url
      }, i != null && i.download ? {
        download: e.file.name
      } : void 0), [(j = (z = (g = i == null ? void 0 : (w = i.slots)["file-name"]) == null ? void 0 : g.call(w, {
        fileItem: e.file
      })) != null ? z : (P = (C = i == null ? void 0 : i.customIcon) == null ? void 0 : C.fileName) == null ? void 0 : P.call(C, e.file)) != null ? j : e.file.name]) : c("span", {
        class: `${n}-name-text`,
        onClick: () => i == null ? void 0 : i.onPreview(e.file)
      }, [(q = (K = (L = i == null ? void 0 : (I = i.slots)["file-name"]) == null ? void 0 : L.call(I, {
        fileItem: e.file
      })) != null ? K : (E = (M = i == null ? void 0 : i.customIcon) == null ? void 0 : M.fileName) == null ? void 0 : E.call(M, e.file)) != null ? q : e.file.name]), e.file.status === "error" && c(yn, {
        content: o("upload.error")
      }, {
        default: () => {
          var Y, Z, U, H, D, R;
          return [c("span", {
            class: [i == null ? void 0 : i.iconCls, `${i == null ? void 0 : i.iconCls}-error`]
          }, [(R = (D = (Z = i == null ? void 0 : (Y = i.slots)["error-icon"]) == null ? void 0 : Z.call(Y)) != null ? D : (H = (U = i == null ? void 0 : i.customIcon) == null ? void 0 : U.errorIcon) == null ? void 0 : H.call(U)) != null ? R : c(Dn, null, null)])];
        }
      })]), c(M2, {
        file: e.file,
        listType: e.listType
      }, null)]), (i == null ? void 0 : i.showRemoveButton) && c("span", {
        class: `${n}-operation`
      }, [c(pt, {
        onClick: () => {
          var Y;
          return (Y = i == null ? void 0 : i.onRemove) == null ? void 0 : Y.call(i, e.file);
        }
      }, {
        default: () => {
          var Y, Z, U, H, D, R;
          return [c("span", {
            class: [i == null ? void 0 : i.iconCls, `${i == null ? void 0 : i.iconCls}-remove`]
          }, [(R = (D = (Z = i == null ? void 0 : (Y = i.slots)["remove-icon"]) == null ? void 0 : Z.call(Y)) != null ? D : (H = (U = i == null ? void 0 : i.customIcon) == null ? void 0 : U.removeIcon) == null ? void 0 : H.call(U)) != null ? R : c(Gr, null, null)])];
        }
      })]), (X = i == null ? void 0 : (T = i.slots)["extra-button"]) == null ? void 0 : X.call(T, {
        fileItem: e.file
      })]);
    };
  }
}), Dp = S({
  name: "UploadPictureItem",
  props: {
    file: {
      type: Object,
      required: !0
    },
    disabled: {
      type: Boolean,
      default: !1
    }
  },
  setup(e) {
    const n = `${B("upload-list")}-picture`, o = a(() => [n, {
      [`${n}-status-error`]: e.file.status === "error"
    }]), i = Ge(_r, void 0), r = () => {
      var l, s, u, f, d, p, h, k, y, w, g, C, P, z, j, I, L, M, E, K, q, T, X, Y, Z, U, H, D, R;
      return e.file.status === "uploading" ? c(M2, {
        file: e.file,
        listType: "picture-card"
      }, null) : c(Ae, null, [(u = (s = i == null ? void 0 : (l = i.slots).image) == null ? void 0 : s.call(l, {
        fileItem: e.file
      })) != null ? u : c("img", se({
        src: e.file.url,
        alt: e.file.name
      }, i != null && i.imageLoading ? {
        loading: i.imageLoading
      } : void 0), null), c("div", {
        class: `${n}-mask`
      }, [e.file.status === "error" && (i == null ? void 0 : i.showCancelButton) && c("div", {
        class: `${n}-error-tip`
      }, [c("span", {
        class: [i == null ? void 0 : i.iconCls, `${i == null ? void 0 : i.iconCls}-error`]
      }, [(y = (k = (d = i == null ? void 0 : (f = i.slots)["error-icon"]) == null ? void 0 : d.call(f)) != null ? k : (h = (p = i == null ? void 0 : i.customIcon) == null ? void 0 : p.errorIcon) == null ? void 0 : h.call(p)) != null ? y : c(Or, null, null)])]), c("div", {
        class: `${n}-operation`
      }, [e.file.status !== "error" && (i == null ? void 0 : i.showPreviewButton) && c("span", {
        class: [i == null ? void 0 : i.iconCls, `${i == null ? void 0 : i.iconCls}-preview`],
        onClick: () => i == null ? void 0 : i.onPreview(e.file)
      }, [(j = (z = (g = i == null ? void 0 : (w = i.slots)["preview-icon"]) == null ? void 0 : g.call(w)) != null ? z : (P = (C = i == null ? void 0 : i.customIcon) == null ? void 0 : C.previewIcon) == null ? void 0 : P.call(C)) != null ? j : c(Bv, null, null)]), ["init", "error"].includes(e.file.status) && (i == null ? void 0 : i.showRetryButton) && c("span", {
        class: [i == null ? void 0 : i.iconCls, `${i == null ? void 0 : i.iconCls}-upload`],
        onClick: () => i == null ? void 0 : i.onUpload(e.file)
      }, [(q = (K = (L = i == null ? void 0 : (I = i.slots)["retry-icon"]) == null ? void 0 : L.call(I)) != null ? K : (E = (M = i == null ? void 0 : i.customIcon) == null ? void 0 : M.retryIcon) == null ? void 0 : E.call(M)) != null ? q : c(Qr, null, null)]), !(i != null && i.disabled) && (i == null ? void 0 : i.showRemoveButton) && c("span", {
        class: [i == null ? void 0 : i.iconCls, `${i == null ? void 0 : i.iconCls}-remove`],
        onClick: () => i == null ? void 0 : i.onRemove(e.file)
      }, [(H = (U = (X = i == null ? void 0 : (T = i.slots)["remove-icon"]) == null ? void 0 : X.call(T)) != null ? U : (Z = (Y = i == null ? void 0 : i.customIcon) == null ? void 0 : Y.removeIcon) == null ? void 0 : Z.call(Y)) != null ? H : c(Gr, null, null)]), (R = i == null ? void 0 : (D = i.slots)["extra-button"]) == null ? void 0 : R.call(D, e.file)])])]);
    };
    return () => c("span", {
      class: o.value
    }, [r()]);
  }
}), Ez = S({
  name: "UploadList",
  components: {
    UploadListItem: Fp,
    UploadPictureItem: Dp
  },
  props: {
    fileList: {
      type: Array,
      required: !0
    },
    listType: {
      type: String,
      required: !0
    }
  },
  setup(e, {
    slots: t
  }) {
    const n = B("upload"), o = a(() => [`${n}-list`, `${n}-list-type-${e.listType}`]), i = (r, l) => Ne(t["upload-item"]) ? t["upload-item"]({
      fileItem: r,
      index: l
    }) : e.listType === "picture-card" ? c(Dp, {
      file: r,
      key: `item-${l}`
    }, null) : c(Fp, {
      file: r,
      listType: e.listType,
      key: `item-${l}`
    }, null);
    return () => c(jo, {
      tag: "div",
      class: o.value
    }, {
      default: () => {
        var r;
        return [...e.fileList.map((l, s) => i(l, s)), e.listType === "picture-card" && ((r = t["upload-button"]) == null ? void 0 : r.call(t))];
      }
    });
  }
}), Mu = S({
  name: "Upload",
  props: {
    fileList: {
      type: Array,
      default: void 0
    },
    defaultFileList: {
      type: Array,
      default: () => []
    },
    accept: String,
    action: String,
    disabled: {
      type: Boolean,
      default: !1
    },
    multiple: {
      type: Boolean,
      default: !1
    },
    directory: {
      type: Boolean,
      default: !1
    },
    draggable: {
      type: Boolean,
      default: !1
    },
    tip: String,
    headers: {
      type: Object
    },
    data: {
      type: [Object, Function]
    },
    name: {
      type: [String, Function]
    },
    withCredentials: {
      type: Boolean,
      default: !1
    },
    customRequest: {
      type: Function
    },
    limit: {
      type: Number,
      default: 0
    },
    autoUpload: {
      type: Boolean,
      default: !0
    },
    showFileList: {
      type: Boolean,
      default: !0
    },
    showRemoveButton: {
      type: Boolean,
      default: !0
    },
    showRetryButton: {
      type: Boolean,
      default: !0
    },
    showCancelButton: {
      type: Boolean,
      default: !0
    },
    showUploadButton: {
      type: [Boolean, Object],
      default: !0
    },
    showPreviewButton: {
      type: Boolean,
      default: !0
    },
    download: {
      type: Boolean,
      default: !1
    },
    showLink: {
      type: Boolean,
      default: !0
    },
    imageLoading: {
      type: String
    },
    listType: {
      type: String,
      default: "text"
    },
    responseUrlKey: {
      type: [String, Function]
    },
    customIcon: {
      type: Object
    },
    imagePreview: {
      type: Boolean,
      default: !1
    },
    onBeforeUpload: {
      type: Function
    },
    onBeforeRemove: {
      type: Function
    },
    onButtonClick: {
      type: Function
    }
  },
  emits: {
    "update:fileList": (e) => !0,
    exceedLimit: (e, t) => !0,
    change: (e, t) => !0,
    progress: (e, t) => !0,
    preview: (e) => !0,
    success: (e) => !0,
    error: (e) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const {
      fileList: o,
      disabled: i,
      listType: r,
      customIcon: l,
      showRetryButton: s,
      showCancelButton: u,
      showRemoveButton: f,
      showPreviewButton: d,
      imageLoading: p,
      download: h,
      showLink: k
    } = ve(e), y = B("upload"), {
      mergedDisabled: w,
      eventHandlers: g
    } = mt({
      disabled: i
    }), C = V([]), P = /* @__PURE__ */ new Map(), z = /* @__PURE__ */ new Map(), j = a(() => e.limit > 0 && C.value.length >= e.limit), I = (ee) => {
      P.clear();
      const Q = ee == null ? void 0 : ee.map((ae, ge) => {
        var Se, be, Le;
        const pe = (Se = ae.status) != null ? Se : "done", Me = me({
          ...ae,
          uid: (be = ae.uid) != null ? be : `${Date.now()}${ge}`,
          status: pe,
          percent: (Le = ae.percent) != null ? Le : ["error", "init"].indexOf(pe) > -1 ? 0 : 1
        });
        return P.set(Me.uid, Me), Me;
      });
      C.value = Q ?? [];
    };
    I(e.defaultFileList), ze(o, (ee) => {
      ee && I(ee);
    }, {
      immediate: !0,
      deep: !0
    });
    const L = (ee) => {
      var Q, ae;
      t("update:fileList", C.value), t("change", C.value, ee), (ae = (Q = g.value) == null ? void 0 : Q.onChange) == null || ae.call(Q);
    }, M = (ee, Q) => {
      for (const ae of C.value)
        if (ae.uid === ee) {
          ae.file = Q, L(ae);
          break;
        }
    }, E = (ee) => {
      const Q = (Le, pe) => {
        const Me = P.get(ee.uid);
        Me && (Me.status = "uploading", Me.percent = Le, t("progress", Me, pe), L(Me));
      }, ae = (Le) => {
        const pe = P.get(ee.uid);
        pe && (pe.status = "done", pe.percent = 1, pe.response = Le, e.responseUrlKey && (Ne(e.responseUrlKey) ? pe.url = e.responseUrlKey(pe) : Le[e.responseUrlKey] && (pe.url = Le[e.responseUrlKey])), z.delete(pe.uid), t("success", pe), L(pe));
      }, ge = (Le) => {
        const pe = P.get(ee.uid);
        pe && (pe.status = "error", pe.percent = 0, pe.response = Le, z.delete(pe.uid), t("error", pe), L(pe));
      }, Se = {
        fileItem: ee,
        action: e.action,
        name: e.name,
        data: e.data,
        headers: e.headers,
        withCredentials: e.withCredentials,
        onProgress: Q,
        onSuccess: ae,
        onError: ge
      };
      ee.status = "uploading", ee.percent = 0;
      const be = Ne(e.customRequest) ? e.customRequest(Se) : fz(Se);
      z.set(ee.uid, be), L(ee);
    }, K = (ee) => {
      var Q;
      const ae = z.get(ee.uid);
      if (ae) {
        (Q = ae.abort) == null || Q.call(ae), z.delete(ee.uid);
        const ge = P.get(ee.uid);
        ge && (ge.status = "error", ge.percent = 0, L(ge));
      }
    }, q = (ee) => {
      if (ee) {
        const Q = P.get(ee.uid);
        Q && E(Q);
      } else
        for (const Q of C.value)
          Q.status === "init" && E(Q);
    }, T = async (ee, Q) => {
      const ae = `${Date.now()}-${Q}`, ge = pz(ee) ? URL.createObjectURL(ee) : void 0, Se = me({
        uid: ae,
        file: ee,
        url: ge,
        name: ee.name,
        status: "init",
        percent: 0
      });
      P.set(ae, Se), C.value = [...C.value, Se], L(Se), e.autoUpload && E(Se);
    }, X = (ee) => {
      if (e.limit > 0 && C.value.length + ee.length > e.limit) {
        t("exceedLimit", C.value, ee);
        return;
      }
      for (let Q = 0; Q < ee.length; Q++) {
        const ae = ee[Q];
        Ne(e.onBeforeUpload) ? Promise.resolve(e.onBeforeUpload(ae)).then((ge) => {
          ge && T(Xt(ge) ? ae : ge, Q);
        }).catch((ge) => {
          console.error(ge);
        }) : T(ae, Q);
      }
    }, Y = (ee) => {
      C.value = C.value.filter((Q) => Q.uid !== ee.uid), L(ee);
    }, Z = (ee) => {
      Ne(e.onBeforeRemove) ? Promise.resolve(e.onBeforeRemove(ee)).then((Q) => {
        Q && Y(ee);
      }).catch((Q) => {
        console.error(Q);
      }) : Y(ee);
    }, U = (ee) => {
      if (e.imagePreview && ee.url) {
        const Q = G.value.indexOf(ee.url);
        Q > -1 && (W.value = Q, R.value = !0);
      }
      t("preview", ee);
    };
    it(_r, me({
      disabled: w,
      listType: r,
      iconCls: `${y}-icon`,
      showRemoveButton: f,
      showRetryButton: s,
      showCancelButton: u,
      showPreviewButton: d,
      showLink: k,
      imageLoading: p,
      download: h,
      customIcon: l,
      slots: n,
      onUpload: E,
      onAbort: K,
      onRemove: Z,
      onPreview: U
    }));
    const H = a(() => {
      if (e.accept)
        return e.accept;
      if (e.listType === "picture" || e.listType === "picture-card")
        return "image/*";
    }), D = () => {
      const ee = c(gz, {
        key: "arco-upload-button",
        disabled: w.value,
        draggable: e.draggable,
        listType: e.listType,
        uploadFiles: X,
        multiple: e.multiple,
        directory: e.directory,
        tip: e.tip,
        hide: !e.showUploadButton || j.value && !(Qe(e.showUploadButton) && e.showUploadButton.showOnExceedLimit),
        accept: H.value,
        onButtonClick: e.onButtonClick
      }, {
        default: n["upload-button"]
      });
      return e.tip && e.listType !== "picture-card" && !e.draggable ? c("span", null, [ee, c("div", {
        class: `${y}-tip`
      }, [e.tip])]) : ee;
    }, R = V(!1), W = V(0), O = (ee) => {
      W.value = ee;
    }, x = (ee) => {
      R.value = ee;
    }, G = a(() => C.value.filter((ee) => !!ee.url).map((ee) => ee.url));
    return {
      prefixCls: y,
      render: () => e.showFileList ? c("div", {
        class: [`${y}-wrapper`, `${y}-wrapper-type-${e.listType}`]
      }, [e.imagePreview && G.value.length > 0 && c(ko, {
        srcList: G.value,
        visible: R.value,
        current: W.value,
        onChange: O,
        onVisibleChange: x
      }, null), e.listType !== "picture-card" && e.showUploadButton && D(), c(Ez, {
        fileList: C.value,
        listType: e.listType
      }, {
        "upload-button": D,
        "upload-item": n["upload-item"]
      })]) : e.showUploadButton && D(),
      innerSubmit: q,
      innerAbort: K,
      innerUpdateFile: M,
      innerUpload: X
    };
  },
  methods: {
    submit(e) {
      return this.innerSubmit(e);
    },
    abort(e) {
      return this.innerAbort(e);
    },
    updateFile(e, t) {
      return this.innerUpdateFile(e, t);
    },
    upload(e) {
      return this.innerUpload(e);
    }
  },
  render() {
    return this.render();
  }
});
const Wz = Object.assign(Mu, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Mu.name, Mu);
  }
});
var Nu = S({
  name: "OverflowList",
  props: {
    min: {
      type: Number,
      default: 0
    },
    margin: {
      type: Number,
      default: 8
    },
    from: {
      type: String,
      default: "end"
    }
  },
  emits: {
    change: (e) => !0
  },
  setup(e, {
    emit: t,
    slots: n
  }) {
    const o = B("overflow-list"), i = V(), r = V(), l = V(), s = {}, u = [], f = V(0), d = V(0), p = a(() => d.value > 0), h = V(0), k = a(() => e.from === "start");
    ze(f, (g, C) => {
      d.value > 0 && (d.value += g - C, d.value < 0 && (d.value = 0));
    }), ze(d, (g) => {
      t("change", g);
    });
    const y = () => {
      var g, C, P;
      if (i.value && s.value && l.value) {
        const z = l.value.offsetWidth;
        if (z > 1 && (d.value === 0 || z < h.value))
          return;
        for (let M = 0; M < s.value.length; M++) {
          const E = s.value[M].el;
          E && E.offsetWidth && (u[M] = E.offsetWidth + e.margin);
        }
        let j = i.value.clientWidth - ((C = (g = r.value) == null ? void 0 : g.offsetWidth) != null ? C : 0) - (k.value ? e.margin : 0);
        const I = k.value ? pS(u) : u;
        let L = 0;
        for (let M = 0; M < I.length; M++) {
          const E = (P = I[M]) != null ? P : 0;
          if (E < j - 1)
            j -= E, L += 1;
          else {
            h.value = E;
            break;
          }
        }
        L < e.min && e.min < f.value && (L = e.min), d.value !== f.value - L && (d.value = f.value - L);
      }
    };
    ze(p, () => y(), {
      flush: "post"
    }), Je(() => {
      l.value && l.value.offsetWidth < 1 && y();
    });
    const w = () => {
      var g, C;
      const P = k.value ? {
        marginRight: `${e.margin}px`
      } : void 0;
      return c("div", {
        ref: r,
        class: `${o}-overflow`,
        style: P
      }, [(C = (g = n.overflow) == null ? void 0 : g.call(n, {
        number: d.value
      })) != null ? C : c(Fv, null, {
        default: () => [Re("+"), d.value]
      })]);
    };
    return () => {
      var g, C;
      s.value = En((g = n.default) == null ? void 0 : g.call(n)), f.value !== s.value.length && (f.value = s.value.length, u.length = f.value);
      let P = s.value;
      d.value > 0 && (P = k.value ? s.value.slice(d.value) : s.value.slice(0, -d.value));
      const z = d.value === 0 || k.value ? P.length - 1 : P.length;
      for (let j = 0; j < z; j++)
        P[j].props = se((C = P[j].props) != null ? C : {}, {
          style: {
            marginRight: `${e.margin}px`
          }
        });
      return c("div", {
        ref: i,
        class: o
      }, [k.value && d.value > 0 && w(), P, !k.value && d.value > 0 && w(), c(al, {
        onResize: y
      }, {
        default: () => [c("div", {
          ref: l,
          class: `${o}-spacer`
        }, null)]
      })]);
    };
  }
});
const Fz = Object.assign(Nu, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Nu.name, Nu);
  }
});
var Ou = S({
  name: "VerificationCode",
  props: {
    modelValue: String,
    defaultValue: {
      type: String,
      default: ""
    },
    length: {
      type: Number,
      default: 6
    },
    size: {
      type: String
    },
    disabled: Boolean,
    masked: Boolean,
    readonly: Boolean,
    error: {
      type: Boolean,
      default: !1
    },
    separator: {
      type: Function
    },
    formatter: {
      type: Function
    }
  },
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0,
    finish: (e) => !0,
    input: (e, t, n) => !0
  },
  setup(e, {
    emit: t
  }) {
    const n = B("verification-code"), o = B("input"), i = V([]), r = a(() => {
      var g;
      return (g = e.modelValue) != null ? g : e.defaultValue;
    }), l = a(() => e.masked ? "password" : "text"), s = a(() => [o, {
      [`${o}-size-${e.size}`]: e.size
    }]), u = a(() => {
      const g = String(r.value).split("");
      return new Array(e.length).fill("").map((C, P) => T0(g[P]) ? String(g[P]) : "");
    }), f = V(u.value);
    ze(r, () => {
      f.value = u.value;
    });
    const d = () => {
      const g = f.value.join("").trim();
      t("update:modelValue", g), t("change", g), g.length === e.length && t("finish", g), h();
    }, p = (g) => i == null ? void 0 : i.value[g].focus(), h = (g) => {
      if (!(T0(g) && f.value[g])) {
        for (let C = 0; C < f.value.length; C++)
          if (!f.value[C]) {
            p(C);
            break;
          }
      }
    }, k = (g, C) => {
      g.preventDefault();
      const {
        clipboardData: P
      } = g, z = P == null ? void 0 : P.getData("text");
      z && (z.split("").forEach((j, I) => {
        if (!(C + I >= e.length)) {
          if (Ne(e.formatter)) {
            const L = e.formatter(j, C + I, f.value.join(""));
            if (L === !1) {
              C -= 1;
              return;
            }
            zt(L) && (j = L.charAt(0));
          }
          f.value[C + I] = j;
        }
      }), d());
    }, y = (g, C) => {
      const P = C.code || C.key;
      P === um.code && !f.value[g] ? (C.preventDefault(), f.value[Math.max(g - 1, 0)] = "", d()) : P === Wg.code && g > 0 ? (C.preventDefault(), p(g - 1)) : P === Fg.code && f.value[g] && g < e.length - 1 && (C.preventDefault(), p(g + 1));
    }, w = (g, C, P) => {
      let z = (C || "").trim().charAt(C.length - 1);
      if (t("input", z, g, P), Ne(e.formatter)) {
        const j = e.formatter(z, g, f.value.join(""));
        if (j === !1)
          return;
        zt(j) && (z = j.charAt(0));
      }
      f.value[g] = z, d();
    };
    return () => c("div", {
      class: n
    }, [f.value.map((g, C) => {
      var P;
      return c(Ae, null, [c(cl, {
        key: C,
        ref: (z) => i.value[C] = z,
        type: l.value,
        class: s.value,
        modelValue: g,
        size: e.size,
        error: e.error,
        disabled: e.disabled,
        readonly: e.readonly,
        onFocus: () => h(C),
        onInput: (z, j) => w(C, z, j),
        onKeydown: (z) => y(C, z),
        onPaste: (z) => k(z, C)
      }, null), (P = e.separator) == null ? void 0 : P.call(e, C, g)]);
    })]);
  }
});
const Dz = Object.assign(Ou, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Ou.name, Ou);
  }
}), xz = typeof window < "u" ? window : void 0;
function Rz(e) {
  var t;
  const n = tk(e);
  return (t = n == null ? void 0 : n.$el) != null ? t : n;
}
function Hz(e) {
  return nk() ? (lk(e), !0) : !1;
}
function A2(e, t, n = {}) {
  const { window: o = xz, ...i } = n, r = o && "MutationObserver" in o;
  let l;
  const s = () => {
    l && (l.disconnect(), l = void 0);
  }, u = ze(
    () => Rz(e),
    (d) => {
      s(), r && o && d && (l = new MutationObserver(t), l.observe(d, i));
    },
    { immediate: !0 }
  ), f = () => {
    s(), u();
  };
  return Hz(f), {
    isSupported: r,
    stop: f
  };
}
const Vu = "arco-theme", ei = {
  Dark: "dark",
  Light: "light"
}, qz = (e) => {
  const t = V(ei.Light), n = (i) => {
    t.value = i;
  }, o = (i) => i.getAttribute(Vu) === ei.Dark ? ei.Dark : ei.Light;
  return A2(
    document.body,
    (i) => {
      for (const r of i)
        if (r.type === "attributes" && r.attributeName === Vu) {
          n(o(r.target)), e == null || e();
          break;
        }
    },
    {
      attributes: !0,
      attributeFilter: [Vu],
      subtree: !1,
      childList: !1,
      characterData: !1
    }
  ), n(o(document.body)), {
    theme: t,
    setTheme: n
  };
};
function Zz(e) {
  return e.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase();
}
function Kz(e) {
  return Object.entries(e).map(([t, n]) => `${Zz(t)}:${n}`).join(";");
}
function Yz(e) {
  const t = e.getContext("2d");
  if (!t)
    return;
  const n = t.getImageData(0, 0, e.width, e.height), { data: o } = n;
  for (let i = 0; i < o.length; i += 4) {
    const r = (o[i] + o[i + 1] + o[i + 2]) / 3;
    o[i] = r, o[i + 1] = r, o[i + 2] = r;
  }
  t.putImageData(n, 0, 0);
}
var Tu = S({
  name: "Watermark",
  props: {
    content: {
      type: [String, Array]
    },
    image: {
      type: String
    },
    width: {
      type: Number
    },
    height: {
      type: Number
    },
    gap: {
      type: Array,
      default: () => [90, 90]
    },
    offset: {
      type: Array
    },
    rotate: {
      type: Number,
      default: -22
    },
    font: {
      type: Object
    },
    zIndex: {
      type: Number,
      default: 6
    },
    alpha: {
      type: Number,
      default: 1
    },
    antiTamper: {
      type: Boolean,
      default: !0
    },
    grayscale: {
      type: Boolean,
      default: !1
    },
    repeat: {
      type: Boolean,
      default: !0
    },
    staggered: {
      type: Boolean,
      default: !0
    }
  },
  setup(e, {
    slots: t,
    attrs: n
  }) {
    const {
      width: o,
      height: i,
      image: r,
      rotate: l,
      alpha: s,
      repeat: u,
      grayscale: f
    } = ve(e), d = B("watermark"), p = window.devicePixelRatio || 1, h = ok(), k = V(/* @__PURE__ */ new Map()), y = a(() => {
      var W, O;
      return (O = (W = e.font) == null ? void 0 : W.fontSize) != null ? O : 16;
    }), w = a(() => {
      var W, O;
      return (O = (W = e.font) == null ? void 0 : W.fontWeight) != null ? O : "normal";
    }), g = a(() => {
      var W, O;
      return (O = (W = e.font) == null ? void 0 : W.fontStyle) != null ? O : "normal";
    }), C = a(() => {
      var W, O;
      return (O = (W = e.font) == null ? void 0 : W.fontFamily) != null ? O : "sans-serif";
    }), P = a(() => {
      var W, O;
      return (O = (W = e.font) == null ? void 0 : W.textAlign) != null ? O : "center";
    }), z = a(() => He(e.content) ? e.content : [e.content]), j = a(() => {
      var W, O;
      return (O = (W = e.font) == null ? void 0 : W.color) != null ? O : R.value === "dark" ? "rgba(255, 255, 255, 0.15)" : "rgba(0, 0, 0, 0.15)";
    }), I = a(() => {
      var W, O;
      return (O = (W = e.gap) == null ? void 0 : W[0]) != null ? O : 90;
    }), L = a(() => {
      var W, O;
      return (O = (W = e.gap) == null ? void 0 : W[1]) != null ? O : 90;
    }), M = a(() => I.value / 2), E = a(() => L.value / 2), K = a(() => {
      var W, O;
      return (O = (W = e.offset) == null ? void 0 : W[0]) != null ? O : M.value;
    }), q = a(() => {
      var W, O;
      return (O = (W = e.offset) == null ? void 0 : W[1]) != null ? O : E.value;
    }), T = a(() => {
      var W;
      const O = K.value - M.value, x = q.value - E.value;
      return {
        position: "absolute",
        left: O > 0 ? `${O}px` : 0,
        top: x > 0 ? `${x}px` : 0,
        width: O > 0 ? `calc(100% - ${O}px)` : "100%",
        height: x > 0 ? `calc(100% - ${x}px)` : "100%",
        pointerEvents: "none",
        backgroundRepeat: e.repeat ? "repeat" : "no-repeat",
        backgroundPosition: `${O > 0 ? 0 : O}px ${x > 0 ? 0 : x}px`,
        zIndex: (W = e.zIndex) != null ? W : 6
      };
    }), X = a(() => e.repeat && e.staggered), Y = (W, O) => {
      var x;
      if (h.value) {
        const G = k.value.get(h.value);
        G && (h.value.contains(G) && h.value.removeChild(G), k.value.delete(h.value));
        const ne = document.createElement("div");
        ne.setAttribute("style", Kz({
          ...T.value,
          backgroundImage: `url('${W}')`,
          backgroundSize: `${O}px`
        })), (x = h.value) == null || x.append(ne), k.value.set(h.value, ne);
      }
    }, Z = (W) => {
      var O, x;
      let G = 120, ne = 28;
      if (!r.value && W.measureText) {
        W.font = `${y.value}px ${C.value}`;
        const ee = z.value.map((Q) => W.measureText(Q).width);
        G = Math.ceil(Math.max(...ee)), ne = y.value * z.value.length + (z.value.length - 1) * 3;
      }
      return [(O = o.value) != null ? O : G, (x = i.value) != null ? x : ne];
    }, U = () => {
      var W;
      const O = document.createElement("canvas"), x = O.getContext("2d");
      if (!x)
        return;
      const [G, ne] = Z(x), ee = G * p, Q = ne * p, ae = (I.value + G) * p, ge = (L.value + ne) * p, Se = I.value / 2 * p, be = L.value / 2 * p, Le = ae / 2, pe = ge / 2, Me = X.value ? 2 : 1, ke = (I.value + G) * Me;
      O.width = ae * Me, O.height = ge * Me, x.globalAlpha = s.value, x.save(), x.translate(Le, pe), x.rotate(Math.PI / 180 * l.value), x.translate(-Le, -pe);
      const le = () => {
        x.restore(), X.value && x.drawImage(O, 0, 0, ae, ge, ae, ge, ae, ge), f.value && Yz(O), Y(O.toDataURL(), ke);
      };
      if (r.value) {
        const re = new Image();
        re.onload = () => {
          x.drawImage(re, Se, be, ee, Q), le();
        }, re.crossOrigin = "anonymous", re.referrerPolicy = "no-referrer", re.src = r.value;
      } else {
        const re = Number(y.value) * p;
        x.font = `${g.value} normal ${w.value} ${re}px/${ne}px ${C.value}`, x.fillStyle = j.value, x.textAlign = P.value, x.textBaseline = "top", x.translate(ee / 2, 0), (W = z.value) == null || W.forEach((fe, Oe) => {
          x.fillText(fe ?? "", Se, be + Oe * (re + 3 * p));
        }), le();
      }
    }, H = (W) => Array.from(k.value.values()).includes(W), D = (W) => {
      if (e.antiTamper)
        for (const O of W) {
          const x = Array.from(O.removedNodes).some((ne) => H(ne)), G = O.type === "attributes" && H(O.target);
          if (x || G) {
            U();
            break;
          }
        }
    }, {
      theme: R
    } = qz(U);
    return Je(() => {
      U(), A2(h.value, D, {
        attributes: !0,
        childList: !0,
        characterData: !0,
        subtree: !0
      });
    }), ze(e, U, {
      deep: !0,
      flush: "post"
    }), () => {
      var W;
      return c("div", se({
        ref: h,
        class: d,
        style: {
          position: "relative",
          overflow: "hidden"
        }
      }, n), [(W = t.default) == null ? void 0 : W.call(t)]);
    };
  }
});
const Uz = Object.assign(Tu, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Tu.name, Tu);
  }
});
function Gz(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !Ct(e);
}
var Xz = S({
  name: "TreeSelectPanel",
  components: {
    Tree: $v
  },
  props: {
    treeProps: {
      type: Object,
      default: () => ({})
    },
    selectedKeys: {
      type: Array
    },
    showCheckable: {
      type: Boolean
    },
    treeSlots: {
      type: Object,
      default: () => ({})
    },
    scrollbar: {
      type: [Boolean, Object],
      default: !0
    }
  },
  emits: ["change"],
  setup(e, {
    emit: t
  }) {
    const {
      showCheckable: n,
      selectedKeys: o,
      treeProps: i,
      scrollbar: r
    } = ve(e), {
      displayScrollbar: l,
      scrollbarProps: s
    } = Br(r), u = B("tree-select"), f = V(), d = a(() => ({
      ...i.value,
      disableSelectActionOnly: !0,
      checkedKeys: n.value ? o.value : [],
      selectedKeys: n.value ? [] : o.value
    })), p = (y, w) => {
      var g, C;
      n.value ? (C = (g = f.value) == null ? void 0 : g.toggleCheck) == null || C.call(g, y[0], w) : t("change", y);
    }, h = (y) => {
      t("change", y);
    }, k = () => c($v, se({
      ref: f
    }, d.value, {
      onSelect: p,
      onCheck: h
    }), e.treeSlots);
    return () => {
      if (l.value) {
        let y;
        return c(In, se({
          class: `${u}-tree-wrapper`
        }, s.value), Gz(y = k()) ? y : {
          default: () => [y]
        });
      }
      return c("div", {
        class: `${u}-tree-wrapper`
      }, [k()]);
    };
  }
});
function v0(e) {
  return Qe(e);
}
function E2(e) {
  return e != null && e !== "";
}
function p0(e) {
  return v0(e) ? e.value : e;
}
function Qz(e) {
  return v0(e) ? e.label : void 0;
}
function xp(e) {
  const t = p0(e);
  return E2(t);
}
function Rp(e) {
  return e.map(p0).filter(E2);
}
function _z(e) {
  var t;
  const {
    defaultValue: n,
    modelValue: o,
    key2TreeNode: i,
    multiple: r,
    treeCheckable: l,
    fallbackOption: s,
    fieldNames: u
  } = ve(e);
  function f(j) {
    const I = (He(j) ? j : [j]).filter(xp);
    return r != null && r.value || l != null && l.value ? I : I.slice(0, 1);
  }
  function d(j, I) {
    const L = [], M = j ? j.filter(xp) : [];
    if (M.length) {
      const E = /* @__PURE__ */ new Map();
      I == null || I.forEach((K) => {
        E.set(K.value, K);
      }), M.forEach((K) => {
        var q, T, X, Y, Z;
        const U = p0(K), H = E.get(U), D = i.value.get(U);
        let R = null;
        const W = ((q = u == null ? void 0 : u.value) == null ? void 0 : q.title) || "title";
        if (!D) {
          const O = Ne(s == null ? void 0 : s.value) ? s == null ? void 0 : s.value(U) : s == null ? void 0 : s.value;
          if (O === !1)
            return;
          Qe(O) && (R = O);
        }
        L.push({
          ...v0(K) ? K : {},
          ...H || {},
          value: U,
          label: (Z = (Y = (X = (T = Qz(K)) != null ? T : D == null ? void 0 : D.title) != null ? X : H == null ? void 0 : H.label) != null ? Y : R == null ? void 0 : R[W]) != null ? Z : U
        });
      });
    }
    return L;
  }
  const p = V(), h = V();
  Wt(() => {
    var j;
    const I = (o == null ? void 0 : o.value) !== void 0, L = f((j = o == null ? void 0 : o.value) != null ? j : []), M = Rp(L);
    h.value = I ? d(M, d(L)) : void 0, p.value = I ? M : void 0;
  });
  const k = f((t = n == null ? void 0 : n.value) != null ? t : []), y = Rp(k), w = d(
    y,
    d(k)
  ), g = V(y || []), C = V(w);
  ze(g, () => {
    C.value = d(g.value, w);
  }), ze([p, h], ([j, I]) => {
    g.value = j || [], C.value = I || [];
  });
  const P = a(
    () => {
      var j;
      return (j = p.value) != null ? j : g.value;
    }
  ), z = a(
    () => {
      var j;
      return (j = h.value) != null ? j : C.value;
    }
  );
  return {
    selectedKeys: P,
    selectedValue: z,
    setLocalSelectedKeys(j) {
      g.value = j;
    },
    localSelectedKeys: g,
    localSelectedValue: C
  };
}
function Jz(e) {
  const {
    searchValue: t,
    flattenTreeData: n,
    filterMethod: o,
    disableFilter: i,
    fieldNames: r
  } = ve(e), l = a(
    () => {
      var y;
      return ((y = r.value) == null ? void 0 : y.key) || "key";
    }
  ), s = (y, w) => {
    const g = w[l.value];
    return !Ve(g) && String(g).indexOf(y) > -1;
  }, u = a(
    () => (o == null ? void 0 : o.value) || s
  ), f = V(), d = a(() => !!t.value), p = a(
    () => !(i != null && i.value) && d.value && f.value && f.value.size === 0
  ), h = a(
    () => i != null && i.value ? void 0 : (y) => {
      var w, g;
      if (!d.value)
        return !0;
      const C = y[l.value];
      return (g = (w = f.value) == null ? void 0 : w.has(C || "")) != null ? g : !1;
    }
  ), k = So(
    (y, w) => {
      const g = y.filter(
        (P) => u.value(w, P.treeNodeData)
      ), C = /* @__PURE__ */ new Set();
      g.forEach((P) => {
        C.add(P.key), P.pathParentKeys.forEach((z) => {
          C.add(z);
        });
      }), f.value = C;
    },
    100
  );
  return Wt(() => {
    i != null && i.value ? f.value = void 0 : k(n.value, t.value);
  }), {
    isEmptyFilterResult: p,
    filterTreeNode: h
  };
}
function eL(e, t) {
  const n = `${t}-slot-`;
  return Object.keys(e).reduce(
    (i, r) => {
      if (r.startsWith(n)) {
        const l = r.slice(n.length);
        l && (i[l] = e[r]);
      }
      return i;
    },
    {}
  );
}
const tL = S({
  name: "TreeSelect",
  components: {
    Trigger: Tt,
    SelectView: dr,
    Panel: Xz,
    Empty: Gn,
    Spin: Pn
  },
  inheritAttrs: !1,
  props: {
    disabled: {
      type: Boolean
    },
    loading: {
      type: Boolean
    },
    error: {
      type: Boolean
    },
    size: {
      type: String
    },
    border: {
      type: Boolean,
      default: !0
    },
    allowSearch: {
      type: [Boolean, Object],
      default: (e) => !!e.multiple
    },
    allowClear: {
      type: Boolean
    },
    placeholder: {
      type: String
    },
    maxTagCount: {
      type: Number
    },
    multiple: {
      type: Boolean
    },
    defaultValue: {
      type: [String, Number, Array, Object]
    },
    modelValue: {
      type: [String, Number, Array, Object]
    },
    fieldNames: {
      type: Object
    },
    data: {
      type: Array,
      default: () => []
    },
    labelInValue: {
      type: Boolean
    },
    treeCheckable: {
      type: Boolean
    },
    treeCheckStrictly: {
      type: Boolean
    },
    treeCheckedStrategy: {
      type: String,
      default: "all"
    },
    treeProps: {
      type: Object
    },
    triggerProps: {
      type: Object
    },
    popupVisible: {
      type: Boolean,
      default: void 0
    },
    defaultPopupVisible: {
      type: Boolean
    },
    dropdownStyle: {
      type: Object
    },
    dropdownClassName: {
      type: [String, Array]
    },
    filterTreeNode: {
      type: Function
    },
    loadMore: {
      type: Function
    },
    disableFilter: {
      type: Boolean
    },
    popupContainer: {
      type: [String, Object]
    },
    fallbackOption: {
      type: [Boolean, Function],
      default: !0
    },
    selectable: {
      type: [Boolean, String, Function],
      default: !0
    },
    scrollbar: {
      type: [Boolean, Object],
      default: !0
    },
    showHeaderOnEmpty: {
      type: Boolean,
      default: !1
    },
    showFooterOnEmpty: {
      type: Boolean,
      default: !1
    },
    inputValue: {
      type: String
    },
    defaultInputValue: {
      type: String,
      default: ""
    }
  },
  emits: {
    change: (e) => !0,
    "update:modelValue": (e) => !0,
    "update:inputValue": (e) => !0,
    "popup-visible-change": (e) => !0,
    "update:popupVisible": (e) => !0,
    search: (e) => !0,
    clear: () => !0,
    inputValueChange: (e) => !0
  },
  setup(e, { emit: t, slots: n }) {
    var o, i, r;
    const {
      defaultValue: l,
      modelValue: s,
      multiple: u,
      popupVisible: f,
      defaultPopupVisible: d,
      treeCheckable: p,
      treeCheckStrictly: h,
      data: k,
      fieldNames: y,
      disabled: w,
      labelInValue: g,
      filterTreeNode: C,
      disableFilter: P,
      dropdownStyle: z,
      treeProps: j,
      fallbackOption: I,
      selectable: L,
      dropdownClassName: M
    } = ve(e), { mergedDisabled: E, eventHandlers: K } = mt({
      disabled: w
    }), q = B("tree-select"), T = Ge(Kt, void 0), X = (r = (i = T == null ? void 0 : (o = T.slots).empty) == null ? void 0 : i.call(o, {
      component: "tree-select"
    })) == null ? void 0 : r[0], Y = a(() => u.value || p.value), Z = (he, Ue) => {
      var et;
      return L.value === "leaf" ? Ue.isLeaf : Ne(L.value) ? L.value(he, Ue) : (et = L.value) != null ? et : !1;
    }, U = a(
      () => p.value ? Z : !1
    ), H = a(
      () => Qe(e.allowSearch) && !!e.allowSearch.retainInputValue
    ), { flattenTreeData: D, key2TreeNode: R } = S2(
      me({
        treeData: k,
        fieldNames: y,
        selectable: Z,
        checkable: U
      })
    ), {
      selectedKeys: W,
      selectedValue: O,
      setLocalSelectedKeys: x,
      localSelectedKeys: G,
      localSelectedValue: ne
    } = _z(
      me({
        defaultValue: l,
        modelValue: s,
        key2TreeNode: R,
        multiple: u,
        treeCheckable: p,
        treeCheckStrictly: h,
        fallbackOption: I,
        fieldNames: y
      })
    );
    function ee(he) {
      return p.value ? Cl(he) : kv(he);
    }
    const Q = a(() => Ve(O.value) ? [] : Y.value && !E.value ? O.value.map((he) => {
      const Ue = R.value.get(he.value);
      return {
        ...he,
        closable: !Ue || ee(Ue)
      };
    }) : O.value), ae = (he) => {
      x(he), at(() => {
        var Ue, et;
        const tt = (g.value ? ne.value : G.value) || [], st = Y.value ? tt : tt[0];
        t("update:modelValue", st), t("change", st), (et = (Ue = K.value) == null ? void 0 : Ue.onChange) == null || et.call(Ue);
      });
    }, ge = V(e.defaultInputValue), Se = a(
      () => {
        var he;
        return (he = e.inputValue) != null ? he : ge.value;
      }
    ), be = (he) => {
      ge.value = he, t("update:inputValue", he), t("inputValueChange", he);
    }, Le = (he) => {
      he !== Se.value && (ke(!0), be(he), e.allowSearch && t("search", he));
    }, [pe, Me] = Vt(
      d.value,
      me({
        value: f
      })
    ), ke = (he) => {
      he !== pe.value && (Me(he), t("popup-visible-change", he), t("update:popupVisible", he)), he || Oe.value && Oe.value.blur && Oe.value.blur();
    }, { isEmptyFilterResult: le, filterTreeNode: re } = Jz(
      me({
        searchValue: Se,
        flattenTreeData: D,
        filterMethod: C,
        disableFilter: P,
        fieldNames: y
      })
    ), fe = a(
      () => !D.value.length || le.value
    ), Oe = V(), Be = a(() => {
      var he;
      return [
        (z == null ? void 0 : z.value) || {},
        (he = j == null ? void 0 : j.value) != null && he.virtualListProps ? { "max-height": "unset" } : {}
      ];
    });
    return {
      refSelectView: Oe,
      prefixCls: q,
      TreeSelectEmpty: X,
      selectedValue: O,
      selectedKeys: W,
      mergedDisabled: E,
      searchValue: Se,
      panelVisible: pe,
      isEmpty: fe,
      computedFilterTreeNode: re,
      isMultiple: Y,
      selectViewValue: Q,
      computedDropdownStyle: Be,
      onSearchValueChange: Le,
      onSelectChange(he) {
        ae(he), !H.value && Se.value && be(""), Y.value || ke(!1);
      },
      onVisibleChange: ke,
      onInnerClear() {
        ae([]), t("clear");
      },
      pickSubCompSlots: eL,
      isSelectable: Z,
      isCheckable: U,
      onBlur: () => {
        !H.value && Se.value && be("");
      },
      onItemRemove(he) {
        if (E.value)
          return;
        const Ue = R.value.get(he);
        if (p.value && Ue) {
          if (ee(Ue)) {
            const [et] = bv({
              node: Ue,
              checked: !1,
              checkedKeys: W.value,
              indeterminateKeys: [],
              checkStrictly: h.value
            });
            ae(et);
          }
        } else {
          const et = W.value.filter((tt) => tt !== he);
          ae(et);
        }
      }
    };
  }
});
function nL(e, t, n, o, i, r) {
  const l = J("SelectView"), s = J("Spin"), u = J("Panel"), f = J("Trigger");
  return v(), oe(f, se({
    class: `${e.prefixCls}-trigger`,
    "auto-fit-popup-min-width": "",
    trigger: "click",
    position: "bl",
    "popup-offset": 4,
    "animation-name": "slide-dynamic-origin",
    "prevent-focus": !0
  }, e.triggerProps, {
    disabled: e.mergedDisabled,
    "popup-visible": e.panelVisible,
    "popup-container": e.popupContainer,
    "click-to-close": !e.allowSearch,
    "auto-fit-transform-origin": "",
    onPopupVisibleChange: e.onVisibleChange
  }), {
    content: ue(() => [
      $("div", {
        class: m([
          `${e.prefixCls}-popup`,
          {
            [`${e.prefixCls}-has-header`]: !!e.$slots.header,
            [`${e.prefixCls}-has-footer`]: !!e.$slots.footer
          },
          e.dropdownClassName
        ]),
        style: F(e.computedDropdownStyle)
      }, [
        e.$slots.header && (!e.isEmpty || e.showHeaderOnEmpty) ? (v(), b("div", {
          key: 0,
          class: m(`${e.prefixCls}-header`)
        }, [
          _(e.$slots, "header")
        ], 2)) : te("v-if", !0),
        e.loading ? _(e.$slots, "loader", { key: 1 }, () => [
          c(s)
        ]) : e.isEmpty ? _(e.$slots, "empty", { key: 2 }, () => [
          (v(), oe(sn(e.TreeSelectEmpty ? e.TreeSelectEmpty : "Empty")))
        ]) : (v(), oe(u, {
          key: 3,
          "selected-keys": e.selectedKeys,
          "show-checkable": e.treeCheckable,
          scrollbar: e.scrollbar,
          "tree-props": {
            actionOnNodeClick: e.selectable === "leaf" ? "expand" : void 0,
            blockNode: !0,
            ...e.treeProps,
            data: e.data,
            checkStrictly: e.treeCheckStrictly,
            checkedStrategy: e.treeCheckedStrategy,
            fieldNames: e.fieldNames,
            multiple: e.multiple,
            loadMore: e.loadMore,
            filterTreeNode: e.computedFilterTreeNode,
            size: e.size,
            checkable: e.isCheckable,
            selectable: e.isSelectable,
            searchValue: e.searchValue
          },
          "tree-slots": e.pickSubCompSlots(e.$slots, "tree"),
          onChange: e.onSelectChange
        }, null, 8, ["selected-keys", "show-checkable", "scrollbar", "tree-props", "tree-slots", "onChange"])),
        e.$slots.footer && (!e.isEmpty || e.showFooterOnEmpty) ? (v(), b("div", {
          key: 4,
          class: m(`${e.prefixCls}-footer`)
        }, [
          _(e.$slots, "footer")
        ], 2)) : te("v-if", !0)
      ], 6)
    ]),
    default: ue(() => [
      _(e.$slots, "trigger", {}, () => [
        c(l, se({
          ref: "refSelectView",
          "model-value": e.selectViewValue,
          "input-value": e.searchValue,
          "allow-search": !!e.allowSearch,
          "allow-clear": e.allowClear,
          loading: e.loading,
          size: e.size,
          "max-tag-count": e.maxTagCount,
          disabled: e.mergedDisabled,
          opened: e.panelVisible,
          error: e.error,
          bordered: e.border,
          placeholder: e.placeholder,
          multiple: e.isMultiple
        }, e.$attrs, {
          onInputValueChange: e.onSearchValueChange,
          onClear: e.onInnerClear,
          onRemove: e.onItemRemove,
          onBlur: e.onBlur
        }), kt({ _: 2 }, [
          e.$slots.prefix ? {
            name: "prefix",
            fn: ue(() => [
              _(e.$slots, "prefix")
            ]),
            key: "0"
          } : void 0,
          e.$slots.label ? {
            name: "label",
            fn: ue((d) => [
              _(e.$slots, "label", dt(Gt(d)))
            ]),
            key: "1"
          } : void 0
        ]), 1040, ["model-value", "input-value", "allow-search", "allow-clear", "loading", "size", "max-tag-count", "disabled", "opened", "error", "bordered", "placeholder", "multiple", "onInputValueChange", "onClear", "onRemove", "onBlur"])
      ])
    ]),
    _: 3
  }, 16, ["class", "disabled", "popup-visible", "popup-container", "click-to-close", "onPopupVisibleChange"]);
}
var Au = /* @__PURE__ */ N(tL, [["render", nL]]);
const lL = Object.assign(Au, {
  install: (e, t) => {
    De(e, t);
    const n = Fe(t);
    e.component(n + Au.name, Au);
  }
}), wv = {
  Button: Qt,
  Link: dh,
  Typography: cz,
  Divider: L$,
  Grid: uo,
  Layout: K6,
  Space: D7,
  Avatar: e4,
  Badge: c4,
  Calendar: Vm,
  Card: Ob,
  Carousel: Yb,
  Collapse: d3,
  Comment: H3,
  ColorPicker: A3,
  Descriptions: z$,
  Empty: Gn,
  Image: C6,
  Scrollbar: In,
  List: Uh,
  Popover: Av,
  Statistic: Q7,
  Table: WS,
  Tabs: QS,
  Tag: Fv,
  Timeline: r9,
  Tooltip: yn,
  AutoComplete: qy,
  Cascader: n3,
  Checkbox: Ln,
  DatePicker: C$,
  Form: w5,
  Input: cl,
  InputNumber: Vo,
  InputTag: Nm,
  Mention: k8,
  Radio: Ul,
  Rate: l7,
  Select: zo,
  Slider: F7,
  Switch: rS,
  Textarea: Gh,
  TimePicker: n9,
  Transfer: h9,
  Tree: $v,
  Upload: Wz,
  TreeSelect: lL,
  Alert: rm,
  Drawer: sv,
  Message: vv,
  Modal: pv,
  Notification: mv,
  Popconfirm: pw,
  Progress: n2,
  Result: v7,
  Spin: Pn,
  Skeleton: b7,
  Breadcrumb: T4,
  Dropdown: wm,
  Menu: Z8,
  PageHeader: dw,
  Pagination: e0,
  Steps: nS,
  Affix: xk,
  Anchor: Ng,
  BackTop: r4,
  ConfigProvider: K3,
  ResizeBox: Zh,
  Trigger: Tt,
  Split: q7,
  Icon: P5,
  OverflowList: Fz,
  Watermark: Uz,
  VerificationCode: Dz
}, oL = (e, t) => {
  for (const n of Object.keys(wv))
    e.use(wv[n], t);
}, iL = {
  ...wv,
  Alter: rm,
  AnchorLink: ni,
  AvatarGroup: ui,
  BreadcrumbItem: vo,
  ButtonGroup: fo,
  Calendar: Vm,
  CardMeta: Si,
  CardGrid: zi,
  CarouselItem: Li,
  CascaderPanel: ji,
  CheckboxGroup: ai,
  CollapseItem: Pi,
  DescriptionsItem: Ti,
  WeekPicker: Bi,
  MonthPicker: Mi,
  YearPicker: Ni,
  QuarterPicker: Oi,
  RangePicker: Vi,
  Doption: Rl,
  Dgroup: di,
  Dsubmenu: fi,
  DropdownButton: vi,
  FormItem: Wi,
  Row: mo,
  Col: ho,
  GridItem: Ei,
  ImagePreview: Hl,
  ImagePreviewAction: yr,
  ImagePreviewGroup: ko,
  InputGroup: xl,
  InputSearch: li,
  InputPassword: oi,
  LayoutHeader: Di,
  LayoutContent: xi,
  LayoutFooter: Ri,
  LayoutSider: Hi,
  ListItem: qi,
  ListItemMeta: Zi,
  MenuItem: Ki,
  MenuItemGroup: Yi,
  SubMenu: go,
  RadioGroup: wi,
  Option: kl,
  Optgroup: po,
  SkeletonLine: Xi,
  SkeletonShape: Qi,
  Countdown: _i,
  Step: Ji,
  Thead: bo,
  Td: ol,
  Th: $o,
  Tr: Kn,
  Tbody: Co,
  TableColumn: er,
  TabPane: tr,
  TimelineItem: Zl,
  TypographyParagraph: nr,
  TypographyTitle: lr,
  TypographyText: or,
  install: oL,
  addI18nMessages: sk,
  useLocale: uk,
  getLocale: ck,
  useFormItem: mt
}, rL = S({
  name: "IconArrowDown",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-arrow-down`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), aL = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function sL(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m11.27 27.728 12.727 12.728 12.728-12.728M24 5v34.295" }, null, -1)
  ]), 14, aL);
}
var Eu = /* @__PURE__ */ N(rL, [["render", sL]]);
const uL = Object.assign(Eu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Eu.name, Eu);
  }
}), cL = S({
  name: "IconArrowFall",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-arrow-fall`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), dL = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function fL(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24.008 41.99a.01.01 0 0 1-.016 0l-9.978-11.974A.01.01 0 0 1 14.02 30H33.98a.01.01 0 0 1 .007.016l-9.978 11.975Z" }, null, -1),
    $("path", {
      d: "M24 42 14 30h20L24 42Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M22 6h4v26h-4z" }, null, -1),
    $("path", {
      fill: "currentColor",
      stroke: "none",
      d: "M22 6h4v26h-4z"
    }, null, -1)
  ]), 14, dL);
}
var Wu = /* @__PURE__ */ N(cL, [["render", fL]]);
const vL = Object.assign(Wu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Wu.name, Wu);
  }
}), pL = S({
  name: "IconArrowLeft",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-arrow-left`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), mL = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function hL(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M20.272 11.27 7.544 23.998l12.728 12.728M43 24H8.705" }, null, -1)
  ]), 14, mL);
}
var Fu = /* @__PURE__ */ N(pL, [["render", hL]]);
const kL = Object.assign(Fu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Fu.name, Fu);
  }
}), gL = S({
  name: "IconArrowRight",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-arrow-right`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), yL = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function bL(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m27.728 11.27 12.728 12.728-12.728 12.728M5 24h34.295" }, null, -1)
  ]), 14, yL);
}
var Du = /* @__PURE__ */ N(gL, [["render", bL]]);
const CL = Object.assign(Du, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Du.name, Du);
  }
}), $L = S({
  name: "IconArrowRise",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-arrow-rise`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), wL = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function SL(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M23.992 6.01a.01.01 0 0 1 .016 0l9.978 11.974a.01.01 0 0 1-.007.016H14.02a.01.01 0 0 1-.007-.016l9.978-11.975Z" }, null, -1),
    $("path", {
      d: "m24 6 10 12H14L24 6Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M26 42h-4V16h4z" }, null, -1),
    $("path", {
      fill: "currentColor",
      stroke: "none",
      d: "M26 42h-4V16h4z"
    }, null, -1)
  ]), 14, wL);
}
var xu = /* @__PURE__ */ N($L, [["render", SL]]);
const zL = Object.assign(xu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + xu.name, xu);
  }
}), LL = S({
  name: "IconArrowUp",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-arrow-up`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), jL = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function PL(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M11.27 20.272 23.997 7.544l12.728 12.728M24 43V8.705" }, null, -1)
  ]), 14, jL);
}
var Ru = /* @__PURE__ */ N(LL, [["render", PL]]);
const IL = Object.assign(Ru, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ru.name, Ru);
  }
}), BL = S({
  name: "IconDoubleDown",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-double-down`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ML = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function NL(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m9.9 11.142 14.143 14.142 14.142-14.142M9.9 22.456l14.143 14.142 14.142-14.142" }, null, -1)
  ]), 14, ML);
}
var Hu = /* @__PURE__ */ N(BL, [["render", NL]]);
const OL = Object.assign(Hu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Hu.name, Hu);
  }
}), VL = S({
  name: "IconDoubleUp",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-double-up`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), TL = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function AL(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M38.1 36.858 23.957 22.716 9.816 36.858M38.1 25.544 23.957 11.402 9.816 25.544" }, null, -1)
  ]), 14, TL);
}
var qu = /* @__PURE__ */ N(VL, [["render", AL]]);
const EL = Object.assign(qu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + qu.name, qu);
  }
}), WL = S({
  name: "IconDownCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-down-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), FL = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function DL(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("circle", {
      cx: "24",
      cy: "24",
      r: "18",
      transform: "rotate(-180 24 24)"
    }, null, -1),
    $("path", { d: "M32.484 20.515 24 29l-8.485-8.485" }, null, -1)
  ]), 14, FL);
}
var Zu = /* @__PURE__ */ N(WL, [["render", DL]]);
const xL = Object.assign(Zu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Zu.name, Zu);
  }
}), RL = S({
  name: "IconDragArrow",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-drag-arrow`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), HL = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function qL(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 24h34M24 7v34M30 12l-6-6-6 6M36 30l6-6-6-6M12 30l-6-6 6-6M18 36l6 6 6-6" }, null, -1)
  ]), 14, HL);
}
var Ku = /* @__PURE__ */ N(RL, [["render", qL]]);
const ZL = Object.assign(Ku, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ku.name, Ku);
  }
}), KL = S({
  name: "IconExpand",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-expand`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), YL = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function UL(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 26v14c0 .552.444 1 .996 1H22m19-19V8c0-.552-.444-1-.996-1H26" }, null, -1)
  ]), 14, YL);
}
var Yu = /* @__PURE__ */ N(KL, [["render", UL]]);
const GL = Object.assign(Yu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Yu.name, Yu);
  }
}), XL = S({
  name: "IconLeftCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-left-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), QL = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function _L(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("circle", {
      cx: "24",
      cy: "24",
      r: "18"
    }, null, -1),
    $("path", { d: "M28.485 32.485 20 24l8.485-8.485" }, null, -1)
  ]), 14, QL);
}
var Uu = /* @__PURE__ */ N(XL, [["render", _L]]);
const JL = Object.assign(Uu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Uu.name, Uu);
  }
}), ej = S({
  name: "IconRightCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-right-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), tj = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function nj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("circle", {
      cx: "24",
      cy: "24",
      r: "18"
    }, null, -1),
    $("path", { d: "M19.485 15.515 27.971 24l-8.486 8.485" }, null, -1)
  ]), 14, tj);
}
var Gu = /* @__PURE__ */ N(ej, [["render", nj]]);
const lj = Object.assign(Gu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Gu.name, Gu);
  }
}), oj = S({
  name: "IconShrink",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-shrink`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ij = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function rj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M20 44V29c0-.552-.444-1-.996-1H4M28 4v15c0 .552.444 1 .996 1H44" }, null, -1)
  ]), 14, ij);
}
var Xu = /* @__PURE__ */ N(oj, [["render", rj]]);
const aj = Object.assign(Xu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Xu.name, Xu);
  }
}), sj = S({
  name: "IconSwap",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-swap`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), uj = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function cj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M5 17h35.586c.89 0 1.337-1.077.707-1.707L33 7M43 31H7.414c-.89 0-1.337 1.077-.707 1.707L15 41" }, null, -1)
  ]), 14, uj);
}
var Qu = /* @__PURE__ */ N(sj, [["render", cj]]);
const dj = Object.assign(Qu, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Qu.name, Qu);
  }
}), fj = S({
  name: "IconToBottom",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-to-bottom`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), vj = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function pj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M5 41h38M24 28V5M24 34.04 17.547 27h12.907L24 34.04Zm-.736.803v.001Z" }, null, -1),
    $("path", {
      d: "m24 34 6-7H18l6 7Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, vj);
}
var _u = /* @__PURE__ */ N(fj, [["render", pj]]);
const mj = Object.assign(_u, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + _u.name, _u);
  }
}), hj = S({
  name: "IconToLeft",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-to-left`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), kj = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function gj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 5v38M20 24h23M20.999 17.547v12.907L13.959 24l7.04-6.453Z" }, null, -1),
    $("path", {
      d: "m14 24 7 6V18l-7 6Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, kj);
}
var Ju = /* @__PURE__ */ N(hj, [["render", gj]]);
const yj = Object.assign(Ju, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ju.name, Ju);
  }
}), bj = S({
  name: "IconToRight",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-to-right`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Cj = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function $j(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M41 43V5M28 24H5M34.04 24 27 30.453V17.546L34.04 24Zm.803.736h.001Z" }, null, -1),
    $("path", {
      d: "m34 24-7-6v12l7-6Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, Cj);
}
var ec = /* @__PURE__ */ N(bj, [["render", $j]]);
const wj = Object.assign(ec, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ec.name, ec);
  }
}), Sj = S({
  name: "IconUpCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-up-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), zj = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Lj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("circle", {
      cx: "24",
      cy: "24",
      r: "18"
    }, null, -1),
    $("path", { d: "M15.516 28.485 24 20l8.485 8.485" }, null, -1)
  ]), 14, zj);
}
var tc = /* @__PURE__ */ N(Sj, [["render", Lj]]);
const jj = Object.assign(tc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + tc.name, tc);
  }
}), Pj = S({
  name: "IconExclamationPolygonFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-exclamation-polygon-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Ij = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Bj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M15.553 4a1 1 0 0 0-.74.327L4.26 15.937a1 1 0 0 0-.26.672V31.39a1 1 0 0 0 .26.673l10.553 11.609a1 1 0 0 0 .74.327h16.893a1 1 0 0 0 .74-.327l10.554-11.61a1 1 0 0 0 .26-.672V16.61a1 1 0 0 0-.26-.673L33.187 4.327a1 1 0 0 0-.74-.327H15.553ZM22 33a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1v2Zm4-18a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V15Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, Ij);
}
var nc = /* @__PURE__ */ N(Pj, [["render", Bj]]);
const Mj = Object.assign(nc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + nc.name, nc);
  }
}), Nj = S({
  name: "IconMinusCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-minus-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Oj = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Vj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4 4 12.954 4 24s8.954 20 20 20Zm-7-22a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h14a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1H17Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, Oj);
}
var lc = /* @__PURE__ */ N(Nj, [["render", Vj]]);
const Tj = Object.assign(lc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + lc.name, lc);
  }
}), Aj = S({
  name: "IconPlusCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-plus-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Ej = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Wj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4 4 12.954 4 24s8.954 20 20 20Zm2-28v6h6a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-6v6a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1v-6h-6a1 1 0 0 1-1-1v-2a1 1 0 0 1 1-1h6v-6a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, Ej);
}
var oc = /* @__PURE__ */ N(Aj, [["render", Wj]]);
const Fj = Object.assign(oc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + oc.name, oc);
  }
}), Dj = S({
  name: "IconQuestionCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-question-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), xj = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Rj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4 4 12.954 4 24s8.954 20 20 20Zm-3.862-24.021a.461.461 0 0 0 .462-.462 2.37 2.37 0 0 1 .636-1.615C21.64 17.48 22.43 17 23.988 17c1.465 0 2.483.7 3.002 1.493.555.848.446 1.559.182 1.914-.328.444-.736.853-1.228 1.296-.15.135-.335.296-.533.468-.354.308-.75.654-1.067.955C23.22 24.195 22 25.686 22 28v.013a1 1 0 0 0 1.006.993l2.008-.012a.993.993 0 0 0 .986-1c.002-.683.282-1.19 1.101-1.97.276-.262.523-.477.806-.722.21-.18.439-.379.713-.626.57-.513 1.205-1.13 1.767-1.888 1.516-2.047 1.161-4.634-.05-6.485C29.092 14.398 26.825 13 23.988 13c-2.454 0-4.357.794-5.642 2.137-1.25 1.307-1.742 2.954-1.746 4.37 0 .26.21.472.47.472h3.068Zm1.868 14.029a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V32a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1v2.008Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, xj);
}
var ic = /* @__PURE__ */ N(Dj, [["render", Rj]]);
const Hj = Object.assign(ic, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ic.name, ic);
  }
}), qj = S({
  name: "IconCheckCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-check-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Zj = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Kj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m15 22 7 7 11.5-11.5M42 24c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6s18 8.059 18 18Z" }, null, -1)
  ]), 14, Zj);
}
var rc = /* @__PURE__ */ N(qj, [["render", Kj]]);
const Yj = Object.assign(rc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + rc.name, rc);
  }
}), Uj = S({
  name: "IconCheckSquare",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-check-square`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Gj = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Xj(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M34.603 16.672 21.168 30.107l-7.778-7.779M8 41h32a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H8a1 1 0 0 0-1 1v32a1 1 0 0 0 1 1Z" }, null, -1)
  ]), 14, Gj);
}
var ac = /* @__PURE__ */ N(Uj, [["render", Xj]]);
const Qj = Object.assign(ac, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ac.name, ac);
  }
}), _j = S({
  name: "IconCloseCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-close-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Jj = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function eP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m17.643 17.643 6.364 6.364m0 0 6.364 6.364m-6.364-6.364 6.364-6.364m-6.364 6.364-6.364 6.364M42 24c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6s18 8.059 18 18Z" }, null, -1)
  ]), 14, Jj);
}
var sc = /* @__PURE__ */ N(_j, [["render", eP]]);
const tP = Object.assign(sc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + sc.name, sc);
  }
}), nP = S({
  name: "IconExclamationCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-exclamation-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), lP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function oP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 28V14m0 16v4M6 24c0-9.941 8.059-18 18-18s18 8.059 18 18-8.059 18-18 18S6 33.941 6 24Z" }, null, -1)
  ]), 14, lP);
}
var uc = /* @__PURE__ */ N(nP, [["render", oP]]);
const iP = Object.assign(uc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + uc.name, uc);
  }
}), rP = S({
  name: "IconInfoCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-info-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), aP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function sP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 20v14m0-16v-4m18 10c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6s18 8.059 18 18Z" }, null, -1)
  ]), 14, aP);
}
var cc = /* @__PURE__ */ N(rP, [["render", sP]]);
const uP = Object.assign(cc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + cc.name, cc);
  }
}), cP = S({
  name: "IconMinusCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-minus-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), dP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function fP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M32 24H16m26 0c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6s18 8.059 18 18Z" }, null, -1)
  ]), 14, dP);
}
var dc = /* @__PURE__ */ N(cP, [["render", fP]]);
const vP = Object.assign(dc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + dc.name, dc);
  }
}), pP = S({
  name: "IconPlusCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-plus-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), mP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function hP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M32 24h-8m-8 0h8m0 0v8m0-8v-8m18 8c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6s18 8.059 18 18Z" }, null, -1)
  ]), 14, mP);
}
var fc = /* @__PURE__ */ N(pP, [["render", hP]]);
const kP = Object.assign(fc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + fc.name, fc);
  }
}), gP = S({
  name: "IconQuestion",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-question`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), yP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function bP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M13 17c0-5.523 4.925-10 11-10s11 4.477 11 10c0 3.607-2.1 6.767-5.25 8.526C26.857 27.142 24 29.686 24 33v3m0 5h.02v.02H24V41Z" }, null, -1)
  ]), 14, yP);
}
var vc = /* @__PURE__ */ N(gP, [["render", bP]]);
const CP = Object.assign(vc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + vc.name, vc);
  }
}), $P = S({
  name: "IconStop",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-stop`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), wP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function SP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M36.728 36.728c7.03-7.03 7.03-18.427 0-25.456-7.03-7.03-18.427-7.03-25.456 0m25.456 25.456c-7.03 7.03-18.427 7.03-25.456 0-7.03-7.03-7.03-18.427 0-25.456m25.456 25.456L11.272 11.272" }, null, -1)
  ]), 14, wP);
}
var pc = /* @__PURE__ */ N($P, [["render", SP]]);
const zP = Object.assign(pc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + pc.name, pc);
  }
}), LP = S({
  name: "IconHeartFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-heart-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), jP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function PP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M24 10.541c4.35-4.522 11.405-4.814 15.756-.292 4.35 4.522 4.15 11.365.448 17.135C36.153 33.7 28 41.5 24 42c-4-.5-12.152-8.3-16.204-14.616-3.702-5.77-3.902-12.613.448-17.135C12.595 5.727 19.65 6.019 24 10.54Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, jP);
}
var mc = /* @__PURE__ */ N(LP, [["render", PP]]);
const IP = Object.assign(mc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + mc.name, mc);
  }
}), BP = S({
  name: "IconThumbDownFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-thumb-down-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), MP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function NP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M43 5v26h-4V5h4Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", {
      d: "M20.9 43.537a2 2 0 0 0 2.83-.364L32.964 31H36V5H12.424a2 2 0 0 0-1.89 1.346L4.838 25.692C3.938 28.29 5.868 31 8.618 31h10.568l-2.421 5.448a4 4 0 0 0 1.184 4.77l2.951 2.32Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, MP);
}
var hc = /* @__PURE__ */ N(BP, [["render", NP]]);
const OP = Object.assign(hc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + hc.name, hc);
  }
}), VP = S({
  name: "IconThumbUpFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-thumb-up-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), TP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function AP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M5 43V17h4v26H5Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", {
      d: "M27.1 4.463a2 2 0 0 0-2.83.364L15.036 17H12v26h23.576a2 2 0 0 0 1.89-1.346l5.697-19.346c.899-2.598-1.03-5.308-3.78-5.308h-10.57l2.422-5.448a4 4 0 0 0-1.184-4.77L27.1 4.462Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, TP);
}
var kc = /* @__PURE__ */ N(VP, [["render", AP]]);
const EP = Object.assign(kc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + kc.name, kc);
  }
}), WP = S({
  name: "IconAt",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-at`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), FP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function DP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M31 23a7 7 0 1 1-14 0 7 7 0 0 1 14 0Zm0 0c0 3.038 2.462 6.5 5.5 6.5A5.5 5.5 0 0 0 42 24c0-9.941-8.059-18-18-18S6 14.059 6 24s8.059 18 18 18c4.244 0 8.145-1.469 11.222-3.925" }, null, -1)
  ]), 14, FP);
}
var gc = /* @__PURE__ */ N(WP, [["render", DP]]);
const xP = Object.assign(gc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + gc.name, gc);
  }
}), RP = S({
  name: "IconCloudDownload",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-cloud-download`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), HP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function qP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M43 22c0-7.732-6.492-14-14.5-14S14 14.268 14 22v.055A9.001 9.001 0 0 0 15 40h13m16.142-5.929-7.07 7.071L30 34.072M37.07 26v15" }, null, -1)
  ]), 14, HP);
}
var yc = /* @__PURE__ */ N(RP, [["render", qP]]);
const ZP = Object.assign(yc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + yc.name, yc);
  }
}), KP = S({
  name: "IconCodeBlock",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-code-block`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), YP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function UP(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M19 6h-4a3 3 0 0 0-3 3v10c0 3-4.343 5-6 5 1.657 0 6 2 6 5v10a3 3 0 0 0 3 3h4M29 6h4a3 3 0 0 1 3 3v10c0 3 4.343 5 6 5-1.657 0-6 2-6 5v10a3 3 0 0 1-3 3h-4" }, null, -1)
  ]), 14, YP);
}
var bc = /* @__PURE__ */ N(KP, [["render", UP]]);
const GP = Object.assign(bc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + bc.name, bc);
  }
}), XP = S({
  name: "IconCodeSquare",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-code-square`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), QP = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function _P(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M23.071 17 16 24.071l7.071 7.071m9.001-14.624-4.14 15.454M9 42h30a1 1 0 0 0 1-1V7a1 1 0 0 0-1-1H9a1 1 0 0 0-1 1v34a1 1 0 0 0 1 1Z" }, null, -1)
  ]), 14, QP);
}
var Cc = /* @__PURE__ */ N(XP, [["render", _P]]);
const JP = Object.assign(Cc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Cc.name, Cc);
  }
}), eI = S({
  name: "IconCode",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-code`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), tI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function nI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M16.734 12.686 5.42 24l11.314 11.314m14.521-22.628L42.57 24 31.255 35.314M27.2 6.28l-6.251 35.453" }, null, -1)
  ]), 14, tI);
}
var $c = /* @__PURE__ */ N(eI, [["render", nI]]);
const lI = Object.assign($c, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + $c.name, $c);
  }
}), oI = S({
  name: "IconCustomerService",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-customer-service`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), iI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function rI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M11 31V20c0-7.18 5.82-13 13-13s13 5.82 13 13v8c0 5.784-3.778 10.686-9 12.373m0 0A12.99 12.99 0 0 1 24 41h-3a1 1 0 0 1-1-1v-2a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1v2.373Zm0 0V41m9-20h3a1 1 0 0 1 1 1v6a1 1 0 0 1-1 1h-3v-8Zm-26 0H8a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h3v-8Z" }, null, -1)
  ]), 14, iI);
}
var wc = /* @__PURE__ */ N(oI, [["render", rI]]);
const aI = Object.assign(wc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + wc.name, wc);
  }
}), sI = S({
  name: "IconDownload",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-download`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), uI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function cI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m33.072 22.071-9.07 9.071-9.072-9.07M24 5v26m16 4v6H8v-6" }, null, -1)
  ]), 14, uI);
}
var Sc = /* @__PURE__ */ N(sI, [["render", cI]]);
const dI = Object.assign(Sc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Sc.name, Sc);
  }
}), fI = S({
  name: "IconExport",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-export`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), vI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function pI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M31.928 33.072 41 24.002l-9.072-9.072M16.858 24h24M31 41H7V7h24" }, null, -1)
  ]), 14, vI);
}
var zc = /* @__PURE__ */ N(fI, [["render", pI]]);
const mI = Object.assign(zc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + zc.name, zc);
  }
}), hI = S({
  name: "IconHeart",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-heart`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), kI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function gI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M38.083 12.912a9.929 9.929 0 0 1 .177 13.878l-.177.18L25.76 39.273c-.972.97-2.548.97-3.52 0L9.917 26.971l-.177-.181a9.929 9.929 0 0 1 .177-13.878c3.889-3.883 10.194-3.883 14.083 0 3.889-3.883 10.194-3.883 14.083 0Z" }, null, -1)
  ]), 14, kI);
}
var Lc = /* @__PURE__ */ N(hI, [["render", gI]]);
const yI = Object.assign(Lc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Lc.name, Lc);
  }
}), bI = S({
  name: "IconHistory",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-history`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), CI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function $I(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6 24c0-9.941 8.059-18 18-18s18 8.059 18 18-8.059 18-18 18c-6.26 0-11.775-3.197-15-8.047M6 24l-.5-.757h1L6 24Zm26 2h-9v-9" }, null, -1)
  ]), 14, CI);
}
var jc = /* @__PURE__ */ N(bI, [["render", $I]]);
const wI = Object.assign(jc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + jc.name, jc);
  }
}), SI = S({
  name: "IconHome",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-home`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), zI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function LI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 17 24 7l17 10v24H7V17Z" }, null, -1),
    $("path", { d: "M20 28h8v13h-8V28Z" }, null, -1)
  ]), 14, zI);
}
var Pc = /* @__PURE__ */ N(SI, [["render", LI]]);
const jI = Object.assign(Pc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Pc.name, Pc);
  }
}), PI = S({
  name: "IconImport",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-import`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), II = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function BI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m27.929 33.072-9.071-9.07 9.07-9.072M43 24H19m12 17H7V7h24" }, null, -1)
  ]), 14, II);
}
var Ic = /* @__PURE__ */ N(PI, [["render", BI]]);
const MI = Object.assign(Ic, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ic.name, Ic);
  }
}), NI = S({
  name: "IconLaunch",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-launch`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), OI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function VI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    stroke: "currentColor",
    xmlns: "http://www.w3.org/2000/svg",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M41 26v14a1 1 0 0 1-1 1H8a1 1 0 0 1-1-1V8a1 1 0 0 1 1-1h14M19.822 28.178 39.899 8.1M41 20V7H28" }, null, -1)
  ]), 14, OI);
}
var Bc = /* @__PURE__ */ N(NI, [["render", VI]]);
const TI = Object.assign(Bc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Bc.name, Bc);
  }
}), AI = S({
  name: "IconList",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-list`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), EI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function WI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M13 24h30M5 12h4m4 24h30M13 12h30M5 24h4M5 36h4" }, null, -1)
  ]), 14, EI);
}
var Mc = /* @__PURE__ */ N(AI, [["render", WI]]);
const FI = Object.assign(Mc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Mc.name, Mc);
  }
}), DI = S({
  name: "IconMessageBanned",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-message-banned`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), xI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function RI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M40.527 20C38.727 12.541 32.01 7 24 7 14.611 7 7 14.611 7 24v17h14m19.364-.636a9 9 0 0 0-12.728-12.728m12.728 12.728a9 9 0 0 1-12.728-12.728m12.728 12.728L27.636 27.636M13 20h12m-12 9h6" }, null, -1)
  ]), 14, xI);
}
var Nc = /* @__PURE__ */ N(DI, [["render", RI]]);
const HI = Object.assign(Nc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Nc.name, Nc);
  }
}), qI = S({
  name: "IconMessage",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-message`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ZI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function KI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M15 20h18m-18 9h9M7 41h17.63C33.67 41 41 33.67 41 24.63V24c0-9.389-7.611-17-17-17S7 14.611 7 24v17Z" }, null, -1)
  ]), 14, ZI);
}
var Oc = /* @__PURE__ */ N(qI, [["render", KI]]);
const YI = Object.assign(Oc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Oc.name, Oc);
  }
}), UI = S({
  name: "IconMoreVertical",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-more-vertical`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), GI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function XI(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M25 10h-2V8h2v2ZM25 25h-2v-2h2v2ZM25 40h-2v-2h2v2Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M25 10h-2V8h2v2ZM25 25h-2v-2h2v2ZM25 40h-2v-2h2v2Z" }, null, -1)
  ]), 14, GI);
}
var Vc = /* @__PURE__ */ N(UI, [["render", XI]]);
const QI = Object.assign(Vc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Vc.name, Vc);
  }
}), _I = S({
  name: "IconPoweroff",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-poweroff`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), JI = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function eB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M15.5 9.274C10.419 12.214 7 17.708 7 24c0 9.389 7.611 17 17 17s17-7.611 17-17c0-6.292-3.419-11.786-8.5-14.726M24 5v22" }, null, -1)
  ]), 14, JI);
}
var Tc = /* @__PURE__ */ N(_I, [["render", eB]]);
const tB = Object.assign(Tc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Tc.name, Tc);
  }
}), nB = S({
  name: "IconRefresh",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-refresh`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), lB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function oB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M38.837 18C36.463 12.136 30.715 8 24 8 15.163 8 8 15.163 8 24s7.163 16 16 16c7.455 0 13.72-5.1 15.496-12M40 8v10H30" }, null, -1)
  ]), 14, lB);
}
var Ac = /* @__PURE__ */ N(nB, [["render", oB]]);
const iB = Object.assign(Ac, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ac.name, Ac);
  }
}), rB = S({
  name: "IconReply",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-reply`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), aB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function sB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m6.642 24.684 14.012 14.947a.2.2 0 0 0 .346-.137v-8.949A23.077 23.077 0 0 1 26 30c6.208 0 11.84 2.459 15.978 6.456a.01.01 0 0 0 .017-.007C42 36.299 42 36.15 42 36c0-10.493-8.506-19-19-19-.675 0-1.342.035-2 .104V8.506a.2.2 0 0 0-.346-.137L6.642 23.316a1 1 0 0 0 0 1.368Z" }, null, -1)
  ]), 14, aB);
}
var Ec = /* @__PURE__ */ N(rB, [["render", sB]]);
const uB = Object.assign(Ec, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ec.name, Ec);
  }
}), cB = S({
  name: "IconSave",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-save`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), dB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function fB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M21 13v9m18 20H9a1 1 0 0 1-1-1V7a1 1 0 0 1 1-1h22.55a1 1 0 0 1 .748.336l7.45 8.38a1 1 0 0 1 .252.664V41a1 1 0 0 1-1 1ZM14 6h14v15a1 1 0 0 1-1 1H15a1 1 0 0 1-1-1V6Z" }, null, -1)
  ]), 14, dB);
}
var Wc = /* @__PURE__ */ N(cB, [["render", fB]]);
const vB = Object.assign(Wc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Wc.name, Wc);
  }
}), pB = S({
  name: "IconScan",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-scan`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), mB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function hB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 17V7h10m24 10V7H31m10 24v10H31M7 31v10h10M5 24h38" }, null, -1)
  ]), 14, mB);
}
var Fc = /* @__PURE__ */ N(pB, [["render", hB]]);
const kB = Object.assign(Fc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Fc.name, Fc);
  }
}), gB = S({
  name: "IconSelectAll",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-select-all`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), yB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function bB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m17.314 7.243-7.071 7.07L6 10.072m11.314 10.172-7.071 7.07L6 23.072m11.314 10.172-7.071 7.07L6 36.072M21 11h22M21 25h22M21 39h22" }, null, -1)
  ]), 14, yB);
}
var Dc = /* @__PURE__ */ N(gB, [["render", bB]]);
const CB = Object.assign(Dc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Dc.name, Dc);
  }
}), $B = S({
  name: "IconSend",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-send`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), wB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function SB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "m14 24-7-5V7l34 17L7 41V29l7-5Zm0 0h25",
      "stroke-miterlimit": "3.864"
    }, null, -1)
  ]), 14, wB);
}
var xc = /* @__PURE__ */ N($B, [["render", SB]]);
const zB = Object.assign(xc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + xc.name, xc);
  }
}), LB = S({
  name: "IconSettings",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-settings`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), jB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function PB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M18.797 6.732A1 1 0 0 1 19.76 6h8.48a1 1 0 0 1 .964.732l1.285 4.628a1 1 0 0 0 1.213.7l4.651-1.2a1 1 0 0 1 1.116.468l4.24 7.344a1 1 0 0 1-.153 1.2L38.193 23.3a1 1 0 0 0 0 1.402l3.364 3.427a1 1 0 0 1 .153 1.2l-4.24 7.344a1 1 0 0 1-1.116.468l-4.65-1.2a1 1 0 0 0-1.214.7l-1.285 4.628a1 1 0 0 1-.964.732h-8.48a1 1 0 0 1-.963-.732L17.51 36.64a1 1 0 0 0-1.213-.7l-4.65 1.2a1 1 0 0 1-1.116-.468l-4.24-7.344a1 1 0 0 1 .153-1.2L9.809 24.7a1 1 0 0 0 0-1.402l-3.364-3.427a1 1 0 0 1-.153-1.2l4.24-7.344a1 1 0 0 1 1.116-.468l4.65 1.2a1 1 0 0 0 1.213-.7l1.286-4.628Z" }, null, -1),
    $("path", { d: "M30 24a6 6 0 1 1-12 0 6 6 0 0 1 12 0Z" }, null, -1)
  ]), 14, jB);
}
var Rc = /* @__PURE__ */ N(LB, [["render", PB]]);
const IB = Object.assign(Rc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Rc.name, Rc);
  }
}), BB = S({
  name: "IconShareAlt",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-share-alt`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), MB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function NB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M32.442 21.552a4.5 4.5 0 1 1 .065 4.025m-.065-4.025-16.884-8.104m16.884 8.104A4.483 4.483 0 0 0 32 23.5c0 .75.183 1.455.507 2.077m-16.95-12.13a4.5 4.5 0 1 1-8.113-3.895 4.5 4.5 0 0 1 8.114 3.896Zm-.064 20.977A4.5 4.5 0 1 0 11.5 41c3.334-.001 5.503-3.68 3.993-6.578Zm0 0 17.014-8.847" }, null, -1)
  ]), 14, MB);
}
var Hc = /* @__PURE__ */ N(BB, [["render", NB]]);
const OB = Object.assign(Hc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Hc.name, Hc);
  }
}), VB = S({
  name: "IconShareExternal",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-share-external`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), TB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function AB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M18 20h-7a1 1 0 0 0-1 1v20a1 1 0 0 0 1 1h26a1 1 0 0 0 1-1V21a1 1 0 0 0-1-1h-7m2.368-5.636L24.004 6l-8.364 8.364M24.003 28V6.604",
      "stroke-miterlimit": "16"
    }, null, -1)
  ]), 14, TB);
}
var qc = /* @__PURE__ */ N(VB, [["render", AB]]);
const EB = Object.assign(qc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + qc.name, qc);
  }
}), WB = S({
  name: "IconShareInternal",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-share-internal`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), FB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function DB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M40 35v6H8v-6m1.108-4c1.29-8.868 13.917-15.85 29.392-15.998M30 6l9 9-9 9" }, null, -1)
  ]), 14, FB);
}
var Zc = /* @__PURE__ */ N(WB, [["render", DB]]);
const xB = Object.assign(Zc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Zc.name, Zc);
  }
}), RB = S({
  name: "IconStar",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-star`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), HB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function qB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M22.552 6.908a.5.5 0 0 1 .896 0l5.02 10.17a.5.5 0 0 0 .376.274l11.224 1.631a.5.5 0 0 1 .277.853l-8.122 7.916a.5.5 0 0 0-.143.443l1.917 11.178a.5.5 0 0 1-.726.527l-10.038-5.278a.5.5 0 0 0-.466 0L12.73 39.9a.5.5 0 0 1-.726-.527l1.918-11.178a.5.5 0 0 0-.144-.443l-8.122-7.916a.5.5 0 0 1 .278-.853l11.223-1.63a.5.5 0 0 0 .376-.274l5.02-10.17Z" }, null, -1)
  ]), 14, HB);
}
var Kc = /* @__PURE__ */ N(RB, [["render", qB]]);
const ZB = Object.assign(Kc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Kc.name, Kc);
  }
}), KB = S({
  name: "IconSync",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-sync`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), YB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function UB(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M11.98 11.703c-6.64 6.64-6.64 17.403 0 24.042a16.922 16.922 0 0 0 8.942 4.7M34.603 37.156l1.414-1.415c6.64-6.639 6.64-17.402 0-24.041A16.922 16.922 0 0 0 27.075 7M14.81 11.982l-1.414-1.414-1.414-1.414h2.829v2.828ZM33.192 36.02l1.414 1.414 1.414 1.415h-2.828V36.02Z" }, null, -1)
  ]), 14, YB);
}
var Yc = /* @__PURE__ */ N(KB, [["render", UB]]);
const GB = Object.assign(Yc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Yc.name, Yc);
  }
}), XB = S({
  name: "IconThumbDown",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-thumb-down`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), QB = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function _B(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M41 31V5M5.83 26.394l5.949-18.697A1 1 0 0 1 12.732 7H34v22h-3l-9.403 12.223a1 1 0 0 1-1.386.196l-2.536-1.87a6 6 0 0 1-2.043-6.974L17 29H7.736a2 2 0 0 1-1.906-2.606Z" }, null, -1)
  ]), 14, QB);
}
var Uc = /* @__PURE__ */ N(XB, [["render", _B]]);
const JB = Object.assign(Uc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Uc.name, Uc);
  }
}), eM = S({
  name: "IconThumbUp",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-thumb-up`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), tM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function nM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 17v26m35.17-21.394-5.948 18.697a1 1 0 0 1-.953.697H14V19h3l9.403-12.223a1 1 0 0 1 1.386-.196l2.535 1.87a6 6 0 0 1 2.044 6.974L31 19h9.265a2 2 0 0 1 1.906 2.606Z" }, null, -1)
  ]), 14, tM);
}
var Gc = /* @__PURE__ */ N(eM, [["render", nM]]);
const lM = Object.assign(Gc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Gc.name, Gc);
  }
}), oM = S({
  name: "IconTranslate",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-translate`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), iM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function rM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M42 25c0 9.941-8.059 18-18 18-6.867 0-12.836-3.845-15.87-9.5M28.374 27 25 18h-2l-3.375 9m8.75 0L31 34m-2.625-7h-8.75m0 0L17 34M6 25c0-9.941 8.059-18 18-18 6.867 0 12.836 3.845 15.87 9.5M43 25h-2l1-1 1 1ZM5 25h2l-1 1-1-1Z" }, null, -1)
  ]), 14, iM);
}
var Xc = /* @__PURE__ */ N(oM, [["render", rM]]);
const aM = Object.assign(Xc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Xc.name, Xc);
  }
}), sM = S({
  name: "IconVoice",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-voice`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), uM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function cM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M41 21v1c0 8.837-7.163 16-16 16h-2c-8.837 0-16-7.163-16-16v-1m17 17v6m0-14a9 9 0 0 1-9-9v-6a9 9 0 1 1 18 0v6a9 9 0 0 1-9 9Z" }, null, -1)
  ]), 14, uM);
}
var Qc = /* @__PURE__ */ N(sM, [["render", cM]]);
const dM = Object.assign(Qc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Qc.name, Qc);
  }
}), fM = S({
  name: "IconAlignCenter",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-align-center`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), vM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function pM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M44 9H4m38 20H6m28-10H14m20 20H14" }, null, -1)
  ]), 14, vM);
}
var _c = /* @__PURE__ */ N(fM, [["render", pM]]);
const mM = Object.assign(_c, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + _c.name, _c);
  }
}), hM = S({
  name: "IconAlignLeft",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-align-left`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), kM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function gM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M44 9H4m36 20H4m21-10H4m21 20H4" }, null, -1)
  ]), 14, kM);
}
var Jc = /* @__PURE__ */ N(hM, [["render", gM]]);
const yM = Object.assign(Jc, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Jc.name, Jc);
  }
}), bM = S({
  name: "IconAlignRight",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-align-right`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), CM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function $M(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M4 9h40M8 29h36M23 19h21M23 39h21" }, null, -1)
  ]), 14, CM);
}
var ed = /* @__PURE__ */ N(bM, [["render", $M]]);
const wM = Object.assign(ed, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ed.name, ed);
  }
}), SM = S({
  name: "IconAttachment",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-attachment`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), zM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function LM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    stroke: "currentColor",
    xmlns: "http://www.w3.org/2000/svg",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M29.037 15.236s-9.174 9.267-11.48 11.594c-2.305 2.327-1.646 4.987-.329 6.316 1.317 1.33 3.994 1.953 6.258-.332L37.32 18.851c3.623-3.657 2.092-8.492 0-10.639-2.093-2.147-6.916-3.657-10.54 0L11.3 23.838c-3.623 3.657-3.953 10.638.329 14.96 4.282 4.322 11.115 4.105 14.821.333 3.706-3.773 8.74-8.822 11.224-11.33" }, null, -1)
  ]), 14, zM);
}
var td = /* @__PURE__ */ N(SM, [["render", LM]]);
const jM = Object.assign(td, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + td.name, td);
  }
}), PM = S({
  name: "IconBgColors",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-bg-colors`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), IM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function BM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "m9.442 25.25 10.351 10.765a1 1 0 0 0 1.428.014L32 25.25H9.442Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M19 5.25 22.75 9m0 0 12.043 12.043a1 1 0 0 1 0 1.414L32 25.25M22.75 9 8.693 23.057a1 1 0 0 0-.013 1.4l.762.793m0 0 10.351 10.765a1 1 0 0 0 1.428.014L32 25.25m-22.558 0H32M6 42h36" }, null, -1),
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M40.013 29.812 37.201 27l-2.812 2.812a4 4 0 1 0 5.624 0Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, IM);
}
var nd = /* @__PURE__ */ N(PM, [["render", BM]]);
const MM = Object.assign(nd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + nd.name, nd);
  }
}), NM = S({
  name: "IconBold",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-bold`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), OM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function VM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M13 24h12a8 8 0 1 0 0-16H13.2a.2.2 0 0 0-.2.2V24Zm0 0h16a8 8 0 1 1 0 16H13.2a.2.2 0 0 1-.2-.2V24Z" }, null, -1)
  ]), 14, OM);
}
var ld = /* @__PURE__ */ N(NM, [["render", VM]]);
const TM = Object.assign(ld, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ld.name, ld);
  }
}), AM = S({
  name: "IconBrush",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-brush`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), EM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function WM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M33 13h7a1 1 0 0 1 1 1v12.14a1 1 0 0 1-.85.99l-21.3 3.24a1 1 0 0 0-.85.99V43M33 8v10.002A.998.998 0 0 1 32 19H8a1 1 0 0 1-1-1V8c0-.552.444-1 .997-1H32.01c.552 0 .99.447.99 1Z" }, null, -1)
  ]), 14, EM);
}
var od = /* @__PURE__ */ N(AM, [["render", WM]]);
const FM = Object.assign(od, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + od.name, od);
  }
}), DM = S({
  name: "IconEraser",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-eraser`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), xM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function RM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M25.5 40.503 14.914 40.5a1 1 0 0 1-.707-.293l-9-9a1 1 0 0 1 0-1.414L13.5 21.5m12 19.003L44 40.5m-18.5.003L29 37M13.5 21.5 26.793 8.207a1 1 0 0 1 1.414 0l14.086 14.086a1 1 0 0 1 0 1.414L29 37M13.5 21.5 29 37" }, null, -1)
  ]), 14, xM);
}
var id = /* @__PURE__ */ N(DM, [["render", RM]]);
const HM = Object.assign(id, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + id.name, id);
  }
}), qM = S({
  name: "IconFindReplace",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-find-replace`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ZM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function KM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M42.353 40.854 36.01 34.51m0 0a9 9 0 0 1-15.364-6.364c0-5 4-9 9-9s9 4 9 9a8.972 8.972 0 0 1-2.636 6.364Zm5.636-26.365h-36m10 16h-10m10 16h-10" }, null, -1)
  ]), 14, ZM);
}
var rd = /* @__PURE__ */ N(qM, [["render", KM]]);
const YM = Object.assign(rd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + rd.name, rd);
  }
}), UM = S({
  name: "IconFontColors",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-font-colors`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), GM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function XM(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M9 41h30M16.467 22 11.5 34m20.032-12L24.998 7h-2l-6.532 15h15.065Zm0 0H16.467h15.065Zm0 0L36.5 34l-4.968-12Z" }, null, -1)
  ]), 14, GM);
}
var ad = /* @__PURE__ */ N(UM, [["render", XM]]);
const QM = Object.assign(ad, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ad.name, ad);
  }
}), _M = S({
  name: "IconFormula",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-formula`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), JM = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function eN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M40 8H10a1 1 0 0 0-1 1v.546a1 1 0 0 0 .341.753L24.17 23.273a1 1 0 0 1 .026 1.482l-.195.183L9.343 37.7a1 1 0 0 0-.343.754V39a1 1 0 0 0 1 1h30" }, null, -1)
  ]), 14, JM);
}
var sd = /* @__PURE__ */ N(_M, [["render", eN]]);
const tN = Object.assign(sd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + sd.name, sd);
  }
}), nN = S({
  name: "IconH1",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-h1`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), lN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function oN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6 6v18m0 0v18m0-18h20m0 0V6m0 18v18M40 42V21h-1l-6 3" }, null, -1)
  ]), 14, lN);
}
var ud = /* @__PURE__ */ N(nN, [["render", oN]]);
const iN = Object.assign(ud, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ud.name, ud);
  }
}), rN = S({
  name: "IconH2",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-h2`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), aN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function sN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6 6v18m0 0v18m0-18h20m0 0V6m0 18v18M44 40H32v-.5l7.5-9c.914-1.117 2.5-3 2.5-5 0-2.485-2.239-4.5-5-4.5s-5 2.515-5 5" }, null, -1)
  ]), 14, aN);
}
var cd = /* @__PURE__ */ N(rN, [["render", sN]]);
const uN = Object.assign(cd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + cd.name, cd);
  }
}), cN = S({
  name: "IconH3",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-h3`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), dN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function fN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6 6v18m0 0v18m0-18h20m0 0V6m0 18v18M37.001 30h-2m2 0a5 5 0 0 0 0-10h-.556a4.444 4.444 0 0 0-4.444 4.444m5 5.556a5 5 0 0 1 0 10h-.556a4.444 4.444 0 0 1-4.444-4.444" }, null, -1)
  ]), 14, dN);
}
var dd = /* @__PURE__ */ N(cN, [["render", fN]]);
const vN = Object.assign(dd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + dd.name, dd);
  }
}), pN = S({
  name: "IconH4",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-h4`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), mN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function hN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6 6v18m0 0v18m0-18h20m0 0V6m0 18v18m14.5-6H31v-1l8-15h1.5v16Zm0 0H44m-3.5 0v6" }, null, -1)
  ]), 14, mN);
}
var fd = /* @__PURE__ */ N(pN, [["render", hN]]);
const kN = Object.assign(fd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + fd.name, fd);
  }
}), gN = S({
  name: "IconH5",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-h5`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), yN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function bN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6 6v18m0 0v18m0-18h20m0 0V6m0 18v18M43 21H32.5v9h.5s1.5-1 4-1a5 5 0 0 1 5 5v1a5 5 0 0 1-5 5c-2.05 0-4.728-1.234-5.5-3" }, null, -1)
  ]), 14, yN);
}
var vd = /* @__PURE__ */ N(gN, [["render", bN]]);
const CN = Object.assign(vd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + vd.name, vd);
  }
}), $N = S({
  name: "IconH6",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-h6`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), wN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function SN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6 6v18m0 0v18m0-18h20m0 0V6m0 18v18M32 34.5c0 3.038 2.239 5.5 5 5.5s5-2.462 5-5.5-2.239-5.5-5-5.5-5 2.462-5 5.5Zm0 0v-5.73c0-4.444 3.867-7.677 8-7.263.437.044.736.08.952.115" }, null, -1)
  ]), 14, wN);
}
var pd = /* @__PURE__ */ N($N, [["render", SN]]);
const zN = Object.assign(pd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + pd.name, pd);
  }
}), LN = S({
  name: "IconH7",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-h7`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), jN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function PN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6 6v18m0 0v18m0-18h20m0 0V6m0 18v18m4-21h12v1l-4.4 16-1.1 3.5" }, null, -1)
  ]), 14, jN);
}
var md = /* @__PURE__ */ N(LN, [["render", PN]]);
const IN = Object.assign(md, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + md.name, md);
  }
}), BN = S({
  name: "IconHighlight",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-highlight`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), MN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function NN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M19 18V9.28a1 1 0 0 1 .758-.97l8-2A1 1 0 0 1 29 7.28V18m-10 0h-4a1 1 0 0 0-1 1v8h-4a1 1 0 0 0-1 1v15m10-25h10m0 0h4a1 1 0 0 1 1 1v8h4a1 1 0 0 1 1 1v15" }, null, -1)
  ]), 14, MN);
}
var hd = /* @__PURE__ */ N(BN, [["render", NN]]);
const ON = Object.assign(hd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + hd.name, hd);
  }
}), VN = S({
  name: "IconItalic",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-italic`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), TN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function AN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M18 8h9m8 0h-8m0 0-6 32m0 0h-8m8 0h9" }, null, -1)
  ]), 14, TN);
}
var kd = /* @__PURE__ */ N(VN, [["render", AN]]);
const EN = Object.assign(kd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + kd.name, kd);
  }
}), WN = S({
  name: "IconLineHeight",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-line-height`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), FN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function DN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M4 8h14.5M33 8H18.5m0 0v34" }, null, -1),
    $("path", {
      d: "M39 9.5 37 13h4l-2-3.5ZM39 38.5 37 35h4l-2 3.5Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M39 13h2l-2-3.5-2 3.5h2Zm0 0v22m0 0h2l-2 3.5-2-3.5h2Z" }, null, -1)
  ]), 14, FN);
}
var gd = /* @__PURE__ */ N(WN, [["render", DN]]);
const xN = Object.assign(gd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + gd.name, gd);
  }
}), RN = S({
  name: "IconOrderedList",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-ordered-list`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), HN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function qN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M13 24h30M13 37h30M13 11h30" }, null, -1),
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M5.578 13.06v1.695h5.041V13.06H9.164V7.555H7.748L5.255 8.968l.763 1.513 1.114-.636v3.215H5.578ZM5.37 26.205v1.49h5.07V26H7.964l.94-.94c.454-.44.783-.86.982-1.258.199-.404.298-.826.298-1.266 0-.686-.224-1.225-.683-1.6-.45-.372-1.093-.55-1.912-.55-.473 0-.933.072-1.38.214a3.63 3.63 0 0 0-1.133.582l-.066.053.652 1.533.113-.085c.263-.199.524-.345.783-.44.266-.094.524-.141.774-.141.309 0 .52.06.652.165.128.1.198.252.198.477 0 .177-.05.356-.154.54l-.001.002c-.099.186-.274.416-.528.69L5.37 26.205ZM10.381 38.344c0-.443-.118-.826-.358-1.145a1.702 1.702 0 0 0-.713-.56 1.652 1.652 0 0 0 .586-.52 1.73 1.73 0 0 0 .307-1.022c0-.404-.108-.763-.327-1.074a2.076 2.076 0 0 0-.918-.71c-.386-.166-.833-.247-1.34-.247-.48 0-.952.071-1.417.213-.459.134-.836.318-1.127.554l-.065.053.652 1.486.11-.076c.275-.193.563-.34.863-.442h.002c.3-.109.581-.162.844-.162.266 0 .454.065.579.18l.004.002c.128.107.198.262.198.48 0 .201-.07.33-.197.412-.138.089-.376.141-.733.141h-1.01v1.626h1.188c.371 0 .614.056.75.15.127.085.2.23.2.463 0 .254-.078.412-.21.503l-.002.002c-.136.097-.386.157-.777.157-.595 0-1.194-.199-1.8-.605l-.11-.073-.65 1.483.064.053c.285.236.662.424 1.127.565h.002c.465.136.95.203 1.456.203.852 0 1.538-.178 2.045-.546.517-.377.777-.896.777-1.544Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, HN);
}
var yd = /* @__PURE__ */ N(RN, [["render", qN]]);
const ZN = Object.assign(yd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + yd.name, yd);
  }
}), KN = S({
  name: "IconPaste",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-paste`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), YN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function UN(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("rect", {
      x: "8",
      y: "14",
      width: "24",
      height: "28",
      rx: "1"
    }, null, -1),
    $("path", {
      d: "M24 6h.01v.01H24V6ZM32 6h.01v.01H32V6ZM40 6h.01v.01H40V6ZM40 13h.01v.01H40V13ZM40 21h.01v.01H40V21Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M24 6h.01v.01H24V6ZM32 6h.01v.01H32V6ZM40 6h.01v.01H40V6ZM40 13h.01v.01H40V13ZM40 21h.01v.01H40V21Z" }, null, -1)
  ]), 14, YN);
}
var bd = /* @__PURE__ */ N(KN, [["render", UN]]);
const GN = Object.assign(bd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + bd.name, bd);
  }
}), XN = S({
  name: "IconQuote",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-quote`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), QN = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function _N(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M18.08 33.093a6 6 0 0 1-12 0c-.212-3.593 2.686-6 6-6a6 6 0 0 1 6 6ZM39.08 33.093a6 6 0 0 1-12 0c-.212-3.593 2.686-6 6-6a6 6 0 0 1 6 6Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M6.08 33.093a6 6 0 1 0 6-6c-3.314 0-6.212 2.407-6 6Zm0 0c-.5-8.5 1-25.5 15-24m6 24a6 6 0 1 0 6-6c-3.314 0-6.212 2.407-6 6Zm0 0c-.5-8.5 1-25.5 15-24" }, null, -1)
  ]), 14, QN);
}
var Cd = /* @__PURE__ */ N(XN, [["render", _N]]);
const JN = Object.assign(Cd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Cd.name, Cd);
  }
}), eO = S({
  name: "IconRedo",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-redo`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), tO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function nO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m32.678 23.78 7.778-7.778-7.778-7.778M39.19 16H18.5C12.149 16 7 21.15 7 27.5 7 33.852 12.149 39 18.5 39H31" }, null, -1)
  ]), 14, tO);
}
var $d = /* @__PURE__ */ N(eO, [["render", nO]]);
const lO = Object.assign($d, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + $d.name, $d);
  }
}), oO = S({
  name: "IconScissor",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-scissor`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), iO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function rO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m40.293 7.707-23.05 23.05m0 0a6 6 0 1 0-8.485 8.485 6 6 0 0 0 8.485-8.485Zm13.514 0a6 6 0 1 0 8.485 8.485 6 6 0 0 0-8.485-8.485Zm0 0L7.707 7.707" }, null, -1)
  ]), 14, iO);
}
var wd = /* @__PURE__ */ N(oO, [["render", rO]]);
const aO = Object.assign(wd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + wd.name, wd);
  }
}), sO = S({
  name: "IconSortAscending",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-sort-ascending`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), uO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function cO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M15 6v33.759a.1.1 0 0 1-.17.07L8 33m17-6h10.4v.65L27 39.35V40h11m-1-19L31.4 8h-.8L25 21" }, null, -1)
  ]), 14, uO);
}
var Sd = /* @__PURE__ */ N(sO, [["render", cO]]);
const dO = Object.assign(Sd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Sd.name, Sd);
  }
}), fO = S({
  name: "IconSortDescending",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-sort-descending`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), vO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function pO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M25 27h10.4v.65L27 39.35V40h11m-21.999 2V7.24a.1.1 0 0 0-.17-.07L9 14m28 7L31.4 8h-.8L25 21" }, null, -1)
  ]), 14, vO);
}
var zd = /* @__PURE__ */ N(fO, [["render", pO]]);
const mO = Object.assign(zd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + zd.name, zd);
  }
}), hO = S({
  name: "IconSort",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-sort`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), kO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function gO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M43 9H5m0 30h14m15.5-15H5" }, null, -1)
  ]), 14, kO);
}
var Ld = /* @__PURE__ */ N(hO, [["render", gO]]);
const yO = Object.assign(Ld, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ld.name, Ld);
  }
}), bO = S({
  name: "IconStrikethrough",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-strikethrough`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), CO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function $O(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M13 32c0 5.246 5.149 9 11.5 9S36 36.746 36 31.5c0-1.708-.5-4.5-3.5-5.695m0 0H43m-10.5 0H5M34 14.5C34 10.358 29.523 7 24 7s-10 3.358-10 7.5c0 1.794 1.6 4.21 3 5.5" }, null, -1)
  ]), 14, CO);
}
var jd = /* @__PURE__ */ N(bO, [["render", $O]]);
const wO = Object.assign(jd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + jd.name, jd);
  }
}), SO = S({
  name: "IconUnderline",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-underline`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), zO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function LO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M13 5v17.5C13 27 15.5 33 24 33s11-5 11-10.5V5M9 41h30" }, null, -1)
  ]), 14, zO);
}
var Pd = /* @__PURE__ */ N(SO, [["render", LO]]);
const jO = Object.assign(Pd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Pd.name, Pd);
  }
}), PO = S({
  name: "IconUndo",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-undo`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), IO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function BO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m15.322 23.78-7.778-7.778 7.778-7.778M8.81 16H29.5C35.851 16 41 21.15 41 27.5 41 33.852 35.851 39 29.5 39H17" }, null, -1)
  ]), 14, IO);
}
var Id = /* @__PURE__ */ N(PO, [["render", BO]]);
const MO = Object.assign(Id, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Id.name, Id);
  }
}), NO = S({
  name: "IconUnorderedList",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-unordered-list`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), OO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function VO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M13 24h30M5 11h4m4 26h30M13 11h30M5 24h4M5 37h4" }, null, -1)
  ]), 14, OO);
}
var Bd = /* @__PURE__ */ N(NO, [["render", VO]]);
const TO = Object.assign(Bd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Bd.name, Bd);
  }
}), AO = S({
  name: "IconMuteFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-mute-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), EO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function WO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M5.931 13.001A2 2 0 0 0 4 15v18a2 2 0 0 0 2 2h7.37l9.483 6.639A2 2 0 0 0 26 40v-6.93L5.931 13.001ZM35.27 28.199l-3.311-3.313a7.985 7.985 0 0 0-1.96-6.107.525.525 0 0 1 .011-.718l2.122-2.122a.485.485 0 0 1 .7.008c3.125 3.393 3.938 8.15 2.439 12.252ZM41.13 34.059l-2.936-2.937c3.07-5.89 2.226-13.288-2.531-18.348a.513.513 0 0 1 .004-.713l2.122-2.122a.492.492 0 0 1 .703.006c6.322 6.64 7.202 16.56 2.639 24.114ZM26 18.928l-8.688-8.688 5.541-3.878A2 2 0 0 1 26 8v10.928Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "m7.012 4.184 35.272 35.272-2.828 2.828L4.184 7.012l2.828-2.828Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, EO);
}
var Md = /* @__PURE__ */ N(AO, [["render", WO]]);
const FO = Object.assign(Md, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Md.name, Md);
  }
}), DO = S({
  name: "IconPauseCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-pause-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), xO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function RO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4 4 12.954 4 24s8.954 20 20 20Zm-6-27a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h3a1 1 0 0 0 1-1V18a1 1 0 0 0-1-1h-3Zm9 0a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h3a1 1 0 0 0 1-1V18a1 1 0 0 0-1-1h-3Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, xO);
}
var Nd = /* @__PURE__ */ N(DO, [["render", RO]]);
const HO = Object.assign(Nd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Nd.name, Nd);
  }
}), qO = S({
  name: "IconPlayCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-play-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ZO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function KO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M44 24c0 11.046-8.954 20-20 20S4 35.046 4 24 12.954 4 24 4s20 8.954 20 20Zm-23.662-7.783C19.302 15.605 18 16.36 18 17.575v12.85c0 1.214 1.302 1.97 2.338 1.358l10.89-6.425c1.03-.607 1.03-2.11 0-2.716l-10.89-6.425Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, ZO);
}
var Od = /* @__PURE__ */ N(qO, [["render", KO]]);
const YO = Object.assign(Od, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Od.name, Od);
  }
}), UO = S({
  name: "IconSkipNextFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-skip-next-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), GO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function XO(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M13.585 12.145a1 1 0 0 0-1.585.81v22.09a1 1 0 0 0 1.585.81L28.878 24.81a1 1 0 0 0 0-1.622L13.585 12.145Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M33 36a1 1 0 0 1-1-1V13a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v22a1 1 0 0 1-1 1h-2Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, GO);
}
var Vd = /* @__PURE__ */ N(UO, [["render", XO]]);
const QO = Object.assign(Vd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Vd.name, Vd);
  }
}), _O = S({
  name: "IconSkipPreviousFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-skip-previous-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), JO = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function eV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M34.414 35.855a1 1 0 0 0 1.586-.81v-22.09a1 1 0 0 0-1.586-.81L19.122 23.19a1 1 0 0 0 0 1.622l15.292 11.044Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M15 12a1 1 0 0 1 1 1v22a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V13a1 1 0 0 1 1-1h2Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, JO);
}
var Td = /* @__PURE__ */ N(_O, [["render", eV]]);
const tV = Object.assign(Td, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Td.name, Td);
  }
}), nV = S({
  name: "IconSoundFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-sound-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), lV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function oV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "m14 15 10-7v32l-10-7H6V15h8Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", {
      d: "M24.924 6.226A2 2 0 0 1 26 8v32a2 2 0 0 1-3.147 1.639L13.37 35H6a2 2 0 0 1-2-2V15a2 2 0 0 1 2-2h7.37l9.483-6.638a2 2 0 0 1 2.07-.136ZM35.314 35.042c6.248-6.249 6.248-16.38 0-22.628l2.828-2.828c7.81 7.81 7.81 20.474 0 28.284l-2.828-2.828Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", {
      d: "M29.657 29.728a8 8 0 0 0 0-11.314l2.828-2.828c4.687 4.686 4.687 12.284 0 16.97l-2.828-2.828Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, lV);
}
var Ad = /* @__PURE__ */ N(nV, [["render", oV]]);
const iV = Object.assign(Ad, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ad.name, Ad);
  }
}), rV = S({
  name: "IconBackward",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-backward`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), aV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function sV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M38.293 36.293 26.707 24.707a1 1 0 0 1 0-1.414l11.586-11.586c.63-.63 1.707-.184 1.707.707v23.172c0 .89-1.077 1.337-1.707.707ZM21 12.414v23.172c0 .89-1.077 1.337-1.707.707L7.707 24.707a1 1 0 0 1 0-1.414l11.586-11.586c.63-.63 1.707-.184 1.707.707Z" }, null, -1)
  ]), 14, aV);
}
var Ed = /* @__PURE__ */ N(rV, [["render", sV]]);
const uV = Object.assign(Ed, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ed.name, Ed);
  }
}), cV = S({
  name: "IconForward",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-forward`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), dV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function fV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m9.707 11.707 11.586 11.586a1 1 0 0 1 0 1.414L9.707 36.293c-.63.63-1.707.184-1.707-.707V12.414c0-.89 1.077-1.337 1.707-.707ZM27 35.586V12.414c0-.89 1.077-1.337 1.707-.707l11.586 11.586a1 1 0 0 1 0 1.414L28.707 36.293c-.63.63-1.707.184-1.707-.707Z" }, null, -1)
  ]), 14, dV);
}
var Wd = /* @__PURE__ */ N(cV, [["render", fV]]);
const vV = Object.assign(Wd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Wd.name, Wd);
  }
}), pV = S({
  name: "IconFullscreenExit",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-fullscreen-exit`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), mV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function hV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M35 6v8a1 1 0 0 0 1 1h8M13 6v8a1 1 0 0 1-1 1H4m31 27v-8a1 1 0 0 1 1-1h8m-31 9v-8a1 1 0 0 0-1-1H4" }, null, -1)
  ]), 14, mV);
}
var Fd = /* @__PURE__ */ N(pV, [["render", hV]]);
const kV = Object.assign(Fd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Fd.name, Fd);
  }
}), gV = S({
  name: "IconLiveBroadcast",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-live-broadcast`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), yV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function bV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M29 16h12a1 1 0 0 1 1 1v22a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V17a1 1 0 0 1 1-1h12m10 0 8-9m-8 9H19m0 0-8-9m17.281 21.88-6.195 4.475a1 1 0 0 1-1.586-.81v-8.262a1 1 0 0 1 1.521-.853l6.196 3.786a1 1 0 0 1 .064 1.664Z" }, null, -1)
  ]), 14, yV);
}
var Dd = /* @__PURE__ */ N(gV, [["render", bV]]);
const CV = Object.assign(Dd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Dd.name, Dd);
  }
}), $V = S({
  name: "IconMusic",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-music`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), wV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function SV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M15 37a4 4 0 1 0-8 0 4 4 0 0 0 8 0Zm0 0V18.5M41 37a4 4 0 1 0-8 0 4 4 0 0 0 8 0Zm0 0V16.5m-26 2V9.926a1 1 0 0 1 .923-.997l24-1.846A1 1 0 0 1 41 8.08v8.42m-26 2 26-2" }, null, -1)
  ]), 14, wV);
}
var xd = /* @__PURE__ */ N($V, [["render", SV]]);
const zV = Object.assign(xd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + xd.name, xd);
  }
}), LV = S({
  name: "IconMute",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-mute`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), jV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function PV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m19 11.5 4.833-4.35a.1.1 0 0 1 .167.075V17m-14-1H7.1a.1.1 0 0 0-.1.1v15.8a.1.1 0 0 0 .1.1H14l9.833 8.85a.1.1 0 0 0 .167-.075V31m6.071-14.071C32.535 19.393 34 23 32.799 26m2.929-14.728C41.508 17.052 42.5 25 39.123 32M6.5 6.5l35 35" }, null, -1)
  ]), 14, jV);
}
var Rd = /* @__PURE__ */ N(LV, [["render", PV]]);
const IV = Object.assign(Rd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Rd.name, Rd);
  }
}), BV = S({
  name: "IconPauseCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-pause-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), MV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function NV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M42 24c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6s18 8.059 18 18Z" }, null, -1),
    $("path", { d: "M19 19v10h1V19h-1ZM28 19v10h1V19h-1Z" }, null, -1)
  ]), 14, MV);
}
var Hd = /* @__PURE__ */ N(BV, [["render", NV]]);
const OV = Object.assign(Hd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Hd.name, Hd);
  }
}), VV = S({
  name: "IconPlayArrow",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-play-arrow`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), TV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function AV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M12.533 7.965A1 1 0 0 0 11 8.81v30.377a1 1 0 0 0 1.533.846L36.656 24.84a1 1 0 0 0 0-1.692L12.533 7.965Z" }, null, -1)
  ]), 14, TV);
}
var qd = /* @__PURE__ */ N(VV, [["render", AV]]);
const EV = Object.assign(qd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + qd.name, qd);
  }
}), WV = S({
  name: "IconPlayCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-play-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), FV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function DV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 42c9.941 0 18-8.059 18-18S33.941 6 24 6 6 14.059 6 24s8.059 18 18 18Z" }, null, -1),
    $("path", { d: "M19 17v14l12-7-12-7Z" }, null, -1)
  ]), 14, FV);
}
var Zd = /* @__PURE__ */ N(WV, [["render", DV]]);
const xV = Object.assign(Zd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Zd.name, Zd);
  }
}), RV = S({
  name: "IconRecordStop",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-record-stop`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), HV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function qV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "clip-rule": "evenodd",
      d: "M24 6c9.941 0 18 8.059 18 18s-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6Z"
    }, null, -1),
    $("path", {
      d: "M19 20a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1h-8a1 1 0 0 1-1-1v-8Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M19 20a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1h-8a1 1 0 0 1-1-1v-8Z" }, null, -1)
  ]), 14, HV);
}
var Kd = /* @__PURE__ */ N(RV, [["render", qV]]);
const ZV = Object.assign(Kd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Kd.name, Kd);
  }
}), KV = S({
  name: "IconRecord",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-record`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), YV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function UV(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "clip-rule": "evenodd",
      d: "M24 6c9.941 0 18 8.059 18 18s-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6Z"
    }, null, -1),
    $("path", {
      d: "M30 24a6 6 0 1 1-12 0 6 6 0 0 1 12 0Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M30 24a6 6 0 1 1-12 0 6 6 0 0 1 12 0Z" }, null, -1)
  ]), 14, YV);
}
var Yd = /* @__PURE__ */ N(KV, [["render", UV]]);
const GV = Object.assign(Yd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Yd.name, Yd);
  }
}), XV = S({
  name: "IconSkipNext",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-skip-next`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), QV = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function _V(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M34 24 10 40V8l24 16Z" }, null, -1),
    $("path", { d: "M38 6v36" }, null, -1)
  ]), 14, QV);
}
var Ud = /* @__PURE__ */ N(XV, [["render", _V]]);
const JV = Object.assign(Ud, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ud.name, Ud);
  }
}), eT = S({
  name: "IconSkipPrevious",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-skip-previous`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), tT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function nT(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m14 24 24 16V8L14 24Z" }, null, -1),
    $("path", { d: "M10 6v36" }, null, -1)
  ]), 14, tT);
}
var Gd = /* @__PURE__ */ N(eT, [["render", nT]]);
const lT = Object.assign(Gd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Gd.name, Gd);
  }
}), oT = S({
  name: "IconSound",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-sound`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), iT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function rT(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m14 16 10-9v34l-10-9H6V16h8Z" }, null, -1),
    $("path", { d: "M31.071 16.929c3.905 3.905 3.905 10.237 0 14.142M36.727 11.272c7.03 7.03 7.03 18.426 0 25.456" }, null, -1)
  ]), 14, iT);
}
var Xd = /* @__PURE__ */ N(oT, [["render", rT]]);
const aT = Object.assign(Xd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Xd.name, Xd);
  }
}), sT = S({
  name: "IconBytedanceColor",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-bytedance-color`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), uT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function cT(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 1024 1024",
    xmlns: "http://www.w3.org/2000/svg",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M280.416 794.112 128 829.952v-636.32l152.416 35.84z",
      fill: "#325AB4"
    }, null, -1),
    $("path", {
      d: "M928 828.48 800 864V160l128 35.52z",
      fill: "#78E6DC"
    }, null, -1),
    $("path", {
      d: "M480 798.304 352 832V480l128 33.696z",
      fill: "#3C8CFF"
    }, null, -1),
    $("path", {
      d: "M576 449.696 704 416v352l-128-33.696z",
      fill: "#00C8D2"
    }, null, -1)
  ]), 14, uT);
}
var Qd = /* @__PURE__ */ N(sT, [["render", cT]]);
const dT = Object.assign(Qd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Qd.name, Qd);
  }
}), fT = S({
  name: "IconLarkColor",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-lark-color`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), vT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function pT(e, t, n, o, i, r) {
  return v(), b("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 512 512",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      fill: "#00d6b9",
      d: "m273.46 264.31 1.01-1.01c.65-.65 1.36-1.36 2.06-2.01l1.41-1.36 4.17-4.12 5.73-5.58 4.88-4.83 4.57-4.52 4.78-4.73 4.37-4.32 6.13-6.03c1.16-1.16 2.36-2.26 3.57-3.37 2.21-2.01 4.52-3.97 6.84-5.88 2.16-1.71 4.37-3.37 6.64-4.98 3.17-2.26 6.43-4.32 9.75-6.33 3.27-1.91 6.64-3.72 10.05-5.43 3.22-1.56 6.54-3.02 9.9-4.32 1.86-.75 3.77-1.41 5.68-2.06.96-.3 1.91-.65 2.92-.96a241.19 241.19 0 0 0-45.6-91.5c-4.17-5.18-10.51-8.19-17.14-8.19H128.97c-1.81 0-3.32 1.46-3.32 3.32 0 1.06.5 2.01 1.36 2.66 60.13 44.09 110 100.75 146.04 166l.4-.45Z"
    }, null, -1),
    $("path", {
      fill: "#133c9a",
      d: "M203.43 419.4c90.99 0 170.27-50.22 211.6-124.43 1.46-2.61 2.87-5.23 4.22-7.89a96.374 96.374 0 0 1-6.94 11.41c-.9 1.26-1.81 2.51-2.77 3.77-1.21 1.56-2.41 3.02-3.67 4.47a98.086 98.086 0 0 1-3.07 3.37 85.486 85.486 0 0 1-6.64 6.28c-1.31 1.11-2.56 2.16-3.92 3.17a76.24 76.24 0 0 1-4.78 3.42c-1.01.7-2.06 1.36-3.12 2.01-1.06.65-2.16 1.31-3.32 1.96a91.35 91.35 0 0 1-6.99 3.52c-2.06.9-4.17 1.76-6.28 2.56a82.5 82.5 0 0 1-7.04 2.26 86.613 86.613 0 0 1-10.81 2.31c-2.61.4-5.33.7-7.99.9-2.82.2-5.68.25-8.55.25-3.17-.05-6.33-.25-9.55-.6-2.36-.25-4.73-.6-7.09-1.01-2.06-.35-4.12-.8-6.18-1.31-1.11-.25-2.16-.55-3.27-.85-3.02-.8-6.03-1.66-9.05-2.51-1.51-.45-3.02-.85-4.47-1.31-2.26-.65-4.47-1.36-6.69-2.06-1.81-.55-3.62-1.16-5.43-1.76-1.71-.55-3.47-1.11-5.18-1.71l-3.52-1.21c-1.41-.5-2.87-1.01-4.27-1.51l-3.02-1.11c-2.01-.7-4.02-1.46-5.98-2.21-1.16-.45-2.31-.85-3.47-1.31-1.56-.6-3.07-1.21-4.63-1.81-1.61-.65-3.27-1.31-4.88-1.96l-3.17-1.31-3.92-1.61-3.02-1.26-3.12-1.36-2.71-1.21-2.46-1.11-2.51-1.16-2.56-1.21-3.27-1.51-3.42-1.61c-1.21-.6-2.41-1.16-3.62-1.76l-3.07-1.51A508.746 508.746 0 0 1 65.6 190.35c-1.26-1.31-3.32-1.41-4.68-.15-.65.6-1.06 1.51-1.06 2.41l.1 155.49v12.62c0 7.34 3.62 14.18 9.7 18.25 39.56 26.44 86.12 40.47 133.73 40.37"
    }, null, -1),
    $("path", {
      fill: "#3370ff",
      d: "M470.83 200.21c-30.72-15.03-65.86-18.25-98.79-9-1.41.4-2.77.8-4.12 1.21-.96.3-1.91.6-2.92.96-1.91.65-3.82 1.36-5.68 2.06-3.37 1.31-6.64 2.77-9.9 4.32-3.42 1.66-6.79 3.47-10.05 5.38-3.37 1.96-6.59 4.07-9.75 6.33-2.26 1.61-4.47 3.27-6.64 4.98-2.36 1.91-4.63 3.82-6.84 5.88-1.21 1.11-2.36 2.21-3.57 3.37l-6.13 6.03-4.37 4.32-4.78 4.73-4.57 4.52-4.88 4.83-5.68 5.63-4.17 4.12-1.41 1.36c-.65.65-1.36 1.36-2.06 2.01l-1.01 1.01-1.56 1.46-1.76 1.61c-15.13 13.93-32.02 25.84-50.17 35.54l3.27 1.51 2.56 1.21 2.51 1.16 2.46 1.11 2.71 1.21 3.12 1.36 3.02 1.26 3.92 1.61 3.17 1.31c1.61.65 3.27 1.31 4.88 1.96 1.51.6 3.07 1.21 4.63 1.81 1.16.45 2.31.85 3.47 1.31 2.01.75 4.02 1.46 5.98 2.21l3.02 1.11c1.41.5 2.82 1.01 4.27 1.51l3.52 1.21c1.71.55 3.42 1.16 5.18 1.71 1.81.6 3.62 1.16 5.43 1.76 2.21.7 4.47 1.36 6.69 2.06 1.51.45 3.02.9 4.47 1.31 3.02.85 6.03 1.71 9.05 2.51 1.11.3 2.16.55 3.27.85 2.06.5 4.12.9 6.18 1.31 2.36.4 4.73.75 7.09 1.01 3.22.35 6.38.55 9.55.6 2.87.05 5.73-.05 8.55-.25 2.71-.2 5.38-.5 7.99-.9 3.62-.55 7.24-1.36 10.81-2.31 2.36-.65 4.73-1.41 7.04-2.26a75.16 75.16 0 0 0 6.28-2.56 91.35 91.35 0 0 0 6.99-3.52c1.11-.6 2.21-1.26 3.32-1.96 1.11-.65 2.11-1.36 3.12-2.01 1.61-1.11 3.22-2.21 4.78-3.42 1.36-1.01 2.66-2.06 3.92-3.17 2.26-1.96 4.47-4.07 6.59-6.28 1.06-1.11 2.06-2.21 3.07-3.37 1.26-1.46 2.51-2.97 3.67-4.47a73.33 73.33 0 0 0 2.77-3.77c2.51-3.62 4.83-7.39 6.89-11.31l2.36-4.68 21.01-41.88.25-.5c6.94-14.98 16.39-28.45 28-39.97Z"
    }, null, -1)
  ]), 14, vT);
}
var _d = /* @__PURE__ */ N(fT, [["render", pT]]);
const mT = Object.assign(_d, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + _d.name, _d);
  }
}), hT = S({
  name: "IconTiktokColor",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-tiktok-color`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), kT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function gT(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 1024 1024",
    xmlns: "http://www.w3.org/2000/svg",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    Cr('<path d="M928 310.4v148.8c-8 0-17.6 1.6-27.2 1.6-72 0-139.2-27.2-190.4-70.4v316.8c0 64-20.8 124.8-57.6 172.8-51.2 68.8-134.4 115.2-228.8 115.2-102.4 0-192-54.4-241.6-134.4 51.2 48 120 78.4 195.2 78.4 92.8 0 176-44.8 227.2-115.2 35.2-48 57.6-107.2 57.6-172.8V332.8c51.2 44.8 116.8 70.4 190.4 70.4 9.6 0 17.6 0 27.2-1.6v-96c14.4 3.2 27.2 4.8 41.6 4.8h6.4z" fill="#FF004F"></path><path d="M464 420.8v164.8c-11.2-3.2-24-4.8-35.2-4.8-70.4 0-128 59.2-128 131.2 0 16 3.2 30.4 8 44.8-32-24-54.4-62.4-54.4-105.6 0-72 57.6-131.2 128-131.2 12.8 0 24 1.6 35.2 4.8V419.2h9.6c12.8 0 25.6 0 36.8 1.6zM734.4 192c-28.8-25.6-49.6-60.8-60.8-97.6H712v22.4c3.2 25.6 11.2 51.2 22.4 75.2z" fill="#FF004F"></path><path d="M881.6 307.2v96c-8 1.6-17.6 1.6-27.2 1.6-72 0-139.2-27.2-190.4-70.4v316.8c0 64-20.8 124.8-57.6 172.8-52.8 70.4-134.4 115.2-227.2 115.2-75.2 0-144-30.4-195.2-78.4-27.2-44.8-43.2-96-43.2-152 0-155.2 123.2-281.6 276.8-286.4V528c-11.2-3.2-24-4.8-35.2-4.8-70.4 0-128 59.2-128 131.2 0 43.2 20.8 83.2 54.4 105.6 17.6 49.6 65.6 86.4 120 86.4 70.4 0 128-59.2 128-131.2V94.4h116.8c11.2 38.4 32 72 60.8 97.6 28.8 57.6 83.2 100.8 147.2 115.2z"></path><path d="M417.6 364.8v54.4C264 424 140.8 550.4 140.8 705.6c0 56 16 107.2 43.2 152-54.4-52.8-88-126.4-88-209.6 0-158.4 128-286.4 284.8-286.4 12.8 0 25.6 1.6 36.8 3.2z" fill="#00F7EF"></path><path d="M673.6 94.4H556.8V712c0 72-57.6 131.2-128 131.2-56 0-102.4-35.2-120-86.4 20.8 14.4 46.4 24 73.6 24 70.4 0 128-57.6 128-129.6V32h155.2v3.2c0 6.4 0 12.8 1.6 19.2 0 12.8 3.2 27.2 6.4 40zm208 153.6v57.6c-64-12.8-118.4-56-148.8-113.6 40 36.8 91.2 57.6 148.8 56z" fill="#00F7EF"></path>', 5)
  ]), 14, kT);
}
var Jd = /* @__PURE__ */ N(hT, [["render", gT]]);
const yT = Object.assign(Jd, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Jd.name, Jd);
  }
}), bT = S({
  name: "IconXiguaColor",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-xigua-color`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), CT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function $T(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 1024 1024",
    xmlns: "http://www.w3.org/2000/svg",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M381.968 38.684c-202.85 54.614-351.085 232.757-371.89 446.01C-.326 590.018 28.281 630.328 140.108 668.037c104.026 33.808 176.843 101.425 209.351 189.846 40.31 115.729 44.211 122.23 91.023 144.336 40.31 19.504 58.514 19.504 131.332 7.802 211.951-36.41 362.788-171.642 416.101-374.492C1059.434 368.965 882.59 90.697 605.623 32.183 517.2 13.978 470.39 15.279 381.968 38.684zm176.843 322.48c158.64 74.117 201.55 158.638 119.63 237.957-102.725 97.524-240.56 136.534-291.271 80.62-20.806-23.406-24.707-48.112-24.707-161.24s3.901-137.833 24.707-161.239c32.507-36.409 88.421-35.108 171.641 3.901z",
      fill: "#FE163E"
    }, null, -1)
  ]), 14, CT);
}
var ef = /* @__PURE__ */ N(bT, [["render", $T]]);
const wT = Object.assign(ef, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ef.name, ef);
  }
}), ST = S({
  name: "IconFaceBookCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-faceBook-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), zT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function LT(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M24 1C11.29 1 1 11.29 1 24s10.29 23 23 23 23-10.29 23-23S36.71 1 24 1Zm6.172 22.88H26.18v14.404h-5.931V23.88H17.22v-4.962h3.027V15.89c0-3.993 1.695-6.414 6.414-6.414h3.993v4.962h-2.421c-1.815 0-1.936.727-1.936 1.936v2.421h4.478l-.605 5.084h.001Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, zT);
}
var tf = /* @__PURE__ */ N(ST, [["render", LT]]);
const jT = Object.assign(tf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + tf.name, tf);
  }
}), PT = S({
  name: "IconFacebookSquareFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-facebook-square-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), IT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function BT(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M43.125 2.475c.6 0 1.2.225 1.688.713.524.487.75 1.012.75 1.612v38.363c0 .6-.263 1.2-.75 1.612-.526.488-1.088.713-1.688.713H32.138V28.913h5.625l.825-6.563h-6.45v-4.275c0-2.137 1.087-3.225 3.3-3.225h3.374V9.263c-1.2-.225-2.85-.338-5.024-.338-2.513 0-4.5.75-6.038 2.25-1.538 1.5-2.288 3.675-2.288 6.375v4.8h-5.625v6.563h5.625v16.575h-20.7c-.6 0-1.2-.225-1.612-.713-.487-.487-.712-1.012-.712-1.612V4.8c0-.6.224-1.2.712-1.612.488-.488 1.012-.713 1.613-.713h38.362Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, IT);
}
var nf = /* @__PURE__ */ N(PT, [["render", BT]]);
const MT = Object.assign(nf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + nf.name, nf);
  }
}), NT = S({
  name: "IconGoogleCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-google-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), OT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function VT(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M32.571 33.526c-2.084 1.92-4.927 3.05-8.322 3.05a12.568 12.568 0 0 1-12.572-12.577A12.58 12.58 0 0 1 24.25 11.416a12.103 12.103 0 0 1 8.414 3.277L29.061 18.3a6.787 6.787 0 0 0-4.807-1.88c-3.277 0-6.045 2.213-7.037 5.186a7.567 7.567 0 0 0-.394 2.392c0 .833.144 1.638.394 2.391.992 2.973 3.763 5.187 7.032 5.187 1.696 0 3.133-.449 4.254-1.202a5.778 5.778 0 0 0 2.513-3.8h-6.767V21.71h11.844c.15.825.227 1.682.227 2.57 0 3.835-1.371 7.055-3.749 9.246ZM24 1A23 23 0 1 0 24 47 23 23 0 0 0 24 1Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, OT);
}
var lf = /* @__PURE__ */ N(NT, [["render", VT]]);
const TT = Object.assign(lf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + lf.name, lf);
  }
}), AT = S({
  name: "IconQqCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-qq-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ET = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function WT(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M24.007 1C11.281 1 1 11.281 1 24.007c0 13.23 11.216 23.87 24.733 22.936 11.288-.791 20.49-9.994 21.21-21.354C47.877 12.144 37.237 1 24.007 1Zm11.36 29.262s-.79 2.23-2.3 4.242c0 0 2.66.935 2.444 3.236 0 0 .072 2.66-5.68 2.444 0 0-4.026-.287-5.248-2.013h-1.079c-1.222 1.726-5.248 2.013-5.248 2.013-5.752.216-5.68-2.444-5.68-2.444-.216-2.373 2.444-3.236 2.444-3.236-1.51-2.013-2.3-4.241-2.3-4.241-3.596 5.895-3.236-.791-3.236-.791.647-3.955 3.523-6.543 3.523-6.543-.431-3.595 1.078-4.242 1.078-4.242.216-11.072 9.707-10.929 9.922-10.929.216 0 9.707-.215 9.994 10.929 0 0 1.51.647 1.079 4.242 0 0 2.876 2.588 3.523 6.543 0 0 .36 6.686-3.236.79Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, ET);
}
var of = /* @__PURE__ */ N(AT, [["render", WT]]);
const FT = Object.assign(of, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + of.name, of);
  }
}), DT = S({
  name: "IconTwitterCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-twitter-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), xT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function RT(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M24 1C11.296 1 1 11.297 1 24s10.296 23 23 23c12.703 0 23-10.297 23-23S36.703 1 24 1Zm11.698 18.592c-.13 9.818-6.408 16.542-15.78 16.965-3.864.176-6.664-1.072-9.1-2.62 2.855.456 6.397-.686 8.292-2.307-2.8-.273-4.458-1.698-5.233-3.991.808.14 1.66.103 2.43-.06-2.527-.846-4.331-2.407-4.424-5.68.709.323 1.448.626 2.43.686-1.891-1.075-3.29-5.007-1.688-7.607 2.806 3.076 6.182 5.586 11.724 5.926-1.391-5.949 6.492-9.175 9.791-5.177 1.395-.27 2.53-.799 3.622-1.374-.45 1.381-1.315 2.347-2.37 3.119 1.158-.157 2.184-.44 3.06-.872-.544 1.128-1.732 2.14-2.754 2.992Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, xT);
}
var rf = /* @__PURE__ */ N(DT, [["render", RT]]);
const HT = Object.assign(rf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + rf.name, rf);
  }
}), qT = S({
  name: "IconWeiboCircleFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-weibo-circle-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ZT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function KT(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M24 47a23 23 0 1 1 23-23 22.988 22.988 0 0 1-23 23Zm1.276-26.994c-.544.063-2.259 1.171-1.297-1.108C25 15 20.235 15.293 17.874 16.16A23.776 23.776 0 0 0 7.649 27.283c-2.007 6.419 5.018 10.329 10.246 11.123 5.227.795 13.068-.502 16.622-4.85 2.635-3.179 3.137-7.507-1.84-8.761-1.651-.398-.69-1.088-.271-2.259a2.775 2.775 0 0 0-2.175-3.24 2.092 2.092 0 0 0-.335-.042 12.468 12.468 0 0 0-4.62.752Zm7.004-3.889a2.326 2.326 0 0 0-1.903.544c-.377.339-.418 1.338.962 1.652.458.021.913.084 1.36.188a1.836 1.836 0 0 1 1.233 2.07c-.21 1.924.878 2.237 1.652 1.714a1.647 1.647 0 0 0 .627-1.338 4.117 4.117 0 0 0-3.325-4.767c-.042-.008-.61-.063-.606-.063Zm7.423.084a8.408 8.408 0 0 0-6.838-4.6c-1.129-.126-3.512-.397-3.784 1.15a1.17 1.17 0 0 0 .857 1.4c.042 0 .084.022.126.022.523.02 1.048 0 1.568-.063a6.481 6.481 0 0 1 6.524 6.44c0 .3-.02.601-.063.9-.063.355-.105.71-.147 1.066A1.277 1.277 0 0 0 38.93 24a1.255 1.255 0 0 0 1.338-.648c.71-2.373.501-4.926-.585-7.151h.02ZM21.616 36.44c-5.457.69-10.245-1.673-10.684-5.27-.44-3.595 3.575-7.066 9.033-7.756 5.457-.69 10.245 1.672 10.705 5.269.46 3.596-3.617 7.088-9.075 7.757h.021Zm-1.484-10.266a5.181 5.181 0 0 0-5.353 4.913 4.662 4.662 0 0 0 4.935 4.391c.14-.004.28-.017.418-.042a5.503 5.503 0 0 0 5.185-5.143 4.472 4.472 0 0 0-4.746-4.182l-.44.063Zm1.003 4.244a.669.669 0 0 1-.773-.544v-.083a.76.76 0 0 1 .774-.711.642.642 0 0 1 .731.544.076.076 0 0 1 .021.062.807.807 0 0 1-.753.732Zm-2.78 2.781a1.65 1.65 0 0 1-1.861-1.422.266.266 0 0 1-.021-.125 1.844 1.844 0 0 1 1.882-1.736 1.562 1.562 0 0 1 1.819 1.297.46.46 0 0 1 .02.167 1.96 1.96 0 0 1-1.84 1.819Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, ZT);
}
var af = /* @__PURE__ */ N(qT, [["render", KT]]);
const YT = Object.assign(af, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + af.name, af);
  }
}), UT = S({
  name: "IconAlipayCircle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-alipay-circle`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), GT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function XT(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M10.8 27.025c-.566.456-1.174 1.122-1.35 1.968-.24 1.156-.05 2.604 1.065 3.739 1.352 1.376 3.405 1.753 4.292 1.818 2.41.174 4.978-1.02 6.913-2.384.759-.535 2.058-1.61 3.3-3.268-2.783-1.437-6.257-3.026-9.97-2.87-1.898.079-3.256.472-4.25.997Zm35.29 6.354A23.872 23.872 0 0 0 48 24C48 10.767 37.234 0 24 0S0 10.767 0 24c0 13.234 10.766 24 24 24 7.987 0 15.07-3.925 19.436-9.943a2688.801 2688.801 0 0 0-15.11-7.467c-1.999 2.277-4.953 4.56-8.29 5.554-2.097.623-3.986.86-5.963.457-1.956-.4-3.397-1.317-4.237-2.235-.428-.469-.92-1.064-1.275-1.773.033.09.056.143.056.143s-.204-.353-.361-.914a4.03 4.03 0 0 1-.157-.85 4.383 4.383 0 0 1-.009-.612 4.409 4.409 0 0 1 .078-1.128c.197-.948.601-2.054 1.649-3.08 2.3-2.251 5.38-2.372 6.976-2.363 2.363.014 6.47 1.048 9.928 2.27.958-2.04 1.573-4.221 1.97-5.676H14.31v-1.555h7.384V15.72h-8.938v-1.555h8.938v-3.108c0-.427.084-.778.777-.778h3.498v3.886h9.717v1.555H25.97v3.11h7.773s-.78 4.35-3.221 8.64c5.416 1.934 13.037 4.914 15.568 5.91Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, GT);
}
var sf = /* @__PURE__ */ N(UT, [["render", XT]]);
const QT = Object.assign(sf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + sf.name, sf);
  }
}), _T = S({
  name: "IconCodeSandbox",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-code-sandbox`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), JT = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function eA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "m25.002 1.6 17.9 10.3c.6.4 1 1 1 1.7v20.7c0 .7-.4 1.4-1 1.7l-17.9 10.4c-.6.4-1.4.4-2 0l-17.9-10.3c-.6-.4-1-1-1-1.7V13.7c0-.7.4-1.4 1-1.7l17.9-10.4c.6-.4 1.4-.4 2 0Zm13.5 12.4-7.9-4.5-6.6 4.5-6.5-4-7.3 4.3 13.8 8.7 14.5-9Zm-16.5 26.4V26.3l-14-8.9v7.9l8 5.5V37l6 3.4Zm4 0 6-3.5v-5.2l8-5.5v-8.9l-14 8.9v14.2Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, JT);
}
var uf = /* @__PURE__ */ N(_T, [["render", eA]]);
const tA = Object.assign(uf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + uf.name, uf);
  }
}), nA = S({
  name: "IconCodepen",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-codepen`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), lA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function oA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M45 15.7v17.1L24.5 44.7c-.3.2-.7.2-1 0l-20-11.5c-.3-.2-.5-.5-.5-.9V15.7c0-.4.2-.7.5-.9l20-11.6c.3-.2.7-.2 1 0l20 11.6c.3.2.5.5.5.9ZM26 9v9.8l5.5 3.2 8.5-4.9L26 9Zm-4 0L8 17.1l8.4 4.9 5.6-3.2V9Zm0 21.2L16.5 27 9 31.4 22 39v-8.8Zm17 1.2L31.4 27 26 30.2V39l13-7.6Zm2-3.4v-6l-5 3 5 3Zm-29-3-5-3v6l5-3Zm8 0 4 2 4-2-4-2-4 2Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, lA);
}
var cf = /* @__PURE__ */ N(nA, [["render", oA]]);
const iA = Object.assign(cf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + cf.name, cf);
  }
}), rA = S({
  name: "IconFacebook",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-facebook`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), aA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function sA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M35.184 15.727 34.312 24h-6.613v24h-9.933V24h-4.95v-8.273h4.95v-4.98C17.766 4.016 20.564 0 28.518 0h6.61v8.273H30.99c-3.086 0-3.292 1.166-3.292 3.32v4.134h7.485Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, aA);
}
var df = /* @__PURE__ */ N(rA, [["render", sA]]);
const uA = Object.assign(df, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + df.name, df);
  }
}), cA = S({
  name: "IconGithub",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-github`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), dA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function fA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M.056 24.618c0 10.454 6.7 19.344 16.038 22.608 1.259.32 1.067-.582 1.067-1.19v-4.148c-7.265.853-7.553-3.957-8.043-4.758-.987-1.686-3.312-2.112-2.62-2.912 1.654-.853 3.34.213 5.291 3.1 1.413 2.09 4.166 1.738 5.562 1.385a6.777 6.777 0 0 1 1.856-3.253C11.687 34.112 8.55 29.519 8.55 24.057c0-2.646.874-5.082 2.586-7.045-1.088-3.243.102-6.01.26-6.422 3.11-.282 6.337 2.225 6.587 2.421 1.766-.474 3.782-.73 6.038-.73 2.266 0 4.293.26 6.069.74.603-.458 3.6-2.608 6.49-2.345.155.41 1.317 3.12.294 6.315 1.734 1.968 2.62 4.422 2.62 7.077 0 5.472-3.158 10.07-10.699 11.397a6.82 6.82 0 0 1 2.037 4.875v6.02c.042.48 0 .96.806.96 9.477-3.194 16.299-12.15 16.299-22.697C47.938 11.396 37.218.68 23.996.68 10.77.675.055 11.391.055 24.617l.001.001Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, dA);
}
var ff = /* @__PURE__ */ N(cA, [["render", fA]]);
const vA = Object.assign(ff, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + ff.name, ff);
  }
}), pA = S({
  name: "IconGitlab",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-gitlab`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), mA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function hA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M45.53 26.154 39.694 6.289v-.005c-.407-1.227-1.377-1.955-2.587-1.955-1.254 0-2.277.723-2.663 1.885L30.62 17.625H17.4l-3.825-11.41c-.386-1.163-1.41-1.886-2.663-1.886-1.237 0-2.276.792-2.592 1.96l-5.83 19.865a2.047 2.047 0 0 0 .724 2.18l19.741 14.807c.14.193.332.338.557.418l.461.343.455-.343c.263-.091.483-.252.638-.477L44.8 28.33a2.03 2.03 0 0 0 .728-2.175ZM36.84 6.932c.053-.096.155-.102.187-.102.06 0 .134.016.182.161l3.183 10.704H33.24l3.6-10.763Zm-26.11.054c.047-.14.122-.156.181-.156.145 0 .156.006.183.091L14.699 17.7H7.633l3.096-10.714ZM5.076 26.502l1.511-5.213 10.843 14.475-12.354-9.262Zm3.96-6.236h6.54l4.865 15.23-11.406-15.23Zm15.01 17.877-5.743-17.877h11.48l-5.737 17.877Zm8.459-17.877h6.402L27.642 35.31l4.864-15.043Zm-2.18 15.745L41.43 21.187l1.58 5.315-12.685 9.509Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, mA);
}
var vf = /* @__PURE__ */ N(pA, [["render", hA]]);
const kA = Object.assign(vf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + vf.name, vf);
  }
}), gA = S({
  name: "IconGoogle",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-google`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), yA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function bA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M23.997 21.054h19.42a19.46 19.46 0 0 1 .321 3.428c0 3.875-.812 7.335-2.437 10.38-1.625 3.044-3.942 5.424-6.951 7.138-3.01 1.714-6.46 2.572-10.353 2.572-2.803 0-5.473-.54-8.009-1.621-2.535-1.08-4.723-2.54-6.562-4.38-1.84-1.839-3.3-4.026-4.38-6.562A20.223 20.223 0 0 1 3.426 24c0-2.803.54-5.473 1.62-8.009 1.08-2.535 2.54-4.723 4.38-6.562 1.84-1.84 4.027-3.3 6.562-4.38a20.223 20.223 0 0 1 8.01-1.62c5.356 0 9.955 1.794 13.794 5.384l-5.598 5.384c-2.197-2.125-4.929-3.188-8.197-3.188-2.303 0-4.433.58-6.388 1.741a12.83 12.83 0 0 0-4.648 4.728c-1.142 1.99-1.714 4.165-1.714 6.522s.572 4.531 1.714 6.523a12.83 12.83 0 0 0 4.648 4.727c1.955 1.16 4.085 1.741 6.388 1.741 1.554 0 2.982-.214 4.286-.643 1.303-.428 2.375-.964 3.214-1.607a11.63 11.63 0 0 0 2.197-2.196c.625-.822 1.084-1.598 1.38-2.33a9.84 9.84 0 0 0 .602-2.09H23.997v-7.071Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, yA);
}
var pf = /* @__PURE__ */ N(gA, [["render", bA]]);
const CA = Object.assign(pf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + pf.name, pf);
  }
}), $A = S({
  name: "IconQqZone",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-qq-zone`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), wA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function SA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M25.1 3.9c.2.1.4.3.5.5l6.8 10L44 17.8c1.1.3 1.7 1.4 1.4 2.5-.1.2-.2.5-.3.7l-7.4 9.5.4 12c0 1.1-.8 2-1.9 2.1-.2 0-.5 0-.7-.1L24 40.4l-11.3 4.1c-1 .4-2.2-.2-2.6-1.2-.1-.3-.1-.6-.1-.8l.4-12L3 20.9c-.7-.9-.5-2.1.4-2.8.2-.2.4-.3.7-.3l11.6-3.4 6.8-10c.5-.9 1.7-1.1 2.6-.5ZM24 9.1l-5.9 8.7-10.1 3 6.5 8.3-.3 10.5 9.9-3.6 9.9 3.6-.3-10.5 6.5-8.3-10.1-3L24 9.1Zm5 11.5c.8 0 1.5.5 1.8 1.2.3.7.1 1.6-.5 2.1L24 29.6h5c1 0 1.9.9 1.9 1.9 0 1-.9 1.9-1.9 1.9H19c-.8 0-1.5-.5-1.8-1.2-.3-.7-.1-1.6.5-2.1l6.3-5.7h-5c-1 0-1.9-.9-1.9-1.9 0-1 .9-1.9 1.9-1.9h10Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, wA);
}
var mf = /* @__PURE__ */ N($A, [["render", SA]]);
const zA = Object.assign(mf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + mf.name, mf);
  }
}), LA = S({
  name: "IconQq",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-qq`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), jA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function PA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M7.85 32.825s1.153 3.136 3.264 5.955c0 0-3.779 1.281-3.458 4.61 0 0-.128 3.714 8.069 3.458 0 0 5.764-.45 7.494-2.88h1.52c1.73 2.432 7.494 2.88 7.494 2.88 8.193.256 8.068-3.457 8.068-3.457.318-3.33-3.458-4.611-3.458-4.611 2.11-2.82 3.264-5.955 3.264-5.955 5.122 8.259 4.611-1.154 4.611-1.154-.96-5.57-4.995-9.221-4.995-9.221.576-5.058-1.537-5.955-1.537-5.955C37.742.844 24.26 1.12 23.978 1.126 23.694 1.12 10.21.846 9.767 16.495c0 0-2.113.897-1.537 5.955 0 0-4.034 3.65-4.995 9.221.005 0-.51 9.413 4.615 1.154Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, jA);
}
var hf = /* @__PURE__ */ N(LA, [["render", PA]]);
const IA = Object.assign(hf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + hf.name, hf);
  }
}), BA = S({
  name: "IconTwitter",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-twitter`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), MA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function NA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M43.277 13.575c0 16.613-10.912 28.575-26.962 29.1-6.788.525-11.438-1.537-15.6-4.65 4.65.525 10.912-1.012 13.987-4.163-4.65 0-7.275-2.625-8.812-6.187h4.162C5.89 26.1 2.74 22.987 2.74 17.812c1.012.525 2.062 1.013 4.162 1.013-3.637-2.063-5.7-8.813-3.112-12.975 4.65 5.175 10.35 9.863 19.762 10.35C20.927 5.85 34.465.6 40.165 7.388c2.625-.525 4.162-1.538 6.187-2.625-.525 2.625-2.062 4.162-4.162 5.175 2.062 0 3.637-.525 5.175-1.538-.488 2.063-2.55 4.162-4.088 5.175Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, MA);
}
var kf = /* @__PURE__ */ N(BA, [["render", NA]]);
const OA = Object.assign(kf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + kf.name, kf);
  }
}), VA = S({
  name: "IconWechat",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-wechat`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), TA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function AA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M32.09 16.362a14.39 14.39 0 0 0-6.927 1.716 13.087 13.087 0 0 0-5.008 4.676 11.936 11.936 0 0 0-1.856 6.473c.01 1.137.185 2.273.517 3.36h-1.505a26.653 26.653 0 0 1-4.766-.593l-.925-.166-5.665 2.93 1.55-4.848C3.179 26.783 1.018 23.077 1 18.792a11.951 11.951 0 0 1 2.188-6.927 14.943 14.943 0 0 1 5.938-5.027 18.579 18.579 0 0 1 8.248-1.837A18.82 18.82 0 0 1 24.8 6.506a16.863 16.863 0 0 1 5.893 4.128 11.963 11.963 0 0 1 2.992 5.817 17.922 17.922 0 0 0-1.595-.09Zm-20.152-.414a2.167 2.167 0 0 0 1.505-.471c.405-.378.62-.908.593-1.46a1.881 1.881 0 0 0-.592-1.46 2.025 2.025 0 0 0-1.506-.535 2.778 2.778 0 0 0-1.67.535c-.454.323-.728.849-.728 1.401a1.708 1.708 0 0 0 .727 1.523 2.925 2.925 0 0 0 1.671.467ZM47 28.99a9.573 9.573 0 0 1-1.59 5.193c-1.128 1.6-2.52 3-4.129 4.128l1.258 4.129-4.51-2.413h-.243a20.758 20.758 0 0 1-4.6.76 15.538 15.538 0 0 1-7.03-1.59 13.089 13.089 0 0 1-5.008-4.313 10.501 10.501 0 0 1-1.838-5.939 10.29 10.29 0 0 1 1.838-5.92c1.266-1.847 3-3.334 5.008-4.313a15.579 15.579 0 0 1 7.03-1.59 14.919 14.919 0 0 1 6.761 1.59 13.286 13.286 0 0 1 5.09 4.312 10.004 10.004 0 0 1 1.94 5.966H47ZM23.407 11.955a2.77 2.77 0 0 0-1.747.534 1.65 1.65 0 0 0-.76 1.46c-.017.584.27 1.146.76 1.46.498.36 1.1.544 1.716.535a2.083 2.083 0 0 0 1.505-.472c.368-.404.561-.925.534-1.46a1.834 1.834 0 0 0-.534-1.532 1.887 1.887 0 0 0-1.532-.534h.063v.009h-.005Zm5.256 15.03a2.016 2.016 0 0 0 1.46-.498c.332-.288.525-.7.534-1.137a1.612 1.612 0 0 0-.534-1.136 2.062 2.062 0 0 0-1.46-.499 1.58 1.58 0 0 0-1.092.499c-.305.296-.49.71-.498 1.136.009.427.184.84.498 1.137.288.305.679.48 1.092.499Zm8.953 0a2.016 2.016 0 0 0 1.46-.498c.332-.288.525-.7.534-1.137a1.558 1.558 0 0 0-.593-1.136 2.12 2.12 0 0 0-1.401-.499 1.493 1.493 0 0 0-1.092.499c-.305.296-.49.71-.498 1.136.009.427.184.84.498 1.137.279.305.674.49 1.092.499Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, TA);
}
var gf = /* @__PURE__ */ N(VA, [["render", AA]]);
const EA = Object.assign(gf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + gf.name, gf);
  }
}), WA = S({
  name: "IconWechatpay",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-wechatpay`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), FA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function DA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M17.514 29.52a1.502 1.502 0 0 1-.715.165c-.608 0-1.104-.33-1.38-.826l-.113-.219-4.357-9.493c-.054-.112-.054-.219-.054-.33 0-.444.331-.774.774-.774.165 0 .33.053.496.165l5.13 3.643c.384.218.827.384 1.323.384.277 0 .55-.054.827-.166l24.058-10.704C39.2 6.288 32.085 2.976 24.026 2.976 10.896 2.976.191 11.861.191 22.837c0 5.958 3.2 11.366 8.22 15.008.383.278.66.774.66 1.27 0 .165-.053.33-.112.496-.384 1.488-1.05 3.92-1.05 4.026a2.025 2.025 0 0 0-.112.608c0 .443.33.774.773.774.165 0 .33-.054.443-.166l5.184-3.034c.384-.219.826-.384 1.27-.384.218 0 .495.053.714.112a27.712 27.712 0 0 0 7.781 1.104c13.13 0 23.835-8.886 23.835-19.862 0-3.312-.992-6.453-2.704-9.216L17.679 29.408l-.165.112Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, FA);
}
var yf = /* @__PURE__ */ N(WA, [["render", DA]]);
const xA = Object.assign(yf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + yf.name, yf);
  }
}), RA = S({
  name: "IconWeibo",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-weibo`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), HA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function qA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M31.82 5.6c-1.445.635-1.776 2.144-.727 3.192.515.516.993.608 3.11.608 2.952 0 4.94.781 6.448 2.53 1.84 2.079 2.052 2.714 2.052 6.513 0 3.377 0 3.441.782 3.892 1.812 1.021 3.017-.24 3.44-3.616.544-4.397-2.078-9.531-6.025-11.877-2.595-1.509-7.029-2.116-9.08-1.242Zm-14.831 5.612c-3.376 1.205-6.633 3.524-10.13 7.268-8.288 8.804-7.746 17.186 1.39 21.648 9.494 4.636 22.282 3.1 29.247-3.533 5.216-4.94 4.581-11.16-1.353-13.267-1.058-.358-1.389-.634-1.232-.966.542-1.324.726-2.86.423-3.772-.939-2.86-4.343-3.523-9.403-1.812l-2.024.69.184-2.024c.212-2.383-.303-3.68-1.72-4.398-1.187-.588-3.45-.524-5.382.166Zm8.381 11.666c4.49 1.232 7.231 3.946 7.231 7.176 0 3.588-3.192 6.817-8.38 8.528-2.77.902-7.931 1.086-10.461.396-4.793-1.353-7.507-4.012-7.507-7.416 0-1.867.81-3.496 2.594-5.152 1.656-1.564 2.926-2.318 5.364-3.137 3.689-1.242 7.636-1.389 11.16-.395Zm-9.494 2.925c-3.045 1.417-4.674 3.588-4.674 6.302 0 2.475 1.086 4.159 3.469 5.428 1.84.994 5.216.902 7.268-.147 2.622-1.39 4.342-3.947 4.342-6.45-.028-2.05-1.84-4.489-3.984-5.363-1.72-.736-4.609-.616-6.421.23Zm2.199 5.667c.211.212.358.727.358 1.178 0 1.509-2.53 2.742-3.56 1.72-.57-.57-.423-1.987.24-2.65.662-.662 2.391-.818 2.962-.248Zm14.26-19.688c-1.39 1.39-.451 3.046 1.748 3.046 1.895 0 2.741.966 2.741 3.137 0 1.352.12 1.748.663 2.107 1.628 1.15 2.953-.12 2.953-2.806 0-3.285-2.355-5.76-5.695-5.999-1.509-.12-1.868-.027-2.41.515Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, HA);
}
var bf = /* @__PURE__ */ N(RA, [["render", qA]]);
const ZA = Object.assign(bf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + bf.name, bf);
  }
}), KA = S({
  name: "IconChineseFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-chinese-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), YA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function UA(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M22 21h-5v4.094h5V21ZM26 25.094V21h5v4.094h-5Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M24 4C12.954 4 4 12.954 4 24s8.954 20 20 20 20-8.954 20-20S35.046 4 24 4Zm2 13v-5h-4v5h-6.5a2.5 2.5 0 0 0-2.5 2.5v7.094a2.5 2.5 0 0 0 2.5 2.5H22V36h4v-6.906h6.5a2.5 2.5 0 0 0 2.5-2.5V19.5a2.5 2.5 0 0 0-2.5-2.5H26Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, YA);
}
var Cf = /* @__PURE__ */ N(KA, [["render", UA]]);
const GA = Object.assign(Cf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Cf.name, Cf);
  }
}), XA = S({
  name: "IconEnglishFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-english-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), QA = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function _A(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M23.2 4C12.596 4 4 12.596 4 23.2v1.6C4 35.404 12.596 44 23.2 44h1.6C35.404 44 44 35.404 44 24.8v-1.6C44 12.596 35.404 4 24.8 4h-1.6Zm-9.086 10A2.114 2.114 0 0 0 12 16.114v15.772c0 1.167.947 2.114 2.114 2.114H25v-4h-9v-4h7.778v-4H16v-4h9v-4H14.114ZM32.4 22a5.4 5.4 0 0 0-5.4 5.4V34h4v-6.6a1.4 1.4 0 0 1 2.801 0V34h4v-6.6a5.4 5.4 0 0 0-5.4-5.4Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, QA);
}
var $f = /* @__PURE__ */ N(XA, [["render", _A]]);
const JA = Object.assign($f, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + $f.name, $f);
  }
}), eE = S({
  name: "IconMoonFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-moon-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), tE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function nE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M42.108 29.769c.124-.387-.258-.736-.645-.613A17.99 17.99 0 0 1 36 30c-9.941 0-18-8.059-18-18 0-1.904.296-3.74.844-5.463.123-.387-.226-.768-.613-.645C10.558 8.334 5 15.518 5 24c0 10.493 8.507 19 19 19 8.482 0 15.666-5.558 18.108-13.231Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, tE);
}
var wf = /* @__PURE__ */ N(eE, [["render", nE]]);
const lE = Object.assign(wf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + wf.name, wf);
  }
}), oE = S({
  name: "IconPenFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-pen-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), iE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function rE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      fill: "currentColor",
      stroke: "none",
      d: "m31.07 8.444 8.485 8.485L19.05 37.435l-8.485-8.485zM33.9 5.615a2 2 0 0 1 2.829 0l5.657 5.657a2 2 0 0 1 0 2.829l-1.415 1.414-8.485-8.486L33.9 5.615ZM17.636 38.85 9.15 30.363l-3.61 10.83a1 1 0 0 0 1.265 1.265l10.83-3.61Z"
    }, null, -1)
  ]), 14, iE);
}
var Sf = /* @__PURE__ */ N(oE, [["render", rE]]);
const aE = Object.assign(Sf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Sf.name, Sf);
  }
}), sE = S({
  name: "IconSunFill",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-sun-fill`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), uE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function cE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("circle", {
      cx: "24",
      cy: "24",
      r: "9",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", {
      d: "M21 5.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-5ZM21 37.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-5ZM42.5 21a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-5a.5.5 0 0 1 .5-.5h5ZM10.5 21a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-5a.5.5 0 0 1 .5-.5h5ZM39.203 34.96a.5.5 0 0 1 0 .707l-3.536 3.536a.5.5 0 0 1-.707 0l-3.535-3.536a.5.5 0 0 1 0-.707l3.535-3.535a.5.5 0 0 1 .707 0l3.536 3.535ZM16.575 12.333a.5.5 0 0 1 0 .707l-3.535 3.535a.5.5 0 0 1-.707 0L8.797 13.04a.5.5 0 0 1 0-.707l3.536-3.536a.5.5 0 0 1 .707 0l3.535 3.536ZM13.04 39.203a.5.5 0 0 1-.707 0l-3.536-3.536a.5.5 0 0 1 0-.707l3.536-3.535a.5.5 0 0 1 .707 0l3.536 3.535a.5.5 0 0 1 0 .707l-3.536 3.536ZM35.668 16.575a.5.5 0 0 1-.708 0l-3.535-3.535a.5.5 0 0 1 0-.707l3.535-3.536a.5.5 0 0 1 .708 0l3.535 3.536a.5.5 0 0 1 0 .707l-3.535 3.535Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, uE);
}
var zf = /* @__PURE__ */ N(sE, [["render", cE]]);
const dE = Object.assign(zf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + zf.name, zf);
  }
}), fE = S({
  name: "IconApps",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-apps`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), vE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function pE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 7h13v13H7zM28 7h13v13H28zM7 28h13v13H7zM28 28h13v13H28z" }, null, -1)
  ]), 14, vE);
}
var Lf = /* @__PURE__ */ N(fE, [["render", pE]]);
const mE = Object.assign(Lf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Lf.name, Lf);
  }
}), hE = S({
  name: "IconArchive",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-archive`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), kE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function gE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    stroke: "currentColor",
    xmlns: "http://www.w3.org/2000/svg",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("rect", {
      x: "9",
      y: "18",
      width: "30",
      height: "22",
      rx: "1"
    }, null, -1),
    $("path", { d: "M6 9a1 1 0 0 1 1-1h34a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V9ZM19 27h10" }, null, -1)
  ]), 14, kE);
}
var jf = /* @__PURE__ */ N(hE, [["render", gE]]);
const yE = Object.assign(jf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + jf.name, jf);
  }
}), bE = S({
  name: "IconBarChart",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-bar-chart`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), CE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function $E(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    stroke: "currentColor",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M41 7H29v34h12V7ZM29 18H18v23h11V18ZM18 29H7v12h11V29Z" }, null, -1)
  ]), 14, CE);
}
var Pf = /* @__PURE__ */ N(bE, [["render", $E]]);
const wE = Object.assign(Pf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Pf.name, Pf);
  }
}), SE = S({
  name: "IconBook",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-book`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), zE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function LE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 13 7 7v28l17 6 17-6V7l-17 6Zm0 0v27.5M29 18l7-2.5M29 25l7-2.5M29 32l7-2.5M19 18l-7-2.5m7 9.5-7-2.5m7 9.5-7-2.5" }, null, -1)
  ]), 14, zE);
}
var If = /* @__PURE__ */ N(SE, [["render", LE]]);
const jE = Object.assign(If, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + If.name, If);
  }
}), PE = S({
  name: "IconBookmark",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-bookmark`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), IE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function BE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    stroke: "currentColor",
    xmlns: "http://www.w3.org/2000/svg",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M16 16h16M16 24h8" }, null, -1),
    $("path", { d: "M24 41H8V6h32v17" }, null, -1),
    $("path", { d: "M30 29h11v13l-5.5-3.5L30 42V29Z" }, null, -1)
  ]), 14, IE);
}
var Bf = /* @__PURE__ */ N(PE, [["render", BE]]);
const ME = Object.assign(Bf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Bf.name, Bf);
  }
}), NE = S({
  name: "IconBranch",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-branch`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), OE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function VE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M19 10a4 4 0 1 1-8 0 4 4 0 0 1 8 0ZM38 10a4 4 0 1 1-8 0 4 4 0 0 1 8 0ZM19 38a4 4 0 1 1-8 0 4 4 0 0 1 8 0ZM15 15v15m0 3.5V30m0 0c0-5 19-7 19-15" }, null, -1)
  ]), 14, OE);
}
var Mf = /* @__PURE__ */ N(NE, [["render", VE]]);
const TE = Object.assign(Mf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Mf.name, Mf);
  }
}), AE = S({
  name: "IconBug",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-bug`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), EE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function WE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 42c-6.075 0-11-4.925-11-11V18h22v13c0 6.075-4.925 11-11 11Zm0 0V23m11 4h8M5 27h8M7 14a4 4 0 0 0 4 4h26a4 4 0 0 0 4-4m0 28v-.5a6.5 6.5 0 0 0-6.5-6.5M7 42v-.5a6.5 6.5 0 0 1 6.5-6.5M17 14a7 7 0 1 1 14 0" }, null, -1)
  ]), 14, EE);
}
var Nf = /* @__PURE__ */ N(AE, [["render", WE]]);
const FE = Object.assign(Nf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Nf.name, Nf);
  }
}), DE = S({
  name: "IconBulb",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-bulb`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), xE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function RE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M17 42h14m6-24c0 2.823-.9 5.437-2.43 7.568-1.539 2.147-3.185 4.32-3.77 6.897l-.623 2.756A1 1 0 0 1 29.2 36H18.8a1 1 0 0 1-.976-.779l-.624-2.756c-.584-2.576-2.23-4.75-3.77-6.897A12.94 12.94 0 0 1 11 18c0-7.18 5.82-13 13-13s13 5.82 13 13Z" }, null, -1)
  ]), 14, xE);
}
var Of = /* @__PURE__ */ N(DE, [["render", RE]]);
const HE = Object.assign(Of, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Of.name, Of);
  }
}), qE = S({
  name: "IconCalendarClock",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-calendar-clock`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ZE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function KE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 22h34V10a1 1 0 0 0-1-1H8a1 1 0 0 0-1 1v30a1 1 0 0 0 1 1h18M34 5v8M14 5v8" }, null, -1),
    $("path", {
      "fill-rule": "evenodd",
      "clip-rule": "evenodd",
      d: "M36 44a9 9 0 1 0 0-18 9 9 0 0 0 0 18Zm1.5-9.75V29h-3v8.25H42v-3h-4.5Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, ZE);
}
var Vf = /* @__PURE__ */ N(qE, [["render", KE]]);
const YE = Object.assign(Vf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Vf.name, Vf);
  }
}), UE = S({
  name: "IconCamera",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-camera`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), GE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function XE(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m33 12-1.862-3.724A.5.5 0 0 0 30.691 8H17.309a.5.5 0 0 0-.447.276L15 12m16 14a7 7 0 1 1-14 0 7 7 0 0 1 14 0ZM7 40h34a1 1 0 0 0 1-1V13a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v26a1 1 0 0 0 1 1Z" }, null, -1)
  ]), 14, GE);
}
var Tf = /* @__PURE__ */ N(UE, [["render", XE]]);
const QE = Object.assign(Tf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Tf.name, Tf);
  }
}), _E = S({
  name: "IconCloud",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-cloud`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), JE = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function eW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M5 29a9 9 0 0 0 9 9h19c5.523 0 10-4.477 10-10 0-5.312-4.142-9.657-9.373-9.98C32.3 12.833 27.598 9 22 9c-6.606 0-11.965 5.338-12 11.935A9 9 0 0 0 5 29Z" }, null, -1)
  ]), 14, JE);
}
var Af = /* @__PURE__ */ N(_E, [["render", eW]]);
const tW = Object.assign(Af, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Af.name, Af);
  }
}), nW = S({
  name: "IconCommand",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-command`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), lW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function oW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M29 19v-6a6 6 0 1 1 6 6h-6Zm0 0v10m0-10H19m10 10v6a6 6 0 1 0 6-6h-6Zm0 0H19m0-10v10m0-10v-6a6 6 0 1 0-6 6h6Zm0 10v6a6 6 0 1 1-6-6h6Z" }, null, -1)
  ]), 14, lW);
}
var Ef = /* @__PURE__ */ N(nW, [["render", oW]]);
const iW = Object.assign(Ef, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ef.name, Ef);
  }
}), rW = S({
  name: "IconCommon",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-common`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), aW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function sW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 23 7.652 14.345M24 23l16.366-8.664M24 23v19.438M7 14v20l17 9 17-9V14L24 5 7 14Z" }, null, -1)
  ]), 14, aW);
}
var Wf = /* @__PURE__ */ N(rW, [["render", sW]]);
const uW = Object.assign(Wf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Wf.name, Wf);
  }
}), cW = S({
  name: "IconCompass",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-compass`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), dW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function fW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M42 24c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6s18 8.059 18 18Z" }, null, -1),
    $("path", { d: "m21.177 21.183 10.108-4.717a.2.2 0 0 1 .266.265L26.834 26.84l-10.109 4.717a.2.2 0 0 1-.266-.266l4.718-10.108Z" }, null, -1)
  ]), 14, dW);
}
var Ff = /* @__PURE__ */ N(cW, [["render", fW]]);
const vW = Object.assign(Ff, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Ff.name, Ff);
  }
}), pW = S({
  name: "IconComputer",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-computer`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), mW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function hW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    stroke: "currentColor",
    xmlns: "http://www.w3.org/2000/svg",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M41 7H7v22h34V7Z" }, null, -1),
    $("path", { d: "M23.778 29v10" }, null, -1),
    $("path", { d: "M16 39h16" }, null, -1),
    $("path", { d: "m20.243 14.657 5.657 5.657M15.414 22.314l7.071-7.071M24.485 21.728l7.071-7.071" }, null, -1)
  ]), 14, mW);
}
var Df = /* @__PURE__ */ N(pW, [["render", hW]]);
const kW = Object.assign(Df, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Df.name, Df);
  }
}), gW = S({
  name: "IconCopyright",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-copyright`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), yW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function bW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M29.292 18a8 8 0 1 0 0 12M42 24c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6s18 8.059 18 18Z" }, null, -1)
  ]), 14, yW);
}
var xf = /* @__PURE__ */ N(gW, [["render", bW]]);
const CW = Object.assign(xf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + xf.name, xf);
  }
}), $W = S({
  name: "IconDashboard",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-dashboard`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), wW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function SW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M41.808 24c.118 4.63-1.486 9.333-5.21 13m5.21-13h-8.309m8.309 0c-.112-4.38-1.767-8.694-4.627-12M24 6c5.531 0 10.07 2.404 13.18 6M24 6c-5.724 0-10.384 2.574-13.5 6.38M24 6v7.5M37.18 12 31 17.5m-20.5-5.12L17 17.5m-6.5-5.12C6.99 16.662 5.44 22.508 6.53 28m4.872 9c-2.65-2.609-4.226-5.742-4.873-9m0 0 8.97-3.5" }, null, -1),
    $("path", { d: "M24 32a5 5 0 1 0 0 10 5 5 0 0 0 0-10Zm0 0V19" }, null, -1)
  ]), 14, wW);
}
var Rf = /* @__PURE__ */ N($W, [["render", SW]]);
const zW = Object.assign(Rf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Rf.name, Rf);
  }
}), LW = S({
  name: "IconDesktop",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-desktop`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), jW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function PW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 32v8m0 0h-9m9 0h9M7 32h34a1 1 0 0 0 1-1V9a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v22a1 1 0 0 0 1 1Z" }, null, -1)
  ]), 14, jW);
}
var Hf = /* @__PURE__ */ N(LW, [["render", PW]]);
const IW = Object.assign(Hf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Hf.name, Hf);
  }
}), BW = S({
  name: "IconDice",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-dice`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), MW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function NW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    Cr('<rect x="6.998" y="7" width="34" height="34" rx="1.5"></rect><circle cx="16" cy="16" r="2"></circle><circle cx="24" cy="24" r="2"></circle><circle cx="16" cy="32" r="2"></circle><circle cx="32" cy="16" r="2"></circle><circle cx="32" cy="32" r="2"></circle><circle cx="16" cy="16" r="2" fill="currentColor" stroke="none"></circle><circle cx="24" cy="24" r="2" fill="currentColor" stroke="none"></circle><circle cx="16" cy="32" r="2" fill="currentColor" stroke="none"></circle><circle cx="32" cy="16" r="2" fill="currentColor" stroke="none"></circle><circle cx="32" cy="32" r="2" fill="currentColor" stroke="none"></circle>', 11)
  ]), 14, MW);
}
var qf = /* @__PURE__ */ N(BW, [["render", NW]]);
const OW = Object.assign(qf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + qf.name, qf);
  }
}), VW = S({
  name: "IconDriveFile",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-drive-file`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), TW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function AW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M38.5 17H29a1 1 0 0 1-1-1V6.5m0-.5H10a1 1 0 0 0-1 1v34a1 1 0 0 0 1 1h28a1 1 0 0 0 1-1V17L28 6Z" }, null, -1)
  ]), 14, TW);
}
var Zf = /* @__PURE__ */ N(VW, [["render", AW]]);
const EW = Object.assign(Zf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Zf.name, Zf);
  }
}), WW = S({
  name: "IconEar",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-ear`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), FW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function DW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M13 15.528C14.32 12.386 18.403 6.977 23.556 7c7.944.036 14.514 8.528 10.116 15.71-4.399 7.181-5.718 10.323-6.598 14.363-.82 3.766-9.288 7.143-11.498-1.515M20 18.5c1-3.083 4.5-4.5 6.5-2 2.85 3.562-3.503 8.312-5.5 12.5" }, null, -1)
  ]), 14, FW);
}
var Kf = /* @__PURE__ */ N(WW, [["render", DW]]);
const xW = Object.assign(Kf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Kf.name, Kf);
  }
}), RW = S({
  name: "IconEmail",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-email`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), HW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function qW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("rect", {
      x: "6",
      y: "8",
      width: "36",
      height: "32",
      rx: "1"
    }, null, -1),
    $("path", { d: "m37 17-12.43 8.606a1 1 0 0 1-1.14 0L11 17" }, null, -1)
  ]), 14, HW);
}
var Yf = /* @__PURE__ */ N(RW, [["render", qW]]);
const ZW = Object.assign(Yf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Yf.name, Yf);
  }
}), KW = S({
  name: "IconExperiment",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-experiment`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), YW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function UW(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M10.5 7h6m0 0v10.5l-5.25 14M16.5 7h15m0 0h6m-6 0v10.5L37 32.167M11.25 31.5l-2.344 6.853A2 2 0 0 0 10.8 41h26.758a2 2 0 0 0 1.86-2.737L37 32.167M11.25 31.5c1.916 1.833 7.05 4.4 12.25 0s11.166-1.389 13.5.667M26 22.5v.01" }, null, -1)
  ]), 14, YW);
}
var Uf = /* @__PURE__ */ N(KW, [["render", UW]]);
const GW = Object.assign(Uf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Uf.name, Uf);
  }
}), XW = S({
  name: "IconFire",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-fire`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), QW = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function _W(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M17.577 27.477C20.022 22.579 17.041 12.98 24.546 6c0 0-1.156 15.55 5.36 17.181 2.145.537 2.68-5.369 4.289-8.59 0 0 .536 4.832 2.68 8.59 3.217 7.517-1 14.117-5.896 17.182-4.289 2.684-14.587 2.807-19.835-5.37-4.824-7.516 0-15.57 0-15.57s4.289 12.35 6.433 8.054Z" }, null, -1)
  ]), 14, QW);
}
var Gf = /* @__PURE__ */ N(XW, [["render", _W]]);
const JW = Object.assign(Gf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Gf.name, Gf);
  }
}), eF = S({
  name: "IconFolderAdd",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-folder-add`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), tF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function nF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 19v14m-7-7h14M6 13h18l-2.527-3.557a1.077 1.077 0 0 0-.88-.443H7.06C6.474 9 6 9.448 6 10v3Zm0 0h33.882c1.17 0 2.118.895 2.118 2v21c0 1.105-.948 3-2.118 3H8.118C6.948 39 6 38.105 6 37V13Z" }, null, -1)
  ]), 14, tF);
}
var Xf = /* @__PURE__ */ N(eF, [["render", nF]]);
const lF = Object.assign(Xf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Xf.name, Xf);
  }
}), oF = S({
  name: "IconFolderDelete",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-folder-delete`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), iF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function rF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M17 26h14M6 13h18l-2.527-3.557a1.077 1.077 0 0 0-.88-.443H7.06C6.474 9 6 9.448 6 10v3Zm0 0h33.882c1.17 0 2.118.895 2.118 2v21c0 1.105-.948 3-2.118 3H8.118C6.948 39 6 38.105 6 37V13Z" }, null, -1)
  ]), 14, iF);
}
var Qf = /* @__PURE__ */ N(oF, [["render", rF]]);
const aF = Object.assign(Qf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Qf.name, Qf);
  }
}), sF = S({
  name: "IconFolder",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-folder`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), uF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function cF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6 13h18l-2.527-3.557a1.077 1.077 0 0 0-.88-.443H7.06C6.474 9 6 9.448 6 10v3Zm0 0h33.882c1.17 0 2.118.895 2.118 2v21c0 1.105-.948 3-2.118 3H8.118C6.948 39 6 38.105 6 37V13Z" }, null, -1)
  ]), 14, uF);
}
var _f = /* @__PURE__ */ N(sF, [["render", cF]]);
const dF = Object.assign(_f, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + _f.name, _f);
  }
}), fF = S({
  name: "IconGift",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-gift`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), vF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function pF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M13.45 14.043H8a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h32a1 1 0 0 0 1-1v-8a1 1 0 0 0-1-1h-4.893m-21.657 0c-1.036-2.833-.615-5.6 1.182-6.637 2.152-1.243 5.464.464 7.397 3.812.539.933.914 1.896 1.127 2.825m-9.706 0h9.706m0 0H25.4m0 0a10.31 10.31 0 0 1 1.128-2.825c1.933-3.348 5.244-5.055 7.397-3.812 1.797 1.037 2.217 3.804 1.182 6.637m-9.707 0h9.707M10 26.043a2 2 0 0 1 2-2h24a2 2 0 0 1 2 2v13a2 2 0 0 1-2 2H12a2 2 0 0 1-2-2v-13Z" }, null, -1)
  ]), 14, vF);
}
var Jf = /* @__PURE__ */ N(fF, [["render", pF]]);
const mF = Object.assign(Jf, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Jf.name, Jf);
  }
}), hF = S({
  name: "IconIdcard",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-idcard`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), kF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function gF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M11 17h9m-9 7h9m-9 7h5m-8 9h32a2 2 0 0 0 2-2V10a2 2 0 0 0-2-2H8a2 2 0 0 0-2 2v28a2 2 0 0 0 2 2Z" }, null, -1),
    $("path", { d: "M36 33a7 7 0 1 0-14 0" }, null, -1),
    $("circle", {
      cx: "29",
      cy: "20",
      r: "4"
    }, null, -1)
  ]), 14, kF);
}
var e1 = /* @__PURE__ */ N(hF, [["render", gF]]);
const yF = Object.assign(e1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + e1.name, e1);
  }
}), bF = S({
  name: "IconImage",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-image`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), CF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function $F(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m24 33 9-9v9h-9Zm0 0-3.5-4.5L17 33h7Zm15 8H9a2 2 0 0 1-2-2V9a2 2 0 0 1 2-2h30a2 2 0 0 1 2 2v30a2 2 0 0 1-2 2ZM15 15h2v2h-2v-2Z" }, null, -1),
    $("path", {
      d: "M33 33v-9l-9 9h9ZM23.5 33l-3-4-3 4h6ZM15 15h2v2h-2z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, CF);
}
var t1 = /* @__PURE__ */ N(bF, [["render", $F]]);
const wF = Object.assign(t1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + t1.name, t1);
  }
}), SF = S({
  name: "IconInteraction",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-interaction`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), zF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function LF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M8 19h16m16 0H24m0 0v23m14 0H10a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h28a2 2 0 0 1 2 2v32a2 2 0 0 1-2 2Z" }, null, -1)
  ]), 14, zF);
}
var n1 = /* @__PURE__ */ N(SF, [["render", LF]]);
const jF = Object.assign(n1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + n1.name, n1);
  }
}), PF = S({
  name: "IconLanguage",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-language`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), IF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function BF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m42 43-2.385-6M26 43l2.384-6m11.231 0-.795-2-4.18-10h-1.28l-4.181 10-.795 2m11.231 0h-11.23M17 5l1 5M5 11h26M11 11s1.889 7.826 6.611 12.174C22.333 27.522 30 31 30 31" }, null, -1),
    $("path", { d: "M25 11s-1.889 7.826-6.611 12.174C13.667 27.522 6 31 6 31" }, null, -1)
  ]), 14, IF);
}
var l1 = /* @__PURE__ */ N(PF, [["render", BF]]);
const MF = Object.assign(l1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + l1.name, l1);
  }
}), NF = S({
  name: "IconLayers",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-layers`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), OF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function VF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    stroke: "currentColor",
    xmlns: "http://www.w3.org/2000/svg",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24.015 7.017 41 14.62l-16.985 7.605L7.03 14.62l16.985-7.604Z" }, null, -1),
    $("path", { d: "m41 23.255-16.985 7.604L7.03 23.255M40.97 33.412l-16.985 7.605L7 33.412" }, null, -1)
  ]), 14, OF);
}
var o1 = /* @__PURE__ */ N(NF, [["render", VF]]);
const TF = Object.assign(o1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + o1.name, o1);
  }
}), AF = S({
  name: "IconLayout",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-layout`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), EF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function WF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M19 40V8m23 2a2 2 0 0 0-2-2H8a2 2 0 0 0-2 2v28a2 2 0 0 0 2 2h32a2 2 0 0 0 2-2V10Z" }, null, -1)
  ]), 14, EF);
}
var i1 = /* @__PURE__ */ N(AF, [["render", WF]]);
const FF = Object.assign(i1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + i1.name, i1);
  }
}), DF = S({
  name: "IconLocation",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-location`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), xF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function RF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("circle", {
      cx: "24",
      cy: "19",
      r: "5"
    }, null, -1),
    $("path", { d: "M39 20.405C39 28.914 24 43 24 43S9 28.914 9 20.405C9 11.897 15.716 5 24 5c8.284 0 15 6.897 15 15.405Z" }, null, -1)
  ]), 14, xF);
}
var r1 = /* @__PURE__ */ N(DF, [["render", RF]]);
const HF = Object.assign(r1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + r1.name, r1);
  }
}), qF = S({
  name: "IconLock",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-lock`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ZF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function KF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("rect", {
      x: "7",
      y: "21",
      width: "34",
      height: "20",
      rx: "1"
    }, null, -1),
    $("path", { d: "M15 21v-6a9 9 0 1 1 18 0v6M24 35v-8" }, null, -1)
  ]), 14, ZF);
}
var a1 = /* @__PURE__ */ N(qF, [["render", KF]]);
const YF = Object.assign(a1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + a1.name, a1);
  }
}), UF = S({
  name: "IconLoop",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-loop`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), GF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function XF(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 38c-7.732 0-14-6.268-14-14 0-3.815 1.526-7.273 4-9.798M24 10c7.732 0 14 6.268 14 14 0 3.815-1.526 7.273-4 9.798M24 7v6l-4-3 4-3Zm0 33v-6l4 3-4 3Z" }, null, -1)
  ]), 14, GF);
}
var s1 = /* @__PURE__ */ N(UF, [["render", XF]]);
const QF = Object.assign(s1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + s1.name, s1);
  }
}), _F = S({
  name: "IconMan",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-man`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), JF = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function eD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M40 8 29.68 18.321M31 8h9v9m-7 10c0 7.18-5.82 13-13 13S7 34.18 7 27s5.82-13 13-13 13 5.82 13 13Z" }, null, -1)
  ]), 14, JF);
}
var u1 = /* @__PURE__ */ N(_F, [["render", eD]]);
const tD = Object.assign(u1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + u1.name, u1);
  }
}), nD = S({
  name: "IconMenu",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-menu`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), lD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function oD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M5 10h38M5 24h38M5 38h38" }, null, -1)
  ]), 14, lD);
}
var c1 = /* @__PURE__ */ N(nD, [["render", oD]]);
const iD = Object.assign(c1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + c1.name, c1);
  }
}), rD = S({
  name: "IconMindMapping",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-mind-mapping`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), aD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function sD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M20 10h23M20 24h23M20 38h23M9 12v28m0-28a2 2 0 1 0 0-4 2 2 0 0 0 0 4Zm0 26h7M9 24h7" }, null, -1)
  ]), 14, aD);
}
var d1 = /* @__PURE__ */ N(rD, [["render", sD]]);
const uD = Object.assign(d1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + d1.name, d1);
  }
}), cD = S({
  name: "IconMobile",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-mobile`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), dD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function fD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M17 14h14m6.125 28h-26.25C9.839 42 9 41.105 9 40V8c0-1.105.84-2 1.875-2h26.25C38.16 6 39 6.895 39 8v32c0 1.105-.84 2-1.875 2ZM22 33a2 2 0 1 1 4 0 2 2 0 0 1-4 0Z" }, null, -1),
    $("circle", {
      cx: "24",
      cy: "33",
      r: "2",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, dD);
}
var f1 = /* @__PURE__ */ N(cD, [["render", fD]]);
const vD = Object.assign(f1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + f1.name, f1);
  }
}), pD = S({
  name: "IconMoon",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-moon`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), mD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function hD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M39.979 29.241c.11-.344-.23-.654-.574-.544-1.53.487-3.162.75-4.855.75-8.834 0-15.997-7.163-15.997-15.997 0-1.693.263-3.324.75-4.855.11-.344-.2-.684-.544-.574C11.939 10.19 7 16.576 7 24.114 7 33.44 14.56 41 23.886 41c7.538 0 13.923-4.94 16.093-11.759Z" }, null, -1)
  ]), 14, mD);
}
var v1 = /* @__PURE__ */ N(pD, [["render", hD]]);
const kD = Object.assign(v1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + v1.name, v1);
  }
}), gD = S({
  name: "IconMosaic",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-mosaic`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), yD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function bD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M6 7h4v4H6V7ZM6 23h4v4H6v-4ZM6 38h4v4H6v-4ZM14 15h4v4h-4v-4ZM14 31h4v4h-4v-4ZM22 7h4v4h-4V7ZM22 23h4v4h-4v-4ZM22 38h4v4h-4v-4ZM30 15h4v4h-4v-4ZM30 31h4v4h-4v-4ZM38 7h4v4h-4V7ZM38 23h4v4h-4v-4ZM38 38h4v4h-4v-4Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M6 7h4v4H6V7ZM6 23h4v4H6v-4ZM6 38h4v4H6v-4ZM14 15h4v4h-4v-4ZM14 31h4v4h-4v-4ZM22 7h4v4h-4V7ZM22 23h4v4h-4v-4ZM22 38h4v4h-4v-4ZM30 15h4v4h-4v-4ZM30 31h4v4h-4v-4ZM38 7h4v4h-4V7ZM38 23h4v4h-4v-4ZM38 38h4v4h-4v-4Z" }, null, -1)
  ]), 14, yD);
}
var p1 = /* @__PURE__ */ N(gD, [["render", bD]]);
const CD = Object.assign(p1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + p1.name, p1);
  }
}), $D = S({
  name: "IconNav",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-nav`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), wD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function SD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6 19h10m0 0h26m-26 0V9m0 10v10m0 0v10m0-10H6m10 0h26M6 9h36v30H6V9Z" }, null, -1)
  ]), 14, wD);
}
var m1 = /* @__PURE__ */ N($D, [["render", SD]]);
const zD = Object.assign(m1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + m1.name, m1);
  }
}), LD = S({
  name: "IconNotificationClose",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-notification-close`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), jD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function PD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M11 35V22c0-1.835.38-3.58 1.066-5.163M11 35H6m5 0h15.5M24 9c7.18 0 13 5.82 13 13v7.5M24 9V4m0 5a12.94 12.94 0 0 0-6.5 1.74M17 42h14M6 4l36 40" }, null, -1)
  ]), 14, jD);
}
var h1 = /* @__PURE__ */ N(LD, [["render", PD]]);
const ID = Object.assign(h1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + h1.name, h1);
  }
}), BD = S({
  name: "IconNotification",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-notification`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), MD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function ND(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 9c7.18 0 13 5.82 13 13v13H11V22c0-7.18 5.82-13 13-13Zm0 0V4M6 35h36m-25 7h14" }, null, -1)
  ]), 14, MD);
}
var k1 = /* @__PURE__ */ N(BD, [["render", ND]]);
const OD = Object.assign(k1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + k1.name, k1);
  }
}), VD = S({
  name: "IconPalette",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-palette`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), TD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function AD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    Cr('<path d="M31.813 12.02C29.73 10.459 27.013 10 24 10c-9.78 0-17.708 6.987-17.708 15.042 0 8.054 8.97 14.583 18.75 14.583 5.277 0 2.485-5.318 5.73-8.333 2.767-2.574 10.937-1.563 10.937-6.25 0-2.792-.521-5.209-2.605-7.617"></path><path d="M25.042 25.563 42.23 8.375"></path><circle cx="22.5" cy="17.5" r="2.5" fill="currentColor" stroke="none"></circle><circle cx="15.5" cy="20.5" r="2.5" fill="currentColor" stroke="none"></circle><circle cx="14.5" cy="28.5" r="2.5" fill="currentColor" stroke="none"></circle>', 5)
  ]), 14, TD);
}
var g1 = /* @__PURE__ */ N(VD, [["render", AD]]);
const ED = Object.assign(g1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + g1.name, g1);
  }
}), WD = S({
  name: "IconPen",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-pen`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), FD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function DD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m28.364 11.565 7.07 7.071M7.15 32.778 33.313 6.615l7.071 7.071L14.221 39.85h-7.07v-7.07Z" }, null, -1)
  ]), 14, FD);
}
var y1 = /* @__PURE__ */ N(WD, [["render", DD]]);
const xD = Object.assign(y1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + y1.name, y1);
  }
}), RD = S({
  name: "IconPhone",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-phone`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), HD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function qD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M6.707 34.284a1 1 0 0 1 0-1.414l5.657-5.657a1 1 0 0 1 1.414 0l4.95 4.95s3.535-1.414 7.778-5.657c4.243-4.243 5.657-7.778 5.657-7.778l-4.95-4.95a1 1 0 0 1 0-1.414l5.657-5.657a1 1 0 0 1 1.414 0l6.01 6.01s3.183 7.425-8.485 19.092c-11.667 11.668-19.092 8.485-19.092 8.485l-6.01-6.01Z" }, null, -1)
  ]), 14, HD);
}
var b1 = /* @__PURE__ */ N(RD, [["render", qD]]);
const ZD = Object.assign(b1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + b1.name, b1);
  }
}), KD = S({
  name: "IconPrinter",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-printer`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), YD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function UD(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M14 15V8a1 1 0 0 1 1-1h18a1 1 0 0 1 1 1v7m-20 0H7a1 1 0 0 0-1 1v17a1 1 0 0 0 1 1h6m1-19h20m0 0h7a1 1 0 0 1 1 1v17a1 1 0 0 1-1 1h-6m-22 0v6a1 1 0 0 0 1 1h20a1 1 0 0 0 1-1v-6m-22 0v-5a1 1 0 0 1 1-1h20a1 1 0 0 1 1 1v5" }, null, -1)
  ]), 14, YD);
}
var C1 = /* @__PURE__ */ N(KD, [["render", UD]]);
const GD = Object.assign(C1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + C1.name, C1);
  }
}), XD = S({
  name: "IconPublic",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-public`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), QD = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function _D(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M15 21.5 6.704 19M15 21.5l4.683 5.152a1 1 0 0 1 .25.814L18 40.976l10.918-16.117a1 1 0 0 0-.298-1.409L21.5 19 15 21.5Zm0 0 6.062-6.995a1 1 0 0 0 .138-1.103L18 7.024M42 24c0 9.941-8.059 18-18 18S6 33.941 6 24 14.059 6 24 6s18 8.059 18 18Z" }, null, -1)
  ]), 14, QD);
}
var $1 = /* @__PURE__ */ N(XD, [["render", _D]]);
const JD = Object.assign($1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + $1.name, $1);
  }
}), ex = S({
  name: "IconPushpin",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-pushpin`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), tx = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function nx(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M19.921 28.163 7.193 40.89m12.728-12.728 8.884 8.883c.17.17.447.17.617 0l5.12-5.12a7.862 7.862 0 0 0 1.667-8.655.093.093 0 0 1 .02-.102l4.906-4.906a2 2 0 0 0 0-2.828L32.648 6.95a2 2 0 0 0-2.828 0l-4.89 4.889a.126.126 0 0 1-.139.027 7.828 7.828 0 0 0-8.618 1.66l-5.027 5.026a.591.591 0 0 0 0 .836l8.774 8.775Z" }, null, -1)
  ]), 14, tx);
}
var w1 = /* @__PURE__ */ N(ex, [["render", nx]]);
const lx = Object.assign(w1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + w1.name, w1);
  }
}), ox = S({
  name: "IconQrcode",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-qrcode`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ix = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function rx(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 30v4m0 3v6m19-19h-6m-3 0h-4M7 7h17v17H7V7Zm0 25h9v9H7v-9Zm25 0h9v9h-9v-9Zm0-25h9v9h-9V7Zm-18 7h3v3h-3v-3Z" }, null, -1)
  ]), 14, ix);
}
var S1 = /* @__PURE__ */ N(ox, [["render", rx]]);
const ax = Object.assign(S1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + S1.name, S1);
  }
}), sx = S({
  name: "IconRelation",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-relation`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), ux = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function cx(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    stroke: "currentColor",
    xmlns: "http://www.w3.org/2000/svg",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M19.714 14C15.204 15.784 12 20.302 12 25.593c0 1.142.15 2.247.429 3.298m16.285-14.712C32.998 16.073 36 20.471 36 25.593c0 1.07-.131 2.11-.378 3.102m-18.32 7.194a11.676 11.676 0 0 0 13.556-.112" }, null, -1),
    $("path", { d: "M24 19a6 6 0 1 0 0-12 6 6 0 0 0 0 12ZM36 40a6 6 0 1 0 0-12 6 6 0 0 0 0 12ZM12 40a6 6 0 1 0 0-12 6 6 0 0 0 0 12Z" }, null, -1)
  ]), 14, ux);
}
var z1 = /* @__PURE__ */ N(sx, [["render", cx]]);
const dx = Object.assign(z1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + z1.name, z1);
  }
}), fx = S({
  name: "IconRobotAdd",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-robot-add`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), vx = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function px(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 7v6m0-6h5m-5 0h-5M3 21v11m25 8H9V13h30v11m-7 11h14m-7-7v14M18 26h1v1h-1v-1Zm11 0h1v1h-1v-1Z" }, null, -1)
  ]), 14, vx);
}
var L1 = /* @__PURE__ */ N(fx, [["render", px]]);
const mx = Object.assign(L1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + L1.name, L1);
  }
}), hx = S({
  name: "IconRobot",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-robot`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), kx = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function gx(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", {
      d: "M18 26h1v1h-1v-1ZM29 26h1v1h-1v-1Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M24 7v6m0-6h5m-5 0h-5M3 21v11m36 8H9V13h30v29m6-21v11m-27-6h1v1h-1v-1Zm11 0h1v1h-1v-1Z" }, null, -1)
  ]), 14, kx);
}
var j1 = /* @__PURE__ */ N(hx, [["render", gx]]);
const yx = Object.assign(j1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + j1.name, j1);
  }
}), bx = S({
  name: "IconSafe",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-safe`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Cx = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function $x(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m16.825 22.165 6 6 10-10M24 6c7 4 16 5 16 5v15s-2 12-16 16.027C10 38 8 26 8 26V11s9-1 16-5Z" }, null, -1)
  ]), 14, Cx);
}
var P1 = /* @__PURE__ */ N(bx, [["render", $x]]);
const wx = Object.assign(P1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + P1.name, P1);
  }
}), Sx = S({
  name: "IconSchedule",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-schedule`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), zx = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Lx(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("circle", {
      cx: "24",
      cy: "24",
      r: "18"
    }, null, -1),
    $("path", { d: "M24 13v10l6.5 7" }, null, -1)
  ]), 14, zx);
}
var I1 = /* @__PURE__ */ N(Sx, [["render", Lx]]);
const jx = Object.assign(I1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + I1.name, I1);
  }
}), Px = S({
  name: "IconShake",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-shake`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Ix = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Bx(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M43.092 27.536 31.778 38.849M20.465 4.91 9.15 16.221m9.192 14.85a1 1 0 1 1-1.414-1.415 1 1 0 0 1 1.414 1.414ZM6.323 28.95 19.05 41.678a1 1 0 0 0 1.415 0l21.213-21.213a1 1 0 0 0 0-1.415L28.95 6.322a1 1 0 0 0-1.415 0L6.322 27.536a1 1 0 0 0 0 1.414Z" }, null, -1),
    $("circle", {
      cx: "17.637",
      cy: "30.364",
      r: "1",
      transform: "rotate(45 17.637 30.364)",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, Ix);
}
var B1 = /* @__PURE__ */ N(Px, [["render", Bx]]);
const Mx = Object.assign(B1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + B1.name, B1);
  }
}), Nx = S({
  name: "IconSkin",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-skin`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Ox = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Vx(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M17.936 6H7a1 1 0 0 0-1 1v17.559a1 1 0 0 0 1 1h4V40a1 1 0 0 0 1 1h24a1 1 0 0 0 1-1V25.559h4a1 1 0 0 0 1-1V7a1 1 0 0 0-1-1H30.064C28.854 7.23 26.59 9.059 24 9.059S19.147 7.23 17.936 6Z" }, null, -1)
  ]), 14, Ox);
}
var M1 = /* @__PURE__ */ N(Nx, [["render", Vx]]);
const Tx = Object.assign(M1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + M1.name, M1);
  }
}), Ax = S({
  name: "IconStamp",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-stamp`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Ex = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Wx(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 33a1 1 0 0 1 1-1h32a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H8a1 1 0 0 1-1-1v-7ZM29.081 21.18a8 8 0 1 0-10.163 0L14 32h20l-4.919-10.82Z" }, null, -1)
  ]), 14, Ex);
}
var N1 = /* @__PURE__ */ N(Ax, [["render", Wx]]);
const Fx = Object.assign(N1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + N1.name, N1);
  }
}), Dx = S({
  name: "IconStorage",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-storage`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), xx = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Rx(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 18h34v12H7V18ZM40 6H8a1 1 0 0 0-1 1v11h34V7a1 1 0 0 0-1-1ZM7 30h34v11a1 1 0 0 1-1 1H8a1 1 0 0 1-1-1V30Z" }, null, -1),
    $("path", { d: "M13.02 36H13v.02h.02V36Z" }, null, -1),
    $("path", {
      d: "M13 12v-2h-2v2h2Zm.02 0h2v-2h-2v2Zm0 .02v2h2v-2h-2Zm-.02 0h-2v2h2v-2ZM13 14h.02v-4H13v4Zm-1.98-2v.02h4V12h-4Zm2-1.98H13v4h.02v-4Zm1.98 2V12h-4v.02h4Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1),
    $("path", { d: "M13.02 24H13v.02h.02V24Z" }, null, -1)
  ]), 14, xx);
}
var O1 = /* @__PURE__ */ N(Dx, [["render", Rx]]);
const Hx = Object.assign(O1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + O1.name, O1);
  }
}), qx = S({
  name: "IconSubscribeAdd",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-subscribe-add`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Zx = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Kx(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24.53 6.007H9.97c-.535 0-.97.449-.97 1.003V41.8c0 .148.152.245.28.179l15.25-7.881 14.248 7.88c.129.067.28-.03.28-.179V22.06M27.413 11.023h6.794m0 0H41m-6.794 0V4m0 7.023v7.023" }, null, -1)
  ]), 14, Zx);
}
var V1 = /* @__PURE__ */ N(qx, [["render", Kx]]);
const Yx = Object.assign(V1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + V1.name, V1);
  }
}), Ux = S({
  name: "IconSubscribe",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-subscribe`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Gx = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function Xx(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M9 7v34.667a.2.2 0 0 0 .294.176L24 34l14.706 7.843a.2.2 0 0 0 .294-.176V7a1 1 0 0 0-1-1H10a1 1 0 0 0-1 1Z" }, null, -1)
  ]), 14, Gx);
}
var T1 = /* @__PURE__ */ N(Ux, [["render", Xx]]);
const Qx = Object.assign(T1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + T1.name, T1);
  }
}), _x = S({
  name: "IconSubscribed",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-subscribed`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), Jx = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function eR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m31.289 15.596-9.193 9.193-4.95-4.95M24 34l14.706 7.843a.2.2 0 0 0 .294-.176V7a1 1 0 0 0-1-1H10a1 1 0 0 0-1 1v34.667a.2.2 0 0 0 .294.176L24 34Z" }, null, -1)
  ]), 14, Jx);
}
var A1 = /* @__PURE__ */ N(_x, [["render", eR]]);
const tR = Object.assign(A1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + A1.name, A1);
  }
}), nR = S({
  name: "IconSun",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-sun`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), lR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function oR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("circle", {
      cx: "24",
      cy: "24",
      r: "7"
    }, null, -1),
    $("path", { d: "M23 7h2v2h-2zM23 39h2v2h-2zM41 23v2h-2v-2zM9 23v2H7v-2zM36.73 35.313l-1.415 1.415-1.414-1.415 1.414-1.414zM14.099 12.686l-1.414 1.415-1.414-1.415 1.414-1.414zM12.687 36.728l-1.414-1.415 1.414-1.414 1.414 1.414zM35.314 14.1 33.9 12.686l1.414-1.414 1.415 1.414z" }, null, -1),
    $("path", {
      fill: "currentColor",
      stroke: "none",
      d: "M23 7h2v2h-2zM23 39h2v2h-2zM41 23v2h-2v-2zM9 23v2H7v-2zM36.73 35.313l-1.415 1.415-1.414-1.415 1.414-1.414zM14.099 12.686l-1.414 1.415-1.414-1.415 1.414-1.414zM12.687 36.728l-1.414-1.415 1.414-1.414 1.414 1.414zM35.314 14.1 33.9 12.686l1.414-1.414 1.415 1.414z"
    }, null, -1)
  ]), 14, lR);
}
var E1 = /* @__PURE__ */ N(nR, [["render", oR]]);
const iR = Object.assign(E1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + E1.name, E1);
  }
}), rR = S({
  name: "IconTag",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-tag`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), aR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function sR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24.835 6.035a1 1 0 0 1 .903-.273l12.964 2.592a1 1 0 0 1 .784.785l2.593 12.963a1 1 0 0 1-.274.904L21.678 43.133a1 1 0 0 1-1.415 0L4.708 27.577a1 1 0 0 1 0-1.414L24.835 6.035Z" }, null, -1),
    $("path", { d: "M31.577 17.346a1 1 0 1 1 0-2 1 1 0 0 1 0 2Z" }, null, -1),
    $("path", {
      d: "M31.582 17.349a1 1 0 1 1 0-2 1 1 0 0 1 0 2Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, aR);
}
var W1 = /* @__PURE__ */ N(rR, [["render", sR]]);
const uR = Object.assign(W1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + W1.name, W1);
  }
}), cR = S({
  name: "IconTags",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-tags`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), dR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function fR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "m37.581 28.123-14.849 14.85a1 1 0 0 1-1.414 0L8.59 30.243m25.982-22.68-10.685-.628a1 1 0 0 0-.766.291L9.297 21.052a1 1 0 0 0 0 1.414L20.61 33.78a1 1 0 0 0 1.415 0l13.824-13.825a1 1 0 0 0 .291-.765l-.628-10.686a1 1 0 0 0-.94-.94Zm-6.874 7.729a1 1 0 1 1 1.414-1.414 1 1 0 0 1-1.414 1.414Z" }, null, -1),
    $("path", {
      d: "M27.697 15.292a1 1 0 1 1 1.414-1.414 1 1 0 0 1-1.414 1.414Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, dR);
}
var F1 = /* @__PURE__ */ N(cR, [["render", fR]]);
const vR = Object.assign(F1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + F1.name, F1);
  }
}), pR = S({
  name: "IconThunderbolt",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-thunderbolt`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), mR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function hR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M27.824 5.203A.1.1 0 0 1 28 5.27V21h10.782a.1.1 0 0 1 .075.165L20.176 42.797A.1.1 0 0 1 20 42.73V27H9.219a.1.1 0 0 1-.076-.165L27.824 5.203Z" }, null, -1)
  ]), 14, mR);
}
var D1 = /* @__PURE__ */ N(pR, [["render", hR]]);
const kR = Object.assign(D1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + D1.name, D1);
  }
}), gR = S({
  name: "IconTool",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-tool`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), yR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function bR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M19.994 11.035c3.66-3.659 9.094-4.46 13.531-2.405a.1.1 0 0 1 .028.16l-6.488 6.488a1 1 0 0 0 0 1.414l4.243 4.243a1 1 0 0 0 1.414 0l6.488-6.488a.1.1 0 0 1 .16.028c2.056 4.437 1.254 9.872-2.405 13.53-3.695 3.696-9.2 4.477-13.66 2.347L12.923 40.733a1 1 0 0 1-1.414 0L7.266 36.49a1 1 0 0 1 0-1.414l10.382-10.382c-2.13-4.46-1.349-9.965 2.346-13.66Z" }, null, -1)
  ]), 14, yR);
}
var x1 = /* @__PURE__ */ N(gR, [["render", bR]]);
const CR = Object.assign(x1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + x1.name, x1);
  }
}), $R = S({
  name: "IconTrophy",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-trophy`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), wR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function SR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 33c-6.075 0-11-4.925-11-11m11 11c6.075 0 11-4.925 11-11M24 33v8M13 22V7h22v15m-22 0V9H7v7a6 6 0 0 0 6 6Zm22 0V9h6v7a6 6 0 0 1-6 6ZM12 41h24" }, null, -1)
  ]), 14, wR);
}
var R1 = /* @__PURE__ */ N($R, [["render", SR]]);
const zR = Object.assign(R1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + R1.name, R1);
  }
}), LR = S({
  name: "IconUnlock",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-unlock`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), jR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function PR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("rect", {
      x: "7",
      y: "21",
      width: "34",
      height: "20",
      rx: "1"
    }, null, -1),
    $("path", { d: "M44 15a9 9 0 1 0-18 0v6M24 35v-8" }, null, -1)
  ]), 14, jR);
}
var H1 = /* @__PURE__ */ N(LR, [["render", PR]]);
const IR = Object.assign(H1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + H1.name, H1);
  }
}), BR = S({
  name: "IconUserAdd",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-user-add`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), MR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function NR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M25 27h-8c-5.523 0-10 4.477-10 10v4h18m11-14v8m0 0v8m0-8h8m-8 0h-8m3-21a7 7 0 1 1-14 0 7 7 0 0 1 14 0Z" }, null, -1)
  ]), 14, MR);
}
var q1 = /* @__PURE__ */ N(BR, [["render", NR]]);
const OR = Object.assign(q1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + q1.name, q1);
  }
}), VR = S({
  name: "IconUserGroup",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-user-group`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), TR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function AR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("circle", {
      cx: "18",
      cy: "15",
      r: "7"
    }, null, -1),
    $("circle", {
      cx: "34",
      cy: "19",
      r: "4"
    }, null, -1),
    $("path", { d: "M6 34a6 6 0 0 1 6-6h12a6 6 0 0 1 6 6v6H6v-6ZM34 30h4a4 4 0 0 1 4 4v4h-8" }, null, -1)
  ]), 14, TR);
}
var Z1 = /* @__PURE__ */ N(VR, [["render", AR]]);
const ER = Object.assign(Z1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Z1.name, Z1);
  }
}), WR = S({
  name: "IconUser",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-user`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), FR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function DR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M7 37c0-4.97 4.03-8 9-8h16c4.97 0 9 3.03 9 8v3a1 1 0 0 1-1 1H8a1 1 0 0 1-1-1v-3Z" }, null, -1),
    $("circle", {
      cx: "24",
      cy: "15",
      r: "8"
    }, null, -1)
  ]), 14, FR);
}
var K1 = /* @__PURE__ */ N(WR, [["render", DR]]);
const xR = Object.assign(K1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + K1.name, K1);
  }
}), RR = S({
  name: "IconVideoCamera",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-video-camera`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), HR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function qR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M33 18v12m0-12v-6a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v24a1 1 0 0 0 1 1h25a1 1 0 0 0 1-1v-6m0-12 8.713-2.614a1 1 0 0 1 1.287.958v15.312a1 1 0 0 1-1.287.958L33 30M11 19h6" }, null, -1)
  ]), 14, HR);
}
var Y1 = /* @__PURE__ */ N(RR, [["render", qR]]);
const ZR = Object.assign(Y1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + Y1.name, Y1);
  }
}), KR = S({
  name: "IconWifi",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-wifi`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), YR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function UR(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M31.587 31.485A9.978 9.978 0 0 0 24 28a9.977 9.977 0 0 0-7.586 3.485M37.255 25.822A17.953 17.953 0 0 0 24 20a17.953 17.953 0 0 0-13.256 5.822M43.618 19.449C38.696 14.246 31.728 11 24 11c-7.727 0-14.696 3.246-19.617 8.449" }, null, -1),
    $("path", {
      d: "M27.535 35.465a5 5 0 0 0-7.07 0L24 39l3.535-3.535Z",
      fill: "currentColor",
      stroke: "none"
    }, null, -1)
  ]), 14, YR);
}
var U1 = /* @__PURE__ */ N(KR, [["render", UR]]);
const GR = Object.assign(U1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + U1.name, U1);
  }
}), XR = S({
  name: "IconWoman",
  props: {
    size: {
      type: [Number, String]
    },
    strokeWidth: {
      type: Number,
      default: 4
    },
    strokeLinecap: {
      type: String,
      default: "butt",
      validator: (e) => ["butt", "round", "square"].includes(e)
    },
    strokeLinejoin: {
      type: String,
      default: "miter",
      validator: (e) => ["arcs", "bevel", "miter", "miter-clip", "round"].includes(e)
    },
    rotate: Number,
    spin: Boolean
  },
  emits: {
    click: (e) => !0
  },
  setup(e, { emit: t }) {
    const n = B("icon"), o = a(() => [n, `${n}-woman`, { [`${n}-spin`]: e.spin }]), i = a(() => {
      const l = {};
      return e.size && (l.fontSize = A(e.size) ? `${e.size}px` : e.size), e.rotate && (l.transform = `rotate(${e.rotate}deg)`), l;
    });
    return {
      cls: o,
      innerStyle: i,
      onClick: (l) => {
        t("click", l);
      }
    };
  }
}), QR = ["stroke-width", "stroke-linecap", "stroke-linejoin"];
function _R(e, t, n, o, i, r) {
  return v(), b("svg", {
    viewBox: "0 0 48 48",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg",
    stroke: "currentColor",
    class: m(e.cls),
    style: F(e.innerStyle),
    "stroke-width": e.strokeWidth,
    "stroke-linecap": e.strokeLinecap,
    "stroke-linejoin": e.strokeLinejoin,
    onClick: t[0] || (t[0] = (...l) => e.onClick && e.onClick(...l))
  }, t[1] || (t[1] = [
    $("path", { d: "M24 29c6.075 0 11-4.925 11-11S30.075 7 24 7s-11 4.925-11 11 4.925 11 11 11Zm0 0v15M15 36h18" }, null, -1)
  ]), 14, QR);
}
var G1 = /* @__PURE__ */ N(XR, [["render", _R]]);
const JR = Object.assign(G1, {
  install: (e, t) => {
    var n;
    const o = (n = t == null ? void 0 : t.iconPrefix) != null ? n : "";
    e.component(o + G1.name, G1);
  }
}), Sv = {
  IconArrowDown: uL,
  IconArrowFall: vL,
  IconArrowLeft: kL,
  IconArrowRight: CL,
  IconArrowRise: zL,
  IconArrowUp: IL,
  IconCaretDown: a0,
  IconCaretLeft: qm,
  IconCaretRight: Hm,
  IconCaretUp: h2,
  IconDoubleDown: OL,
  IconDoubleLeft: nh,
  IconDoubleRight: lh,
  IconDoubleUp: EL,
  IconDownCircle: xL,
  IconDown: Il,
  IconDragArrow: ZL,
  IconExpand: GL,
  IconLeftCircle: JL,
  IconLeft: xn,
  IconMenuFold: Qh,
  IconMenuUnfold: _h,
  IconRightCircle: lj,
  IconRight: bn,
  IconRotateLeft: Oh,
  IconRotateRight: Vh,
  IconShrink: aj,
  IconSwap: dj,
  IconToBottom: mj,
  IconToLeft: yj,
  IconToRight: wj,
  IconToTop: ym,
  IconUpCircle: jj,
  IconUp: Ar,
  IconCheckCircleFill: ul,
  IconCloseCircleFill: jl,
  IconExclamationCircleFill: Dn,
  IconExclamationPolygonFill: Mj,
  IconInfoCircleFill: Xl,
  IconMinusCircleFill: Tj,
  IconPlusCircleFill: Fj,
  IconQuestionCircleFill: Hj,
  IconCheckCircle: Yj,
  IconCheckSquare: Qj,
  IconCheck: Wo,
  IconClockCircle: Yv,
  IconCloseCircle: tP,
  IconClose: Dt,
  IconExclamationCircle: iP,
  IconExclamation: o0,
  IconInfoCircle: uP,
  IconInfo: r2,
  IconMinusCircle: vP,
  IconMinus: Fr,
  IconPlusCircle: kP,
  IconPlus: zl,
  IconQuestionCircle: Ph,
  IconQuestion: CP,
  IconStop: zP,
  IconHeartFill: IP,
  IconStarFill: l2,
  IconThumbDownFill: OP,
  IconThumbUpFill: EP,
  IconAt: xP,
  IconCloudDownload: ZP,
  IconCodeBlock: GP,
  IconCodeSquare: JP,
  IconCode: lI,
  IconCustomerService: aI,
  IconDownload: dI,
  IconExport: mI,
  IconEyeInvisible: fm,
  IconEye: Bv,
  IconHeart: yI,
  IconHistory: wI,
  IconHome: jI,
  IconImport: MI,
  IconLaunch: TI,
  IconList: FI,
  IconMessageBanned: HI,
  IconMessage: YI,
  IconMoreVertical: QI,
  IconMore: Vr,
  IconPoweroff: tB,
  IconRefresh: iB,
  IconReply: uB,
  IconSave: vB,
  IconScan: kB,
  IconSearch: ur,
  IconSelectAll: CB,
  IconSend: zB,
  IconSettings: IB,
  IconShareAlt: OB,
  IconShareExternal: EB,
  IconShareInternal: xB,
  IconStar: ZB,
  IconSync: GB,
  IconThumbDown: JB,
  IconThumbUp: lM,
  IconTranslate: aM,
  IconUpload: Qr,
  IconVoice: dM,
  IconAlignCenter: mM,
  IconAlignLeft: yM,
  IconAlignRight: wM,
  IconAttachment: jM,
  IconBgColors: MM,
  IconBold: TM,
  IconBrush: FM,
  IconCopy: z2,
  IconDelete: Gr,
  IconEdit: L2,
  IconEraser: HM,
  IconFilter: k2,
  IconFindReplace: YM,
  IconFontColors: QM,
  IconFormula: tN,
  IconH1: iN,
  IconH2: uN,
  IconH3: vN,
  IconH4: kN,
  IconH5: CN,
  IconH6: zN,
  IconH7: IN,
  IconHighlight: ON,
  IconItalic: EN,
  IconLineHeight: xN,
  IconLink: ch,
  IconObliqueLine: Cm,
  IconOrderedList: ZN,
  IconOriginalSize: Th,
  IconPaste: GN,
  IconQuote: JN,
  IconRedo: lO,
  IconScissor: aO,
  IconSortAscending: dO,
  IconSortDescending: mO,
  IconSort: yO,
  IconStrikethrough: wO,
  IconUnderline: jO,
  IconUndo: MO,
  IconUnorderedList: TO,
  IconZoomIn: Mh,
  IconZoomOut: Bh,
  IconMuteFill: FO,
  IconPauseCircleFill: HO,
  IconPlayArrowFill: B2,
  IconPlayCircleFill: YO,
  IconSkipNextFill: QO,
  IconSkipPreviousFill: tV,
  IconSoundFill: iV,
  IconBackward: uV,
  IconForward: vV,
  IconFullscreenExit: kV,
  IconFullscreen: Nh,
  IconLiveBroadcast: CV,
  IconMusic: zV,
  IconMute: IV,
  IconPauseCircle: OV,
  IconPause: I2,
  IconPlayArrow: EV,
  IconPlayCircle: xV,
  IconRecordStop: ZV,
  IconRecord: GV,
  IconSkipNext: JV,
  IconSkipPrevious: lT,
  IconSound: aT,
  IconBytedanceColor: dT,
  IconLarkColor: mT,
  IconTiktokColor: yT,
  IconXiguaColor: wT,
  IconFaceBookCircleFill: jT,
  IconFacebookSquareFill: MT,
  IconGoogleCircleFill: TT,
  IconQqCircleFill: FT,
  IconTwitterCircleFill: HT,
  IconWeiboCircleFill: YT,
  IconAlipayCircle: QT,
  IconCodeSandbox: tA,
  IconCodepen: iA,
  IconFacebook: uA,
  IconGithub: vA,
  IconGitlab: kA,
  IconGoogle: CA,
  IconQqZone: zA,
  IconQq: IA,
  IconTwitter: OA,
  IconWechat: EA,
  IconWechatpay: xA,
  IconWeibo: ZA,
  IconChineseFill: GA,
  IconEnglishFill: JA,
  IconFaceFrownFill: i2,
  IconFaceMehFill: hv,
  IconFaceSmileFill: o2,
  IconMoonFill: lE,
  IconPenFill: aE,
  IconSunFill: dE,
  IconApps: mE,
  IconArchive: yE,
  IconBarChart: wE,
  IconBook: jE,
  IconBookmark: ME,
  IconBranch: TE,
  IconBug: FE,
  IconBulb: HE,
  IconCalendarClock: YE,
  IconCalendar: Rr,
  IconCamera: QE,
  IconCloud: tW,
  IconCommand: iW,
  IconCommon: uW,
  IconCompass: vW,
  IconComputer: kW,
  IconCopyright: CW,
  IconDashboard: zW,
  IconDesktop: IW,
  IconDice: OW,
  IconDragDotVertical: Zr,
  IconDragDot: xh,
  IconDriveFile: EW,
  IconEar: xW,
  IconEmail: ZW,
  IconEmpty: pm,
  IconExperiment: GW,
  IconFileAudio: T2,
  IconFileImage: O2,
  IconFilePdf: N2,
  IconFileVideo: V2,
  IconFile: d0,
  IconFire: JW,
  IconFolderAdd: lF,
  IconFolderDelete: aF,
  IconFolder: dF,
  IconGift: mF,
  IconIdcard: yF,
  IconImageClose: Or,
  IconImage: wF,
  IconInteraction: jF,
  IconLanguage: MF,
  IconLayers: TF,
  IconLayout: FF,
  IconLoading: Yt,
  IconLocation: HF,
  IconLock: YF,
  IconLoop: QF,
  IconMan: tD,
  IconMenu: iD,
  IconMindMapping: uD,
  IconMobile: vD,
  IconMoon: kD,
  IconMosaic: CD,
  IconNav: zD,
  IconNotificationClose: ID,
  IconNotification: OD,
  IconPalette: ED,
  IconPen: xD,
  IconPhone: ZD,
  IconPrinter: GD,
  IconPublic: JD,
  IconPushpin: lx,
  IconQrcode: ax,
  IconRelation: dx,
  IconRobotAdd: mx,
  IconRobot: yx,
  IconSafe: wx,
  IconSchedule: jx,
  IconShake: Mx,
  IconSkin: Tx,
  IconStamp: Fx,
  IconStorage: Hx,
  IconSubscribeAdd: Yx,
  IconSubscribe: Qx,
  IconSubscribed: tR,
  IconSun: iR,
  IconTag: uR,
  IconTags: vR,
  IconThunderbolt: kR,
  IconTool: CR,
  IconTrophy: zR,
  IconUnlock: IR,
  IconUserAdd: OR,
  IconUserGroup: ER,
  IconUser: xR,
  IconVideoCamera: ZR,
  IconWifi: GR,
  IconWoman: JR
}, eH = (e, t) => {
  for (const n of Object.keys(Sv))
    e.use(Sv[n], t);
}, tH = {
  ...Sv,
  install: eH
};
function rH(e) {
  e.use(tH, { iconPrefix: "a" }), e.use(iL);
}
export {
  rH as install
};
